package Monitoring::GLPlugin::SNMP::MibsAndOids::OLDCISCOCPUMIB;

$Monitoring::GLPlugin::SNMP::MibsAndOids::origin->{'OLD-CISCO-CPU-MIB'} = {
  url => '',
  name => 'OLD-CISCO-CPU-MIB',
};

$Monitoring::GLPlugin::SNMP::MibsAndOids::mibs_and_oids->{'OLD-CISCO-CPU-MIB'} = {
  'busyPer' => '1.3.6.1.4.1.9.2.1.56.0',
  'avgBusy1' => '1.3.6.1.4.1.9.2.1.57.0',
  'avgBusy5' => '1.3.6.1.4.1.9.2.1.58.0',
  'idleCount' => '1.3.6.1.4.1.9.2.1.59.0',
  'idleWired' => '1.3.6.1.4.1.9.2.1.60.0',
};


1;

__END__
