package Monitoring::GLPlugin::SNMP::MibsAndOids::SPECTRALOGICGLOBALREG;

$Monitoring::GLPlugin::SNMP::MibsAndOids::origin->{'SPECTRALOGIC-GLOBAL-REG'} = {
  url => '',
  name => 'SPECTRALOGIC-GLOBAL-REG',
};

$Monitoring::GLPlugin::SNMP::MibsAndOids::mibs_and_oids->{'SPECTRALOGIC-GLOBAL-REG'} = {
  'spectralogic' => '1.3.6.1.4.1.3478',
  'slHardware' => '1.3.6.1.4.1.3478.1',
  'slLibraries' => '1.3.6.1.4.1.3478.1.1',
  'slTSeries' => '1.3.6.1.4.1.3478.1.1.3',
  'slT950' => '1.3.6.1.4.1.3478.1.1.3.1',
};


1;

__END__
