package Monitoring::GLPlugin::SNMP::MibsAndOids::CISCOFIREWALLMIB;

$Monitoring::GLPlugin::SNMP::MibsAndOids::origin->{'CISCO-FIREWALL-MIB'} = {
  url => '',
  name => 'CISCO-FIREWALL-MIB',
};

#$Monitoring::GLPlugin::SNMP::MibsAndOids::mib_ids->{'CISCO-FIREWALL-MIB'} = 

$Monitoring::GLPlugin::SNMP::MibsAndOids::mibs_and_oids->{'CISCO-FIREWALL-MIB'} = {
  ciscoFirewallMIB => '1.3.6.1.4.1.9.9.147',
  ciscoFirewallMIBObjects => '1.3.6.1.4.1.9.9.147.1',
  cfwEvents => '1.3.6.1.4.1.9.9.147.1.1',
  cfwBasicEvents => '1.3.6.1.4.1.9.9.147.1.1.1',
  cfwBasicEventsTableLastRow => '1.3.6.1.4.1.9.9.147.1.1.1.1',
  cfwBasicEventsTable => '1.3.6.1.4.1.9.9.147.1.1.1.2',
  cfwBasicEventsEntry => '1.3.6.1.4.1.9.9.147.1.1.1.2.1',
  cfwBasicEventIndex => '1.3.6.1.4.1.9.9.147.1.1.1.2.1.1',
  cfwBasicEventTime => '1.3.6.1.4.1.9.9.147.1.1.1.2.1.2',
  cfwBasicSecurityEventType => '1.3.6.1.4.1.9.9.147.1.1.1.2.1.3',
  cfwBasicSecurityEventTypeDefinition => 'CISCO-FIREWALL-MIB::SecurityEvent',
  cfwBasicContentInspEventType => '1.3.6.1.4.1.9.9.147.1.1.1.2.1.4',
  cfwBasicContentInspEventTypeDefinition => 'CISCO-FIREWALL-MIB::ContentInspectionEvent',
  cfwBasicConnectionEventType => '1.3.6.1.4.1.9.9.147.1.1.1.2.1.5',
  cfwBasicConnectionEventTypeDefinition => 'CISCO-FIREWALL-MIB::ConnectionEvent',
  cfwBasicAccessEventType => '1.3.6.1.4.1.9.9.147.1.1.1.2.1.6',
  cfwBasicAccessEventTypeDefinition => 'CISCO-FIREWALL-MIB::AccessEvent',
  cfwBasicAuthenticationEventType => '1.3.6.1.4.1.9.9.147.1.1.1.2.1.7',
  cfwBasicAuthenticationEventTypeDefinition => 'CISCO-FIREWALL-MIB::AuthenticationEvent',
  cfwBasicGenericEventType => '1.3.6.1.4.1.9.9.147.1.1.1.2.1.8',
  cfwBasicGenericEventTypeDefinition => 'CISCO-FIREWALL-MIB::GenericEvent',
  cfwBasicEventDescription => '1.3.6.1.4.1.9.9.147.1.1.1.2.1.9',
  cfwBasicEventDetailsTableRow => '1.3.6.1.4.1.9.9.147.1.1.1.2.1.10',
  cfwNetEvents => '1.3.6.1.4.1.9.9.147.1.1.2',
  cfwNetEventsTableLastRow => '1.3.6.1.4.1.9.9.147.1.1.2.1',
  cfwNetEventsTable => '1.3.6.1.4.1.9.9.147.1.1.2.2',
  cfwNetEventsEntry => '1.3.6.1.4.1.9.9.147.1.1.2.2.1',
  cfwNetEventIndex => '1.3.6.1.4.1.9.9.147.1.1.2.2.1.1',
  cfwNetEventInterface => '1.3.6.1.4.1.9.9.147.1.1.2.2.1.2',
  cfwNetEventSrcIpAddress => '1.3.6.1.4.1.9.9.147.1.1.2.2.1.3',
  cfwNetEventInsideSrcIpAddress => '1.3.6.1.4.1.9.9.147.1.1.2.2.1.4',
  cfwNetEventDstIpAddress => '1.3.6.1.4.1.9.9.147.1.1.2.2.1.5',
  cfwNetEventInsideDstIpAddress => '1.3.6.1.4.1.9.9.147.1.1.2.2.1.6',
  cfwNetEventSrcIpPort => '1.3.6.1.4.1.9.9.147.1.1.2.2.1.7',
  cfwNetEventInsideSrcIpPort => '1.3.6.1.4.1.9.9.147.1.1.2.2.1.8',
  cfwNetEventDstIpPort => '1.3.6.1.4.1.9.9.147.1.1.2.2.1.9',
  cfwNetEventInsideDstIpPort => '1.3.6.1.4.1.9.9.147.1.1.2.2.1.10',
  cfwNetEventService => '1.3.6.1.4.1.9.9.147.1.1.2.2.1.11',
  cfwNetEventServiceDefinition => 'CISCO-FIREWALL-MIB::Services',
  cfwNetEventServiceInformation => '1.3.6.1.4.1.9.9.147.1.1.2.2.1.12',
  cfwNetEventIdentity => '1.3.6.1.4.1.9.9.147.1.1.2.2.1.13',
  cfwNetEventDescription => '1.3.6.1.4.1.9.9.147.1.1.2.2.1.14',
  cfwSystem => '1.3.6.1.4.1.9.9.147.1.2',
  cfwStatus => '1.3.6.1.4.1.9.9.147.1.2.1',
  cfwHardwareStatusTable => '1.3.6.1.4.1.9.9.147.1.2.1.1',
  cfwHardwareStatusEntry => '1.3.6.1.4.1.9.9.147.1.2.1.1.1',
  cfwHardwareType => '1.3.6.1.4.1.9.9.147.1.2.1.1.1.1',
  cfwHardwareTypeDefinition => 'CISCO-FIREWALL-MIB::Hardware',
  cfwHardwareInformation => '1.3.6.1.4.1.9.9.147.1.2.1.1.1.2',
  cfwHardwareStatusValue => '1.3.6.1.4.1.9.9.147.1.2.1.1.1.3',
  cfwHardwareStatusValueDefinition => 'CISCO-FIREWALL-MIB::HardwareStatus',
  cfwHardwareStatusDetail => '1.3.6.1.4.1.9.9.147.1.2.1.1.1.4',
  cfwStatistics => '1.3.6.1.4.1.9.9.147.1.2.2',
  cfwBufferStatsTable => '1.3.6.1.4.1.9.9.147.1.2.2.1',
  cfwBufferStatsEntry => '1.3.6.1.4.1.9.9.147.1.2.2.1.1',
  cfwBufferStatSize => '1.3.6.1.4.1.9.9.147.1.2.2.1.1.1',
  cfwBufferStatType => '1.3.6.1.4.1.9.9.147.1.2.2.1.1.2',
  cfwBufferStatTypeDefinition => 'CISCO-FIREWALL-MIB::ResourceStatistics',
  cfwBufferStatInformation => '1.3.6.1.4.1.9.9.147.1.2.2.1.1.3',
  cfwBufferStatValue => '1.3.6.1.4.1.9.9.147.1.2.2.1.1.4',
  cfwConnectionStatTable => '1.3.6.1.4.1.9.9.147.1.2.2.2',
  cfwConnectionStatEntry => '1.3.6.1.4.1.9.9.147.1.2.2.2.1',
  cfwConnectionStatService => '1.3.6.1.4.1.9.9.147.1.2.2.2.1.1',
  cfwConnectionStatServiceDefinition => 'CISCO-FIREWALL-MIB::Services',
  cfwConnectionStatType => '1.3.6.1.4.1.9.9.147.1.2.2.2.1.2',
  cfwConnectionStatTypeDefinition => 'CISCO-FIREWALL-MIB::ConnectionStat',
  cfwConnectionStatDescription => '1.3.6.1.4.1.9.9.147.1.2.2.2.1.3',
  cfwConnectionStatCount => '1.3.6.1.4.1.9.9.147.1.2.2.2.1.4',
  cfwConnectionStatValue => '1.3.6.1.4.1.9.9.147.1.2.2.2.1.5',
  ciscoFirewallMIBNotificationPrefix => '1.3.6.1.4.1.9.9.147.2',
  ciscoFirewallMIBNotifications => '1.3.6.1.4.1.9.9.147.2.0',
  ciscoFirewallMIBConformance => '1.3.6.1.4.1.9.9.147.3',
  ciscoFirewallMIBCompliances => '1.3.6.1.4.1.9.9.147.3.1',
  ciscoFirewallMIBGroups => '1.3.6.1.4.1.9.9.147.3.2',
};

$Monitoring::GLPlugin::SNMP::MibsAndOids::definitions->{'CISCO-FIREWALL-MIB'} = {
  AccessEvent => {
    '1' => 'other',
    '2' => 'grant',
    '3' => 'deny',
    '4' => 'denyMult',
    '5' => 'error',
  },
  GenericEvent => {
    '1' => 'abnormal',
    '2' => 'okay',
    '3' => 'error',
  },
  ResourceStatistics => {
    '1' => 'highUse',
    '2' => 'highLoad',
    '3' => 'maximum',
    '4' => 'minimum',
    '5' => 'low',
    '6' => 'high',
    '7' => 'average',
    '8' => 'free',
    '9' => 'inUse',
  },
  ConnectionEvent => {
    '1' => 'other',
    '2' => 'accept',
    '3' => 'error',
    '4' => 'drop',
    '5' => 'close',
    '6' => 'timeout',
    '7' => 'refused',
    '8' => 'reset',
    '9' => 'noResp',
  },
  AuthenticationEvent => {
    '1' => 'other',
    '2' => 'succ',
    '3' => 'error',
    '4' => 'fail',
    '5' => 'succPriv',
    '6' => 'failPriv',
    '7' => 'failMult',
  },
  ContentInspectionEvent => {
    '1' => 'other',
    '2' => 'okay',
    '3' => 'error',
    '4' => 'found',
    '5' => 'clean',
    '6' => 'reject',
    '7' => 'saved',
  },
  HardwareStatus => {
    '1' => 'other',
    '2' => 'up',
    '3' => 'down',
    '4' => 'error',
    '5' => 'overTemp',
    '6' => 'busy',
    '7' => 'noMedia',
    '8' => 'backup',
    '9' => 'active',
    '10' => 'standby',
  },
  Hardware => {
    '1' => 'memory',
    '2' => 'disk',
    '3' => 'power',
    '4' => 'netInterface',
    '5' => 'cpu',
    '6' => 'primaryUnit',
    '7' => 'secondaryUnit',
    '8' => 'other',
  },
  ConnectionStat => {
    '1' => 'other',
    '2' => 'totalOpen',
    '3' => 'currentOpen',
    '4' => 'currentClosing',
    '5' => 'currentHalfOpen',
    '6' => 'currentInUse',
    '7' => 'high',
  },
  Services => {
    '1' => 'otherFWService',
    '2' => 'fileXferFtp',
    '3' => 'fileXferTftp',
    '4' => 'fileXferFtps',
    '5' => 'loginTelnet',
    '6' => 'loginRlogin',
    '7' => 'loginTelnets',
    '8' => 'remoteExecSunRPC',
    '9' => 'remoteExecMSRPC',
    '10' => 'remoteExecRsh',
    '11' => 'remoteExecXserver',
    '12' => 'webHttp',
    '13' => 'webHttps',
    '14' => 'mailSmtp',
    '15' => 'multimediaStreamworks',
    '16' => 'multimediaH323',
    '17' => 'multimediaNetShow',
    '18' => 'multimediaVDOLive',
    '19' => 'multimediaRealAV',
    '20' => 'multimediaRTSP',
    '21' => 'dbOracle',
    '22' => 'dbMSsql',
    '23' => 'contInspProgLang',
    '24' => 'contInspUrl',
    '25' => 'directoryNis',
    '26' => 'directoryDns',
    '27' => 'directoryNetbiosns',
    '28' => 'directoryNetbiosdgm',
    '29' => 'directoryNetbiosssn',
    '30' => 'directoryWins',
    '31' => 'qryWhois',
    '32' => 'qryFinger',
    '33' => 'qryIdent',
    '34' => 'fsNfsStatus',
    '35' => 'fsNfs',
    '36' => 'fsCifs',
    '37' => 'protoIcmp',
    '38' => 'protoTcp',
    '39' => 'protoUdp',
    '40' => 'protoIp',
    '41' => 'protoSnmp',
  },
  SecurityEvent => {
    '1' => 'other',
    '2' => 'none',
    '3' => 'dos',
    '4' => 'recon',
    '5' => 'pakFwd',
    '6' => 'addrSpoof',
    '7' => 'svcSpoof',
    '8' => 'thirdParty',
    '9' => 'complete',
    '10' => 'invalPak',
    '11' => 'illegCom',
    '12' => 'policy',
  },
};
