package Monitoring::GLPlugin::SNMP::MibsAndOids::SPECTRALOGICGLOBALREGSLHARDWARESLLIBRARIESSLTSERIES;

$Monitoring::GLPlugin::SNMP::MibsAndOids::origin->{'SPECTRALOGIC-GLOBAL-REG-SLHARDWARE-SLLIBRARIES-SLTSERIES'} = {
  url => '',
  name => 'SPECTRALOGIC-GLOBAL-REG-SLHARDWARE-SLLIBRARIES-SLTSERIES',
};

$Monitoring::GLPlugin::SNMP::MibsAndOids::mib_ids->{'SPECTRALOGIC-GLOBAL-REG-SLHARDWARE-SLLIBRARIES-SLTSERIES'} =
  '1.3.6.1.4.1.3478.1.1.3';

1;
__END__
