package Monitoring::GLPlugin::SNMP::MibsAndOids::CISCOBGP4MIB;

$Monitoring::GLPlugin::SNMP::MibsAndOids::origin->{'CISCO-BGP4-MIB'} = {
  url => '',
  name => 'CISCO-BGP4-MIB',
};

$Monitoring::GLPlugin::SNMP::MibsAndOids::mibs_and_oids->{'CISCO-BGP4-MIB'} = {
  'cbgpPeerAddrFamilyPrefixTable' => '1.3.6.1.4.1.9.9.187.1.2.4',
  'cbgpPeerAddrFamilyPrefixEntry' => '1.3.6.1.4.1.9.9.187.1.2.4.1',
  'cbgpPeerAddrAcceptedPrefixes' => '1.3.6.1.4.1.9.9.187.1.2.4.1.1',
};


1;

__END__
