package Monitoring::GLPlugin::SNMP::MibsAndOids::FCMGMTMIB;

$Monitoring::GLPlugin::SNMP::MibsAndOids::origin->{'FCMGMT-MIB'} = {
  url => '',
  name => 'FCMGMT-MIB',
};

$Monitoring::GLPlugin::SNMP::MibsAndOids::mibs_and_oids->{'FCMGMT-MIB'} = {
  'fcConnUnitPortStatTxObjects' => '1.3',
  'fcConnUnitSEventTime' => '1.3',
  'fcConnUnitTable' => '1.3',
  'fcConnUnitPortFCClassCap' => '1.3',
  'fcConnUnitLinkPortNumberX' => '1.3',
  'fcConnUnitType' => '1.3',
  'fcConnUnitSnsPortName' => '1.3',
  'fcConnUnitRevsDescription' => '1.3',
  'fcConnUnitEntry' => '1.3.1',
  'fcConnUnitPortStatTable' => '1.3.1',
  'fcConnUnitPortStatEntry' => '1.3.1.1',
  'fcConnUnitId' => '1.3.1.1',
  'fcConnUnitPortStatIndex' => '1.3.1.1.1',
  'fcConnUnitPortStatErrs' => '1.3.1.1.2',
  'fcConnUnitPortStatRxObjects' => '1.3.1.1.4',
  'fcConnUnitPortStatTxElements' => '1.3.1.1.5',
  'fcConnUnitPortStatRxElements' => '1.3.1.1.6',
  'fcConnUnitPortStatBBCreditZero' => '1.3.1.1.7',
  'fcConnUnitPortStatInputBuffsFull' => '1.3.1.1.8',
  'fcConnUnitPortStatFBSYFrames' => '1.3.1.1.9',
  'fcConnUnitPortStatPBSYFrames' => '1.3.1.1.10',
  'fcConnUnitPortStatFRJTFrames' => '1.3.1.1.11',
  'fcConnUnitPortStatPRJTFrames' => '1.3.1.1.12',
  'fcConnUnitPortStatC1RxFrames' => '1.3.1.1.13',
  'fcConnUnitPortStatC1TxFrames' => '1.3.1.1.14',
  'fcConnUnitPortStatC1FBSYFrames' => '1.3.1.1.15',
  'fcConnUnitPortStatC1PBSYFrames' => '1.3.1.1.16',
  'fcConnUnitPortStatC1FRJTFrames' => '1.3.1.1.17',
  'fcConnUnitPortStatC1PRJTFrames' => '1.3.1.1.18',
  'fcConnUnitPortStatC2RxFrames' => '1.3.1.1.19',
  'fcConnUnitPortStatC2TxFrames' => '1.3.1.1.20',
  'fcConnUnitPortStatC2FBSYFrames' => '1.3.1.1.21',
  'fcConnUnitPortStatC2PBSYFrames' => '1.3.1.1.22',
  'fcConnUnitPortStatC2FRJTFrames' => '1.3.1.1.23',
  'fcConnUnitPortStatC2PRJTFrames' => '1.3.1.1.24',
  'fcConnUnitPortStatC3RxFrames' => '1.3.1.1.25',
  'fcConnUnitPortStatC3TxFrames' => '1.3.1.1.26',
  'fcConnUnitPortStatC3Discards' => '1.3.1.1.27',
  'fcConnUnitPortStatRxMcastObjects' => '1.3.1.1.28',
  'fcConnUnitPortStatTxMcastObjects' => '1.3.1.1.29',
  'fcConnUnitPortStatInvalidTxWords' => '1.3.1.1.40',
  'fcConnUnitPortStatPSPErrs' => '1.3.1.1.41',
  'fcConnUnitPortStatLossOfSignal' => '1.3.1.1.42',
  'fcConnUnitPortStatLossOfSync' => '1.3.1.1.43',
  'fcConnUnitPortStatInvOrderedSets' => '1.3.1.1.44',
  'fcConnUnitPortStatFramesTooLong' => '1.3.1.1.45',
  'fcConnUnitPortStatFramesTooShort' => '1.3.1.1.46',
  'fcConnUnitPortStatAddressErrs' => '1.3.1.1.47',
  'fcConnUnitPortStatDelimiterErrs' => '1.3.1.1.48',
  'fcConnUnitPortStatEncodingErrs' => '1.3.1.1.49',
  'fcConnUnitGlobalId' => '1.3.1.2',
  'fcConnUnitNumPorts' => '1.3.1.4',
  'fcConnUnitState' => '1.3.1.5',
  'fcConnUnitStatus' => '1.3.1.6',
  'fcConnUnitProduct' => '1.3.1.7',
  'fcConnUnitSerialNo' => '1.3.1.8',
  'fcConnUnitUpTime' => '1.3.1.9',
  'fcConnUnitUrl' => '1.3.1.10',
  'fcConnUnitDomainId' => '1.3.1.11',
  'fcConnUnitProxyMaster' => '1.3.1.12',
  'fcConnUnitPrincipal' => '1.3.1.13',
  'fcConnUnitNumSensors' => '1.3.1.14',
  'fcConnUnitNumRevs' => '1.3.1.15',
  'fcConnUnitModuleId' => '1.3.1.16',
  'fcConnUnitName' => '1.3.1.17',
  'fcConnUnitInfo' => '1.3.1.18',
  'fcConnUnitControl' => '1.3.1.19',
  'fcConnUnitContact' => '1.3.1.20',
  'fcConnUnitLocation' => '1.3.1.21',
  'fcConnUnitEventFilter' => '1.3.1.22',
  'fcConnUnitNumEvents' => '1.3.1.23',
  'fcConnUnitMaxEvents' => '1.3.1.24',
  'fcConnUnitEventCurrID' => '1.3.1.25',
  'fcConnUnitRevsTable' => '1.3.6.1.2.1.8888.1.1.4',
  'fcConnUnitRevsEntry' => '1.3.6.1.2.1.8888.1.1.4.1',
  'fcConnUnitRevsIndex' => '1.3.6.1.2.1.8888.1.1.4.1.1',
  'fcConnUnitRevsRevision' => '1.3.6.1.2.1.8888.1.1.4.1.2',
  'fcConnUnitSensorTable' => '1.3.6.1.2.1.8888.1.1.5',
  'fcConnUnitSensorEntry' => '1.3.6.1.2.1.8888.1.1.5.1',
  'fcConnUnitSensorIndex' => '1.3.6.1.2.1.8888.1.1.5.1.1',
  'fcConnUnitSensorName' => '1.3.6.1.2.1.8888.1.1.5.1.2',
  'fcConnUnitSensorStatus' => '1.3.6.1.2.1.8888.1.1.5.1.3',
  'fcConnUnitSensorStatusDefinition' => {
    '1' => 'unknown',
    '2' => 'other',
    '3' => 'ok',
    '4' => 'warning',
    '5' => 'failed',
  },
  'fcConnUnitSensorInfo' => '1.3.6.1.2.1.8888.1.1.5.1.4',
  'fcConnUnitSensorMessage' => '1.3.6.1.2.1.8888.1.1.5.1.5',
  'fcConnUnitSensorType' => '1.3.6.1.2.1.8888.1.1.5.1.6',
  'fcConnUnitSensorTypeDefinition' => {
    '1' => 'unknown',
    '2' => 'other',
    '3' => 'battery',
    '4' => 'fan',
    '5' => 'powerSupply',
    '6' => 'transmitter',
    '7' => 'enclosure',
    '8' => 'board',
    '9' => 'receiver',
  },
  'fcConnUnitSensorCharacteristic' => '1.3.6.1.2.1.8888.1.1.5.1.7',
  'fcConnUnitSensorCharacteristicDefinition' => {
    '1' => 'unknown',
    '2' => 'other',
    '3' => 'temperature',
    '4' => 'pressure',
    '5' => 'emf',
    '6' => 'currentValue',
    '7' => 'airflow',
    '8' => 'frequency',
    '9' => 'power',
  },
  'fcConnUnitPortTable' => '1.3.6.1.2.1.8888.1.1.6',
  'fcConnUnitPortEntry' => '1.3.6.1.2.1.8888.1.1.6.1',
  'fcConnUnitPortIndex' => '1.3.6.1.2.1.8888.1.1.6.1.1',
  'fcConnUnitPortType' => '1.3.6.1.2.1.8888.1.1.6.1.2',
  'fcConnUnitPortFCClassOp' => '1.3.6.1.2.1.8888.1.1.6.1.4',
  'fcConnUnitPortState' => '1.3.6.1.2.1.8888.1.1.6.1.5',
  'fcConnUnitPortStatus' => '1.3.6.1.2.1.8888.1.1.6.1.6',
  'fcConnUnitPortTransmitterType' => '1.3.6.1.2.1.8888.1.1.6.1.7',
  'fcConnUnitPortModuleType' => '1.3.6.1.2.1.8888.1.1.6.1.8',
  'fcConnUnitPortWwn' => '1.3.6.1.2.1.8888.1.1.6.1.9',
  'fcConnUnitPortFCId' => '1.3.6.1.2.1.8888.1.1.6.1.10',
  'fcConnUnitPortSerialNo' => '1.3.6.1.2.1.8888.1.1.6.1.11',
  'fcConnUnitPortRevision' => '1.3.6.1.2.1.8888.1.1.6.1.12',
  'fcConnUnitPortVendor' => '1.3.6.1.2.1.8888.1.1.6.1.13',
  'fcConnUnitPortSpeed' => '1.3.6.1.2.1.8888.1.1.6.1.14',
  'fcConnUnitPortControl' => '1.3.6.1.2.1.8888.1.1.6.1.15',
  'fcConnUnitPortName' => '1.3.6.1.2.1.8888.1.1.6.1.16',
  'fcConnUnitPortPhysicalNumber' => '1.3.6.1.2.1.8888.1.1.6.1.17',
  'fcConnUnitPortProtocolCap' => '1.3.6.1.2.1.8888.1.1.6.1.18',
  'fcConnUnitPortProtocolOp' => '1.3.6.1.2.1.8888.1.1.6.1.19',
  'fcConnUnitPortNodeWwn' => '1.3.6.1.2.1.8888.1.1.6.1.20',
  'fcConnUnitPortHWState' => '1.3.6.1.2.1.8888.1.1.6.1.21',
  'fcConnUnitEventTable' => '1.3.6.1.2.1.8888.1.1.7',
  'fcConnUnitEventEntry' => '1.3.6.1.2.1.8888.1.1.7.1',
  'fcConnUnitEventIndex' => '1.3.6.1.2.1.8888.1.1.7.1.1',
  'fcConnUnitREventTime' => '1.3.6.1.2.1.8888.1.1.7.1.2',
  'fcConnUnitEventSeverity' => '1.3.6.1.2.1.8888.1.1.7.1.4',
  'fcConnUnitEventType' => '1.3.6.1.2.1.8888.1.1.7.1.5',
  'fcConnUnitEventObject' => '1.3.6.1.2.1.8888.1.1.7.1.6',
  'fcConnUnitEventDescr' => '1.3.6.1.2.1.8888.1.1.7.1.7',
  'fcConnUnitLinkTable' => '1.3.6.1.2.1.8888.1.1.8',
  'fcConnUnitLinkEntry' => '1.3.6.1.2.1.8888.1.1.8.1',
  'fcConnUnitLinkIndex' => '1.3.6.1.2.1.8888.1.1.8.1.1',
  'fcConnUnitLinkNodeIdX' => '1.3.6.1.2.1.8888.1.1.8.1.2',
  'fcConnUnitLinkPortWwnX' => '1.3.6.1.2.1.8888.1.1.8.1.4',
  'fcConnUnitLinkNodeIdY' => '1.3.6.1.2.1.8888.1.1.8.1.5',
  'fcConnUnitLinkPortNumberY' => '1.3.6.1.2.1.8888.1.1.8.1.6',
  'fcConnUnitLinkPortWwnY' => '1.3.6.1.2.1.8888.1.1.8.1.7',
  'fcConnUnitLinkAgentAddressY' => '1.3.6.1.2.1.8888.1.1.8.1.8',
  'fcConnUnitLinkAgentAddressTypeY' => '1.3.6.1.2.1.8888.1.1.8.1.9',
  'fcConnUnitLinkAgentPortY' => '1.3.6.1.2.1.8888.1.1.8.1.10',
  'fcConnUnitLinkUnitTypeY' => '1.3.6.1.2.1.8888.1.1.8.1.11',
  'fcConnUnitLinkConnIdY' => '1.3.6.1.2.1.8888.1.1.8.1.12',
  'fcConnUnitSnsMaxRows' => '1.3.6.1.2.1.8888.1.1.9.0',
  'fcConnUnitSnsTable' => '1.3.6.1.2.1.8888.1.4.1',
  'fcConnUnitSnsEntry' => '1.3.6.1.2.1.8888.1.4.1.1',
  'fcConnUnitSnsPortIndex' => '1.3.6.1.2.1.8888.1.4.1.1.1',
  'fcConnUnitSnsPortIdentifier' => '1.3.6.1.2.1.8888.1.4.1.1.2',
  'fcConnUnitSnsNodeName' => '1.3.6.1.2.1.8888.1.4.1.1.4',
  'fcConnUnitSnsClassOfSvc' => '1.3.6.1.2.1.8888.1.4.1.1.5',
  'fcConnUnitSnsNodeIPAddress' => '1.3.6.1.2.1.8888.1.4.1.1.6',
  'fcConnUnitSnsProcAssoc' => '1.3.6.1.2.1.8888.1.4.1.1.7',
  'fcConnUnitSnsFC4Type' => '1.3.6.1.2.1.8888.1.4.1.1.8',
  'fcConnUnitSnsPortType' => '1.3.6.1.2.1.8888.1.4.1.1.9',
  'fcConnUnitSnsPortIPAddress' => '1.3.6.1.2.1.8888.1.4.1.1.10',
  'fcConnUnitSnsFabricPortName' => '1.3.6.1.2.1.8888.1.4.1.1.11',
  'fcConnUnitSnsHardAddress' => '1.3.6.1.2.1.8888.1.4.1.1.12',
  'fcConnUnitSnsSymbolicPortName' => '1.3.6.1.2.1.8888.1.4.1.1.13',
  'fcConnUnitSnsSymbolicNodeName' => '1.3.6.1.2.1.8888.1.4.1.1.14',
  'fcConnUnitPortStatRxBcastObjects' => '1.30',
  'fcConnUnitPortStatTxBcastObjects' => '1.31',
  'fcConnUnitPortStatRxLinkResets' => '1.32',
  'fcConnUnitPortStatTxLinkResets' => '1.33',
  'fcConnUnitPortStatLinkResets' => '1.34',
  'fcConnUnitPortStatRxOfflineSeqs' => '1.35',
  'fcConnUnitPortStatTxOfflineSeqs' => '1.36',
  'fcConnUnitPortStatOfflineSeqs' => '1.37',
  'fcConnUnitPortStatLinkFailures' => '1.38',
  'fcConnUnitPortStatInvalidCRC' => '1.39',
};


1;

__END__
