package Monitoring::GLPlugin::SNMP::MibsAndOids::XPPCMIB;

$Monitoring::GLPlugin::SNMP::MibsAndOids::origin->{'XPPC-MIB'} = {
  url => "",
  name => "XPPC-MIB",
};

$Monitoring::GLPlugin::SNMP::MibsAndOids::mib_ids->{'XPPC-MIB'} =
  '1.3.6.1.4.1.935';

$Monitoring::GLPlugin::SNMP::MibsAndOids::mibs_and_oids->{'XPPC-MIB'} = {
  ppc => '1.3.6.1.4.1.935',
  products => '1.3.6.1.4.1.935.1',
  hardware => '1.3.6.1.4.1.935.1.1',
  ups => '1.3.6.1.4.1.935.1.1.1',
  upsIdentp => '1.3.6.1.4.1.935.1.1.1.1',
  upsBaseIdent => '1.3.6.1.4.1.935.1.1.1.1.1',
  upsBaseIdentModel => '1.3.6.1.4.1.935.1.1.1.1.1.1',
  upsBaseIdentUpsName => '1.3.6.1.4.1.935.1.1.1.1.1.2',
  upsSmartIdent => '1.3.6.1.4.1.935.1.1.1.1.2',
  upsSmartIdentFirmwareRevision => '1.3.6.1.4.1.935.1.1.1.1.2.1',
  upsSmartIdentDateOfManufacture => '1.3.6.1.4.1.935.1.1.1.1.2.2',
  upsSmartIdentUpsSerialNumber => '1.3.6.1.4.1.935.1.1.1.1.2.3',
  upsSmartIdentAgentFirmwareRevision => '1.3.6.1.4.1.935.1.1.1.1.2.4',
  upsBatteryp => '1.3.6.1.4.1.935.1.1.1.2',
  upsBaseBattery => '1.3.6.1.4.1.935.1.1.1.2.1',
  upsBaseBatteryStatus => '1.3.6.1.4.1.935.1.1.1.2.1.1',
  upsBaseBatteryStatusDefinition => {
    1 => 'unknown',
    3 => 'batteryLow',
    2 => 'batteryNormal',
  },
  upsBaseBatteryTimeOnBattery => '1.3.6.1.4.1.935.1.1.1.2.1.2',
  upsBaseBatteryLastReplaceDate => '1.3.6.1.4.1.935.1.1.1.2.1.3',
  upsSmartBattery => '1.3.6.1.4.1.935.1.1.1.2.2',
  upsSmartBatteryCapacity => '1.3.6.1.4.1.935.1.1.1.2.2.1',
  upsSmartBatteryVoltage => '1.3.6.1.4.1.935.1.1.1.2.2.2',
  upsSmartBatteryTemperature => '1.3.6.1.4.1.935.1.1.1.2.2.3',
  upsSmartBatteryRunTimeRemaining => '1.3.6.1.4.1.935.1.1.1.2.2.4',
  upsSmartBatteryReplaceIndicator => '1.3.6.1.4.1.935.1.1.1.2.2.5',
  upsSmartBatteryReplaceIndicatorDefinition => {
    1 => 'noBatteryNeedsReplacing',
    2 => 'batteryNeedsReplacing',
  },
  upsSmartBatteryFullChargeVoltage => '1.3.6.1.4.1.935.1.1.1.2.2.6',
  upsSmartBatteryCurrent => '1.3.6.1.4.1.935.1.1.1.2.2.7',
  upsInputp => '1.3.6.1.4.1.935.1.1.1.3',
  upsBaseInput => '1.3.6.1.4.1.935.1.1.1.3.1',
  upsBaseInputPhase => '1.3.6.1.4.1.935.1.1.1.3.1.1',
  upsSmartInput => '1.3.6.1.4.1.935.1.1.1.3.2',
  upsSmartInputLineVoltage => '1.3.6.1.4.1.935.1.1.1.3.2.1',
  upsSmartInputMaxLineVoltage => '1.3.6.1.4.1.935.1.1.1.3.2.2',
  upsSmartInputMinLineVoltage => '1.3.6.1.4.1.935.1.1.1.3.2.3',
  upsSmartInputFrequency => '1.3.6.1.4.1.935.1.1.1.3.2.4',
  upsSmartInputLineFailCause => '1.3.6.1.4.1.935.1.1.1.3.2.5',
  upsSmartInputLineFailCauseDefinition => {
    6 => 'deepMomentarySag',
    5 => 'smallMomentarySag',
    2 => 'highLineVoltage',
    8 => 'largeMomentarySpike',
    1 => 'noTransfer',
    4 => 'blackout',
    3 => 'brownout',
    7 => 'smallMomentarySpike',
  },
  upsOutputp => '1.3.6.1.4.1.935.1.1.1.4',
  upsBaseOutput => '1.3.6.1.4.1.935.1.1.1.4.1',
  upsBaseOutputStatus => '1.3.6.1.4.1.935.1.1.1.4.1.1',
  upsBaseOutputStatusDefinition => {
    7 => 'rebooting',
    4 => 'onBoost',
    2 => 'onLine',
    9 => 'onBuck',
    6 => 'onBypass',
    8 => 'standBy',
    1 => 'unknown',
    5 => 'sleeping',
    3 => 'onBattery',
  },
  upsBaseOutputPhase => '1.3.6.1.4.1.935.1.1.1.4.1.2',
  upsSmartOutput => '1.3.6.1.4.1.935.1.1.1.4.2',
  upsSmartOutputVoltage => '1.3.6.1.4.1.935.1.1.1.4.2.1',
  upsSmartOutputFrequency => '1.3.6.1.4.1.935.1.1.1.4.2.2',
  upsSmartOutputLoad => '1.3.6.1.4.1.935.1.1.1.4.2.3',
  upsConfigp => '1.3.6.1.4.1.935.1.1.1.5',
  upsBaseConfig => '1.3.6.1.4.1.935.1.1.1.5.1',
  upsBaseConfigNumDevices => '1.3.6.1.4.1.935.1.1.1.5.1.1',
  upsBaseConfigDeviceTable => '1.3.6.1.4.1.935.1.1.1.5.1.2',
  upsBaseConfigDeviceEntry => '1.3.6.1.4.1.935.1.1.1.5.1.2.1',
  indexOfDevice => '1.3.6.1.4.1.935.1.1.1.5.1.2.1.1',
  nameOfDevice => '1.3.6.1.4.1.935.1.1.1.5.1.2.1.2',
  vaRatingOfDevice => '1.3.6.1.4.1.935.1.1.1.5.1.2.1.3',
  deviceAccept => '1.3.6.1.4.1.935.1.1.1.5.1.2.1.4',
  deviceAcceptDefinition => {
    1 => 'yes',
    2 => 'no',
  },
  upsSmartConfig => '1.3.6.1.4.1.935.1.1.1.5.2',
  upsSmartConfigRatedOutputVoltage => '1.3.6.1.4.1.935.1.1.1.5.2.1',
  upsSmartConfigHighTransferVolt => '1.3.6.1.4.1.935.1.1.1.5.2.2',
  upsSmartConfigLowTransferVolt => '1.3.6.1.4.1.935.1.1.1.5.2.3',
  upsSmartConfigAlarm => '1.3.6.1.4.1.935.1.1.1.5.2.4',
  upsSmartConfigAlarmDefinition => {
    1 => 'timed',
    3 => 'never',
    2 => 'atLowBattery',
  },
  upsSmartConfigAlarmTimer => '1.3.6.1.4.1.935.1.1.1.5.2.5',
  upsSmartConfigMinReturnCapacity => '1.3.6.1.4.1.935.1.1.1.5.2.6',
  upsSmartConfigSensitivity => '1.3.6.1.4.1.935.1.1.1.5.2.7',
  upsSmartConfigSensitivityDefinition => {
    4 => 'high',
    1 => 'auto',
    3 => 'medium',
    2 => 'low',
  },
  upsSmartConfigLowBatteryRunTime => '1.3.6.1.4.1.935.1.1.1.5.2.8',
  upsSmartConfigReturnDelay => '1.3.6.1.4.1.935.1.1.1.5.2.9',
  upsSmartConfigShutoffDelay => '1.3.6.1.4.1.935.1.1.1.5.2.10',
  upsSmartConfigUpsSleepTime => '1.3.6.1.4.1.935.1.1.1.5.2.11',
  upsSmartConfigSetEEPROMDefaults => '1.3.6.1.4.1.935.1.1.1.5.2.12',
  upsSmartConfigSetEEPROMDefaultsDefinition => {
    2 => 'setEEPROMDefaults',
    1 => 'noSetEEPROMDefaults',
  },
  upsControlp => '1.3.6.1.4.1.935.1.1.1.6',
  upsBaseControl => '1.3.6.1.4.1.935.1.1.1.6.1',
  upsBaseControlConserveBattery => '1.3.6.1.4.1.935.1.1.1.6.1.1',
  upsBaseControlConserveBatteryDefinition => {
    2 => 'turnUpsOffToConserveBattery',
    3 => 'turnUpsOffToConserveBatteryDelay',
    1 => 'noTurnOffUps',
  },
  upsSmartControl => '1.3.6.1.4.1.935.1.1.1.6.2',
  upsSmartControlUpsOff => '1.3.6.1.4.1.935.1.1.1.6.2.1',
  upsSmartControlUpsOffDefinition => {
    2 => 'turnUpsOff',
    1 => 'noTurnUpsOff',
  },
  upsSmartControlRebootUps => '1.3.6.1.4.1.935.1.1.1.6.2.2',
  upsSmartControlRebootUpsDefinition => {
    2 => 'rebootUps',
    1 => 'noRebootUps',
  },
  upsSmartControlUpsSleep => '1.3.6.1.4.1.935.1.1.1.6.2.3',
  upsSmartControlUpsSleepDefinition => {
    1 => 'noPutUpsToSleep',
    2 => 'putUpsToSleep',
  },
  upsSmartControlSimulatePowerFail => '1.3.6.1.4.1.935.1.1.1.6.2.4',
  upsSmartControlSimulatePowerFailDefinition => {
    2 => 'simulatePowerFailure',
    1 => 'noSimulatePowerFailure',
  },
  upsSmartControlFlashAndBeep => '1.3.6.1.4.1.935.1.1.1.6.2.5',
  upsSmartControlFlashAndBeepDefinition => {
    2 => 'flashAndBeep',
    1 => 'noFlashAndBeep',
  },
  upsSmartControlTurnOnUpsLoad => '1.3.6.1.4.1.935.1.1.1.6.2.6',
  upsSmartControlTurnOnUpsLoadDefinition => {
    2 => 'upsSmartControlTurnOnUpsLoad',
    1 => 'noUpsSmartControlTurnOnUpsLoad',
  },
  upsTestp => '1.3.6.1.4.1.935.1.1.1.7',
  upsBaseTest => '1.3.6.1.4.1.935.1.1.1.7.1',
  upsSmartTest => '1.3.6.1.4.1.935.1.1.1.7.2',
  upsSmartTestDiagnosticSchedule => '1.3.6.1.4.1.935.1.1.1.7.2.1',
  upsSmartTestDiagnosticScheduleDefinition => {
    3 => 'weekly',
    1 => 'unknown',
    2 => 'biweekly',
    4 => 'never',
  },
  upsSmartTestDiagnostics => '1.3.6.1.4.1.935.1.1.1.7.2.2',
  upsSmartTestDiagnosticsDefinition => {
    2 => 'testDiagnostics',
    1 => 'noTestDiagnostics',
  },
  upsSmartTestDiagnosticsResults => '1.3.6.1.4.1.935.1.1.1.7.2.3',
  upsSmartTestDiagnosticsResultsDefinition => {
    1 => 'ok',
    3 => 'invalidTest',
    4 => 'testInProgress',
    2 => 'failed',
  },
  upsSmartTestLastDiagnosticsDate => '1.3.6.1.4.1.935.1.1.1.7.2.4',
  upsSmartTestIndicators => '1.3.6.1.4.1.935.1.1.1.7.2.5',
  upsSmartTestIndicatorsDefinition => {
    2 => 'testIndicators',
    1 => 'noTestIndicators',
  },
  upsSmartTestRuntimeCalibration => '1.3.6.1.4.1.935.1.1.1.7.2.6',
  upsSmartTestRuntimeCalibrationDefinition => {
    1 => 'noPerformCalibration',
    2 => 'performCalibration',
    3 => 'cancelCurrentCalibration',
  },
  upsSmartTestCalibrationResults => '1.3.6.1.4.1.935.1.1.1.7.2.7',
  upsSmartTestCalibrationResultsDefinition => {
    3 => 'calibrationInProgress',
    1 => 'ok',
    2 => 'invalidTest',
  },
  upsSmartTestCalibrationDate => '1.3.6.1.4.1.935.1.1.1.7.2.8',
  upsThreePhase => '1.3.6.1.4.1.935.1.1.1.8',
  upsThreePhaseBatteryGrp => '1.3.6.1.4.1.935.1.1.1.8.1',
  upsThreePhaseBatteryVoltage => '1.3.6.1.4.1.935.1.1.1.8.1.1',
  upsThreePhaseBatteryCapacityPercentage => '1.3.6.1.4.1.935.1.1.1.8.1.2',
  upsThreePhaseBatteryTimeRemain => '1.3.6.1.4.1.935.1.1.1.8.1.3',
  upsThreePhaseBatteryCurrent => '1.3.6.1.4.1.935.1.1.1.8.1.4',
  upsThreePhaseBatteryTemperature => '1.3.6.1.4.1.935.1.1.1.8.1.5',
  upsThreePhaseInputGrp => '1.3.6.1.4.1.935.1.1.1.8.2',
  upsThreePhaseInputFrequency => '1.3.6.1.4.1.935.1.1.1.8.2.1',
  upsThreePhaseInputVoltageR => '1.3.6.1.4.1.935.1.1.1.8.2.2',
  upsThreePhaseInputVoltageS => '1.3.6.1.4.1.935.1.1.1.8.2.3',
  upsThreePhaseInputVoltageT => '1.3.6.1.4.1.935.1.1.1.8.2.4',
  upsThreePhaseOutputGrp => '1.3.6.1.4.1.935.1.1.1.8.3',
  upsThreePhaseOutputFrequency => '1.3.6.1.4.1.935.1.1.1.8.3.1',
  upsThreePhaseOutputVoltageR => '1.3.6.1.4.1.935.1.1.1.8.3.2',
  upsThreePhaseOutputVoltageS => '1.3.6.1.4.1.935.1.1.1.8.3.3',
  upsThreePhaseOutputVoltageT => '1.3.6.1.4.1.935.1.1.1.8.3.4',
  upsThreePhaseOutputLoadPercentageR => '1.3.6.1.4.1.935.1.1.1.8.3.5',
  upsThreePhaseOutputLoadPercentageS => '1.3.6.1.4.1.935.1.1.1.8.3.6',
  upsThreePhaseOutputLoadPercentageT => '1.3.6.1.4.1.935.1.1.1.8.3.7',
  upsThreePhaseBypassGrp => '1.3.6.1.4.1.935.1.1.1.8.4',
  upsThreePhaseBypassSourceFrequency => '1.3.6.1.4.1.935.1.1.1.8.4.1',
  upsThreePhaseBypssSourceVoltageR => '1.3.6.1.4.1.935.1.1.1.8.4.2',
  upsThreePhaseBypssSourceVoltageS => '1.3.6.1.4.1.935.1.1.1.8.4.3',
  upsThreePhaseBypssSourceVoltageT => '1.3.6.1.4.1.935.1.1.1.8.4.4',
  upsThreePhaseDCandRectifierStatusGrp => '1.3.6.1.4.1.935.1.1.1.8.5',
  upsThreePhaseDCandRectifierStatusRecRotError => '1.3.6.1.4.1.935.1.1.1.8.5.1',
  upsThreePhaseDCandRectifierStatusRecRotErrorDefinition => {
    14 => 'yes',
    16 => 'no',
  },
  upsThreePhaseDCandRectifierStatusLowBatteryShutdown => '1.3.6.1.4.1.935.1.1.1.8.5.2',
  upsThreePhaseDCandRectifierStatusLowBatteryShutdownDefinition => {
    14 => 'yes',
    16 => 'no',
  },
  upsThreePhaseDCandRectifierStatusLowBattery => '1.3.6.1.4.1.935.1.1.1.8.5.3',
  upsThreePhaseDCandRectifierStatusLowBatteryDefinition => {
    14 => 'yes',
    16 => 'no',
  },
  upsThreePhaseDCandRectifierStatusInAndOut => '1.3.6.1.4.1.935.1.1.1.8.5.4',
  upsThreePhaseDCandRectifierStatusInAndOutDefinition => {
    3 => 'threeInThreeOut',
    2 => 'threeInOneOut',
  },
  upsThreePhaseDCandRectifierStatusBatteryStatus => '1.3.6.1.4.1.935.1.1.1.8.5.5',
  upsThreePhaseDCandRectifierStatusBatteryStatusDefinition => {
    5 => 'acnormal',
    4 => 'backup',
  },
  upsThreePhaseDCandRectifierStatusChargeStatus => '1.3.6.1.4.1.935.1.1.1.8.5.6',
  upsThreePhaseDCandRectifierStatusChargeStatusDefinition => {
    7 => 'float',
    6 => 'boost',
    16 => 'no',
  },
  upsThreePhaseDCandRectifierStatusRecOperating => '1.3.6.1.4.1.935.1.1.1.8.5.7',
  upsThreePhaseDCandRectifierStatusRecOperatingDefinition => {
    14 => 'yes',
    16 => 'no',
  },
  upsThreePhaseUPSStatusGrp => '1.3.6.1.4.1.935.1.1.1.8.6',
  upsThreePhaseUPSStatusBypassFreqFail => '1.3.6.1.4.1.935.1.1.1.8.6.1',
  upsThreePhaseUPSStatusBypassFreqFailDefinition => {
    14 => 'yes',
    16 => 'no',
  },
  upsThreePhaseUPSStatusManualBypassBreaker => '1.3.6.1.4.1.935.1.1.1.8.6.2',
  upsThreePhaseUPSStatusManualBypassBreakerDefinition => {
    9 => 'open',
    8 => 'close',
  },
  upsThreePhaseUPSStatusACStatus => '1.3.6.1.4.1.935.1.1.1.8.6.3',
  upsThreePhaseUPSStatusACStatusDefinition => {
    10 => 'normal',
    11 => 'abnormal',
  },
  upsThreePhaseUPSStaticSwitchMode => '1.3.6.1.4.1.935.1.1.1.8.6.4',
  upsThreePhaseUPSStaticSwitchModeDefinition => {
    13 => 'bypassmode',
    12 => 'invermode',
  },
  upsThreePhaseUPSStatusInverterOperating => '1.3.6.1.4.1.935.1.1.1.8.6.5',
  upsThreePhaseUPSStatusInverterOperatingDefinition => {
    14 => 'yes',
    16 => 'no',
  },
  upsThreePhaseFaultStatusGrp => '1.3.6.1.4.1.935.1.1.1.8.7',
  upsThreePhaseFaultStatusEmergencyStop => '1.3.6.1.4.1.935.1.1.1.8.7.1',
  upsThreePhaseFaultStatusEmergencyStopDefinition => {
    14 => 'yes',
    16 => 'no',
  },
  upsThreePhaseFaultStatusHighDCShutdown => '1.3.6.1.4.1.935.1.1.1.8.7.2',
  upsThreePhaseFaultStatusHighDCShutdownDefinition => {
    14 => 'yes',
    16 => 'no',
  },
  upsThreePhaseFaultStatusBypassBreaker => '1.3.6.1.4.1.935.1.1.1.8.7.3',
  upsThreePhaseFaultStatusBypassBreakerDefinition => {
    14 => 'yes',
    16 => 'no',
  },
  upsThreePhaseFaultStatusOverLoad => '1.3.6.1.4.1.935.1.1.1.8.7.4',
  upsThreePhaseFaultStatusOverLoadDefinition => {
    14 => 'yes',
    16 => 'no',
  },
  upsThreePhaseFaultStatusInverterOutputFail => '1.3.6.1.4.1.935.1.1.1.8.7.5',
  upsThreePhaseFaultStatusInverterOutputFailDefinition => {
    14 => 'yes',
    16 => 'no',
  },
  upsThreePhaseFaultStatusOverTemperature => '1.3.6.1.4.1.935.1.1.1.8.7.6',
  upsThreePhaseFaultStatusOverTemperatureDefinition => {
    14 => 'yes',
    16 => 'no',
  },
  upsThreePhaseFaultStatusShortCircuit => '1.3.6.1.4.1.935.1.1.1.8.7.7',
  upsThreePhaseFaultStatusShortCircuitDefinition => {
    14 => 'yes',
    16 => 'no',
  },
  upsThreePhaseRatingGrp => '1.3.6.1.4.1.935.1.1.1.8.8',
  upsThreePhaseRatingRectifierVoltage => '1.3.6.1.4.1.935.1.1.1.8.8.1',
  upsThreePhaseRatingRectifierFrequency => '1.3.6.1.4.1.935.1.1.1.8.8.2',
  upsThreePhaseRatingBypassVoltage => '1.3.6.1.4.1.935.1.1.1.8.8.3',
  upsThreePhaseRatingBypassFrequency => '1.3.6.1.4.1.935.1.1.1.8.8.4',
  upsThreePhaseRatingOutputVoltage => '1.3.6.1.4.1.935.1.1.1.8.8.5',
  upsThreePhaseRatingOutputFrequency => '1.3.6.1.4.1.935.1.1.1.8.8.6',
  upsThreePhaseRatingBatteryVoltage => '1.3.6.1.4.1.935.1.1.1.8.8.7',
  upsThreePhaseRatingPower => '1.3.6.1.4.1.935.1.1.1.8.8.8',
  upsEnvironment => '1.3.6.1.4.1.935.1.1.1.9',
  upsEnvStatus => '1.3.6.1.4.1.935.1.1.1.9.1',
  upsEnvTemperature => '1.3.6.1.4.1.935.1.1.1.9.1.1',
  upsEnvHumidity => '1.3.6.1.4.1.935.1.1.1.9.1.2',
  upsEnvWater => '1.3.6.1.4.1.935.1.1.1.9.1.3',
  upsEnvWaterDefinition => {
    1 => 'normal',
    2 => 'abnormal',
  },
  upsEnvSmoke => '1.3.6.1.4.1.935.1.1.1.9.1.4',
  upsEnvSmokeDefinition => {
    1 => 'normal',
    2 => 'abnormal',
  },
  upsEnvSecurity1 => '1.3.6.1.4.1.935.1.1.1.9.1.5',
  upsEnvSecurity1Definition => {
    1 => 'normal',
    2 => 'abnormal',
  },
  upsEnvSecurity2 => '1.3.6.1.4.1.935.1.1.1.9.1.6',
  upsEnvSecurity2Definition => {
    1 => 'normal',
    2 => 'abnormal',
  },
  upsEnvSecurity3 => '1.3.6.1.4.1.935.1.1.1.9.1.7',
  upsEnvSecurity3Definition => {
    1 => 'normal',
    2 => 'abnormal',
  },
  upsEnvSecurity4 => '1.3.6.1.4.1.935.1.1.1.9.1.8',
  upsEnvSecurity4Definition => {
    1 => 'normal',
    2 => 'abnormal',
  },
  upsEnvSecurity5 => '1.3.6.1.4.1.935.1.1.1.9.1.9',
  upsEnvSecurity5Definition => {
    1 => 'normal',
    2 => 'abnormal',
  },
  upsEnvSecurity6 => '1.3.6.1.4.1.935.1.1.1.9.1.10',
  upsEnvSecurity6Definition => {
    1 => 'normal',
    2 => 'abnormal',
  },
  upsEnvSecurity7 => '1.3.6.1.4.1.935.1.1.1.9.1.11',
  upsEnvSecurity7Definition => {
    1 => 'normal',
    2 => 'abnormal',
  },
  upsEnvSetting => '1.3.6.1.4.1.935.1.1.1.9.2',
  upsEnvOverTemperature => '1.3.6.1.4.1.935.1.1.1.9.2.1',
  upsEnvUnderTemperature => '1.3.6.1.4.1.935.1.1.1.9.2.2',
  upsEnvOverHumidity => '1.3.6.1.4.1.935.1.1.1.9.2.3',
  upsEnvUnderHumidity => '1.3.6.1.4.1.935.1.1.1.9.2.4',
  ppcmgmt => '1.3.6.1.4.1.935.2',
  mconfig => '1.3.6.1.4.1.935.2.1',
  mconfigTrapsReceiversNum => '1.3.6.1.4.1.935.2.1.1',
  mconfigTrapsReceiversTable => '1.3.6.1.4.1.935.2.1.2',
  mconfigTrapsReceiversEntry => '1.3.6.1.4.1.935.2.1.2.1',
  trapsIndex => '1.3.6.1.4.1.935.2.1.2.1.1',
  trapsReceiverAddr => '1.3.6.1.4.1.935.2.1.2.1.2',
  receiverCommunityString => '1.3.6.1.4.1.935.2.1.2.1.3',
  severityLevel => '1.3.6.1.4.1.935.2.1.2.1.4',
  severityLevelDefinition => {
    3 => 'severe',
    2 => 'warning',
    1 => 'information',
  },
  receiverAccept => '1.3.6.1.4.1.935.2.1.2.1.5',
  receiverAcceptDefinition => {
    1 => 'yes',
    2 => 'no',
  },
};

1;

__END__

