package Monitoring::GLPlugin::SNMP::MibsAndOids::POWERNETMIB;

$Monitoring::GLPlugin::SNMP::MibsAndOids::origin->{'PowerNet-MIB'} = {
  url => 'ftp://ftp.apc.com/apc/public/software/pnetmib/mib/417/powernet417.mib',
  name => 'PowerNet-MIB',
};

#$Monitoring::GLPlugin::SNMP::MibsAndOids::mib_ids->{'PowerNet-MIB'} = 

$Monitoring::GLPlugin::SNMP::MibsAndOids::mibs_and_oids->{'PowerNet-MIB'} = {
  apc => '1.3.6.1.4.1.318',
  products => '1.3.6.1.4.1.318.1',
  hardware => '1.3.6.1.4.1.318.1.1',
  ups => '1.3.6.1.4.1.318.1.1.1',
  upsIdent => '1.3.6.1.4.1.318.1.1.1.1',
  upsBasicIdent => '1.3.6.1.4.1.318.1.1.1.1.1',
  upsBasicIdentModel => '1.3.6.1.4.1.318.1.1.1.1.1.1',
  upsBasicIdentName => '1.3.6.1.4.1.318.1.1.1.1.1.2',
  upsAdvIdent => '1.3.6.1.4.1.318.1.1.1.1.2',
  upsAdvIdentFirmwareRevision => '1.3.6.1.4.1.318.1.1.1.1.2.1',
  upsAdvIdentDateOfManufacture => '1.3.6.1.4.1.318.1.1.1.1.2.2',
  upsAdvIdentSerialNumber => '1.3.6.1.4.1.318.1.1.1.1.2.3',
  upsAdvIdentFirmwareRevision2 => '1.3.6.1.4.1.318.1.1.1.1.2.4',
  upsAdvIdentSkuNumber => '1.3.6.1.4.1.318.1.1.1.1.2.5',
  upsBattery => '1.3.6.1.4.1.318.1.1.1.2',
  upsBasicBattery => '1.3.6.1.4.1.318.1.1.1.2.1',
  upsBasicBatteryStatus => '1.3.6.1.4.1.318.1.1.1.2.1.1',
  upsBasicBatteryStatusDefinition => 'PowerNet-MIB::upsBasicBatteryStatus',
  upsBasicBatteryTimeOnBattery => '1.3.6.1.4.1.318.1.1.1.2.1.2',
  upsBasicBatteryLastReplaceDate => '1.3.6.1.4.1.318.1.1.1.2.1.3',
  upsAdvBattery => '1.3.6.1.4.1.318.1.1.1.2.2',
  upsAdvBatteryCapacity => '1.3.6.1.4.1.318.1.1.1.2.2.1',
  upsAdvBatteryTemperature => '1.3.6.1.4.1.318.1.1.1.2.2.2',
  upsAdvBatteryRunTimeRemaining => '1.3.6.1.4.1.318.1.1.1.2.2.3',
  upsAdvBatteryReplaceIndicator => '1.3.6.1.4.1.318.1.1.1.2.2.4',
  upsAdvBatteryReplaceIndicatorDefinition => 'PowerNet-MIB::upsAdvBatteryReplaceIndicator',
  upsAdvBatteryNumOfBattPacks => '1.3.6.1.4.1.318.1.1.1.2.2.5',
  upsAdvBatteryNumOfBadBattPacks => '1.3.6.1.4.1.318.1.1.1.2.2.6',
  upsAdvBatteryNominalVoltage => '1.3.6.1.4.1.318.1.1.1.2.2.7',
  upsAdvBatteryActualVoltage => '1.3.6.1.4.1.318.1.1.1.2.2.8',
  upsAdvBatteryCurrent => '1.3.6.1.4.1.318.1.1.1.2.2.9',
  upsAdvTotalDCCurrent => '1.3.6.1.4.1.318.1.1.1.2.2.10',
  upsAdvBatteryFullCapacity => '1.3.6.1.4.1.318.1.1.1.2.2.11',
  upsAdvBatteryActualVoltageTable => '1.3.6.1.4.1.318.1.1.1.2.2.12',
  upsAdvBatteryActualVoltageEntry => '1.3.6.1.4.1.318.1.1.1.2.2.12.1',
  upsAdvBatteryActualVoltageTableIndex => '1.3.6.1.4.1.318.1.1.1.2.2.12.1.1',
  upsAdvBatteryActualVoltagePolarity => '1.3.6.1.4.1.318.1.1.1.2.2.12.1.2',
  upsAdvBatteryActualVoltagePolarityDefinition => 'PowerNet-MIB::upsAdvBatteryActualVoltagePolarity',
  upsAdvBatteryFrameActualVoltage => '1.3.6.1.4.1.318.1.1.1.2.2.12.1.3',
  upsAdvTotalDCCurrentTable => '1.3.6.1.4.1.318.1.1.1.2.2.13',
  upsAdvTotalDCCurrentEntry => '1.3.6.1.4.1.318.1.1.1.2.2.13.1',
  upsAdvTotalDCCurrentTableIndex => '1.3.6.1.4.1.318.1.1.1.2.2.13.1.1',
  upsAdvTotalDCCurrentPolarity => '1.3.6.1.4.1.318.1.1.1.2.2.13.1.2',
  upsAdvTotalDCCurrentPolarityDefinition => 'PowerNet-MIB::upsAdvTotalDCCurrentPolarity',
  upsAdvTotalFrameDCCurrent => '1.3.6.1.4.1.318.1.1.1.2.2.13.1.3',
  upsAdvBatteryCurrentTable => '1.3.6.1.4.1.318.1.1.1.2.2.14',
  upsAdvBatteryCurrentEntry => '1.3.6.1.4.1.318.1.1.1.2.2.14.1',
  upsAdvBatteryCurrentTableIndex => '1.3.6.1.4.1.318.1.1.1.2.2.14.1.1',
  upsAdvBatteryCurrentIndex => '1.3.6.1.4.1.318.1.1.1.2.2.14.1.2',
  upsAdvBatteryCurrentPolarity => '1.3.6.1.4.1.318.1.1.1.2.2.14.1.3',
  upsAdvBatteryCurrentPolarityDefinition => 'PowerNet-MIB::upsAdvBatteryCurrentPolarity',
  upsAdvBatteryFrameCurrent => '1.3.6.1.4.1.318.1.1.1.2.2.14.1.4',
  upsAdvBatteryEstimatedChargeTime => '1.3.6.1.4.1.318.1.1.1.2.2.15',
  upsAdvBatteryPower => '1.3.6.1.4.1.318.1.1.1.2.2.16',
  upsAdvBatteryChargerStatus => '1.3.6.1.4.1.318.1.1.1.2.2.17',
  upsAdvBatteryChargerStatusDefinition => 'PowerNet-MIB::upsAdvBatteryChargerStatus',
  upsAdvBatteryInternalSKU => '1.3.6.1.4.1.318.1.1.1.2.2.19',
  upsAdvBatteryExternalSKU => '1.3.6.1.4.1.318.1.1.1.2.2.20',
  upsAdvBatteryRecommendedReplaceDate => '1.3.6.1.4.1.318.1.1.1.2.2.21',
  upsHighPrecBattery => '1.3.6.1.4.1.318.1.1.1.2.3',
  upsHighPrecBatteryCapacity => '1.3.6.1.4.1.318.1.1.1.2.3.1',
  upsHighPrecBatteryTemperature => '1.3.6.1.4.1.318.1.1.1.2.3.2',
  upsHighPrecBatteryNominalVoltage => '1.3.6.1.4.1.318.1.1.1.2.3.3',
  upsHighPrecBatteryActualVoltage => '1.3.6.1.4.1.318.1.1.1.2.3.4',
  upsHighPrecBatteryCurrent => '1.3.6.1.4.1.318.1.1.1.2.3.5',
  upsHighPrecTotalDCCurrent => '1.3.6.1.4.1.318.1.1.1.2.3.6',
  upsHighPrecBatteryActualVoltageTable => '1.3.6.1.4.1.318.1.1.1.2.3.7',
  upsHighPrecBatteryActualVoltageEntry => '1.3.6.1.4.1.318.1.1.1.2.3.7.1',
  upsHighPrecBatteryActualVoltageTableIndex => '1.3.6.1.4.1.318.1.1.1.2.3.7.1.1',
  upsHighPrecBatteryActualVoltagePolarity => '1.3.6.1.4.1.318.1.1.1.2.3.7.1.2',
  upsHighPrecBatteryActualVoltagePolarityDefinition => 'PowerNet-MIB::upsHighPrecBatteryActualVoltagePolarity',
  upsHighPrecBatteryVoltage => '1.3.6.1.4.1.318.1.1.1.2.3.7.1.3',
  upsHighPrecTotalDCCurrentTable => '1.3.6.1.4.1.318.1.1.1.2.3.8',
  upsHighPrecTotalDCCurrentEntry => '1.3.6.1.4.1.318.1.1.1.2.3.8.1',
  upsHighPrecTotalDCCurrentTableIndex => '1.3.6.1.4.1.318.1.1.1.2.3.8.1.1',
  upsHighPrecTotalDCCurrentPolarity => '1.3.6.1.4.1.318.1.1.1.2.3.8.1.2',
  upsHighPrecTotalDCCurrentPolarityDefinition => 'PowerNet-MIB::upsHighPrecTotalDCCurrentPolarity',
  upsHighPrecTotalDCFrameCurrent => '1.3.6.1.4.1.318.1.1.1.2.3.8.1.3',
  upsHighPrecBatteryCurrentTable => '1.3.6.1.4.1.318.1.1.1.2.3.9',
  upsHighPrecBatteryCurrentEntry => '1.3.6.1.4.1.318.1.1.1.2.3.9.1',
  upsHighPrecBatteryCurrentTableIndex => '1.3.6.1.4.1.318.1.1.1.2.3.9.1.1',
  upsHighPrecBatteryCurrentIndex => '1.3.6.1.4.1.318.1.1.1.2.3.9.1.2',
  upsHighPrecBatteryCurrentPolarity => '1.3.6.1.4.1.318.1.1.1.2.3.9.1.3',
  upsHighPrecBatteryCurrentPolarityDefinition => 'PowerNet-MIB::upsHighPrecBatteryCurrentPolarity',
  upsHighPrecBatteryFrameCurrent => '1.3.6.1.4.1.318.1.1.1.2.3.9.1.4',
  upsHighPrecBatteryPacks => '1.3.6.1.4.1.318.1.1.1.2.3.10',
  upsHighPrecBatteryPackTableSize => '1.3.6.1.4.1.318.1.1.1.2.3.10.1',
  upsHighPrecBatteryPackTable => '1.3.6.1.4.1.318.1.1.1.2.3.10.2',
  upsHighPrecBatteryPackEntry => '1.3.6.1.4.1.318.1.1.1.2.3.10.2.1',
  upsHighPrecBatteryPackIndex => '1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.1',
  upsHighPrecBatteryCartridgeIndex => '1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.2',
  upsHighPrecBatteryPackFirmwareRevision => '1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.3',
  upsHighPrecBatteryPackSerialNumber => '1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.4',
  upsHighPrecBatteryPackTemperature => '1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.5',
  upsHighPrecBatteryPackStatus => '1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.6',
  upsHighPrecBatteryPackCartridgeHealth => '1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.7',
  upsHighPrecBatteryPackCartridgeReplaceDate => '1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.8',
  upsHighPrecBatteryPackCartridgeInstallDate => '1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.9',
  upsHighPrecBatteryPackCartridgeStatus => '1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.10',
  upsInput => '1.3.6.1.4.1.318.1.1.1.3',
  upsBasicInput => '1.3.6.1.4.1.318.1.1.1.3.1',
  upsBasicInputPhase => '1.3.6.1.4.1.318.1.1.1.3.1.1',
  upsAdvInput => '1.3.6.1.4.1.318.1.1.1.3.2',
  upsAdvInputLineVoltage => '1.3.6.1.4.1.318.1.1.1.3.2.1',
  upsAdvInputMaxLineVoltage => '1.3.6.1.4.1.318.1.1.1.3.2.2',
  upsAdvInputMinLineVoltage => '1.3.6.1.4.1.318.1.1.1.3.2.3',
  upsAdvInputFrequency => '1.3.6.1.4.1.318.1.1.1.3.2.4',
  upsAdvInputLineFailCause => '1.3.6.1.4.1.318.1.1.1.3.2.5',
  upsAdvInputLineFailCauseDefinition => 'PowerNet-MIB::upsAdvInputLineFailCause',
  upsAdvInputNominalFrequency => '1.3.6.1.4.1.318.1.1.1.3.2.6',
  upsAdvInputNominalVoltage => '1.3.6.1.4.1.318.1.1.1.3.2.7',
  upsAdvInputBypassNominalFrequency => '1.3.6.1.4.1.318.1.1.1.3.2.8',
  upsAdvInputBypassNominalVoltage => '1.3.6.1.4.1.318.1.1.1.3.2.9',
  upsAdvInputStatisticsTable => '1.3.6.1.4.1.318.1.1.1.3.2.10',
  upsAdvInputStatisticsEntry => '1.3.6.1.4.1.318.1.1.1.3.2.10.1',
  upsAdvInputStatisticsIndex => '1.3.6.1.4.1.318.1.1.1.3.2.10.1.1',
  upsAdvInputApparentPower => '1.3.6.1.4.1.318.1.1.1.3.2.10.1.2',
  upsAdvInputVoltageTHD => '1.3.6.1.4.1.318.1.1.1.3.2.10.1.3',
  upsAdvInputBypassVoltageTHD => '1.3.6.1.4.1.318.1.1.1.3.2.10.1.4',
  upsAdvInputPeakCurrent => '1.3.6.1.4.1.318.1.1.1.3.2.10.1.5',
  upsAdvInputBypassPeakCurrent => '1.3.6.1.4.1.318.1.1.1.3.2.10.1.6',
  upsAdvInputActivePower => '1.3.6.1.4.1.318.1.1.1.3.2.10.1.7',
  upsAdvInputTotalApparentPower => '1.3.6.1.4.1.318.1.1.1.3.2.11',
  upsAdvInputTotalActivePower => '1.3.6.1.4.1.318.1.1.1.3.2.12',
  upsAdvInputBypassTotalApparentPower => '1.3.6.1.4.1.318.1.1.1.3.2.13',
  upsAdvInputBypassTotalActivePower => '1.3.6.1.4.1.318.1.1.1.3.2.14',
  upsHighPrecInput => '1.3.6.1.4.1.318.1.1.1.3.3',
  upsHighPrecInputLineVoltage => '1.3.6.1.4.1.318.1.1.1.3.3.1',
  upsHighPrecInputMaxLineVoltage => '1.3.6.1.4.1.318.1.1.1.3.3.2',
  upsHighPrecInputMinLineVoltage => '1.3.6.1.4.1.318.1.1.1.3.3.3',
  upsHighPrecInputFrequency => '1.3.6.1.4.1.318.1.1.1.3.3.4',
  upsHighPrecInputEnergyUsage => '1.3.6.1.4.1.318.1.1.1.3.3.5',
  upsHighPrecInputBypassVoltage => '1.3.6.1.4.1.318.1.1.1.3.3.6',
  upsHighPrecInputBypassFrequency => '1.3.6.1.4.1.318.1.1.1.3.3.7',
  upsOutput => '1.3.6.1.4.1.318.1.1.1.4',
  upsBasicOutput => '1.3.6.1.4.1.318.1.1.1.4.1',
  upsBasicOutputStatus => '1.3.6.1.4.1.318.1.1.1.4.1.1',
  upsBasicOutputStatusDefinition => 'PowerNet-MIB::upsBasicOutputStatus',
  upsBasicOutputPhase => '1.3.6.1.4.1.318.1.1.1.4.1.2',
  upsBasicSystemStatus => '1.3.6.1.4.1.318.1.1.1.4.1.3',
  upsBasicSystemStatusDefinition => 'PowerNet-MIB::upsBasicSystemStatus',
  upsBasicSystemInternalTemperature => '1.3.6.1.4.1.318.1.1.1.4.1.4',
  upsBasicSystemInverterStatus => '1.3.6.1.4.1.318.1.1.1.4.1.5',
  upsBasicSystemInverterStatusDefinition => 'PowerNet-MIB::upsBasicSystemInverterStatus',
  upsBasicSystemPFCStatus => '1.3.6.1.4.1.318.1.1.1.4.1.6',
  upsBasicSystemPFCStatusDefinition => 'PowerNet-MIB::upsBasicSystemPFCStatus',
  upsBasicOutputACwiringConfiguration => '1.3.6.1.4.1.318.1.1.1.4.1.7',
  upsBasicOutputACwiringConfigurationDefinition => 'PowerNet-MIB::upsBasicOutputACwiringConfiguration',
  upsAdvOutput => '1.3.6.1.4.1.318.1.1.1.4.2',
  upsAdvOutputVoltage => '1.3.6.1.4.1.318.1.1.1.4.2.1',
  upsAdvOutputFrequency => '1.3.6.1.4.1.318.1.1.1.4.2.2',
  upsAdvOutputLoad => '1.3.6.1.4.1.318.1.1.1.4.2.3',
  upsAdvOutputCurrent => '1.3.6.1.4.1.318.1.1.1.4.2.4',
  upsAdvOutputRedundancy => '1.3.6.1.4.1.318.1.1.1.4.2.5',
  upsAdvOutputKVACapacity => '1.3.6.1.4.1.318.1.1.1.4.2.6',
  upsAdvOutputNominalFrequency => '1.3.6.1.4.1.318.1.1.1.4.2.7',
  upsAdvOutputActivePower => '1.3.6.1.4.1.318.1.1.1.4.2.8',
  upsAdvOutputApparentPower => '1.3.6.1.4.1.318.1.1.1.4.2.9',
  upsAdvOutputStatisticsTable => '1.3.6.1.4.1.318.1.1.1.4.2.10',
  upsAdvOutputStatisticsEntry => '1.3.6.1.4.1.318.1.1.1.4.2.10.1',
  upsAdvOutputStatisticsIndex => '1.3.6.1.4.1.318.1.1.1.4.2.10.1.1',
  upsAdvOutputPeakCurrent => '1.3.6.1.4.1.318.1.1.1.4.2.10.1.2',
  upsAdvOutputCurrentTHD => '1.3.6.1.4.1.318.1.1.1.4.2.10.1.3',
  upsAdvOutputCrestFactor => '1.3.6.1.4.1.318.1.1.1.4.2.10.1.4',
  upsAdvOutputNeutralCurrent => '1.3.6.1.4.1.318.1.1.1.4.2.11',
  upsHighPrecOutput => '1.3.6.1.4.1.318.1.1.1.4.3',
  upsHighPrecOutputVoltage => '1.3.6.1.4.1.318.1.1.1.4.3.1',
  upsHighPrecOutputFrequency => '1.3.6.1.4.1.318.1.1.1.4.3.2',
  upsHighPrecOutputLoad => '1.3.6.1.4.1.318.1.1.1.4.3.3',
  upsHighPrecOutputCurrent => '1.3.6.1.4.1.318.1.1.1.4.3.4',
  upsHighPrecOutputEfficiency => '1.3.6.1.4.1.318.1.1.1.4.3.5',
  upsHighPrecOutputEnergyUsage => '1.3.6.1.4.1.318.1.1.1.4.3.6',
  upsConfig => '1.3.6.1.4.1.318.1.1.1.5',
  upsBasicConfig => '1.3.6.1.4.1.318.1.1.1.5.1',
  upsBasicConfigNumDevices => '1.3.6.1.4.1.318.1.1.1.5.1.1',
  upsBasicConfigDeviceTable => '1.3.6.1.4.1.318.1.1.1.5.1.2',
  upsBasicConfigDeviceEntry => '1.3.6.1.4.1.318.1.1.1.5.1.2.1',
  deviceIndex => '1.3.6.1.4.1.318.1.1.1.5.1.2.1.1',
  deviceName => '1.3.6.1.4.1.318.1.1.1.5.1.2.1.2',
  vaRating => '1.3.6.1.4.1.318.1.1.1.5.1.2.1.3',
  acceptThisDevice => '1.3.6.1.4.1.318.1.1.1.5.1.2.1.4',
  acceptThisDeviceDefinition => 'PowerNet-MIB::acceptThisDevice',
  upsAdvConfig => '1.3.6.1.4.1.318.1.1.1.5.2',
  upsAdvConfigRatedOutputVoltage => '1.3.6.1.4.1.318.1.1.1.5.2.1',
  upsAdvConfigHighTransferVolt => '1.3.6.1.4.1.318.1.1.1.5.2.2',
  upsAdvConfigLowTransferVolt => '1.3.6.1.4.1.318.1.1.1.5.2.3',
  upsAdvConfigAlarm => '1.3.6.1.4.1.318.1.1.1.5.2.4',
  upsAdvConfigAlarmDefinition => 'PowerNet-MIB::upsAdvConfigAlarm',
  upsAdvConfigAlarmTimer => '1.3.6.1.4.1.318.1.1.1.5.2.5',
  upsAdvConfigMinReturnCapacity => '1.3.6.1.4.1.318.1.1.1.5.2.6',
  upsAdvConfigSensitivity => '1.3.6.1.4.1.318.1.1.1.5.2.7',
  upsAdvConfigSensitivityDefinition => 'PowerNet-MIB::upsAdvConfigSensitivity',
  upsAdvConfigLowBatteryRunTime => '1.3.6.1.4.1.318.1.1.1.5.2.8',
  upsAdvConfigReturnDelay => '1.3.6.1.4.1.318.1.1.1.5.2.9',
  upsAdvConfigShutoffDelay => '1.3.6.1.4.1.318.1.1.1.5.2.10',
  upsAdvConfigUpsSleepTime => '1.3.6.1.4.1.318.1.1.1.5.2.11',
  upsAdvConfigSetEEPROMDefaults => '1.3.6.1.4.1.318.1.1.1.5.2.12',
  upsAdvConfigSetEEPROMDefaultsDefinition => 'PowerNet-MIB::upsAdvConfigSetEEPROMDefaults',
  upsAdvConfigDipSwitchTable => '1.3.6.1.4.1.318.1.1.1.5.2.13',
  upsAdvConfigDipSwitchEntry => '1.3.6.1.4.1.318.1.1.1.5.2.13.1',
  dipSwitchIndex => '1.3.6.1.4.1.318.1.1.1.5.2.13.1.1',
  dipSwitchStatus => '1.3.6.1.4.1.318.1.1.1.5.2.13.1.2',
  dipSwitchStatusDefinition => 'PowerNet-MIB::dipSwitchStatus',
  upsAdvConfigBattExhaustThresh => '1.3.6.1.4.1.318.1.1.1.5.2.14',
  upsAdvConfigPassword => '1.3.6.1.4.1.318.1.1.1.5.2.15',
  upsAdvConfigAllowedSetTable => '1.3.6.1.4.1.318.1.1.1.5.2.16',
  upsAdvConfigAllowedSetEntry => '1.3.6.1.4.1.318.1.1.1.5.2.16.1',
  apcUpsConfigFieldIndex => '1.3.6.1.4.1.318.1.1.1.5.2.16.1.1',
  apcUpsConfigFieldOID => '1.3.6.1.4.1.318.1.1.1.5.2.16.1.2',
  apcUpsConfigFieldValueRange => '1.3.6.1.4.1.318.1.1.1.5.2.16.1.3',
  upsAdvConfigBattCabAmpHour => '1.3.6.1.4.1.318.1.1.1.5.2.17',
  upsAdvConfigPositionSelector => '1.3.6.1.4.1.318.1.1.1.5.2.18',
  upsAdvConfigPositionSelectorDefinition => 'PowerNet-MIB::upsAdvConfigPositionSelector',
  upsAdvConfigOutputFreqRange => '1.3.6.1.4.1.318.1.1.1.5.2.19',
  upsAdvConfigOutputFreqRangeDefinition => 'PowerNet-MIB::upsAdvConfigOutputFreqRange',
  upsAdvConfigUPSFail => '1.3.6.1.4.1.318.1.1.1.5.2.20',
  upsAdvConfigUPSFailDefinition => 'PowerNet-MIB::upsAdvConfigUPSFail',
  upsAdvConfigAlarmRedundancy => '1.3.6.1.4.1.318.1.1.1.5.2.21',
  upsAdvConfigAlarmLoadOver => '1.3.6.1.4.1.318.1.1.1.5.2.22',
  upsAdvConfigAlarmRuntimeUnder => '1.3.6.1.4.1.318.1.1.1.5.2.23',
  upsAdvConfigVoutReporting => '1.3.6.1.4.1.318.1.1.1.5.2.24',
  upsAdvConfigVoutReportingDefinition => 'PowerNet-MIB::upsAdvConfigVoutReporting',
  upsAdvConfigNumExternalBatteries => '1.3.6.1.4.1.318.1.1.1.5.2.25',
  upsAdvConfigSimpleSignalShutdowns => '1.3.6.1.4.1.318.1.1.1.5.2.26',
  upsAdvConfigSimpleSignalShutdownsDefinition => 'PowerNet-MIB::upsAdvConfigSimpleSignalShutdowns',
  upsAdvConfigMaxShutdownTime => '1.3.6.1.4.1.318.1.1.1.5.2.27',
  upsAsiUpsControlServerRequestShutdown => '1.3.6.1.4.1.318.1.1.1.5.2.28',
  upsAsiUpsControlServerRequestShutdownDefinition => 'PowerNet-MIB::upsAsiUpsControlServerRequestShutdown',
  upsAdvConfigMinReturnRuntime => '1.3.6.1.4.1.318.1.1.1.5.2.29',
  upsAdvConfigBasicSignalLowBatteryDuration => '1.3.6.1.4.1.318.1.1.1.5.2.30',
  upsAdvConfigBypassPhaseLockRequired => '1.3.6.1.4.1.318.1.1.1.5.2.31',
  upsAdvConfigBypassPhaseLockRequiredDefinition => 'PowerNet-MIB::upsAdvConfigBypassPhaseLockRequired',
  upsAdvConfigOutputFreqSlewRate => '1.3.6.1.4.1.318.1.1.1.5.2.32',
  upsAdvConfigOutputFreqSlewRateDefinition => 'PowerNet-MIB::upsAdvConfigOutputFreqSlewRate',
  upsAdvConfigChargerLevel => '1.3.6.1.4.1.318.1.1.1.5.2.33',
  upsAdvConfigChargerLevelDefinition => 'PowerNet-MIB::upsAdvConfigChargerLevel',
  upsAdvConfigBypassToleranceSetting => '1.3.6.1.4.1.318.1.1.1.5.2.34',
  upsAdvConfigBypassToleranceSettingDefinition => 'PowerNet-MIB::upsAdvConfigBypassToleranceSetting',
  upsAdvConfigMainsSetting => '1.3.6.1.4.1.318.1.1.1.5.2.35',
  upsAdvConfigMainsSettingDefinition => 'PowerNet-MIB::upsAdvConfigMainsSetting',
  upsAdvConfigACWiringSetting => '1.3.6.1.4.1.318.1.1.1.5.2.36',
  upsAdvConfigACWiringSettingDefinition => 'PowerNet-MIB::upsAdvConfigACWiringSetting',
  upsAdvConfigUpperOutputVoltTolerance => '1.3.6.1.4.1.318.1.1.1.5.2.37',
  upsAdvConfigLowerOutputVoltTolerance => '1.3.6.1.4.1.318.1.1.1.5.2.38',
  upsAdvConfigUpperBypassVoltTolerance => '1.3.6.1.4.1.318.1.1.1.5.2.39',
  upsAdvConfigLowerBypassVoltTolerance => '1.3.6.1.4.1.318.1.1.1.5.2.40',
  upsAdvConfigOutofSyncBypassTransferDelay => '1.3.6.1.4.1.318.1.1.1.5.2.41',
  upsAdvConfigWarningAlarmDelay => '1.3.6.1.4.1.318.1.1.1.5.2.43',
  upsAdvConfigInformationalAlarmDelay => '1.3.6.1.4.1.318.1.1.1.5.2.44',
  upsAdvConfigGreenMode => '1.3.6.1.4.1.318.1.1.1.5.2.45',
  upsAdvConfigGreenModeDefinition => 'PowerNet-MIB::upsAdvConfigGreenMode',
  upsAdvConfigLCDLocalLanguage => '1.3.6.1.4.1.318.1.1.1.5.2.46',
  upsAdvConfigLCDLocalLanguageDefinition => 'PowerNet-MIB::upsAdvConfigLCDLocalLanguage',
  upsAdvConfigLCDLockOut => '1.3.6.1.4.1.318.1.1.1.5.2.47',
  upsAdvConfigLCDLockOutDefinition => 'PowerNet-MIB::upsAdvConfigLCDLockOut',
  upsAdvConfigChargerRate => '1.3.6.1.4.1.318.1.1.1.5.2.48',
  upsAdvConfigBatterySelection => '1.3.6.1.4.1.318.1.1.1.5.2.49',
  upsAdvConfigBatterySelectionDefinition => 'PowerNet-MIB::upsAdvConfigBatterySelection',
  upsAdvConfigBatteryHealthAlarmWarningTime => '1.3.6.1.4.1.318.1.1.1.5.2.50',
  upsAdvConfigBatteryHealthAlarmSleepTime => '1.3.6.1.4.1.318.1.1.1.5.2.51',
  upsControl => '1.3.6.1.4.1.318.1.1.1.6',
  upsBasicControl => '1.3.6.1.4.1.318.1.1.1.6.1',
  upsBasicControlConserveBattery => '1.3.6.1.4.1.318.1.1.1.6.1.1',
  upsBasicControlConserveBatteryDefinition => 'PowerNet-MIB::upsBasicControlConserveBattery',
  upsAdvControl => '1.3.6.1.4.1.318.1.1.1.6.2',
  upsAdvControlUpsOff => '1.3.6.1.4.1.318.1.1.1.6.2.1',
  upsAdvControlUpsOffDefinition => 'PowerNet-MIB::upsAdvControlUpsOff',
  upsAdvControlRebootShutdownUps => '1.3.6.1.4.1.318.1.1.1.6.2.2',
  upsAdvControlRebootShutdownUpsDefinition => 'PowerNet-MIB::upsAdvControlRebootShutdownUps',
  upsAdvControlUpsSleep => '1.3.6.1.4.1.318.1.1.1.6.2.3',
  upsAdvControlUpsSleepDefinition => 'PowerNet-MIB::upsAdvControlUpsSleep',
  upsAdvControlSimulatePowerFail => '1.3.6.1.4.1.318.1.1.1.6.2.4',
  upsAdvControlSimulatePowerFailDefinition => 'PowerNet-MIB::upsAdvControlSimulatePowerFail',
  upsAdvControlFlashAndBeep => '1.3.6.1.4.1.318.1.1.1.6.2.5',
  upsAdvControlFlashAndBeepDefinition => 'PowerNet-MIB::upsAdvControlFlashAndBeep',
  upsAdvControlTurnOnUPS => '1.3.6.1.4.1.318.1.1.1.6.2.6',
  upsAdvControlTurnOnUPSDefinition => 'PowerNet-MIB::upsAdvControlTurnOnUPS',
  upsAdvControlBypassSwitch => '1.3.6.1.4.1.318.1.1.1.6.2.7',
  upsAdvControlBypassSwitchDefinition => 'PowerNet-MIB::upsAdvControlBypassSwitch',
  upsAdvControlRebootUpsWithOrWithoutAC => '1.3.6.1.4.1.318.1.1.1.6.2.8',
  upsAdvControlRebootUpsWithOrWithoutACDefinition => 'PowerNet-MIB::upsAdvControlRebootUpsWithOrWithoutAC',
  upsAdvControlFirmwareUpdate => '1.3.6.1.4.1.318.1.1.1.6.2.9',
  upsAdvControlFirmwareUpdateDefinition => 'PowerNet-MIB::upsAdvControlFirmwareUpdate',
  upsTest => '1.3.6.1.4.1.318.1.1.1.7',
  upsBasicTest => '1.3.6.1.4.1.318.1.1.1.7.1',
  upsAdvTest => '1.3.6.1.4.1.318.1.1.1.7.2',
  upsAdvTestDiagnosticSchedule => '1.3.6.1.4.1.318.1.1.1.7.2.1',
  upsAdvTestDiagnosticScheduleDefinition => 'PowerNet-MIB::upsAdvTestDiagnosticSchedule',
  upsAdvTestDiagnostics => '1.3.6.1.4.1.318.1.1.1.7.2.2',
  upsAdvTestDiagnosticsDefinition => 'PowerNet-MIB::upsAdvTestDiagnostics',
  upsAdvTestDiagnosticsResults => '1.3.6.1.4.1.318.1.1.1.7.2.3',
  upsAdvTestDiagnosticsResultsDefinition => 'PowerNet-MIB::upsAdvTestDiagnosticsResults',
  upsAdvTestLastDiagnosticsDate => '1.3.6.1.4.1.318.1.1.1.7.2.4',
  upsAdvTestRuntimeCalibration => '1.3.6.1.4.1.318.1.1.1.7.2.5',
  upsAdvTestRuntimeCalibrationDefinition => 'PowerNet-MIB::upsAdvTestRuntimeCalibration',
  upsAdvTestCalibrationResults => '1.3.6.1.4.1.318.1.1.1.7.2.6',
  upsAdvTestCalibrationResultsDefinition => 'PowerNet-MIB::upsAdvTestCalibrationResults',
  upsAdvTestCalibrationDate => '1.3.6.1.4.1.318.1.1.1.7.2.7',
  upsAdvTestDiagnosticTime => '1.3.6.1.4.1.318.1.1.1.7.2.8',
  upsAdvTestDiagnosticDay => '1.3.6.1.4.1.318.1.1.1.7.2.9',
  upsAdvTestDiagnosticDayDefinition => 'PowerNet-MIB::upsAdvTestDiagnosticDay',
  upsComm => '1.3.6.1.4.1.318.1.1.1.8',
  upsCommStatus => '1.3.6.1.4.1.318.1.1.1.8.1',
  upsCommStatusDefinition => 'PowerNet-MIB::upsCommStatus',
  upsPhase => '1.3.6.1.4.1.318.1.1.1.9',
  upsPhaseResetValues => '1.3.6.1.4.1.318.1.1.1.9.1',
  upsPhaseResetMaxMinValues => '1.3.6.1.4.1.318.1.1.1.9.1.1',
  upsPhaseResetMaxMinValuesDefinition => 'PowerNet-MIB::upsPhaseResetMaxMinValues',
  upsPhaseInput => '1.3.6.1.4.1.318.1.1.1.9.2',
  upsPhaseNumInputs => '1.3.6.1.4.1.318.1.1.1.9.2.1',
  upsPhaseInputTable => '1.3.6.1.4.1.318.1.1.1.9.2.2',
  upsPhaseInputEntry => '1.3.6.1.4.1.318.1.1.1.9.2.2.1',
  upsPhaseInputTableIndex => '1.3.6.1.4.1.318.1.1.1.9.2.2.1.1',
  upsPhaseNumInputPhases => '1.3.6.1.4.1.318.1.1.1.9.2.2.1.2',
  upsPhaseInputVoltageOrientation => '1.3.6.1.4.1.318.1.1.1.9.2.2.1.3',
  upsPhaseInputVoltageOrientationDefinition => 'PowerNet-MIB::upsPhaseInputVoltageOrientation',
  upsPhaseInputFrequency => '1.3.6.1.4.1.318.1.1.1.9.2.2.1.4',
  upsPhaseInputType => '1.3.6.1.4.1.318.1.1.1.9.2.2.1.5',
  upsPhaseInputTypeDefinition => 'PowerNet-MIB::upsPhaseInputType',
  upsPhaseInputName => '1.3.6.1.4.1.318.1.1.1.9.2.2.1.6',
  upsPhaseInputPhaseTable => '1.3.6.1.4.1.318.1.1.1.9.2.3',
  upsPhaseInputPhaseEntry => '1.3.6.1.4.1.318.1.1.1.9.2.3.1',
  upsPhaseInputPhaseTableIndex => '1.3.6.1.4.1.318.1.1.1.9.2.3.1.1',
  upsPhaseInputPhaseIndex => '1.3.6.1.4.1.318.1.1.1.9.2.3.1.2',
  upsPhaseInputVoltage => '1.3.6.1.4.1.318.1.1.1.9.2.3.1.3',
  upsPhaseInputMaxVoltage => '1.3.6.1.4.1.318.1.1.1.9.2.3.1.4',
  upsPhaseInputMinVoltage => '1.3.6.1.4.1.318.1.1.1.9.2.3.1.5',
  upsPhaseInputCurrent => '1.3.6.1.4.1.318.1.1.1.9.2.3.1.6',
  upsPhaseInputMaxCurrent => '1.3.6.1.4.1.318.1.1.1.9.2.3.1.7',
  upsPhaseInputMinCurrent => '1.3.6.1.4.1.318.1.1.1.9.2.3.1.8',
  upsPhaseInputPower => '1.3.6.1.4.1.318.1.1.1.9.2.3.1.9',
  upsPhaseInputMaxPower => '1.3.6.1.4.1.318.1.1.1.9.2.3.1.10',
  upsPhaseInputMinPower => '1.3.6.1.4.1.318.1.1.1.9.2.3.1.11',
  upsPhaseInputApparentPower => '1.3.6.1.4.1.318.1.1.1.9.2.3.1.12',
  upsPhaseInputPowerFactor => '1.3.6.1.4.1.318.1.1.1.9.2.3.1.13',
  upsPhaseOutput => '1.3.6.1.4.1.318.1.1.1.9.3',
  upsPhaseNumOutputs => '1.3.6.1.4.1.318.1.1.1.9.3.1',
  upsPhaseOutputTable => '1.3.6.1.4.1.318.1.1.1.9.3.2',
  upsPhaseOutputEntry => '1.3.6.1.4.1.318.1.1.1.9.3.2.1',
  upsPhaseOutputTableIndex => '1.3.6.1.4.1.318.1.1.1.9.3.2.1.1',
  upsPhaseNumOutputPhases => '1.3.6.1.4.1.318.1.1.1.9.3.2.1.2',
  upsPhaseOutputVoltageOrientation => '1.3.6.1.4.1.318.1.1.1.9.3.2.1.3',
  upsPhaseOutputVoltageOrientationDefinition => 'PowerNet-MIB::upsPhaseOutputVoltageOrientation',
  upsPhaseOutputFrequency => '1.3.6.1.4.1.318.1.1.1.9.3.2.1.4',
  upsPhaseOutputPhaseTable => '1.3.6.1.4.1.318.1.1.1.9.3.3',
  upsPhaseOutputPhaseEntry => '1.3.6.1.4.1.318.1.1.1.9.3.3.1',
  upsPhaseOutputPhaseTableIndex => '1.3.6.1.4.1.318.1.1.1.9.3.3.1.1',
  upsPhaseOutputPhaseIndex => '1.3.6.1.4.1.318.1.1.1.9.3.3.1.2',
  upsPhaseOutputVoltage => '1.3.6.1.4.1.318.1.1.1.9.3.3.1.3',
  upsPhaseOutputCurrent => '1.3.6.1.4.1.318.1.1.1.9.3.3.1.4',
  upsPhaseOutputMaxCurrent => '1.3.6.1.4.1.318.1.1.1.9.3.3.1.5',
  upsPhaseOutputMinCurrent => '1.3.6.1.4.1.318.1.1.1.9.3.3.1.6',
  upsPhaseOutputLoad => '1.3.6.1.4.1.318.1.1.1.9.3.3.1.7',
  upsPhaseOutputMaxLoad => '1.3.6.1.4.1.318.1.1.1.9.3.3.1.8',
  upsPhaseOutputMinLoad => '1.3.6.1.4.1.318.1.1.1.9.3.3.1.9',
  upsPhaseOutputPercentLoad => '1.3.6.1.4.1.318.1.1.1.9.3.3.1.10',
  upsPhaseOutputMaxPercentLoad => '1.3.6.1.4.1.318.1.1.1.9.3.3.1.11',
  upsPhaseOutputMinPercentLoad => '1.3.6.1.4.1.318.1.1.1.9.3.3.1.12',
  upsPhaseOutputPower => '1.3.6.1.4.1.318.1.1.1.9.3.3.1.13',
  upsPhaseOutputMaxPower => '1.3.6.1.4.1.318.1.1.1.9.3.3.1.14',
  upsPhaseOutputMinPower => '1.3.6.1.4.1.318.1.1.1.9.3.3.1.15',
  upsPhaseOutputPercentPower => '1.3.6.1.4.1.318.1.1.1.9.3.3.1.16',
  upsPhaseOutputMaxPercentPower => '1.3.6.1.4.1.318.1.1.1.9.3.3.1.17',
  upsPhaseOutputMinPercentPower => '1.3.6.1.4.1.318.1.1.1.9.3.3.1.18',
  upsPhaseOutputPowerFactor => '1.3.6.1.4.1.318.1.1.1.9.3.3.1.19',
  upsSyncCtrlGroup => '1.3.6.1.4.1.318.1.1.1.10',
  upsSyncCtrlGroupConfig => '1.3.6.1.4.1.318.1.1.1.10.1',
  upsSCGMembershipGroupNumber => '1.3.6.1.4.1.318.1.1.1.10.1.1',
  upsSCGActiveMembershipStatus => '1.3.6.1.4.1.318.1.1.1.10.1.2',
  upsSCGActiveMembershipStatusDefinition => 'PowerNet-MIB::upsSCGActiveMembershipStatus',
  upsSCGPowerSynchronizationDelayTime => '1.3.6.1.4.1.318.1.1.1.10.1.3',
  upsSCGReturnBatteryCapacityOffset => '1.3.6.1.4.1.318.1.1.1.10.1.4',
  upsSCGMultiCastIP => '1.3.6.1.4.1.318.1.1.1.10.1.5',
  upsSyncCtrlGroupStatus => '1.3.6.1.4.1.318.1.1.1.10.2',
  upsSCGNumOfGroupMembers => '1.3.6.1.4.1.318.1.1.1.10.2.1',
  upsSCGStatusTable => '1.3.6.1.4.1.318.1.1.1.10.2.2',
  upsSCGStatusEntry => '1.3.6.1.4.1.318.1.1.1.10.2.2.1',
  upsSCGStatusTableIndex => '1.3.6.1.4.1.318.1.1.1.10.2.2.1.1',
  upsSCGMemberIP => '1.3.6.1.4.1.318.1.1.1.10.2.2.1.2',
  upsSCGACInputStatus => '1.3.6.1.4.1.318.1.1.1.10.2.2.1.3',
  upsSCGACInputStatusDefinition => 'PowerNet-MIB::upsSCGACInputStatus',
  upsSCGACOutputStatus => '1.3.6.1.4.1.318.1.1.1.10.2.2.1.4',
  upsSCGACOutputStatusDefinition => 'PowerNet-MIB::upsSCGACOutputStatus',
  upsState => '1.3.6.1.4.1.318.1.1.1.11',
  upsBasicState => '1.3.6.1.4.1.318.1.1.1.11.1',
  upsBasicStateOutputState => '1.3.6.1.4.1.318.1.1.1.11.1.1',
  upsBasicStateOutputStateDefinition => 'PowerNet-MIB::upsBasicStateOutputState',
  upsAdvState => '1.3.6.1.4.1.318.1.1.1.11.2',
  upsAdvStateAbnormalConditions => '1.3.6.1.4.1.318.1.1.1.11.2.1',
  upsAdvStateSymmetra3PhaseSpecificFaults => '1.3.6.1.4.1.318.1.1.1.11.2.2',
  upsAdvStateDP300ESpecificFaults => '1.3.6.1.4.1.318.1.1.1.11.2.3',
  upsAdvStateSymmetraSpecificFaults => '1.3.6.1.4.1.318.1.1.1.11.2.4',
  upsAdvStateSmartUPSSpecificFaults => '1.3.6.1.4.1.318.1.1.1.11.2.5',
  upsAdvStateSystemMessages => '1.3.6.1.4.1.318.1.1.1.11.2.6',
  upsAdvStateTotaltimeonbattery => '1.3.6.1.4.1.318.1.1.1.11.2.7',
  upsAdvStateTotaltimeonbypass => '1.3.6.1.4.1.318.1.1.1.11.2.8',
  upsAdvStateTotaltimeonNormal => '1.3.6.1.4.1.318.1.1.1.11.2.9',
  upsAdvStateNumberoftimesonbattery => '1.3.6.1.4.1.318.1.1.1.11.2.10',
  upsAdvStateNumberoftimesbypass => '1.3.6.1.4.1.318.1.1.1.11.2.11',
  upsAdvStateNumberoftimesNormal => '1.3.6.1.4.1.318.1.1.1.11.2.12',
  upsAdvStateEcomode => '1.3.6.1.4.1.318.1.1.1.11.2.13',
  upsAdvStateEcomodeDefinition => 'PowerNet-MIB::upsAdvStateEcomode',
  upsOutletGroups => '1.3.6.1.4.1.318.1.1.1.12',
  upsOutletGroupStatus => '1.3.6.1.4.1.318.1.1.1.12.1',
  upsOutletGroupStatusTableSize => '1.3.6.1.4.1.318.1.1.1.12.1.1',
  upsOutletGroupStatusTable => '1.3.6.1.4.1.318.1.1.1.12.1.2',
  upsOutletGroupStatusEntry => '1.3.6.1.4.1.318.1.1.1.12.1.2.1',
  upsOutletGroupStatusIndex => '1.3.6.1.4.1.318.1.1.1.12.1.2.1.1',
  upsOutletGroupStatusName => '1.3.6.1.4.1.318.1.1.1.12.1.2.1.2',
  upsOutletGroupStatusGroupState => '1.3.6.1.4.1.318.1.1.1.12.1.2.1.3',
  upsOutletGroupStatusGroupStateDefinition => 'PowerNet-MIB::upsOutletGroupStatusGroupState',
  upsOutletGroupStatusCommandPending => '1.3.6.1.4.1.318.1.1.1.12.1.2.1.4',
  upsOutletGroupStatusCommandPendingDefinition => 'PowerNet-MIB::upsOutletGroupStatusCommandPending',
  upsOutletGroupStatusOutletType => '1.3.6.1.4.1.318.1.1.1.12.1.2.1.5',
  upsOutletGroupStatusOutletTypeDefinition => 'PowerNet-MIB::upsOutletGroupStatusOutletType',
  upsOutletGroupConfig => '1.3.6.1.4.1.318.1.1.1.12.2',
  upsOutletGroupConfigTableSize => '1.3.6.1.4.1.318.1.1.1.12.2.1',
  upsOutletGroupConfigTable => '1.3.6.1.4.1.318.1.1.1.12.2.2',
  upsOutletGroupConfigEntry => '1.3.6.1.4.1.318.1.1.1.12.2.2.1',
  upsOutletGroupConfigIndex => '1.3.6.1.4.1.318.1.1.1.12.2.2.1.1',
  upsOutletGroupConfigName => '1.3.6.1.4.1.318.1.1.1.12.2.2.1.2',
  upsOutletGroupConfigPowerOnDelay => '1.3.6.1.4.1.318.1.1.1.12.2.2.1.3',
  upsOutletGroupConfigPowerOffDelay => '1.3.6.1.4.1.318.1.1.1.12.2.2.1.4',
  upsOutletGroupConfigRebootDuration => '1.3.6.1.4.1.318.1.1.1.12.2.2.1.5',
  upsOutletGroupConfigMinReturnRuntime => '1.3.6.1.4.1.318.1.1.1.12.2.2.1.6',
  upsOutletGroupConfigOutletType => '1.3.6.1.4.1.318.1.1.1.12.2.2.1.7',
  upsOutletGroupConfigOutletTypeDefinition => 'PowerNet-MIB::upsOutletGroupConfigOutletType',
  upsOutletGroupConfigLoadShedControlSkipOffDelay => '1.3.6.1.4.1.318.1.1.1.12.2.2.1.8',
  upsOutletGroupConfigLoadShedControlSkipOffDelayDefinition => 'PowerNet-MIB::upsOutletGroupConfigLoadShedControlSkipOffDelay',
  upsOutletGroupConfigLoadShedControlAutoRestart => '1.3.6.1.4.1.318.1.1.1.12.2.2.1.9',
  upsOutletGroupConfigLoadShedControlAutoRestartDefinition => 'PowerNet-MIB::upsOutletGroupConfigLoadShedControlAutoRestart',
  upsOutletGroupConfigLoadShedControlTimeOnBattery => '1.3.6.1.4.1.318.1.1.1.12.2.2.1.10',
  upsOutletGroupConfigLoadShedControlTimeOnBatteryDefinition => 'PowerNet-MIB::upsOutletGroupConfigLoadShedControlTimeOnBattery',
  upsOutletGroupConfigLoadShedControlRuntimeRemaining => '1.3.6.1.4.1.318.1.1.1.12.2.2.1.11',
  upsOutletGroupConfigLoadShedControlRuntimeRemainingDefinition => 'PowerNet-MIB::upsOutletGroupConfigLoadShedControlRuntimeRemaining',
  upsOutletGroupConfigLoadShedControlInOverload => '1.3.6.1.4.1.318.1.1.1.12.2.2.1.12',
  upsOutletGroupConfigLoadShedControlInOverloadDefinition => 'PowerNet-MIB::upsOutletGroupConfigLoadShedControlInOverload',
  upsOutletGroupConfigLoadShedTimeOnBattery => '1.3.6.1.4.1.318.1.1.1.12.2.2.1.13',
  upsOutletGroupConfigLoadShedRuntimeRemaining => '1.3.6.1.4.1.318.1.1.1.12.2.2.1.14',
  upsOutletGroupControl => '1.3.6.1.4.1.318.1.1.1.12.3',
  upsOutletGroupControlTableSize => '1.3.6.1.4.1.318.1.1.1.12.3.1',
  upsOutletGroupControlTable => '1.3.6.1.4.1.318.1.1.1.12.3.2',
  upsOutletGroupControlEntry => '1.3.6.1.4.1.318.1.1.1.12.3.2.1',
  upsOutletGroupControlIndex => '1.3.6.1.4.1.318.1.1.1.12.3.2.1.1',
  upsOutletGroupControlName => '1.3.6.1.4.1.318.1.1.1.12.3.2.1.2',
  upsOutletGroupControlCommand => '1.3.6.1.4.1.318.1.1.1.12.3.2.1.3',
  upsOutletGroupControlCommandDefinition => 'PowerNet-MIB::upsOutletGroupControlCommand',
  upsOutletGroupControlOutletType => '1.3.6.1.4.1.318.1.1.1.12.3.2.1.4',
  upsOutletGroupControlOutletTypeDefinition => 'PowerNet-MIB::upsOutletGroupControlOutletType',
  upsDiagnostics => '1.3.6.1.4.1.318.1.1.1.13',
  upsDiagnosticIM => '1.3.6.1.4.1.318.1.1.1.13.1',
  upsDiagIMTableSize => '1.3.6.1.4.1.318.1.1.1.13.1.1',
  upsDiagIMTable => '1.3.6.1.4.1.318.1.1.1.13.1.2',
  upsDiagIMEntry => '1.3.6.1.4.1.318.1.1.1.13.1.2.1',
  upsDiagIMIndex => '1.3.6.1.4.1.318.1.1.1.13.1.2.1.1',
  upsDiagIMType => '1.3.6.1.4.1.318.1.1.1.13.1.2.1.2',
  upsDiagIMTypeDefinition => 'PowerNet-MIB::upsDiagIMType',
  upsDiagIMStatus => '1.3.6.1.4.1.318.1.1.1.13.1.2.1.3',
  upsDiagIMStatusDefinition => 'PowerNet-MIB::upsDiagIMStatus',
  upsDiagIMFirmwareRev => '1.3.6.1.4.1.318.1.1.1.13.1.2.1.4',
  upsDiagIMSlaveFirmwareRev => '1.3.6.1.4.1.318.1.1.1.13.1.2.1.5',
  upsDiagIMHardwareRev => '1.3.6.1.4.1.318.1.1.1.13.1.2.1.6',
  upsDiagIMSerialNum => '1.3.6.1.4.1.318.1.1.1.13.1.2.1.7',
  upsDiagIMManufactureDate => '1.3.6.1.4.1.318.1.1.1.13.1.2.1.8',
  upsDiagnosticPowerModules => '1.3.6.1.4.1.318.1.1.1.13.2',
  upsDiagPMTableSize => '1.3.6.1.4.1.318.1.1.1.13.2.1',
  upsDiagPMTable => '1.3.6.1.4.1.318.1.1.1.13.2.2',
  upsDiagPMEntry => '1.3.6.1.4.1.318.1.1.1.13.2.2.1',
  upsDiagPMIndex => '1.3.6.1.4.1.318.1.1.1.13.2.2.1.1',
  upsDiagPMStatus => '1.3.6.1.4.1.318.1.1.1.13.2.2.1.2',
  upsDiagPMStatusDefinition => 'PowerNet-MIB::upsDiagPMStatus',
  upsDiagPMFirmwareRev => '1.3.6.1.4.1.318.1.1.1.13.2.2.1.3',
  upsDiagPMHardwareRev => '1.3.6.1.4.1.318.1.1.1.13.2.2.1.4',
  upsDiagPMSerialNum => '1.3.6.1.4.1.318.1.1.1.13.2.2.1.5',
  upsDiagPMManufactureDate => '1.3.6.1.4.1.318.1.1.1.13.2.2.1.6',
  upsDiagPMLifetimeInfoTable => '1.3.6.1.4.1.318.1.1.1.13.2.3',
  upsDiagPMLifetimeInfoEntry => '1.3.6.1.4.1.318.1.1.1.13.2.3.1',
  upsDiagPMLifetimeInfoIndex => '1.3.6.1.4.1.318.1.1.1.13.2.3.1.1',
  upsDiagPMLifetimeStatus => '1.3.6.1.4.1.318.1.1.1.13.2.3.1.2',
  upsDiagPMLifetimeStatusDefinition => 'PowerNet-MIB::upsDiagPMLifetimeStatus',
  upsDiagPMEstmtdLifetimeRmng => '1.3.6.1.4.1.318.1.1.1.13.2.3.1.3',
  upsDiagPMEstmtdLifetimeRmngPct => '1.3.6.1.4.1.318.1.1.1.13.2.3.1.4',
  upsDiagPMFanLifetimeStatus => '1.3.6.1.4.1.318.1.1.1.13.2.3.1.5',
  upsDiagPMFanLifetimeStatusDefinition => 'PowerNet-MIB::upsDiagPMFanLifetimeStatus',
  upsDiagPMFanEstmtdLifetimeRmng => '1.3.6.1.4.1.318.1.1.1.13.2.3.1.6',
  upsDiagPMFanEstmtdLifetimeRmngPct => '1.3.6.1.4.1.318.1.1.1.13.2.3.1.7',
  upsDiagPMEnclDoorFltrTableSize => '1.3.6.1.4.1.318.1.1.1.13.2.4',
  upsDiagPMEnclDoorFltrTable => '1.3.6.1.4.1.318.1.1.1.13.2.5',
  upsDiagPMEnclDoorFltrEntry => '1.3.6.1.4.1.318.1.1.1.13.2.5.1',
  upsDiagPMEnclIndex => '1.3.6.1.4.1.318.1.1.1.13.2.5.1.1',
  upsDiagPMEnclDoorFltrLifetime => '1.3.6.1.4.1.318.1.1.1.13.2.5.1.2',
  upsDiagPMEnclDoorFltrLifetimeDefinition => 'PowerNet-MIB::upsDiagPMEnclDoorFltrLifetime',
  upsDiagPMEnclDoorFltrStatus => '1.3.6.1.4.1.318.1.1.1.13.2.5.1.3',
  upsDiagPMEnclDoorFltrStatusDefinition => 'PowerNet-MIB::upsDiagPMEnclDoorFltrStatus',
  upsDiagPMEnclDoorFltrEstmtdLifetimeRmng => '1.3.6.1.4.1.318.1.1.1.13.2.5.1.4',
  upsDiagPMEnclDoorFltrEstmtdLifetimeRmngPct => '1.3.6.1.4.1.318.1.1.1.13.2.5.1.5',
  upsDiagnosticBatteries => '1.3.6.1.4.1.318.1.1.1.13.3',
  upsDiagBatteryTableSize => '1.3.6.1.4.1.318.1.1.1.13.3.1',
  upsDiagBatteryTable => '1.3.6.1.4.1.318.1.1.1.13.3.2',
  upsDiagBatteryEntry => '1.3.6.1.4.1.318.1.1.1.13.3.2.1',
  upsDiagBatteryFrameIndex => '1.3.6.1.4.1.318.1.1.1.13.3.2.1.1',
  upsDiagBatteryIndex => '1.3.6.1.4.1.318.1.1.1.13.3.2.1.2',
  upsDiagBatteryStatus => '1.3.6.1.4.1.318.1.1.1.13.3.2.1.3',
  upsDiagBatteryStatusDefinition => 'PowerNet-MIB::upsDiagBatteryStatus',
  upsDiagBatterySerialNumber => '1.3.6.1.4.1.318.1.1.1.13.3.2.1.4',
  upsDiagBatteryFirmwareRev => '1.3.6.1.4.1.318.1.1.1.13.3.2.1.5',
  upsDiagBatteryManufactureDate => '1.3.6.1.4.1.318.1.1.1.13.3.2.1.6',
  upsDiagBatteryType => '1.3.6.1.4.1.318.1.1.1.13.3.2.1.7',
  upsDiagBatteryFramePresent => '1.3.6.1.4.1.318.1.1.1.13.3.2.1.8',
  upsDiagBatteryFramePresentDefinition => 'PowerNet-MIB::upsDiagBatteryFramePresent',
  upsDiagBatteryFrameTemperature => '1.3.6.1.4.1.318.1.1.1.13.3.2.1.9',
  upsDiagnosticSubsystem => '1.3.6.1.4.1.318.1.1.1.13.4',
  upsDiagSubSysFrameTableSize => '1.3.6.1.4.1.318.1.1.1.13.4.1',
  upsDiagSubSysFrameTable => '1.3.6.1.4.1.318.1.1.1.13.4.2',
  upsDiagSubSysFrameEntry => '1.3.6.1.4.1.318.1.1.1.13.4.2.1',
  upsDiagSubSysFrameIndex => '1.3.6.1.4.1.318.1.1.1.13.4.2.1.1',
  upsDiagSubSysFrameType => '1.3.6.1.4.1.318.1.1.1.13.4.2.1.2',
  upsDiagSubSysFrameTypeDefinition => 'PowerNet-MIB::upsDiagSubSysFrameType',
  upsDiagSubSysFrameFirmwareRev => '1.3.6.1.4.1.318.1.1.1.13.4.2.1.3',
  upsDiagSubSysFrameHardwareRev => '1.3.6.1.4.1.318.1.1.1.13.4.2.1.4',
  upsDiagSubSysFrameSerialNum => '1.3.6.1.4.1.318.1.1.1.13.4.2.1.5',
  upsDiagSubSysFrameManufactureDate => '1.3.6.1.4.1.318.1.1.1.13.4.2.1.6',
  upsDiagSubSysIntBypSwitchTableSize => '1.3.6.1.4.1.318.1.1.1.13.4.3',
  upsDiagSubSysIntBypSwitchTable => '1.3.6.1.4.1.318.1.1.1.13.4.4',
  upsDiagSubSysIntBypSwitchEntry => '1.3.6.1.4.1.318.1.1.1.13.4.4.1',
  upsDiagSubSysIntBypSwitchFrameIndex => '1.3.6.1.4.1.318.1.1.1.13.4.4.1.1',
  upsDiagSubSysIntBypSwitchIndex => '1.3.6.1.4.1.318.1.1.1.13.4.4.1.2',
  upsDiagSubSysIntBypSwitchStatus => '1.3.6.1.4.1.318.1.1.1.13.4.4.1.3',
  upsDiagSubSysIntBypSwitchStatusDefinition => 'PowerNet-MIB::upsDiagSubSysIntBypSwitchStatus',
  upsDiagSubSysIntBypSwitchFirmwareRev => '1.3.6.1.4.1.318.1.1.1.13.4.4.1.4',
  upsDiagSubSysIntBypSwitchHardwareRev => '1.3.6.1.4.1.318.1.1.1.13.4.4.1.5',
  upsDiagSubSysIntBypSwitchSerialNum => '1.3.6.1.4.1.318.1.1.1.13.4.4.1.6',
  upsDiagSubSysIntBypSwitchManufactureDate => '1.3.6.1.4.1.318.1.1.1.13.4.4.1.7',
  upsDiagSubSysBattMonitorTableSize => '1.3.6.1.4.1.318.1.1.1.13.4.5',
  upsDiagSubSysBattMonitorTable => '1.3.6.1.4.1.318.1.1.1.13.4.6',
  upsDiagSubSysBattMonitorEntry => '1.3.6.1.4.1.318.1.1.1.13.4.6.1',
  upsDiagSubSysBattMonitorFrameIndex => '1.3.6.1.4.1.318.1.1.1.13.4.6.1.1',
  upsDiagSubSysBattMonitorIndex => '1.3.6.1.4.1.318.1.1.1.13.4.6.1.2',
  upsDiagSubSysBattMonitorStatus => '1.3.6.1.4.1.318.1.1.1.13.4.6.1.3',
  upsDiagSubSysBattMonitorStatusDefinition => 'PowerNet-MIB::upsDiagSubSysBattMonitorStatus',
  upsDiagSubSysBattMonitorFirmwareRev => '1.3.6.1.4.1.318.1.1.1.13.4.6.1.4',
  upsDiagSubSysBattMonitorHardwareRev => '1.3.6.1.4.1.318.1.1.1.13.4.6.1.5',
  upsDiagSubSysBattMonitorSerialNum => '1.3.6.1.4.1.318.1.1.1.13.4.6.1.6',
  upsDiagSubSysBattMonitorManufactureDate => '1.3.6.1.4.1.318.1.1.1.13.4.6.1.7',
  upsDiagSubSysExternalSwitchGearTableSize => '1.3.6.1.4.1.318.1.1.1.13.4.7',
  upsDiagSubSysExternalSwitchGearTable => '1.3.6.1.4.1.318.1.1.1.13.4.8',
  upsDiagSubSysExternalSwitchGearEntry => '1.3.6.1.4.1.318.1.1.1.13.4.8.1',
  upsDiagSubSysExternalSwitchGearFrameIndex => '1.3.6.1.4.1.318.1.1.1.13.4.8.1.1',
  upsDiagSubSysExternalSwitchGearIndex => '1.3.6.1.4.1.318.1.1.1.13.4.8.1.2',
  upsDiagSubSysExternalSwitchGearStatus => '1.3.6.1.4.1.318.1.1.1.13.4.8.1.3',
  upsDiagSubSysExternalSwitchGearStatusDefinition => 'PowerNet-MIB::upsDiagSubSysExternalSwitchGearStatus',
  upsDiagSubSysExternalSwitchGearFirmwareRev => '1.3.6.1.4.1.318.1.1.1.13.4.8.1.4',
  upsDiagSubSysExternalSwitchGearHardwareRev => '1.3.6.1.4.1.318.1.1.1.13.4.8.1.5',
  upsDiagSubSysExternalSwitchGearSerialNum => '1.3.6.1.4.1.318.1.1.1.13.4.8.1.6',
  upsDiagSubSysExternalSwitchGearManufactureDate => '1.3.6.1.4.1.318.1.1.1.13.4.8.1.7',
  upsDiagSubSysDisplayInterfaceCardTableSize => '1.3.6.1.4.1.318.1.1.1.13.4.9',
  upsDiagSubSysDisplayInterfaceCardTable => '1.3.6.1.4.1.318.1.1.1.13.4.10',
  upsDiagSubSysDisplayInterfaceCardEntry => '1.3.6.1.4.1.318.1.1.1.13.4.10.1',
  upsDiagSubSysDisplayInterfaceCardFrameIndex => '1.3.6.1.4.1.318.1.1.1.13.4.10.1.1',
  upsDiagSubSysDisplayInterfaceCardIndex => '1.3.6.1.4.1.318.1.1.1.13.4.10.1.2',
  upsDiagSubSysDisplayInterfaceCardStatus => '1.3.6.1.4.1.318.1.1.1.13.4.10.1.3',
  upsDiagSubSysDisplayInterfaceCardStatusDefinition => 'PowerNet-MIB::upsDiagSubSysDisplayInterfaceCardStatus',
  upsDiagSubSysDCCircuitBreakerTableSize => '1.3.6.1.4.1.318.1.1.1.13.4.11',
  upsDiagSubSysDCCircuitBreakerTable => '1.3.6.1.4.1.318.1.1.1.13.4.12',
  upsDiagSubSysDCCircuitBreakerEntry => '1.3.6.1.4.1.318.1.1.1.13.4.12.1',
  upsDiagSubSysDCCircuitBreakerFrameIndex => '1.3.6.1.4.1.318.1.1.1.13.4.12.1.1',
  upsDiagSubSysDCCircuitBreakerIndex => '1.3.6.1.4.1.318.1.1.1.13.4.12.1.2',
  upsDiagSubSysDCCircuitBreakerStatus => '1.3.6.1.4.1.318.1.1.1.13.4.12.1.3',
  upsDiagSubSysDCCircuitBreakerStatusDefinition => 'PowerNet-MIB::upsDiagSubSysDCCircuitBreakerStatus',
  upsDiagSubSysSystemPowerSupplyTableSize => '1.3.6.1.4.1.318.1.1.1.13.4.13',
  upsDiagSubSysSystemPowerSupplyTable => '1.3.6.1.4.1.318.1.1.1.13.4.14',
  upsDiagSubSysSystemPowerSupplyEntry => '1.3.6.1.4.1.318.1.1.1.13.4.14.1',
  upsDiagSubSysSystemPowerSupplyFrameIndex => '1.3.6.1.4.1.318.1.1.1.13.4.14.1.1',
  upsDiagSubSysSystemPowerSupplyIndex => '1.3.6.1.4.1.318.1.1.1.13.4.14.1.2',
  upsDiagSubSysSystemPowerSupplyStatus => '1.3.6.1.4.1.318.1.1.1.13.4.14.1.3',
  upsDiagSubSysSystemPowerSupplyStatusDefinition => 'PowerNet-MIB::upsDiagSubSysSystemPowerSupplyStatus',
  upsDiagSubSysSystemPowerSupplyFirmwareRev => '1.3.6.1.4.1.318.1.1.1.13.4.14.1.4',
  upsDiagSubSysSystemPowerSupplyHardwareRev => '1.3.6.1.4.1.318.1.1.1.13.4.14.1.5',
  upsDiagSubSysSystemPowerSupplySerialNum => '1.3.6.1.4.1.318.1.1.1.13.4.14.1.6',
  upsDiagSubSysSystemPowerSupplyManufactureDate => '1.3.6.1.4.1.318.1.1.1.13.4.14.1.7',
  upsDiagSubSysXRCommunicationCardTableSize => '1.3.6.1.4.1.318.1.1.1.13.4.15',
  upsDiagSubSysXRCommunicationCardTable => '1.3.6.1.4.1.318.1.1.1.13.4.16',
  upsDiagSubSysXRCommunicationCardEntry => '1.3.6.1.4.1.318.1.1.1.13.4.16.1',
  upsDiagSubSysXRCommunicationCardFrameIndex => '1.3.6.1.4.1.318.1.1.1.13.4.16.1.1',
  upsDiagSubSysXRCommunicationCardIndex => '1.3.6.1.4.1.318.1.1.1.13.4.16.1.2',
  upsDiagSubSysXRCommunicationCardStatus => '1.3.6.1.4.1.318.1.1.1.13.4.16.1.3',
  upsDiagSubSysXRCommunicationCardStatusDefinition => 'PowerNet-MIB::upsDiagSubSysXRCommunicationCardStatus',
  upsDiagSubSysXRCommunicationCardFirmwareRev => '1.3.6.1.4.1.318.1.1.1.13.4.16.1.4',
  upsDiagSubSysXRCommunicationCardSerialNum => '1.3.6.1.4.1.318.1.1.1.13.4.16.1.5',
  upsDiagSubSysExternalPowerFrameBoardTableSize => '1.3.6.1.4.1.318.1.1.1.13.4.17',
  upsDiagSubSysExternalPowerFrameBoardTable => '1.3.6.1.4.1.318.1.1.1.13.4.18',
  upsDiagSubSysExternalPowerFrameBoardEntry => '1.3.6.1.4.1.318.1.1.1.13.4.18.1',
  upsDiagSubSysExternalPowerFrameBoardFrameIndex => '1.3.6.1.4.1.318.1.1.1.13.4.18.1.1',
  upsDiagSubSysExternalPowerFrameBoardIndex => '1.3.6.1.4.1.318.1.1.1.13.4.18.1.2',
  upsDiagSubSysExternalPowerFrameBoardStatus => '1.3.6.1.4.1.318.1.1.1.13.4.18.1.3',
  upsDiagSubSysExternalPowerFrameBoardStatusDefinition => 'PowerNet-MIB::upsDiagSubSysExternalPowerFrameBoardStatus',
  upsDiagSubSysChargerTableSize => '1.3.6.1.4.1.318.1.1.1.13.4.19',
  upsDiagSubSysChargerTable => '1.3.6.1.4.1.318.1.1.1.13.4.20',
  upsDiagSubSysChargerEntry => '1.3.6.1.4.1.318.1.1.1.13.4.20.1',
  upsDiagSubSysChargerFrameIndex => '1.3.6.1.4.1.318.1.1.1.13.4.20.1.1',
  upsDiagSubSysChargerIndex => '1.3.6.1.4.1.318.1.1.1.13.4.20.1.2',
  upsDiagSubSysChargerStatus => '1.3.6.1.4.1.318.1.1.1.13.4.20.1.3',
  upsDiagSubSysChargerStatusDefinition => 'PowerNet-MIB::upsDiagSubSysChargerStatus',
  upsDiagSubSysInverterTableSize => '1.3.6.1.4.1.318.1.1.1.13.4.21',
  upsDiagSubSysInverterTable => '1.3.6.1.4.1.318.1.1.1.13.4.22',
  upsDiagSubSysInverterEntry => '1.3.6.1.4.1.318.1.1.1.13.4.22.1',
  upsDiagSubSysInverterFrameIndex => '1.3.6.1.4.1.318.1.1.1.13.4.22.1.1',
  upsDiagSubSysInverterIndex => '1.3.6.1.4.1.318.1.1.1.13.4.22.1.2',
  upsDiagSubSysInverterStatus => '1.3.6.1.4.1.318.1.1.1.13.4.22.1.3',
  upsDiagSubSysInverterStatusDefinition => 'PowerNet-MIB::upsDiagSubSysInverterStatus',
  upsDiagSubSysInverterFirmwareRev => '1.3.6.1.4.1.318.1.1.1.13.4.22.1.4',
  upsDiagSubSysInverterHardwareRev => '1.3.6.1.4.1.318.1.1.1.13.4.22.1.5',
  upsDiagSubSysInverterSerialNum => '1.3.6.1.4.1.318.1.1.1.13.4.22.1.6',
  upsDiagSubSysInverterManufactureDate => '1.3.6.1.4.1.318.1.1.1.13.4.22.1.7',
  upsDiagSubSysPowerFactorCorrectionTableSize => '1.3.6.1.4.1.318.1.1.1.13.4.23',
  upsDiagSubSysPowerFactorCorrectionTable => '1.3.6.1.4.1.318.1.1.1.13.4.24',
  upsDiagSubSysPowerFactorCorrectionEntry => '1.3.6.1.4.1.318.1.1.1.13.4.24.1',
  upsDiagSubSysPowerFactorCorrectionFrameIndex => '1.3.6.1.4.1.318.1.1.1.13.4.24.1.1',
  upsDiagSubSysPowerFactorCorrectionIndex => '1.3.6.1.4.1.318.1.1.1.13.4.24.1.2',
  upsDiagSubSysPowerFactorCorrectionStatus => '1.3.6.1.4.1.318.1.1.1.13.4.24.1.3',
  upsDiagSubSysPowerFactorCorrectionStatusDefinition => 'PowerNet-MIB::upsDiagSubSysPowerFactorCorrectionStatus',
  upsDiagSubSysPowerFactorCorrectionFirmwareRev => '1.3.6.1.4.1.318.1.1.1.13.4.24.1.4',
  upsDiagSubSysPowerFactorCorrectionHardwareRev => '1.3.6.1.4.1.318.1.1.1.13.4.24.1.5',
  upsDiagSubSysPowerFactorCorrectionSerialNum => '1.3.6.1.4.1.318.1.1.1.13.4.24.1.6',
  upsDiagSubSysPowerFactorCorrectionManufactureDate => '1.3.6.1.4.1.318.1.1.1.13.4.24.1.7',
  upsDiagSubSysNetworkComCardTableSize => '1.3.6.1.4.1.318.1.1.1.13.4.25',
  upsDiagSubSysNetworkComCardTable => '1.3.6.1.4.1.318.1.1.1.13.4.26',
  upsDiagSubSysNetworkComCardEntry => '1.3.6.1.4.1.318.1.1.1.13.4.26.1',
  upsDiagSubSysNetworkComCardIndex => '1.3.6.1.4.1.318.1.1.1.13.4.26.1.1',
  upsDiagSubSysNetworkComCardModelNumber => '1.3.6.1.4.1.318.1.1.1.13.4.26.1.2',
  upsDiagSubSysNetworkComCardSerialNumber => '1.3.6.1.4.1.318.1.1.1.13.4.26.1.3',
  upsDiagSubSysNetworkComCardDateOfManufacture => '1.3.6.1.4.1.318.1.1.1.13.4.26.1.4',
  upsDiagSubSysNetworkComCardHardwareRev => '1.3.6.1.4.1.318.1.1.1.13.4.26.1.5',
  upsDiagSubSysNetworkComCardFirmwareAppRev => '1.3.6.1.4.1.318.1.1.1.13.4.26.1.6',
  upsDiagSubSysNetworkComCardFirmwareAppOSRev => '1.3.6.1.4.1.318.1.1.1.13.4.26.1.7',
  upsDiagnosticExternalDevices => '1.3.6.1.4.1.318.1.1.1.13.5',
  upsDiagSwitchGear => '1.3.6.1.4.1.318.1.1.1.13.5.1',
  upsDiagSwitchGearStatus => '1.3.6.1.4.1.318.1.1.1.13.5.1.1',
  upsDiagSwitchGearStatusDefinition => 'PowerNet-MIB::upsDiagSwitchGearStatus',
  upsDiagSwitchGearInputSwitchStatus => '1.3.6.1.4.1.318.1.1.1.13.5.1.2',
  upsDiagSwitchGearInputSwitchStatusDefinition => 'PowerNet-MIB::upsDiagSwitchGearInputSwitchStatus',
  upsDiagSwitchGearOutputSwitchStatus => '1.3.6.1.4.1.318.1.1.1.13.5.1.3',
  upsDiagSwitchGearOutputSwitchStatusDefinition => 'PowerNet-MIB::upsDiagSwitchGearOutputSwitchStatus',
  upsDiagSwitchGearBypassSwitchStatus => '1.3.6.1.4.1.318.1.1.1.13.5.1.4',
  upsDiagSwitchGearBypassSwitchStatusDefinition => 'PowerNet-MIB::upsDiagSwitchGearBypassSwitchStatus',
  upsDiagSwitchGearBypassInputSwitchStatus => '1.3.6.1.4.1.318.1.1.1.13.5.1.5',
  upsDiagSwitchGearBypassInputSwitchStatusDefinition => 'PowerNet-MIB::upsDiagSwitchGearBypassInputSwitchStatus',
  upsDiagSwitchGearBreakerTableSize => '1.3.6.1.4.1.318.1.1.1.13.5.1.6',
  upsDiagSwitchGearBreakerTable => '1.3.6.1.4.1.318.1.1.1.13.5.1.7',
  upsDiagSwitchGearBreakerEntry => '1.3.6.1.4.1.318.1.1.1.13.5.1.7.1',
  switchgearBreakerIndex => '1.3.6.1.4.1.318.1.1.1.13.5.1.7.1.1',
  switchgearBreakerPresent => '1.3.6.1.4.1.318.1.1.1.13.5.1.7.1.2',
  switchgearBreakerPresentDefinition => 'PowerNet-MIB::switchgearBreakerPresent',
  switchgearBreakerName => '1.3.6.1.4.1.318.1.1.1.13.5.1.7.1.3',
  switchgearBreakerType => '1.3.6.1.4.1.318.1.1.1.13.5.1.7.1.4',
  switchgearBreakerTypeDefinition => 'PowerNet-MIB::switchgearBreakerType',
  switchgearBreakerStatus => '1.3.6.1.4.1.318.1.1.1.13.5.1.7.1.5',
  switchgearBreakerStatusDefinition => 'PowerNet-MIB::switchgearBreakerStatus',
  upsDiagSubFeedBreakerTableSize => '1.3.6.1.4.1.318.1.1.1.13.5.1.8',
  upsDiagSubFeedBreakerTable => '1.3.6.1.4.1.318.1.1.1.13.5.1.9',
  upsDiagSubFeedBreakerEntry => '1.3.6.1.4.1.318.1.1.1.13.5.1.9.1',
  subfeedBreakerIndex => '1.3.6.1.4.1.318.1.1.1.13.5.1.9.1.1',
  subfeedBreakerPresent => '1.3.6.1.4.1.318.1.1.1.13.5.1.9.1.2',
  subfeedBreakerPresentDefinition => 'PowerNet-MIB::subfeedBreakerPresent',
  subfeedBreakerRating => '1.3.6.1.4.1.318.1.1.1.13.5.1.9.1.3',
  subfeedBreakerUpperAcceptPowerWarning => '1.3.6.1.4.1.318.1.1.1.13.5.1.9.1.4',
  subfeedBreakerUpperAcceptPowerCritical => '1.3.6.1.4.1.318.1.1.1.13.5.1.9.1.5',
  subfeedBreakerStatus => '1.3.6.1.4.1.318.1.1.1.13.5.1.9.1.6',
  subfeedBreakerStatusDefinition => 'PowerNet-MIB::subfeedBreakerStatus',
  subfeedBreakerName => '1.3.6.1.4.1.318.1.1.1.13.5.1.9.1.7',
  upsDiagSwitchGearInstallationLoadPct => '1.3.6.1.4.1.318.1.1.1.13.5.1.10',
  upsDiagSubFeedPhaseTable => '1.3.6.1.4.1.318.1.1.1.13.5.1.11',
  upsDiagSubFeedPhaseEntry => '1.3.6.1.4.1.318.1.1.1.13.5.1.11.1',
  upsDiagSubFeedBreakerIndex => '1.3.6.1.4.1.318.1.1.1.13.5.1.11.1.1',
  upsDiagSubFeedPhaseIndex => '1.3.6.1.4.1.318.1.1.1.13.5.1.11.1.2',
  upsDiagSubFeedPhaseCurrent => '1.3.6.1.4.1.318.1.1.1.13.5.1.11.1.3',
  upsDiagSubFeedPhaseCurrentAlternate => '1.3.6.1.4.1.318.1.1.1.13.5.1.11.1.4',
  upsDiagSwitchgearSerialNumber => '1.3.6.1.4.1.318.1.1.1.13.5.1.12',
  upsDiagMCCBBox => '1.3.6.1.4.1.318.1.1.1.13.5.2',
  upsDiagMCCBBoxStatus => '1.3.6.1.4.1.318.1.1.1.13.5.2.1',
  upsDiagMCCBBoxStatusDefinition => 'PowerNet-MIB::upsDiagMCCBBoxStatus',
  upsDiagTransformer => '1.3.6.1.4.1.318.1.1.1.13.5.3',
  upsDiagTransformerStatus => '1.3.6.1.4.1.318.1.1.1.13.5.3.1',
  upsDiagTransformerStatusDefinition => 'PowerNet-MIB::upsDiagTransformerStatus',
  upsDiagFlyWheel => '1.3.6.1.4.1.318.1.1.1.13.5.4',
  upsDiagFlyWheelStatus => '1.3.6.1.4.1.318.1.1.1.13.5.4.1',
  upsDiagFlyWheelStatusDefinition => 'PowerNet-MIB::upsDiagFlyWheelStatus',
  upsDiagnosticComBus => '1.3.6.1.4.1.318.1.1.1.13.6',
  upsDiagComBusInternalMIMStatus => '1.3.6.1.4.1.318.1.1.1.13.6.1',
  upsDiagComBusInternalMIMStatusDefinition => 'PowerNet-MIB::upsDiagComBusInternalMIMStatus',
  upsDiagComBusInternalRIMStatus => '1.3.6.1.4.1.318.1.1.1.13.6.2',
  upsDiagComBusInternalRIMStatusDefinition => 'PowerNet-MIB::upsDiagComBusInternalRIMStatus',
  upsDiagComBusMIMtoRIMStatus => '1.3.6.1.4.1.318.1.1.1.13.6.3',
  upsDiagComBusMIMtoRIMStatusDefinition => 'PowerNet-MIB::upsDiagComBusMIMtoRIMStatus',
  upsDiagComBusExternalMIMStatus => '1.3.6.1.4.1.318.1.1.1.13.6.4',
  upsDiagComBusExternalMIMStatusDefinition => 'PowerNet-MIB::upsDiagComBusExternalMIMStatus',
  upsDiagComBusExternalRIMStatus => '1.3.6.1.4.1.318.1.1.1.13.6.5',
  upsDiagComBusExternalRIMStatusDefinition => 'PowerNet-MIB::upsDiagComBusExternalRIMStatus',
  upsParallelSystem => '1.3.6.1.4.1.318.1.1.1.14',
  upsParallelSysLocalAddress => '1.3.6.1.4.1.318.1.1.1.14.1',
  upsParallelSysRemoteAddress => '1.3.6.1.4.1.318.1.1.1.14.2',
  upsParallelSysRedundancy => '1.3.6.1.4.1.318.1.1.1.14.3',
  upsParallelSysRedundancyDefinition => 'PowerNet-MIB::upsParallelSysRedundancy',
  upsParallelInputMaximumCurrent => '1.3.6.1.4.1.318.1.1.1.14.4',
  upsParallelTotalOutputPower => '1.3.6.1.4.1.318.1.1.1.14.5',
  upsParallelTotalOutputApparentPower => '1.3.6.1.4.1.318.1.1.1.14.6',
  upsParallelInputPhaseTable => '1.3.6.1.4.1.318.1.1.1.14.7',
  upsParallelInputPhaseEntry => '1.3.6.1.4.1.318.1.1.1.14.7.1',
  upsParallelInputPhaseTableIndex => '1.3.6.1.4.1.318.1.1.1.14.7.1.1',
  upsParallelInputPhaseIndex => '1.3.6.1.4.1.318.1.1.1.14.7.1.2',
  upsParallelInputCurrent => '1.3.6.1.4.1.318.1.1.1.14.7.1.3',
  upsParallelInputActivePower => '1.3.6.1.4.1.318.1.1.1.14.7.1.4',
  upsParallelInputApparentPower => '1.3.6.1.4.1.318.1.1.1.14.7.1.5',
  upsParallelInputVoltage => '1.3.6.1.4.1.318.1.1.1.14.7.1.6',
  upsParallelInputMaxVoltage => '1.3.6.1.4.1.318.1.1.1.14.7.1.7',
  upsParallelInputMaxCurrent => '1.3.6.1.4.1.318.1.1.1.14.7.1.8',
  upsParallelInputTotalActivePower => '1.3.6.1.4.1.318.1.1.1.14.7.1.9',
  upsParallelInputTotalApparentPower => '1.3.6.1.4.1.318.1.1.1.14.7.1.10',
  upsParallelOutputPhaseTable => '1.3.6.1.4.1.318.1.1.1.14.8',
  upsParallelOutputPhaseEntry => '1.3.6.1.4.1.318.1.1.1.14.8.1',
  upsParallelOutputPhaseTableIndex => '1.3.6.1.4.1.318.1.1.1.14.8.1.1',
  upsParallelOutputPhaseIndex => '1.3.6.1.4.1.318.1.1.1.14.8.1.2',
  upsParallelOutputCurrent => '1.3.6.1.4.1.318.1.1.1.14.8.1.3',
  upsParallelOutputLoad => '1.3.6.1.4.1.318.1.1.1.14.8.1.4',
  upsParallelOutputPercentLoad => '1.3.6.1.4.1.318.1.1.1.14.8.1.5',
  upsParallelOutputPower => '1.3.6.1.4.1.318.1.1.1.14.8.1.6',
  upsParallelOutputApparentPowerTable => '1.3.6.1.4.1.318.1.1.1.14.9',
  upsParallelOutputApparentPowerEntry => '1.3.6.1.4.1.318.1.1.1.14.9.1',
  upsParallelOutputApparentPowerTableIndex => '1.3.6.1.4.1.318.1.1.1.14.9.1.1',
  upsParallelOutputApparentPower => '1.3.6.1.4.1.318.1.1.1.14.9.1.2',
  upsParallelDiagSubSysBreakerTable => '1.3.6.1.4.1.318.1.1.1.14.10',
  upsParallelDiagSubSysBreakerEntry => '1.3.6.1.4.1.318.1.1.1.14.10.1',
  upsParallelDiagSubSysBreakerFrameIndex => '1.3.6.1.4.1.318.1.1.1.14.10.1.1',
  upsParallelDiagSubSysBreakerIndex => '1.3.6.1.4.1.318.1.1.1.14.10.1.2',
  upsParallelDiagSubSysBreakerStatus => '1.3.6.1.4.1.318.1.1.1.14.10.1.3',
  upsParallelDiagSubSysBreakerStatusDefinition => 'PowerNet-MIB::upsParallelDiagSubSysBreakerStatus',
  upsParallelDiagSubSysBreakerName => '1.3.6.1.4.1.318.1.1.1.14.10.1.4',
  upsParallelOutputTotalPercentLoad => '1.3.6.1.4.1.318.1.1.1.14.11',
  upsParallelOutputActivePowerTable => '1.3.6.1.4.1.318.1.1.1.14.12',
  upsParallelOutputActivePowerEntry => '1.3.6.1.4.1.318.1.1.1.14.12.1',
  upsParallelOutputActivePowerTableIndex => '1.3.6.1.4.1.318.1.1.1.14.12.1.1',
  upsParallelOutputActivePower => '1.3.6.1.4.1.318.1.1.1.14.12.1.2',
  upsParallelSysSwitchGearInstallationLoadPct => '1.3.6.1.4.1.318.1.1.1.14.13',
  upsParallelSysRedundancyStatus => '1.3.6.1.4.1.318.1.1.1.14.14',
  upsParallelSysRedundancyStatusDefinition => 'PowerNet-MIB::upsParallelSysRedundancyStatus',
  upsParallelSysName => '1.3.6.1.4.1.318.1.1.1.14.15',
  upsPhysicalLayout => '1.3.6.1.4.1.318.1.1.1.15',
  upsIOFrameLayoutPositionID => '1.3.6.1.4.1.318.1.1.1.15.1',
  upsBottomFeedFrameLayoutPositionID => '1.3.6.1.4.1.318.1.1.1.15.2',
  upsSwitchGearLayoutPositionID => '1.3.6.1.4.1.318.1.1.1.15.3',
  upsBatteryFrameLayoutTableSize => '1.3.6.1.4.1.318.1.1.1.15.4',
  upsBatteryFrameLayoutTable => '1.3.6.1.4.1.318.1.1.1.15.5',
  upsBatteryFrameLayoutEntry => '1.3.6.1.4.1.318.1.1.1.15.5.1',
  batteryFrameIndex => '1.3.6.1.4.1.318.1.1.1.15.5.1.1',
  batteryFramePositionID => '1.3.6.1.4.1.318.1.1.1.15.5.1.2',
  upsSideCarFrameLayoutTableSize => '1.3.6.1.4.1.318.1.1.1.15.6',
  upsSideCarFrameLayoutTable => '1.3.6.1.4.1.318.1.1.1.15.7',
  upsSideCarFrameLayoutEntry => '1.3.6.1.4.1.318.1.1.1.15.7.1',
  sideCarFrameIndex => '1.3.6.1.4.1.318.1.1.1.15.7.1.1',
  sideCarFramePositionID => '1.3.6.1.4.1.318.1.1.1.15.7.1.2',
  upsPowerFrameLayoutTableSize => '1.3.6.1.4.1.318.1.1.1.15.8',
  upsPowerFrameLayoutTable => '1.3.6.1.4.1.318.1.1.1.15.9',
  upsPowerFrameLayoutEntry => '1.3.6.1.4.1.318.1.1.1.15.9.1',
  powerFrameIndex => '1.3.6.1.4.1.318.1.1.1.15.9.1.1',
  powerFramePositionID => '1.3.6.1.4.1.318.1.1.1.15.9.1.2',
  upsIntegratedATS => '1.3.6.1.4.1.318.1.1.1.16',
  upsIntegratedATSSelectedSource => '1.3.6.1.4.1.318.1.1.1.16.1',
  upsIntegratedATSSelectedSourceDefinition => 'PowerNet-MIB::upsIntegratedATSSelectedSource',
  upsIntegratedATSPreferredSource => '1.3.6.1.4.1.318.1.1.1.16.2',
  upsIntegratedATSPreferredSourceDefinition => 'PowerNet-MIB::upsIntegratedATSPreferredSource',
  upsIntegratedATSUpsReturnStaggering => '1.3.6.1.4.1.318.1.1.1.16.3',
  upsIntegratedATSSourceTableSize => '1.3.6.1.4.1.318.1.1.1.16.4',
  upsIntegratedATSSourceTable => '1.3.6.1.4.1.318.1.1.1.16.5',
  upsIntegratedATSSourceEntry => '1.3.6.1.4.1.318.1.1.1.16.5.1',
  upsIntegratedATSSourceIndex => '1.3.6.1.4.1.318.1.1.1.16.5.1.1',
  upsIntegratedATSSourceName => '1.3.6.1.4.1.318.1.1.1.16.5.1.2',
  upsIntegratedATSSourceStatus => '1.3.6.1.4.1.318.1.1.1.16.5.1.3',
  upsIntegratedATSSourceStatusDefinition => 'PowerNet-MIB::upsIntegratedATSSourceStatus',
  upsIntegratedATSLineFailDelay => '1.3.6.1.4.1.318.1.1.1.16.5.1.4',
  upsIntegratedATSLineStabilityDelay => '1.3.6.1.4.1.318.1.1.1.16.5.1.5',
  upsDCOutput => '1.3.6.1.4.1.318.1.1.1.17',
  upsDCOutputStatus => '1.3.6.1.4.1.318.1.1.1.17.1',
  upsDCOutputStatusTableSize => '1.3.6.1.4.1.318.1.1.1.17.1.1',
  upsDCOutputStatusTable => '1.3.6.1.4.1.318.1.1.1.17.1.2',
  upsDCOutputStatusEntry => '1.3.6.1.4.1.318.1.1.1.17.1.2.1',
  upsDCOutputStatusTableIndex => '1.3.6.1.4.1.318.1.1.1.17.1.2.1.1',
  upsDCOutputStatusVoltageNominal => '1.3.6.1.4.1.318.1.1.1.17.1.2.1.2',
  upsDCOutputStatusCurrentRating => '1.3.6.1.4.1.318.1.1.1.17.1.2.1.3',
  upsDCOutputStatusVoltage => '1.3.6.1.4.1.318.1.1.1.17.1.2.1.4',
  upsDCOutputStatusCurrent => '1.3.6.1.4.1.318.1.1.1.17.1.2.1.5',
  upsDCOutputStatusAbnormalConditions => '1.3.6.1.4.1.318.1.1.1.17.1.2.1.6',
  measureUps => '1.3.6.1.4.1.318.1.1.2',
  mUpsEnviron => '1.3.6.1.4.1.318.1.1.2.1',
  mUpsEnvironAmbientTemperature => '1.3.6.1.4.1.318.1.1.2.1.1',
  mUpsEnvironRelativeHumidity => '1.3.6.1.4.1.318.1.1.2.1.2',
  mUpsEnvironAmbientTemperature2 => '1.3.6.1.4.1.318.1.1.2.1.3',
  mUpsEnvironRelativeHumidity2 => '1.3.6.1.4.1.318.1.1.2.1.4',
  mUpsContact => '1.3.6.1.4.1.318.1.1.2.2',
  mUpsContactNumContacts => '1.3.6.1.4.1.318.1.1.2.2.1',
  mUpsContactTable => '1.3.6.1.4.1.318.1.1.2.2.2',
  mUpsContactEntry => '1.3.6.1.4.1.318.1.1.2.2.2.1',
  contactNumber => '1.3.6.1.4.1.318.1.1.2.2.2.1.1',
  normalState => '1.3.6.1.4.1.318.1.1.2.2.2.1.2',
  normalStateDefinition => 'PowerNet-MIB::normalState',
  description => '1.3.6.1.4.1.318.1.1.2.2.2.1.3',
  monitoringStatus => '1.3.6.1.4.1.318.1.1.2.2.2.1.4',
  monitoringStatusDefinition => 'PowerNet-MIB::monitoringStatus',
  currentStatus => '1.3.6.1.4.1.318.1.1.2.2.2.1.5',
  currentStatusDefinition => 'PowerNet-MIB::currentStatus',
  miniSNMPadapter => '1.3.6.1.4.1.318.1.1.3',
  serialPort => '1.3.6.1.4.1.318.1.1.3.1',
  serialPort1 => '1.3.6.1.4.1.318.1.1.3.1.1',
  serialPort2 => '1.3.6.1.4.1.318.1.1.3.1.2',
  serialPort2Config => '1.3.6.1.4.1.318.1.1.3.1.2.1',
  serialPort2Mode => '1.3.6.1.4.1.318.1.1.3.1.2.1.1',
  serialPort2ModeDefinition => 'PowerNet-MIB::serialPort2Mode',
  serialPort2Control => '1.3.6.1.4.1.318.1.1.3.1.2.2',
  setPulseOnTXD => '1.3.6.1.4.1.318.1.1.3.1.2.2.1',
  setPulseOnTXDDefinition => 'PowerNet-MIB::setPulseOnTXD',
  masterswitch => '1.3.6.1.4.1.318.1.1.4',
  sPDUIdent => '1.3.6.1.4.1.318.1.1.4.1',
  sPDUIdentHardwareRev => '1.3.6.1.4.1.318.1.1.4.1.1',
  sPDUIdentFirmwareRev => '1.3.6.1.4.1.318.1.1.4.1.2',
  sPDUIdentDateOfManufacture => '1.3.6.1.4.1.318.1.1.4.1.3',
  sPDUIdentModelNumber => '1.3.6.1.4.1.318.1.1.4.1.4',
  sPDUIdentSerialNumber => '1.3.6.1.4.1.318.1.1.4.1.5',
  sPDUMasterControl => '1.3.6.1.4.1.318.1.1.4.2',
  sPDUMasterControlSwitch => '1.3.6.1.4.1.318.1.1.4.2.1',
  sPDUMasterControlSwitchDefinition => 'PowerNet-MIB::sPDUMasterControlSwitch',
  sPDUMasterState => '1.3.6.1.4.1.318.1.1.4.2.2',
  sPDUMasterPending => '1.3.6.1.4.1.318.1.1.4.2.3',
  sPDUMasterConfig => '1.3.6.1.4.1.318.1.1.4.3',
  sPDUMasterConfigPowerOn => '1.3.6.1.4.1.318.1.1.4.3.1',
  sPDUMasterConfigReboot => '1.3.6.1.4.1.318.1.1.4.3.2',
  sPDUMasterConfigPDUName => '1.3.6.1.4.1.318.1.1.4.3.3',
  sPDUOutletControl => '1.3.6.1.4.1.318.1.1.4.4',
  sPDUOutletControlTableSize => '1.3.6.1.4.1.318.1.1.4.4.1',
  sPDUOutletControlTable => '1.3.6.1.4.1.318.1.1.4.4.2',
  sPDUOutletControlEntry => '1.3.6.1.4.1.318.1.1.4.4.2.1',
  sPDUOutletControlIndex => '1.3.6.1.4.1.318.1.1.4.4.2.1.1',
  sPDUOutletPending => '1.3.6.1.4.1.318.1.1.4.4.2.1.2',
  sPDUOutletPendingDefinition => 'PowerNet-MIB::sPDUOutletPending',
  sPDUOutletCtl => '1.3.6.1.4.1.318.1.1.4.4.2.1.3',
  sPDUOutletCtlDefinition => 'PowerNet-MIB::sPDUOutletCtl',
  sPDUOutletCtlName => '1.3.6.1.4.1.318.1.1.4.4.2.1.4',
  sPDUOutletConfig => '1.3.6.1.4.1.318.1.1.4.5',
  sPDUOutletConfigTableSize => '1.3.6.1.4.1.318.1.1.4.5.1',
  sPDUOutletConfigTable => '1.3.6.1.4.1.318.1.1.4.5.2',
  sPDUOutletConfigEntry => '1.3.6.1.4.1.318.1.1.4.5.2.1',
  sPDUOutletConfigIndex => '1.3.6.1.4.1.318.1.1.4.5.2.1.1',
  sPDUOutletPowerOnTime => '1.3.6.1.4.1.318.1.1.4.5.2.1.2',
  sPDUOutletName => '1.3.6.1.4.1.318.1.1.4.5.2.1.3',
  sPDUOutletPowerOffTime => '1.3.6.1.4.1.318.1.1.4.5.2.1.4',
  sPDUOutletRebootDuration => '1.3.6.1.4.1.318.1.1.4.5.2.1.5',
  masterswitchVM => '1.3.6.1.4.1.318.1.1.5',
  sPDUIdentVM => '1.3.6.1.4.1.318.1.1.5.1',
  sPDUIdentVMTableSize => '1.3.6.1.4.1.318.1.1.5.1.1',
  sPDUIdentVMTable => '1.3.6.1.4.1.318.1.1.5.1.2',
  sPDUIdentVMEntry => '1.3.6.1.4.1.318.1.1.5.1.2.1',
  sPDUIdentVMIndex => '1.3.6.1.4.1.318.1.1.5.1.2.1.1',
  sPDUIdentNameVM => '1.3.6.1.4.1.318.1.1.5.1.2.1.2',
  sPDUIdentHardwareRevVM => '1.3.6.1.4.1.318.1.1.5.1.2.1.3',
  sPDUIdentFirmwareRevVM => '1.3.6.1.4.1.318.1.1.5.1.2.1.4',
  sPDUIdentDateOfManufactureVM => '1.3.6.1.4.1.318.1.1.5.1.2.1.5',
  sPDUIdentModelNumberVM => '1.3.6.1.4.1.318.1.1.5.1.2.1.6',
  sPDUIdentSerialNumberVM => '1.3.6.1.4.1.318.1.1.5.1.2.1.7',
  sPDUMasterControlVM => '1.3.6.1.4.1.318.1.1.5.2',
  sPDUMasterControlVMTableSize => '1.3.6.1.4.1.318.1.1.5.2.1',
  sPDUMasterControlVMTable => '1.3.6.1.4.1.318.1.1.5.2.2',
  sPDUMasterControlVMEntry => '1.3.6.1.4.1.318.1.1.5.2.2.1',
  sPDUMasterControlVMIndex => '1.3.6.1.4.1.318.1.1.5.2.2.1.1',
  sPDUMasterControlVMName => '1.3.6.1.4.1.318.1.1.5.2.2.1.2',
  sPDUMasterControlVMCommand => '1.3.6.1.4.1.318.1.1.5.2.2.1.3',
  sPDUMasterControlVMCommandDefinition => 'PowerNet-MIB::sPDUMasterControlVMCommand',
  sPDUMasterConfigVM => '1.3.6.1.4.1.318.1.1.5.3',
  sPDUMasterConfigVMTableSize => '1.3.6.1.4.1.318.1.1.5.3.1',
  sPDUMasterConfigVMTable => '1.3.6.1.4.1.318.1.1.5.3.2',
  sPDUMasterConfigVMEntry => '1.3.6.1.4.1.318.1.1.5.3.2.1',
  sPDUMasterConfigVMIndex => '1.3.6.1.4.1.318.1.1.5.3.2.1.1',
  sPDUMasterConfigVMName => '1.3.6.1.4.1.318.1.1.5.3.2.1.2',
  sPDUMasterConfigVMColdstartDelay => '1.3.6.1.4.1.318.1.1.5.3.2.1.3',
  sPDUMasterConfigVMAudioAlarmActivated => '1.3.6.1.4.1.318.1.1.5.3.2.1.4',
  sPDUMasterConfigVMAudioAlarmActivatedDefinition => 'PowerNet-MIB::sPDUMasterConfigVMAudioAlarmActivated',
  sPDUMasterConfigVMHighLoadWarningThreshold => '1.3.6.1.4.1.318.1.1.5.3.2.1.5',
  sPDUMasterConfigVMLowLoadWarningThreshold => '1.3.6.1.4.1.318.1.1.5.3.2.1.6',
  sPDUMasterConfigVMOverloadRestriction => '1.3.6.1.4.1.318.1.1.5.3.2.1.7',
  sPDUMasterConfigVMOverloadRestrictionDefinition => 'PowerNet-MIB::sPDUMasterConfigVMOverloadRestriction',
  sPDUMasterStatusVM => '1.3.6.1.4.1.318.1.1.5.4',
  sPDUMasterStatusVMTableSize => '1.3.6.1.4.1.318.1.1.5.4.1',
  sPDUMasterStatusVMTable => '1.3.6.1.4.1.318.1.1.5.4.2',
  sPDUMasterStatusVMEntry => '1.3.6.1.4.1.318.1.1.5.4.2.1',
  sPDUMasterStatusVMIndex => '1.3.6.1.4.1.318.1.1.5.4.2.1.1',
  sPDUMasterStatusVMName => '1.3.6.1.4.1.318.1.1.5.4.2.1.2',
  sPDUMasterStatusVMCommandPending => '1.3.6.1.4.1.318.1.1.5.4.2.1.3',
  sPDUMasterStatusVMCommandPendingDefinition => 'PowerNet-MIB::sPDUMasterStatusVMCommandPending',
  sPDUMasterStatusVMOverloadCondition => '1.3.6.1.4.1.318.1.1.5.4.2.1.4',
  sPDUMasterStatusVMOverloadConditionDefinition => 'PowerNet-MIB::sPDUMasterStatusVMOverloadCondition',
  sPDUMasterStatusVMLowLoadCondition => '1.3.6.1.4.1.318.1.1.5.4.2.1.5',
  sPDUMasterStatusVMLowLoadConditionDefinition => 'PowerNet-MIB::sPDUMasterStatusVMLowLoadCondition',
  sPDUMasterStatusVMCurrentLoad => '1.3.6.1.4.1.318.1.1.5.4.2.1.6',
  sPDUMasterStatusVMMaxLoad => '1.3.6.1.4.1.318.1.1.5.4.2.1.7',
  sPDUMasterStatusVMOutletCount => '1.3.6.1.4.1.318.1.1.5.4.2.1.8',
  sPDUMasterStatusVMRebootDuration => '1.3.6.1.4.1.318.1.1.5.4.2.1.9',
  sPDUOutletControlVM => '1.3.6.1.4.1.318.1.1.5.5',
  sPDUOutletControlVMTable => '1.3.6.1.4.1.318.1.1.5.5.1',
  sPDUOutletControlVMEntry => '1.3.6.1.4.1.318.1.1.5.5.1.1',
  sPDUOutletControlVMIndex => '1.3.6.1.4.1.318.1.1.5.5.1.1.1',
  sPDUOutletControlVMName => '1.3.6.1.4.1.318.1.1.5.5.1.1.2',
  sPDUOutletControlVMOutletIndex => '1.3.6.1.4.1.318.1.1.5.5.1.1.3',
  sPDUOutletControlVMOutletName => '1.3.6.1.4.1.318.1.1.5.5.1.1.4',
  sPDUOutletControlVMOutletCommand => '1.3.6.1.4.1.318.1.1.5.5.1.1.5',
  sPDUOutletControlVMOutletCommandDefinition => 'PowerNet-MIB::sPDUOutletControlVMOutletCommand',
  sPDUOutletConfigVM => '1.3.6.1.4.1.318.1.1.5.6',
  sPDUOutletConfigVMTable => '1.3.6.1.4.1.318.1.1.5.6.1',
  sPDUOutletConfigVMEntry => '1.3.6.1.4.1.318.1.1.5.6.1.1',
  sPDUOutletConfigVMIndex => '1.3.6.1.4.1.318.1.1.5.6.1.1.1',
  sPDUOutletConfigVMName => '1.3.6.1.4.1.318.1.1.5.6.1.1.2',
  sPDUOutletConfigVMOutletIndex => '1.3.6.1.4.1.318.1.1.5.6.1.1.3',
  sPDUOutletConfigVMOutletName => '1.3.6.1.4.1.318.1.1.5.6.1.1.4',
  sPDUOutletConfigVMPowerOnTime => '1.3.6.1.4.1.318.1.1.5.6.1.1.5',
  sPDUOutletConfigVMPowerOffTime => '1.3.6.1.4.1.318.1.1.5.6.1.1.6',
  sPDUOutletConfigVMRebootDuration => '1.3.6.1.4.1.318.1.1.5.6.1.1.7',
  sPDUOutletStatusVM => '1.3.6.1.4.1.318.1.1.5.7',
  sPDUOutletStatusVMTable => '1.3.6.1.4.1.318.1.1.5.7.1',
  sPDUOutletStatusVMEntry => '1.3.6.1.4.1.318.1.1.5.7.1.1',
  sPDUOutletStatusVMIndex => '1.3.6.1.4.1.318.1.1.5.7.1.1.1',
  sPDUOutletStatusVMName => '1.3.6.1.4.1.318.1.1.5.7.1.1.2',
  sPDUOutletStatusVMOutletIndex => '1.3.6.1.4.1.318.1.1.5.7.1.1.3',
  sPDUOutletStatusVMOutletName => '1.3.6.1.4.1.318.1.1.5.7.1.1.4',
  sPDUOutletStatusVMOutletState => '1.3.6.1.4.1.318.1.1.5.7.1.1.5',
  sPDUOutletStatusVMOutletStateDefinition => 'PowerNet-MIB::sPDUOutletStatusVMOutletState',
  sPDUOutletStatusVMCommandPending => '1.3.6.1.4.1.318.1.1.5.7.1.1.6',
  sPDUOutletStatusVMCommandPendingDefinition => 'PowerNet-MIB::sPDUOutletStatusVMCommandPending',
  masterswitchMSP => '1.3.6.1.4.1.318.1.1.6',
  sPDUIdentMSP => '1.3.6.1.4.1.318.1.1.6.1',
  sPDUIdentMSPTableSize => '1.3.6.1.4.1.318.1.1.6.1.1',
  sPDUIdentMSPTable => '1.3.6.1.4.1.318.1.1.6.1.2',
  sPDUIdentMSPEntry => '1.3.6.1.4.1.318.1.1.6.1.2.1',
  sPDUIdentMSPIndex => '1.3.6.1.4.1.318.1.1.6.1.2.1.1',
  sPDUIdentNameMSP => '1.3.6.1.4.1.318.1.1.6.1.2.1.2',
  sPDUIdentHardwareRevMSP => '1.3.6.1.4.1.318.1.1.6.1.2.1.3',
  sPDUIdentFirmwareRevMSP => '1.3.6.1.4.1.318.1.1.6.1.2.1.4',
  sPDUIdentDateOfManufactureMSP => '1.3.6.1.4.1.318.1.1.6.1.2.1.5',
  sPDUIdentModelNumberMSP => '1.3.6.1.4.1.318.1.1.6.1.2.1.6',
  sPDUIdentSerialNumberMSP => '1.3.6.1.4.1.318.1.1.6.1.2.1.7',
  sPDUMasterControlMSP => '1.3.6.1.4.1.318.1.1.6.2',
  sPDUMasterControlMSPTableSize => '1.3.6.1.4.1.318.1.1.6.2.1',
  sPDUMasterControlMSPTable => '1.3.6.1.4.1.318.1.1.6.2.2',
  sPDUMasterControlMSPEntry => '1.3.6.1.4.1.318.1.1.6.2.2.1',
  sPDUMasterControlMSPIndex => '1.3.6.1.4.1.318.1.1.6.2.2.1.1',
  sPDUMasterControlMSPName => '1.3.6.1.4.1.318.1.1.6.2.2.1.2',
  sPDUMasterControlMSPCommand => '1.3.6.1.4.1.318.1.1.6.2.2.1.3',
  sPDUMasterControlMSPCommandDefinition => 'PowerNet-MIB::sPDUMasterControlMSPCommand',
  sPDUMasterConfigMSP => '1.3.6.1.4.1.318.1.1.6.3',
  sPDUMasterConfigMSPTableSize => '1.3.6.1.4.1.318.1.1.6.3.1',
  sPDUMasterConfigMSPTable => '1.3.6.1.4.1.318.1.1.6.3.2',
  sPDUMasterConfigMSPEntry => '1.3.6.1.4.1.318.1.1.6.3.2.1',
  sPDUMasterConfigMSPIndex => '1.3.6.1.4.1.318.1.1.6.3.2.1.1',
  sPDUMasterConfigMSPName => '1.3.6.1.4.1.318.1.1.6.3.2.1.2',
  sPDUMasterConfigMSPPowerOnTimeDelay => '1.3.6.1.4.1.318.1.1.6.3.2.1.3',
  sPDUMasterConfigMSPManualButton => '1.3.6.1.4.1.318.1.1.6.3.2.1.4',
  sPDUMasterConfigMSPManualButtonDefinition => 'PowerNet-MIB::sPDUMasterConfigMSPManualButton',
  sPDUMasterStatusMSP => '1.3.6.1.4.1.318.1.1.6.4',
  sPDUMasterStatusMSPTableSize => '1.3.6.1.4.1.318.1.1.6.4.1',
  sPDUMasterStatusMSPTable => '1.3.6.1.4.1.318.1.1.6.4.2',
  sPDUMasterStatusMSPEntry => '1.3.6.1.4.1.318.1.1.6.4.2.1',
  sPDUMasterStatusMSPIndex => '1.3.6.1.4.1.318.1.1.6.4.2.1.1',
  sPDUMasterStatusMSPName => '1.3.6.1.4.1.318.1.1.6.4.2.1.2',
  sPDUMasterStatusMSPOutletCount => '1.3.6.1.4.1.318.1.1.6.4.2.1.3',
  sPDUOutletControlMSP => '1.3.6.1.4.1.318.1.1.6.5',
  sPDUOutletControlMSPTable => '1.3.6.1.4.1.318.1.1.6.5.1',
  sPDUOutletControlMSPEntry => '1.3.6.1.4.1.318.1.1.6.5.1.1',
  sPDUOutletControlMSPIndex => '1.3.6.1.4.1.318.1.1.6.5.1.1.1',
  sPDUOutletControlMSPName => '1.3.6.1.4.1.318.1.1.6.5.1.1.2',
  sPDUOutletControlMSPOutletIndex => '1.3.6.1.4.1.318.1.1.6.5.1.1.3',
  sPDUOutletControlMSPOutletName => '1.3.6.1.4.1.318.1.1.6.5.1.1.4',
  sPDUOutletControlMSPOutletCommand => '1.3.6.1.4.1.318.1.1.6.5.1.1.5',
  sPDUOutletControlMSPOutletCommandDefinition => 'PowerNet-MIB::sPDUOutletControlMSPOutletCommand',
  sPDUOutletConfigMSP => '1.3.6.1.4.1.318.1.1.6.6',
  sPDUOutletConfigMSPall => '1.3.6.1.4.1.318.1.1.6.6.1',
  sPDUOutletConfigMSPallTable => '1.3.6.1.4.1.318.1.1.6.6.1.1',
  sPDUOutletConfigMSPallEntry => '1.3.6.1.4.1.318.1.1.6.6.1.1.1',
  sPDUOutletConfigMSPallIndex => '1.3.6.1.4.1.318.1.1.6.6.1.1.1.1',
  sPDUOutletConfigMSPallName => '1.3.6.1.4.1.318.1.1.6.6.1.1.1.2',
  sPDUOutletConfigMSPallOutletIndex => '1.3.6.1.4.1.318.1.1.6.6.1.1.1.3',
  sPDUOutletConfigMSPallOutletName => '1.3.6.1.4.1.318.1.1.6.6.1.1.1.4',
  sPDUOutletConfigMSPallOutletCtrlMode => '1.3.6.1.4.1.318.1.1.6.6.1.1.1.5',
  sPDUOutletConfigMSPallOutletCtrlModeDefinition => 'PowerNet-MIB::sPDUOutletConfigMSPallOutletCtrlMode',
  sPDUOutletConfigMSPgs => '1.3.6.1.4.1.318.1.1.6.6.2',
  sPDUOutletConfigMSPgsTable => '1.3.6.1.4.1.318.1.1.6.6.2.1',
  sPDUOutletConfigMSPgsEntry => '1.3.6.1.4.1.318.1.1.6.6.2.1.1',
  sPDUOutletConfigMSPgsIndex => '1.3.6.1.4.1.318.1.1.6.6.2.1.1.1',
  sPDUOutletConfigMSPgsName => '1.3.6.1.4.1.318.1.1.6.6.2.1.1.2',
  sPDUOutletConfigMSPgsOutletIndex => '1.3.6.1.4.1.318.1.1.6.6.2.1.1.3',
  sPDUOutletConfigMSPgsOutletName => '1.3.6.1.4.1.318.1.1.6.6.2.1.1.4',
  sPDUOutletConfigMSPgsOutletCtrlMode => '1.3.6.1.4.1.318.1.1.6.6.2.1.1.5',
  sPDUOutletConfigMSPgsOutletCtrlModeDefinition => 'PowerNet-MIB::sPDUOutletConfigMSPgsOutletCtrlMode',
  sPDUOutletConfigMSPgsDeviceConfirm => '1.3.6.1.4.1.318.1.1.6.6.2.1.1.6',
  sPDUOutletConfigMSPgsDeviceConfirmDefinition => 'PowerNet-MIB::sPDUOutletConfigMSPgsDeviceConfirm',
  sPDUOutletConfigMSPgsLowBattWarning => '1.3.6.1.4.1.318.1.1.6.6.2.1.1.7',
  sPDUOutletConfigMSPgsLowBattMult => '1.3.6.1.4.1.318.1.1.6.6.2.1.1.8',
  sPDUOutletConfigMSPgsRestartDelay => '1.3.6.1.4.1.318.1.1.6.6.2.1.1.9',
  sPDUOutletConfigMSPgsPowerOnDelay => '1.3.6.1.4.1.318.1.1.6.6.2.1.1.10',
  sPDUOutletConfigMSPgsPowerOffDelay => '1.3.6.1.4.1.318.1.1.6.6.2.1.1.11',
  sPDUOutletConfigMSPgsBattCapThresh => '1.3.6.1.4.1.318.1.1.6.6.2.1.1.12',
  sPDUOutletConfigMSPgsRebootDuration => '1.3.6.1.4.1.318.1.1.6.6.2.1.1.13',
  sPDUOutletConfigMSPannun => '1.3.6.1.4.1.318.1.1.6.6.3',
  sPDUOutletConfigMSPannunTable => '1.3.6.1.4.1.318.1.1.6.6.3.1',
  sPDUOutletConfigMSPannunEntry => '1.3.6.1.4.1.318.1.1.6.6.3.1.1',
  sPDUOutletConfigMSPannunIndex => '1.3.6.1.4.1.318.1.1.6.6.3.1.1.1',
  sPDUOutletConfigMSPannunName => '1.3.6.1.4.1.318.1.1.6.6.3.1.1.2',
  sPDUOutletConfigMSPannunOutletIndex => '1.3.6.1.4.1.318.1.1.6.6.3.1.1.3',
  sPDUOutletConfigMSPannunOutletName => '1.3.6.1.4.1.318.1.1.6.6.3.1.1.4',
  sPDUOutletConfigMSPannunOutletCtrlMode => '1.3.6.1.4.1.318.1.1.6.6.3.1.1.5',
  sPDUOutletConfigMSPannunOutletCtrlModeDefinition => 'PowerNet-MIB::sPDUOutletConfigMSPannunOutletCtrlMode',
  sPDUOutletConfigMSPannunInitialState => '1.3.6.1.4.1.318.1.1.6.6.3.1.1.6',
  sPDUOutletConfigMSPannunInitialStateDefinition => 'PowerNet-MIB::sPDUOutletConfigMSPannunInitialState',
  sPDUOutletConfigMSPannunAlarmActionDly => '1.3.6.1.4.1.318.1.1.6.6.3.1.1.7',
  sPDUOutletConfigMSPmups => '1.3.6.1.4.1.318.1.1.6.6.4',
  sPDUOutletConfigMSPmupsTable => '1.3.6.1.4.1.318.1.1.6.6.4.1',
  sPDUOutletConfigMSPmupsEntry => '1.3.6.1.4.1.318.1.1.6.6.4.1.1',
  sPDUOutletConfigMSPmupsIndex => '1.3.6.1.4.1.318.1.1.6.6.4.1.1.1',
  sPDUOutletConfigMSPmupsName => '1.3.6.1.4.1.318.1.1.6.6.4.1.1.2',
  sPDUOutletConfigMSPmupsOutletIndex => '1.3.6.1.4.1.318.1.1.6.6.4.1.1.3',
  sPDUOutletConfigMSPmupsOutletName => '1.3.6.1.4.1.318.1.1.6.6.4.1.1.4',
  sPDUOutletConfigMSPmupsZone1 => '1.3.6.1.4.1.318.1.1.6.6.4.1.1.5',
  sPDUOutletConfigMSPmupsZone1Definition => 'PowerNet-MIB::sPDUOutletConfigMSPmupsZone1',
  sPDUOutletConfigMSPmupsZone2 => '1.3.6.1.4.1.318.1.1.6.6.4.1.1.6',
  sPDUOutletConfigMSPmupsZone2Definition => 'PowerNet-MIB::sPDUOutletConfigMSPmupsZone2',
  sPDUOutletConfigMSPmupsZone3 => '1.3.6.1.4.1.318.1.1.6.6.4.1.1.7',
  sPDUOutletConfigMSPmupsZone3Definition => 'PowerNet-MIB::sPDUOutletConfigMSPmupsZone3',
  sPDUOutletConfigMSPmupsZone4 => '1.3.6.1.4.1.318.1.1.6.6.4.1.1.8',
  sPDUOutletConfigMSPmupsZone4Definition => 'PowerNet-MIB::sPDUOutletConfigMSPmupsZone4',
  sPDUOutletConfigMSPmupsP1LowHum => '1.3.6.1.4.1.318.1.1.6.6.4.1.1.9',
  sPDUOutletConfigMSPmupsP1LowHumDefinition => 'PowerNet-MIB::sPDUOutletConfigMSPmupsP1LowHum',
  sPDUOutletConfigMSPmupsP1HiHum => '1.3.6.1.4.1.318.1.1.6.6.4.1.1.10',
  sPDUOutletConfigMSPmupsP1HiHumDefinition => 'PowerNet-MIB::sPDUOutletConfigMSPmupsP1HiHum',
  sPDUOutletConfigMSPmupsP1LowTemp => '1.3.6.1.4.1.318.1.1.6.6.4.1.1.11',
  sPDUOutletConfigMSPmupsP1LowTempDefinition => 'PowerNet-MIB::sPDUOutletConfigMSPmupsP1LowTemp',
  sPDUOutletConfigMSPmupsP1HiTemp => '1.3.6.1.4.1.318.1.1.6.6.4.1.1.12',
  sPDUOutletConfigMSPmupsP1HiTempDefinition => 'PowerNet-MIB::sPDUOutletConfigMSPmupsP1HiTemp',
  sPDUOutletConfigMSPmupsP2LowHum => '1.3.6.1.4.1.318.1.1.6.6.4.1.1.13',
  sPDUOutletConfigMSPmupsP2LowHumDefinition => 'PowerNet-MIB::sPDUOutletConfigMSPmupsP2LowHum',
  sPDUOutletConfigMSPmupsP2HiHum => '1.3.6.1.4.1.318.1.1.6.6.4.1.1.14',
  sPDUOutletConfigMSPmupsP2HiHumDefinition => 'PowerNet-MIB::sPDUOutletConfigMSPmupsP2HiHum',
  sPDUOutletConfigMSPmupsP2LowTemp => '1.3.6.1.4.1.318.1.1.6.6.4.1.1.15',
  sPDUOutletConfigMSPmupsP2LowTempDefinition => 'PowerNet-MIB::sPDUOutletConfigMSPmupsP2LowTemp',
  sPDUOutletConfigMSPmupsP2HiTemp => '1.3.6.1.4.1.318.1.1.6.6.4.1.1.16',
  sPDUOutletConfigMSPmupsP2HiTempDefinition => 'PowerNet-MIB::sPDUOutletConfigMSPmupsP2HiTemp',
  sPDUOutletStatusMSP => '1.3.6.1.4.1.318.1.1.6.7',
  sPDUOutletStatusMSPTable => '1.3.6.1.4.1.318.1.1.6.7.1',
  sPDUOutletStatusMSPEntry => '1.3.6.1.4.1.318.1.1.6.7.1.1',
  sPDUOutletStatusMSPIndex => '1.3.6.1.4.1.318.1.1.6.7.1.1.1',
  sPDUOutletStatusMSPName => '1.3.6.1.4.1.318.1.1.6.7.1.1.2',
  sPDUOutletStatusMSPOutletIndex => '1.3.6.1.4.1.318.1.1.6.7.1.1.3',
  sPDUOutletStatusMSPOutletName => '1.3.6.1.4.1.318.1.1.6.7.1.1.4',
  sPDUOutletStatusMSPOutletState => '1.3.6.1.4.1.318.1.1.6.7.1.1.5',
  sPDUOutletStatusMSPOutletStateDefinition => 'PowerNet-MIB::sPDUOutletStatusMSPOutletState',
  sPDUOutletStatusMSPCommandPending => '1.3.6.1.4.1.318.1.1.6.7.1.1.6',
  sPDUOutletStatusMSPCommandPendingDefinition => 'PowerNet-MIB::sPDUOutletStatusMSPCommandPending',
  sPDUOutletStatusMSPOutletCtrlMode => '1.3.6.1.4.1.318.1.1.6.7.1.1.7',
  sPDUOutletStatusMSPOutletCtrlModeDefinition => 'PowerNet-MIB::sPDUOutletStatusMSPOutletCtrlMode',
  dcDM3 => '1.3.6.1.4.1.318.1.1.7',
  dm3Ident => '1.3.6.1.4.1.318.1.1.7.1',
  dm3IdentSystem => '1.3.6.1.4.1.318.1.1.7.1.1',
  dm3IdentSysDescriptionTableSize => '1.3.6.1.4.1.318.1.1.7.1.1.1',
  dm3IdentSysDescriptionTable => '1.3.6.1.4.1.318.1.1.7.1.1.2',
  dm3IdentSysDescriptionEntry => '1.3.6.1.4.1.318.1.1.7.1.1.2.1',
  dm3IdentSysDescriptionIndex => '1.3.6.1.4.1.318.1.1.7.1.1.2.1.1',
  dm3IdentSysDescriptionText => '1.3.6.1.4.1.318.1.1.7.1.1.2.1.2',
  dm3IdentSysModel => '1.3.6.1.4.1.318.1.1.7.1.1.3',
  dm3IdentSysCntrlRev => '1.3.6.1.4.1.318.1.1.7.1.1.4',
  dm3IdentSysFWVersion => '1.3.6.1.4.1.318.1.1.7.1.1.5',
  dm3Config => '1.3.6.1.4.1.318.1.1.7.2',
  dm3ConfigSystem => '1.3.6.1.4.1.318.1.1.7.2.1',
  dm3ConfigSysDescriptionTableSize => '1.3.6.1.4.1.318.1.1.7.2.1.1',
  dm3ConfigSysDescriptionTable => '1.3.6.1.4.1.318.1.1.7.2.1.2',
  dm3ConfigSysDescriptionEntry => '1.3.6.1.4.1.318.1.1.7.2.1.2.1',
  dm3ConfigSysDescriptionIndex => '1.3.6.1.4.1.318.1.1.7.2.1.2.1.1',
  dm3ConfigSysDescriptionText => '1.3.6.1.4.1.318.1.1.7.2.1.2.1.2',
  dm3ConfigSysHighTempThresh => '1.3.6.1.4.1.318.1.1.7.2.1.3',
  dm3ConfigSysHighTempAlarm => '1.3.6.1.4.1.318.1.1.7.2.1.4',
  dm3ConfigSysHighTempAlarmDefinition => 'PowerNet-MIB::dm3ConfigSysHighTempAlarm',
  dm3ConfigSysLowTempThresh => '1.3.6.1.4.1.318.1.1.7.2.1.5',
  dm3ConfigSysLowTempAlarm => '1.3.6.1.4.1.318.1.1.7.2.1.6',
  dm3ConfigSysLowTempAlarmDefinition => 'PowerNet-MIB::dm3ConfigSysLowTempAlarm',
  dm3ConfigSysHardwareTempAlarm => '1.3.6.1.4.1.318.1.1.7.2.1.7',
  dm3ConfigSysHardwareTempAlarmDefinition => 'PowerNet-MIB::dm3ConfigSysHardwareTempAlarm',
  dm3ConfigSysRemoteAccess => '1.3.6.1.4.1.318.1.1.7.2.1.8',
  dm3ConfigSysRemoteAccessDefinition => 'PowerNet-MIB::dm3ConfigSysRemoteAccess',
  dm3ConfigLVD => '1.3.6.1.4.1.318.1.1.7.2.2',
  dm3ConfigLVDTableSize => '1.3.6.1.4.1.318.1.1.7.2.2.1',
  dm3ConfigLVDTable => '1.3.6.1.4.1.318.1.1.7.2.2.2',
  dm3ConfigLVDEntry => '1.3.6.1.4.1.318.1.1.7.2.2.2.1',
  dm3ConfigLVDIndex => '1.3.6.1.4.1.318.1.1.7.2.2.2.1.1',
  dm3ConfigLVDName => '1.3.6.1.4.1.318.1.1.7.2.2.2.1.2',
  dm3ConfigLVDEnable => '1.3.6.1.4.1.318.1.1.7.2.2.2.1.3',
  dm3ConfigLVDEnableDefinition => 'PowerNet-MIB::dm3ConfigLVDEnable',
  dm3ConfigLVDTripThresh => '1.3.6.1.4.1.318.1.1.7.2.2.2.1.4',
  dm3ConfigLVDResetThresh => '1.3.6.1.4.1.318.1.1.7.2.2.2.1.5',
  dm3ConfigLVDOpenAlarm => '1.3.6.1.4.1.318.1.1.7.2.2.2.1.6',
  dm3ConfigLVDOpenAlarmDefinition => 'PowerNet-MIB::dm3ConfigLVDOpenAlarm',
  dm3ConfigLVDHWAlarm => '1.3.6.1.4.1.318.1.1.7.2.2.2.1.7',
  dm3ConfigLVDHWAlarmDefinition => 'PowerNet-MIB::dm3ConfigLVDHWAlarm',
  dm3ConfigBattery => '1.3.6.1.4.1.318.1.1.7.2.3',
  dm3ConfigBattFloatVolt => '1.3.6.1.4.1.318.1.1.7.2.3.1',
  dm3ConfigBattMaxRecharge => '1.3.6.1.4.1.318.1.1.7.2.3.2',
  dm3ConfigBattDischargeThresh => '1.3.6.1.4.1.318.1.1.7.2.3.3',
  dm3ConfigBattDischargeAlarm => '1.3.6.1.4.1.318.1.1.7.2.3.4',
  dm3ConfigBattDischargeAlarmDefinition => 'PowerNet-MIB::dm3ConfigBattDischargeAlarm',
  dm3ConfigBattHighVoltThresh => '1.3.6.1.4.1.318.1.1.7.2.3.5',
  dm3ConfigBattHighVoltAlarm => '1.3.6.1.4.1.318.1.1.7.2.3.6',
  dm3ConfigBattHighVoltAlarmDefinition => 'PowerNet-MIB::dm3ConfigBattHighVoltAlarm',
  dm3ConfigBattLowVoltThresh => '1.3.6.1.4.1.318.1.1.7.2.3.7',
  dm3ConfigBattLowVoltAlarm => '1.3.6.1.4.1.318.1.1.7.2.3.8',
  dm3ConfigBattLowVoltAlarmDefinition => 'PowerNet-MIB::dm3ConfigBattLowVoltAlarm',
  dm3ConfigBattHighTempThresh => '1.3.6.1.4.1.318.1.1.7.2.3.9',
  dm3ConfigBattHighTempAlarm => '1.3.6.1.4.1.318.1.1.7.2.3.10',
  dm3ConfigBattHighTempAlarmDefinition => 'PowerNet-MIB::dm3ConfigBattHighTempAlarm',
  dm3ConfigBattLowTempThresh => '1.3.6.1.4.1.318.1.1.7.2.3.11',
  dm3ConfigBattLowTempAlarm => '1.3.6.1.4.1.318.1.1.7.2.3.12',
  dm3ConfigBattLowTempAlarmDefinition => 'PowerNet-MIB::dm3ConfigBattLowTempAlarm',
  dm3ConfigBattAmpHour => '1.3.6.1.4.1.318.1.1.7.2.3.13',
  dm3ConfigCompMethod => '1.3.6.1.4.1.318.1.1.7.2.3.14',
  dm3ConfigCompMethodDefinition => 'PowerNet-MIB::dm3ConfigCompMethod',
  dm3ConfigCompTempCoeff => '1.3.6.1.4.1.318.1.1.7.2.3.15',
  dm3ConfigHighKneeTemp => '1.3.6.1.4.1.318.1.1.7.2.3.16',
  dm3ConfigLowKneeTemp => '1.3.6.1.4.1.318.1.1.7.2.3.17',
  dm3ConfigBattHwCurrentAlarm => '1.3.6.1.4.1.318.1.1.7.2.3.18',
  dm3ConfigBattHwCurrentAlarmDefinition => 'PowerNet-MIB::dm3ConfigBattHwCurrentAlarm',
  dm3ConfigBattHwTempAlarm => '1.3.6.1.4.1.318.1.1.7.2.3.19',
  dm3ConfigBattHwTempAlarmDefinition => 'PowerNet-MIB::dm3ConfigBattHwTempAlarm',
  dm3ConfigPowerModules => '1.3.6.1.4.1.318.1.1.7.2.4',
  dm3ConfigRectifier => '1.3.6.1.4.1.318.1.1.7.2.4.1',
  dm3ConfigRectThresh => '1.3.6.1.4.1.318.1.1.7.2.4.1.1',
  dm3ConfigRectHighVoltThresh => '1.3.6.1.4.1.318.1.1.7.2.4.1.1.1',
  dm3ConfigRectLowVoltThresh => '1.3.6.1.4.1.318.1.1.7.2.4.1.1.2',
  dm3ConfigRectFailSafe => '1.3.6.1.4.1.318.1.1.7.2.4.1.1.3',
  dm3ConfigRectFailComm => '1.3.6.1.4.1.318.1.1.7.2.4.1.1.4',
  dm3ConfigRectAlarms => '1.3.6.1.4.1.318.1.1.7.2.4.1.2',
  dm3ConfigRectHighVoltAlarm => '1.3.6.1.4.1.318.1.1.7.2.4.1.2.1',
  dm3ConfigRectHighVoltAlarmDefinition => 'PowerNet-MIB::dm3ConfigRectHighVoltAlarm',
  dm3ConfigRectLowVoltAlarm => '1.3.6.1.4.1.318.1.1.7.2.4.1.2.2',
  dm3ConfigRectLowVoltAlarmDefinition => 'PowerNet-MIB::dm3ConfigRectLowVoltAlarm',
  dm3ConfigRectConfigAlarm => '1.3.6.1.4.1.318.1.1.7.2.4.1.2.3',
  dm3ConfigRectConfigAlarmDefinition => 'PowerNet-MIB::dm3ConfigRectConfigAlarm',
  dm3ConfigRect1ofNAlarm => '1.3.6.1.4.1.318.1.1.7.2.4.1.2.4',
  dm3ConfigRect1ofNAlarmDefinition => 'PowerNet-MIB::dm3ConfigRect1ofNAlarm',
  dm3ConfigRect2ofNAlarm => '1.3.6.1.4.1.318.1.1.7.2.4.1.2.5',
  dm3ConfigRect2ofNAlarmDefinition => 'PowerNet-MIB::dm3ConfigRect2ofNAlarm',
  dm3ConfigRectDiagAlarm => '1.3.6.1.4.1.318.1.1.7.2.4.1.2.6',
  dm3ConfigRectDiagAlarmDefinition => 'PowerNet-MIB::dm3ConfigRectDiagAlarm',
  dm3ConfigRectImbalanceAlarm => '1.3.6.1.4.1.318.1.1.7.2.4.1.2.7',
  dm3ConfigRectImbalanceAlarmDefinition => 'PowerNet-MIB::dm3ConfigRectImbalanceAlarm',
  dm3ConfigRectCurrLimitAlarm => '1.3.6.1.4.1.318.1.1.7.2.4.1.2.8',
  dm3ConfigRectCurrLimitAlarmDefinition => 'PowerNet-MIB::dm3ConfigRectCurrLimitAlarm',
  dm3ConfigRectStandbyAlarm => '1.3.6.1.4.1.318.1.1.7.2.4.1.2.9',
  dm3ConfigRectStandbyAlarmDefinition => 'PowerNet-MIB::dm3ConfigRectStandbyAlarm',
  dm3ConfigRectFanFailAlarm => '1.3.6.1.4.1.318.1.1.7.2.4.1.2.10',
  dm3ConfigRectFanFailAlarmDefinition => 'PowerNet-MIB::dm3ConfigRectFanFailAlarm',
  dm3ConfigRectFailAlarm => '1.3.6.1.4.1.318.1.1.7.2.4.1.2.11',
  dm3ConfigRectFailAlarmDefinition => 'PowerNet-MIB::dm3ConfigRectFailAlarm',
  dm3ConfigRectHwVoltAlarm => '1.3.6.1.4.1.318.1.1.7.2.4.1.2.12',
  dm3ConfigRectHwVoltAlarmDefinition => 'PowerNet-MIB::dm3ConfigRectHwVoltAlarm',
  dm3ConfigConverter => '1.3.6.1.4.1.318.1.1.7.2.4.2',
  dm3ConfigConvThresh => '1.3.6.1.4.1.318.1.1.7.2.4.2.1',
  dm3ConfigConvHighVoltThresh => '1.3.6.1.4.1.318.1.1.7.2.4.2.1.1',
  dm3ConfigConvLowVoltThresh => '1.3.6.1.4.1.318.1.1.7.2.4.2.1.2',
  dm3ConfigConvFailSafe => '1.3.6.1.4.1.318.1.1.7.2.4.2.1.3',
  dm3ConfigConvSetPoint => '1.3.6.1.4.1.318.1.1.7.2.4.2.1.4',
  dm3ConfigConvFailMax => '1.3.6.1.4.1.318.1.1.7.2.4.2.1.5',
  dm3ConfigConvFailMin => '1.3.6.1.4.1.318.1.1.7.2.4.2.1.6',
  dm3ConfigConvFailComm => '1.3.6.1.4.1.318.1.1.7.2.4.2.1.7',
  dm3ConfigConvAlarms => '1.3.6.1.4.1.318.1.1.7.2.4.2.2',
  dm3ConfigConvHighVoltAlarm => '1.3.6.1.4.1.318.1.1.7.2.4.2.2.1',
  dm3ConfigConvHighVoltAlarmDefinition => 'PowerNet-MIB::dm3ConfigConvHighVoltAlarm',
  dm3ConfigConvLowVoltAlarm => '1.3.6.1.4.1.318.1.1.7.2.4.2.2.2',
  dm3ConfigConvLowVoltAlarmDefinition => 'PowerNet-MIB::dm3ConfigConvLowVoltAlarm',
  dm3ConfigConvConfigAlarm => '1.3.6.1.4.1.318.1.1.7.2.4.2.2.3',
  dm3ConfigConvConfigAlarmDefinition => 'PowerNet-MIB::dm3ConfigConvConfigAlarm',
  dm3ConfigConv1ofNAlarm => '1.3.6.1.4.1.318.1.1.7.2.4.2.2.4',
  dm3ConfigConv1ofNAlarmDefinition => 'PowerNet-MIB::dm3ConfigConv1ofNAlarm',
  dm3ConfigConv2ofNAlarm => '1.3.6.1.4.1.318.1.1.7.2.4.2.2.5',
  dm3ConfigConv2ofNAlarmDefinition => 'PowerNet-MIB::dm3ConfigConv2ofNAlarm',
  dm3ConfigConvDiagAlarm => '1.3.6.1.4.1.318.1.1.7.2.4.2.2.6',
  dm3ConfigConvDiagAlarmDefinition => 'PowerNet-MIB::dm3ConfigConvDiagAlarm',
  dm3ConfigConvImbalanceAlarm => '1.3.6.1.4.1.318.1.1.7.2.4.2.2.7',
  dm3ConfigConvImbalanceAlarmDefinition => 'PowerNet-MIB::dm3ConfigConvImbalanceAlarm',
  dm3ConfigConvCurrLimitAlarm => '1.3.6.1.4.1.318.1.1.7.2.4.2.2.8',
  dm3ConfigConvCurrLimitAlarmDefinition => 'PowerNet-MIB::dm3ConfigConvCurrLimitAlarm',
  dm3ConfigConvStandbyAlarm => '1.3.6.1.4.1.318.1.1.7.2.4.2.2.9',
  dm3ConfigConvStandbyAlarmDefinition => 'PowerNet-MIB::dm3ConfigConvStandbyAlarm',
  dm3ConfigConvFanFailAlarm => '1.3.6.1.4.1.318.1.1.7.2.4.2.2.10',
  dm3ConfigConvFanFailAlarmDefinition => 'PowerNet-MIB::dm3ConfigConvFanFailAlarm',
  dm3ConfigConvFailAlarm => '1.3.6.1.4.1.318.1.1.7.2.4.2.2.11',
  dm3ConfigConvFailAlarmDefinition => 'PowerNet-MIB::dm3ConfigConvFailAlarm',
  dm3ConfigConvHwVoltAlarm => '1.3.6.1.4.1.318.1.1.7.2.4.2.2.12',
  dm3ConfigConvHwVoltAlarmDefinition => 'PowerNet-MIB::dm3ConfigConvHwVoltAlarm',
  dm3ConfigRelays => '1.3.6.1.4.1.318.1.1.7.2.5',
  dm3ConfigOutputRelays => '1.3.6.1.4.1.318.1.1.7.2.5.1',
  dm3ConfigOutRlyTableSize => '1.3.6.1.4.1.318.1.1.7.2.5.1.1',
  dm3ConfigOutRlyTable => '1.3.6.1.4.1.318.1.1.7.2.5.1.2',
  dm3ConfigOutRlyEntry => '1.3.6.1.4.1.318.1.1.7.2.5.1.2.1',
  dm3ConfigOutRlyIndex => '1.3.6.1.4.1.318.1.1.7.2.5.1.2.1.1',
  dm3ConfigOutRlyName => '1.3.6.1.4.1.318.1.1.7.2.5.1.2.1.2',
  dm3ConfigOutRlyDelay => '1.3.6.1.4.1.318.1.1.7.2.5.1.2.1.3',
  dm3ConfigOutRlyAlarm => '1.3.6.1.4.1.318.1.1.7.2.5.1.2.1.4',
  dm3ConfigOutRlyAlarmDefinition => 'PowerNet-MIB::dm3ConfigOutRlyAlarm',
  dm3ConfigInputRelays => '1.3.6.1.4.1.318.1.1.7.2.5.2',
  dm3ConfigInRlyTableSize => '1.3.6.1.4.1.318.1.1.7.2.5.2.1',
  dm3ConfigInRlyTable => '1.3.6.1.4.1.318.1.1.7.2.5.2.2',
  dm3ConfigInRlyEntry => '1.3.6.1.4.1.318.1.1.7.2.5.2.2.1',
  dm3ConfigInRlyIndex => '1.3.6.1.4.1.318.1.1.7.2.5.2.2.1.1',
  dm3ConfigInRlyName => '1.3.6.1.4.1.318.1.1.7.2.5.2.2.1.2',
  dm3ConfigInRlyDelay => '1.3.6.1.4.1.318.1.1.7.2.5.2.2.1.3',
  dm3ConfigInRlyAlarm => '1.3.6.1.4.1.318.1.1.7.2.5.2.2.1.4',
  dm3ConfigInRlyAlarmDefinition => 'PowerNet-MIB::dm3ConfigInRlyAlarm',
  dm3ConfigDistribution => '1.3.6.1.4.1.318.1.1.7.2.6',
  dm3ConfigBreakers => '1.3.6.1.4.1.318.1.1.7.2.6.1',
  dm3ConfigBreakersTableSize => '1.3.6.1.4.1.318.1.1.7.2.6.1.1',
  dm3ConfigBreakersTable => '1.3.6.1.4.1.318.1.1.7.2.6.1.2',
  dm3ConfigBreakersEntry => '1.3.6.1.4.1.318.1.1.7.2.6.1.2.1',
  dm3ConfigBreakersIndex => '1.3.6.1.4.1.318.1.1.7.2.6.1.2.1.1',
  dm3ConfigBreakersName => '1.3.6.1.4.1.318.1.1.7.2.6.1.2.1.2',
  dm3ConfigBreakersAlarm => '1.3.6.1.4.1.318.1.1.7.2.6.1.2.1.3',
  dm3ConfigBreakersAlarmDefinition => 'PowerNet-MIB::dm3ConfigBreakersAlarm',
  dm3ConfigFuses => '1.3.6.1.4.1.318.1.1.7.2.6.2',
  dm3ConfigFusesTableSize => '1.3.6.1.4.1.318.1.1.7.2.6.2.1',
  dm3ConfigFusesTable => '1.3.6.1.4.1.318.1.1.7.2.6.2.2',
  dm3ConfigFusesEntry => '1.3.6.1.4.1.318.1.1.7.2.6.2.2.1',
  dm3ConfigFusesIndex => '1.3.6.1.4.1.318.1.1.7.2.6.2.2.1.1',
  dm3ConfigFusesName => '1.3.6.1.4.1.318.1.1.7.2.6.2.2.1.2',
  dm3ConfigFusesAlarm => '1.3.6.1.4.1.318.1.1.7.2.6.2.2.1.3',
  dm3ConfigFusesAlarmDefinition => 'PowerNet-MIB::dm3ConfigFusesAlarm',
  dm3Status => '1.3.6.1.4.1.318.1.1.7.3',
  dm3StatusSystem => '1.3.6.1.4.1.318.1.1.7.3.1',
  dm3StatusSystemTemp => '1.3.6.1.4.1.318.1.1.7.3.1.1',
  dm3StatusSystemStart => '1.3.6.1.4.1.318.1.1.7.3.1.2',
  dm3StatusSysRemoteAccess => '1.3.6.1.4.1.318.1.1.7.3.1.3',
  dm3StatusSysRemoteAccessDefinition => 'PowerNet-MIB::dm3StatusSysRemoteAccess',
  dm3StatusSysSecurityLevel => '1.3.6.1.4.1.318.1.1.7.3.1.4',
  dm3StatusSysTempSanity => '1.3.6.1.4.1.318.1.1.7.3.1.5',
  dm3StatusSysTempSanityDefinition => 'PowerNet-MIB::dm3StatusSysTempSanity',
  dm3StatusSysAlarmState => '1.3.6.1.4.1.318.1.1.7.3.1.6',
  dm3StatusSysAlarmStateDefinition => 'PowerNet-MIB::dm3StatusSysAlarmState',
  dm3StatusSysTempUnits => '1.3.6.1.4.1.318.1.1.7.3.1.7',
  dm3StatusSysTempUnitsDefinition => 'PowerNet-MIB::dm3StatusSysTempUnits',
  dm3StatusAlarms => '1.3.6.1.4.1.318.1.1.7.3.2',
  dm3StatusAlarmsTableSize => '1.3.6.1.4.1.318.1.1.7.3.2.1',
  dm3StatusAlarmsTable => '1.3.6.1.4.1.318.1.1.7.3.2.2',
  dm3StatusAlarmsEntry => '1.3.6.1.4.1.318.1.1.7.3.2.2.1',
  dm3StatusAlarmsIndex => '1.3.6.1.4.1.318.1.1.7.3.2.2.1.1',
  dm3StatusAlarmsText => '1.3.6.1.4.1.318.1.1.7.3.2.2.1.2',
  dm3StatusBattery => '1.3.6.1.4.1.318.1.1.7.3.3',
  dm3StatusBattCurrent => '1.3.6.1.4.1.318.1.1.7.3.3.1',
  dm3StatusBattTemp => '1.3.6.1.4.1.318.1.1.7.3.3.2',
  dm3StatusBattCurrentSanity => '1.3.6.1.4.1.318.1.1.7.3.3.3',
  dm3StatusBattCurrentSanityDefinition => 'PowerNet-MIB::dm3StatusBattCurrentSanity',
  dm3StatusBattTempSanity => '1.3.6.1.4.1.318.1.1.7.3.3.4',
  dm3StatusBattTempSanityDefinition => 'PowerNet-MIB::dm3StatusBattTempSanity',
  dm3StatusOEM => '1.3.6.1.4.1.318.1.1.7.3.4',
  dm3StatusOEMrectOffset => '1.3.6.1.4.1.318.1.1.7.3.4.1',
  dm3StatusOEMrectGain => '1.3.6.1.4.1.318.1.1.7.3.4.2',
  dm3StatusOEMconvOffset => '1.3.6.1.4.1.318.1.1.7.3.4.3',
  dm3StatusOEMconvGain => '1.3.6.1.4.1.318.1.1.7.3.4.4',
  dm3StatusOEMshuntOffset => '1.3.6.1.4.1.318.1.1.7.3.4.5',
  dm3StatusOEMshuntGain => '1.3.6.1.4.1.318.1.1.7.3.4.6',
  dm3StatusLVD => '1.3.6.1.4.1.318.1.1.7.3.5',
  dm3StatusLVDTableSize => '1.3.6.1.4.1.318.1.1.7.3.5.1',
  dm3StatusLVDTable => '1.3.6.1.4.1.318.1.1.7.3.5.2',
  dm3StatusLVDEntry => '1.3.6.1.4.1.318.1.1.7.3.5.2.1',
  dm3StatusLVDIndex => '1.3.6.1.4.1.318.1.1.7.3.5.2.1.1',
  dm3StatusLVDName => '1.3.6.1.4.1.318.1.1.7.3.5.2.1.2',
  dm3StatusLVDState => '1.3.6.1.4.1.318.1.1.7.3.5.2.1.3',
  dm3StatusLVDStateDefinition => 'PowerNet-MIB::dm3StatusLVDState',
  dm3StatusLVDHwFault => '1.3.6.1.4.1.318.1.1.7.3.5.2.1.4',
  dm3StatusLVDHwFaultDefinition => 'PowerNet-MIB::dm3StatusLVDHwFault',
  dm3StatusPowerModules => '1.3.6.1.4.1.318.1.1.7.3.6',
  dm3StatusRectifier => '1.3.6.1.4.1.318.1.1.7.3.6.1',
  dm3StatusRectTableSize => '1.3.6.1.4.1.318.1.1.7.3.6.1.1',
  dm3StatusRectTable => '1.3.6.1.4.1.318.1.1.7.3.6.1.2',
  dm3StatusRectEntry => '1.3.6.1.4.1.318.1.1.7.3.6.1.2.1',
  dm3StatusRectIndex => '1.3.6.1.4.1.318.1.1.7.3.6.1.2.1.1',
  dm3StatusRectID => '1.3.6.1.4.1.318.1.1.7.3.6.1.2.1.2',
  dm3StatusRectDesc => '1.3.6.1.4.1.318.1.1.7.3.6.1.2.1.3',
  dm3StatusRectCurrent => '1.3.6.1.4.1.318.1.1.7.3.6.1.2.1.4',
  dm3StatusRectCurrentLimit => '1.3.6.1.4.1.318.1.1.7.3.6.1.2.1.5',
  dm3StatusRectCurrentLimitDefinition => 'PowerNet-MIB::dm3StatusRectCurrentLimit',
  dm3StatusRectStandby => '1.3.6.1.4.1.318.1.1.7.3.6.1.2.1.6',
  dm3StatusRectStandbyDefinition => 'PowerNet-MIB::dm3StatusRectStandby',
  dm3StatusRectFanFail => '1.3.6.1.4.1.318.1.1.7.3.6.1.2.1.7',
  dm3StatusRectFanFailDefinition => 'PowerNet-MIB::dm3StatusRectFanFail',
  dm3StatusRectFail => '1.3.6.1.4.1.318.1.1.7.3.6.1.2.1.8',
  dm3StatusRectFailDefinition => 'PowerNet-MIB::dm3StatusRectFail',
  dm3StatusRectDevType => '1.3.6.1.4.1.318.1.1.7.3.6.1.2.1.9',
  dm3StatusRectPhyAddr => '1.3.6.1.4.1.318.1.1.7.3.6.1.2.1.10',
  dm3StatusRectCfg => '1.3.6.1.4.1.318.1.1.7.3.6.1.2.1.11',
  dm3StatusRectCfgDefinition => 'PowerNet-MIB::dm3StatusRectCfg',
  dm3StatusRectPcbRev => '1.3.6.1.4.1.318.1.1.7.3.6.1.2.1.12',
  dm3StatusRectFwVer => '1.3.6.1.4.1.318.1.1.7.3.6.1.2.1.13',
  dm3StatusRectPresent => '1.3.6.1.4.1.318.1.1.7.3.6.1.2.1.14',
  dm3StatusRectPresentDefinition => 'PowerNet-MIB::dm3StatusRectPresent',
  dm3StatusRectDiagPass => '1.3.6.1.4.1.318.1.1.7.3.6.1.2.1.15',
  dm3StatusRectDiagPassDefinition => 'PowerNet-MIB::dm3StatusRectDiagPass',
  dm3StatusRectState => '1.3.6.1.4.1.318.1.1.7.3.6.1.2.1.16',
  dm3StatusSysRectVoltSanity => '1.3.6.1.4.1.318.1.1.7.3.6.1.3',
  dm3StatusSysRectVoltSanityDefinition => 'PowerNet-MIB::dm3StatusSysRectVoltSanity',
  dm3StatusSysRectAvailable => '1.3.6.1.4.1.318.1.1.7.3.6.1.4',
  dm3StatusSysRectAvailableDefinition => 'PowerNet-MIB::dm3StatusSysRectAvailable',
  dm3StatusSysRectType => '1.3.6.1.4.1.318.1.1.7.3.6.1.5',
  dm3StatusSysRectVoltage => '1.3.6.1.4.1.318.1.1.7.3.6.1.6',
  dm3StatusSysRectCurrent => '1.3.6.1.4.1.318.1.1.7.3.6.1.7',
  dm3StatusConverter => '1.3.6.1.4.1.318.1.1.7.3.6.2',
  dm3StatusConvTableSize => '1.3.6.1.4.1.318.1.1.7.3.6.2.1',
  dm3StatusConvTable => '1.3.6.1.4.1.318.1.1.7.3.6.2.2',
  dm3StatusConvEntry => '1.3.6.1.4.1.318.1.1.7.3.6.2.2.1',
  dm3StatusConvIndex => '1.3.6.1.4.1.318.1.1.7.3.6.2.2.1.1',
  dm3StatusConvID => '1.3.6.1.4.1.318.1.1.7.3.6.2.2.1.2',
  dm3StatusConvDesc => '1.3.6.1.4.1.318.1.1.7.3.6.2.2.1.3',
  dm3StatusConvCurrent => '1.3.6.1.4.1.318.1.1.7.3.6.2.2.1.4',
  dm3StatusConvCurrentLimit => '1.3.6.1.4.1.318.1.1.7.3.6.2.2.1.5',
  dm3StatusConvCurrentLimitDefinition => 'PowerNet-MIB::dm3StatusConvCurrentLimit',
  dm3StatusConvStandby => '1.3.6.1.4.1.318.1.1.7.3.6.2.2.1.6',
  dm3StatusConvStandbyDefinition => 'PowerNet-MIB::dm3StatusConvStandby',
  dm3StatusConvFanFail => '1.3.6.1.4.1.318.1.1.7.3.6.2.2.1.7',
  dm3StatusConvFanFailDefinition => 'PowerNet-MIB::dm3StatusConvFanFail',
  dm3StatusConvFail => '1.3.6.1.4.1.318.1.1.7.3.6.2.2.1.8',
  dm3StatusConvFailDefinition => 'PowerNet-MIB::dm3StatusConvFail',
  dm3StatusConvDevType => '1.3.6.1.4.1.318.1.1.7.3.6.2.2.1.9',
  dm3StatusConvPhyAddr => '1.3.6.1.4.1.318.1.1.7.3.6.2.2.1.10',
  dm3StatusConvCfg => '1.3.6.1.4.1.318.1.1.7.3.6.2.2.1.11',
  dm3StatusConvCfgDefinition => 'PowerNet-MIB::dm3StatusConvCfg',
  dm3StatusConvPcbRev => '1.3.6.1.4.1.318.1.1.7.3.6.2.2.1.12',
  dm3StatusConvFwVer => '1.3.6.1.4.1.318.1.1.7.3.6.2.2.1.13',
  dm3StatusConvPresent => '1.3.6.1.4.1.318.1.1.7.3.6.2.2.1.14',
  dm3StatusConvPresentDefinition => 'PowerNet-MIB::dm3StatusConvPresent',
  dm3StatusConvDiagPass => '1.3.6.1.4.1.318.1.1.7.3.6.2.2.1.15',
  dm3StatusConvDiagPassDefinition => 'PowerNet-MIB::dm3StatusConvDiagPass',
  dm3StatusConvState => '1.3.6.1.4.1.318.1.1.7.3.6.2.2.1.16',
  dm3StatusSysConvVoltSanity => '1.3.6.1.4.1.318.1.1.7.3.6.2.3',
  dm3StatusSysConvVoltSanityDefinition => 'PowerNet-MIB::dm3StatusSysConvVoltSanity',
  dm3StatusSysConvAvailable => '1.3.6.1.4.1.318.1.1.7.3.6.2.4',
  dm3StatusSysConvAvailableDefinition => 'PowerNet-MIB::dm3StatusSysConvAvailable',
  dm3StatusSysConvType => '1.3.6.1.4.1.318.1.1.7.3.6.2.5',
  dm3StatusSysConvVoltage => '1.3.6.1.4.1.318.1.1.7.3.6.2.6',
  dm3StatusSysConvCurrent => '1.3.6.1.4.1.318.1.1.7.3.6.2.7',
  dm3StatusRelays => '1.3.6.1.4.1.318.1.1.7.3.7',
  dm3StatusOutputRelays => '1.3.6.1.4.1.318.1.1.7.3.7.1',
  dm3StatusOutRlyTableSize => '1.3.6.1.4.1.318.1.1.7.3.7.1.1',
  dm3StatusOutRlyTable => '1.3.6.1.4.1.318.1.1.7.3.7.1.2',
  dm3StatusOutRlyEntry => '1.3.6.1.4.1.318.1.1.7.3.7.1.2.1',
  dm3StatusOutRlyIndex => '1.3.6.1.4.1.318.1.1.7.3.7.1.2.1.1',
  dm3StatusOutRlyName => '1.3.6.1.4.1.318.1.1.7.3.7.1.2.1.2',
  dm3StatusOutRlyStatus => '1.3.6.1.4.1.318.1.1.7.3.7.1.2.1.3',
  dm3StatusOutRlyStatusDefinition => 'PowerNet-MIB::dm3StatusOutRlyStatus',
  dm3StatusInputRelays => '1.3.6.1.4.1.318.1.1.7.3.7.2',
  dm3StatusInRlyTableSize => '1.3.6.1.4.1.318.1.1.7.3.7.2.1',
  dm3StatusInRlyTable => '1.3.6.1.4.1.318.1.1.7.3.7.2.2',
  dm3StatusInRlyEntry => '1.3.6.1.4.1.318.1.1.7.3.7.2.2.1',
  dm3StatusInRlyIndex => '1.3.6.1.4.1.318.1.1.7.3.7.2.2.1.1',
  dm3StatusInRlyName => '1.3.6.1.4.1.318.1.1.7.3.7.2.2.1.2',
  dm3StatusInRlyStatus => '1.3.6.1.4.1.318.1.1.7.3.7.2.2.1.3',
  dm3StatusInRlyStatusDefinition => 'PowerNet-MIB::dm3StatusInRlyStatus',
  dm3StatusDistribution => '1.3.6.1.4.1.318.1.1.7.3.8',
  dm3StatusBreakers => '1.3.6.1.4.1.318.1.1.7.3.8.1',
  dm3StatusBreakersTableSize => '1.3.6.1.4.1.318.1.1.7.3.8.1.1',
  dm3StatusBreakersTable => '1.3.6.1.4.1.318.1.1.7.3.8.1.2',
  dm3StatusBreakersEntry => '1.3.6.1.4.1.318.1.1.7.3.8.1.2.1',
  dm3StatusBreakersIndex => '1.3.6.1.4.1.318.1.1.7.3.8.1.2.1.1',
  dm3StatusBreakersName => '1.3.6.1.4.1.318.1.1.7.3.8.1.2.1.2',
  dm3StatusBreakersStatus => '1.3.6.1.4.1.318.1.1.7.3.8.1.2.1.3',
  dm3StatusBreakersStatusDefinition => 'PowerNet-MIB::dm3StatusBreakersStatus',
  dm3StatusFuses => '1.3.6.1.4.1.318.1.1.7.3.8.2',
  dm3StatusFusesTableSize => '1.3.6.1.4.1.318.1.1.7.3.8.2.1',
  dm3StatusFusesTable => '1.3.6.1.4.1.318.1.1.7.3.8.2.2',
  dm3StatusFusesEntry => '1.3.6.1.4.1.318.1.1.7.3.8.2.2.1',
  dm3StatusFusesIndex => '1.3.6.1.4.1.318.1.1.7.3.8.2.2.1.1',
  dm3StatusFusesName => '1.3.6.1.4.1.318.1.1.7.3.8.2.2.1.2',
  dm3StatusFusesStatus => '1.3.6.1.4.1.318.1.1.7.3.8.2.2.1.3',
  dm3StatusFusesStatusDefinition => 'PowerNet-MIB::dm3StatusFusesStatus',
  automaticTransferSwitch => '1.3.6.1.4.1.318.1.1.8',
  atsIdent => '1.3.6.1.4.1.318.1.1.8.1',
  atsIdentHardwareRev => '1.3.6.1.4.1.318.1.1.8.1.1',
  atsIdentFirmwareRev => '1.3.6.1.4.1.318.1.1.8.1.2',
  atsIdentFirmwareDate => '1.3.6.1.4.1.318.1.1.8.1.3',
  atsIdentDateOfManufacture => '1.3.6.1.4.1.318.1.1.8.1.4',
  atsIdentModelNumber => '1.3.6.1.4.1.318.1.1.8.1.5',
  atsIdentSerialNumber => '1.3.6.1.4.1.318.1.1.8.1.6',
  atsIdentNominalLineVoltage => '1.3.6.1.4.1.318.1.1.8.1.7',
  atsIdentNominalLineFrequency => '1.3.6.1.4.1.318.1.1.8.1.8',
  atsIdentDeviceRating => '1.3.6.1.4.1.318.1.1.8.1.9',
  atsCalibration => '1.3.6.1.4.1.318.1.1.8.2',
  atsCalibrationInput => '1.3.6.1.4.1.318.1.1.8.2.1',
  atsCalibrationNumInputs => '1.3.6.1.4.1.318.1.1.8.2.1.1',
  atsCalibrationNumInputPhases => '1.3.6.1.4.1.318.1.1.8.2.1.2',
  atsCalibrationInputPhaseTable => '1.3.6.1.4.1.318.1.1.8.2.1.3',
  atsCalibrationInputPhaseEntry => '1.3.6.1.4.1.318.1.1.8.2.1.3.1',
  atsCalibrationInputTableIndex => '1.3.6.1.4.1.318.1.1.8.2.1.3.1.1',
  atsCalibrationInputPhaseTableIndex => '1.3.6.1.4.1.318.1.1.8.2.1.3.1.2',
  atsLineVoltageCalibrationFactor => '1.3.6.1.4.1.318.1.1.8.2.1.3.1.3',
  atsCalibrationPowerSupply => '1.3.6.1.4.1.318.1.1.8.2.2',
  atsCalibrationPowerSupplyVoltages => '1.3.6.1.4.1.318.1.1.8.2.2.1',
  atsCalibrationPowerSupplyVoltageTable => '1.3.6.1.4.1.318.1.1.8.2.2.2',
  atsCalibrationPowerSupplyVoltageEntry => '1.3.6.1.4.1.318.1.1.8.2.2.2.1',
  atsCalibrationPowerSupplyVoltageTableIndex => '1.3.6.1.4.1.318.1.1.8.2.2.2.1.1',
  atsCalibrationPowerSupplyVoltage => '1.3.6.1.4.1.318.1.1.8.2.2.2.1.2',
  atsCalibrationPowerSupplyVoltageDefinition => 'PowerNet-MIB::atsCalibrationPowerSupplyVoltage',
  atsPowerSupplyVoltageCalibrationFactor => '1.3.6.1.4.1.318.1.1.8.2.2.2.1.3',
  atsCalibrationOutput => '1.3.6.1.4.1.318.1.1.8.2.3',
  atsCalibrationNumOutputs => '1.3.6.1.4.1.318.1.1.8.2.3.1',
  atsCalibrationNumOutputPhases => '1.3.6.1.4.1.318.1.1.8.2.3.2',
  atsCalibrationOutputTable => '1.3.6.1.4.1.318.1.1.8.2.3.3',
  atsCalibrationOutputEntry => '1.3.6.1.4.1.318.1.1.8.2.3.3.1',
  atsCalibrationOutputTableIndex => '1.3.6.1.4.1.318.1.1.8.2.3.3.1.1',
  atsCalibrationOutputPhasesTableIndex => '1.3.6.1.4.1.318.1.1.8.2.3.3.1.2',
  atsCalibrationOutputPhasesTableIndexDefinition => 'PowerNet-MIB::atsCalibrationOutputPhasesTableIndex',
  atsOutputCurrentCalibrationFactor => '1.3.6.1.4.1.318.1.1.8.2.3.3.1.3',
  atsControl => '1.3.6.1.4.1.318.1.1.8.3',
  atsControlResetATS => '1.3.6.1.4.1.318.1.1.8.3.1',
  atsControlResetATSDefinition => 'PowerNet-MIB::atsControlResetATS',
  atsControlClearAllAlarms => '1.3.6.1.4.1.318.1.1.8.3.2',
  atsControlClearAllAlarmsDefinition => 'PowerNet-MIB::atsControlClearAllAlarms',
  atsConfig => '1.3.6.1.4.1.318.1.1.8.4',
  atsConfigProductName => '1.3.6.1.4.1.318.1.1.8.4.1',
  atsConfigPreferredSource => '1.3.6.1.4.1.318.1.1.8.4.2',
  atsConfigPreferredSourceDefinition => 'PowerNet-MIB::atsConfigPreferredSource',
  atsConfigFrontPanelLockout => '1.3.6.1.4.1.318.1.1.8.4.3',
  atsConfigFrontPanelLockoutDefinition => 'PowerNet-MIB::atsConfigFrontPanelLockout',
  atsConfigVoltageSensitivity => '1.3.6.1.4.1.318.1.1.8.4.4',
  atsConfigVoltageSensitivityDefinition => 'PowerNet-MIB::atsConfigVoltageSensitivity',
  atsConfigTransferVoltageRange => '1.3.6.1.4.1.318.1.1.8.4.5',
  atsConfigTransferVoltageRangeDefinition => 'PowerNet-MIB::atsConfigTransferVoltageRange',
  atsConfigCurrentLimit => '1.3.6.1.4.1.318.1.1.8.4.6',
  atsConfigResetValues => '1.3.6.1.4.1.318.1.1.8.4.7',
  atsConfigResetValuesDefinition => 'PowerNet-MIB::atsConfigResetValues',
  atsConfigLineVRMS => '1.3.6.1.4.1.318.1.1.8.4.8',
  atsConfigLineVRMSNarrowLimit => '1.3.6.1.4.1.318.1.1.8.4.9',
  atsConfigLineVRMSMediumLimit => '1.3.6.1.4.1.318.1.1.8.4.10',
  atsConfigLineVRMSWideLimit => '1.3.6.1.4.1.318.1.1.8.4.11',
  atsConfigFrequencyDeviation => '1.3.6.1.4.1.318.1.1.8.4.12',
  atsConfigFrequencyDeviationDefinition => 'PowerNet-MIB::atsConfigFrequencyDeviation',
  atsConfigBankTableSize => '1.3.6.1.4.1.318.1.1.8.4.13',
  atsConfigBankTable => '1.3.6.1.4.1.318.1.1.8.4.14',
  atsConfigBankEntry => '1.3.6.1.4.1.318.1.1.8.4.14.1',
  atsConfigBankTableIndex => '1.3.6.1.4.1.318.1.1.8.4.14.1.1',
  atsConfigBank => '1.3.6.1.4.1.318.1.1.8.4.14.1.2',
  atsConfigBankDefinition => 'PowerNet-MIB::atsConfigBank',
  atsConfigBankLowLoadThreshold => '1.3.6.1.4.1.318.1.1.8.4.14.1.3',
  atsConfigBankNearOverLoadThreshold => '1.3.6.1.4.1.318.1.1.8.4.14.1.4',
  atsConfigBankOverLoadThreshold => '1.3.6.1.4.1.318.1.1.8.4.14.1.5',
  atsConfigPhaseTableSize => '1.3.6.1.4.1.318.1.1.8.4.15',
  atsConfigPhaseTable => '1.3.6.1.4.1.318.1.1.8.4.16',
  atsConfigPhaseEntry => '1.3.6.1.4.1.318.1.1.8.4.16.1',
  atsConfigPhaseTableIndex => '1.3.6.1.4.1.318.1.1.8.4.16.1.1',
  atsConfigPhase => '1.3.6.1.4.1.318.1.1.8.4.16.1.2',
  atsConfigPhaseDefinition => 'PowerNet-MIB::atsConfigPhase',
  atsConfigPhaseLowLoadThreshold => '1.3.6.1.4.1.318.1.1.8.4.16.1.3',
  atsConfigPhaseNearOverLoadThreshold => '1.3.6.1.4.1.318.1.1.8.4.16.1.4',
  atsConfigPhaseOverLoadThreshold => '1.3.6.1.4.1.318.1.1.8.4.16.1.5',
  atsStatus => '1.3.6.1.4.1.318.1.1.8.5',
  atsStatusDeviceStatus => '1.3.6.1.4.1.318.1.1.8.5.1',
  atsStatusCommStatus => '1.3.6.1.4.1.318.1.1.8.5.1.1',
  atsStatusCommStatusDefinition => 'PowerNet-MIB::atsStatusCommStatus',
  atsStatusSelectedSource => '1.3.6.1.4.1.318.1.1.8.5.1.2',
  atsStatusSelectedSourceDefinition => 'PowerNet-MIB::atsStatusSelectedSource',
  atsStatusRedundancyState => '1.3.6.1.4.1.318.1.1.8.5.1.3',
  atsStatusRedundancyStateDefinition => 'PowerNet-MIB::atsStatusRedundancyState',
  atsStatusOverCurrentState => '1.3.6.1.4.1.318.1.1.8.5.1.4',
  atsStatusOverCurrentStateDefinition => 'PowerNet-MIB::atsStatusOverCurrentState',
  atsStatus5VPowerSupply => '1.3.6.1.4.1.318.1.1.8.5.1.5',
  atsStatus5VPowerSupplyDefinition => 'PowerNet-MIB::atsStatus5VPowerSupply',
  atsStatus24VPowerSupply => '1.3.6.1.4.1.318.1.1.8.5.1.6',
  atsStatus24VPowerSupplyDefinition => 'PowerNet-MIB::atsStatus24VPowerSupply',
  atsStatus24VSourceBPowerSupply => '1.3.6.1.4.1.318.1.1.8.5.1.7',
  atsStatus24VSourceBPowerSupplyDefinition => 'PowerNet-MIB::atsStatus24VSourceBPowerSupply',
  atsStatusPlus12VPowerSupply => '1.3.6.1.4.1.318.1.1.8.5.1.8',
  atsStatusPlus12VPowerSupplyDefinition => 'PowerNet-MIB::atsStatusPlus12VPowerSupply',
  atsStatusMinus12VPowerSupply => '1.3.6.1.4.1.318.1.1.8.5.1.9',
  atsStatusMinus12VPowerSupplyDefinition => 'PowerNet-MIB::atsStatusMinus12VPowerSupply',
  atsStatusSwitchStatus => '1.3.6.1.4.1.318.1.1.8.5.1.10',
  atsStatusSwitchStatusDefinition => 'PowerNet-MIB::atsStatusSwitchStatus',
  atsStatusFrontPanel => '1.3.6.1.4.1.318.1.1.8.5.1.11',
  atsStatusFrontPanelDefinition => 'PowerNet-MIB::atsStatusFrontPanel',
  atsStatusSourceAStatus => '1.3.6.1.4.1.318.1.1.8.5.1.12',
  atsStatusSourceAStatusDefinition => 'PowerNet-MIB::atsStatusSourceAStatus',
  atsStatusSourceBStatus => '1.3.6.1.4.1.318.1.1.8.5.1.13',
  atsStatusSourceBStatusDefinition => 'PowerNet-MIB::atsStatusSourceBStatus',
  atsStatusPhaseSyncStatus => '1.3.6.1.4.1.318.1.1.8.5.1.14',
  atsStatusPhaseSyncStatusDefinition => 'PowerNet-MIB::atsStatusPhaseSyncStatus',
  atsStatusVoltageOutStatus => '1.3.6.1.4.1.318.1.1.8.5.1.15',
  atsStatusVoltageOutStatusDefinition => 'PowerNet-MIB::atsStatusVoltageOutStatus',
  atsStatusHardwareStatus => '1.3.6.1.4.1.318.1.1.8.5.1.16',
  atsStatusHardwareStatusDefinition => 'PowerNet-MIB::atsStatusHardwareStatus',
  atsStatusResetValues => '1.3.6.1.4.1.318.1.1.8.5.2',
  atsStatusResetMaxMinValues => '1.3.6.1.4.1.318.1.1.8.5.2.1',
  atsStatusResetMaxMinValuesDefinition => 'PowerNet-MIB::atsStatusResetMaxMinValues',
  atsStatusInput => '1.3.6.1.4.1.318.1.1.8.5.3',
  atsNumInputs => '1.3.6.1.4.1.318.1.1.8.5.3.1',
  atsInputTable => '1.3.6.1.4.1.318.1.1.8.5.3.2',
  atsInputEntry => '1.3.6.1.4.1.318.1.1.8.5.3.2.1',
  atsInputTableIndex => '1.3.6.1.4.1.318.1.1.8.5.3.2.1.1',
  atsNumInputPhases => '1.3.6.1.4.1.318.1.1.8.5.3.2.1.2',
  atsInputVoltageOrientation => '1.3.6.1.4.1.318.1.1.8.5.3.2.1.3',
  atsInputVoltageOrientationDefinition => 'PowerNet-MIB::atsInputVoltageOrientation',
  atsInputFrequency => '1.3.6.1.4.1.318.1.1.8.5.3.2.1.4',
  atsInputType => '1.3.6.1.4.1.318.1.1.8.5.3.2.1.5',
  atsInputTypeDefinition => 'PowerNet-MIB::atsInputType',
  atsInputName => '1.3.6.1.4.1.318.1.1.8.5.3.2.1.6',
  atsInputPhaseTable => '1.3.6.1.4.1.318.1.1.8.5.3.3',
  atsInputPhaseEntry => '1.3.6.1.4.1.318.1.1.8.5.3.3.1',
  atsInputPhaseTableIndex => '1.3.6.1.4.1.318.1.1.8.5.3.3.1.1',
  atsInputPhaseIndex => '1.3.6.1.4.1.318.1.1.8.5.3.3.1.2',
  atsInputVoltage => '1.3.6.1.4.1.318.1.1.8.5.3.3.1.3',
  atsInputMaxVoltage => '1.3.6.1.4.1.318.1.1.8.5.3.3.1.4',
  atsInputMinVoltage => '1.3.6.1.4.1.318.1.1.8.5.3.3.1.5',
  atsInputCurrent => '1.3.6.1.4.1.318.1.1.8.5.3.3.1.6',
  atsInputMaxCurrent => '1.3.6.1.4.1.318.1.1.8.5.3.3.1.7',
  atsInputMinCurrent => '1.3.6.1.4.1.318.1.1.8.5.3.3.1.8',
  atsInputPower => '1.3.6.1.4.1.318.1.1.8.5.3.3.1.9',
  atsInputMaxPower => '1.3.6.1.4.1.318.1.1.8.5.3.3.1.10',
  atsInputMinPower => '1.3.6.1.4.1.318.1.1.8.5.3.3.1.11',
  atsStatusOutput => '1.3.6.1.4.1.318.1.1.8.5.4',
  atsNumOutputs => '1.3.6.1.4.1.318.1.1.8.5.4.1',
  atsOutputTable => '1.3.6.1.4.1.318.1.1.8.5.4.2',
  atsOutputEntry => '1.3.6.1.4.1.318.1.1.8.5.4.2.1',
  atsOutputTableIndex => '1.3.6.1.4.1.318.1.1.8.5.4.2.1.1',
  atsNumOutputPhases => '1.3.6.1.4.1.318.1.1.8.5.4.2.1.2',
  atsOutputVoltageOrientation => '1.3.6.1.4.1.318.1.1.8.5.4.2.1.3',
  atsOutputVoltageOrientationDefinition => 'PowerNet-MIB::atsOutputVoltageOrientation',
  atsOutputFrequency => '1.3.6.1.4.1.318.1.1.8.5.4.2.1.4',
  atsOutputPhaseTable => '1.3.6.1.4.1.318.1.1.8.5.4.3',
  atsOutputPhaseEntry => '1.3.6.1.4.1.318.1.1.8.5.4.3.1',
  atsOutputPhaseTableIndex => '1.3.6.1.4.1.318.1.1.8.5.4.3.1.1',
  atsOutputPhaseIndex => '1.3.6.1.4.1.318.1.1.8.5.4.3.1.2',
  atsOutputPhaseIndexDefinition => 'PowerNet-MIB::atsOutputPhaseIndex',
  atsOutputVoltage => '1.3.6.1.4.1.318.1.1.8.5.4.3.1.3',
  atsOutputCurrent => '1.3.6.1.4.1.318.1.1.8.5.4.3.1.4',
  atsOutputMaxCurrent => '1.3.6.1.4.1.318.1.1.8.5.4.3.1.5',
  atsOutputMinCurrent => '1.3.6.1.4.1.318.1.1.8.5.4.3.1.6',
  atsOutputLoad => '1.3.6.1.4.1.318.1.1.8.5.4.3.1.7',
  atsOutputMaxLoad => '1.3.6.1.4.1.318.1.1.8.5.4.3.1.8',
  atsOutputMinLoad => '1.3.6.1.4.1.318.1.1.8.5.4.3.1.9',
  atsOutputPercentLoad => '1.3.6.1.4.1.318.1.1.8.5.4.3.1.10',
  atsOutputMaxPercentLoad => '1.3.6.1.4.1.318.1.1.8.5.4.3.1.11',
  atsOutputMinPercentLoad => '1.3.6.1.4.1.318.1.1.8.5.4.3.1.12',
  atsOutputPower => '1.3.6.1.4.1.318.1.1.8.5.4.3.1.13',
  atsOutputMaxPower => '1.3.6.1.4.1.318.1.1.8.5.4.3.1.14',
  atsOutputMinPower => '1.3.6.1.4.1.318.1.1.8.5.4.3.1.15',
  atsOutputPercentPower => '1.3.6.1.4.1.318.1.1.8.5.4.3.1.16',
  atsOutputMaxPercentPower => '1.3.6.1.4.1.318.1.1.8.5.4.3.1.17',
  atsOutputMinPercentPower => '1.3.6.1.4.1.318.1.1.8.5.4.3.1.18',
  atsOutputPhaseState => '1.3.6.1.4.1.318.1.1.8.5.4.3.1.19',
  atsOutputPhaseStateDefinition => 'PowerNet-MIB::atsOutputPhaseState',
  atsOutputBankTableSize => '1.3.6.1.4.1.318.1.1.8.5.4.4',
  atsOutputBankTable => '1.3.6.1.4.1.318.1.1.8.5.4.5',
  atsOutputBankEntry => '1.3.6.1.4.1.318.1.1.8.5.4.5.1',
  atsOutputBankTableIndex => '1.3.6.1.4.1.318.1.1.8.5.4.5.1.1',
  atsOutputPhase => '1.3.6.1.4.1.318.1.1.8.5.4.5.1.2',
  atsOutputPhaseDefinition => 'PowerNet-MIB::atsOutputPhase',
  atsOutputBank => '1.3.6.1.4.1.318.1.1.8.5.4.5.1.3',
  atsOutputBankDefinition => 'PowerNet-MIB::atsOutputBank',
  atsOutputBankCurrent => '1.3.6.1.4.1.318.1.1.8.5.4.5.1.4',
  atsOutputBankState => '1.3.6.1.4.1.318.1.1.8.5.4.5.1.5',
  atsOutputBankStateDefinition => 'PowerNet-MIB::atsOutputBankState',
  atsOutputBankOutputVoltage => '1.3.6.1.4.1.318.1.1.8.5.4.5.1.6',
  atsOutputBankMaxCurrent => '1.3.6.1.4.1.318.1.1.8.5.4.5.1.7',
  atsOutputBankMinCurrent => '1.3.6.1.4.1.318.1.1.8.5.4.5.1.8',
  atsOutputBankLoad => '1.3.6.1.4.1.318.1.1.8.5.4.5.1.9',
  atsOutputBankMaxLoad => '1.3.6.1.4.1.318.1.1.8.5.4.5.1.10',
  atsOutputBankMinLoad => '1.3.6.1.4.1.318.1.1.8.5.4.5.1.11',
  atsOutputBankPercentLoad => '1.3.6.1.4.1.318.1.1.8.5.4.5.1.12',
  atsOutputBankMaxPercentLoad => '1.3.6.1.4.1.318.1.1.8.5.4.5.1.13',
  atsOutputBankMinPercentLoad => '1.3.6.1.4.1.318.1.1.8.5.4.5.1.14',
  atsOutputBankPower => '1.3.6.1.4.1.318.1.1.8.5.4.5.1.15',
  atsOutputBankMaxPower => '1.3.6.1.4.1.318.1.1.8.5.4.5.1.16',
  atsOutputBankMinPower => '1.3.6.1.4.1.318.1.1.8.5.4.5.1.17',
  atsOutputBankPercentPower => '1.3.6.1.4.1.318.1.1.8.5.4.5.1.18',
  atsOutputBankMaxPercentPower => '1.3.6.1.4.1.318.1.1.8.5.4.5.1.19',
  atsOutputBankMinPercentPower => '1.3.6.1.4.1.318.1.1.8.5.4.5.1.20',
  dc2 => '1.3.6.1.4.1.318.1.1.9',
  dcmim2Ident => '1.3.6.1.4.1.318.1.1.9.1',
  dcmim2IdentSystem => '1.3.6.1.4.1.318.1.1.9.1.1',
  dcmim2IdentSysFWVersion => '1.3.6.1.4.1.318.1.1.9.1.1.1',
  dcmim2Control => '1.3.6.1.4.1.318.1.1.9.2',
  dcmim2ControlSystem => '1.3.6.1.4.1.318.1.1.9.2.1',
  dcmim2ControlRunFunctBatteryTest => '1.3.6.1.4.1.318.1.1.9.2.1.1',
  dcmim2ControlRunFunctBatteryTestDefinition => 'PowerNet-MIB::dcmim2ControlRunFunctBatteryTest',
  dcmim2ControlRunCapacityBatteryTest => '1.3.6.1.4.1.318.1.1.9.2.1.2',
  dcmim2ControlRunCapacityBatteryTestDefinition => 'PowerNet-MIB::dcmim2ControlRunCapacityBatteryTest',
  dcmim2Config => '1.3.6.1.4.1.318.1.1.9.3',
  dcmim2ConfigSystem => '1.3.6.1.4.1.318.1.1.9.3.1',
  dcmim2ConfigSysHighTempTrip => '1.3.6.1.4.1.318.1.1.9.3.1.1',
  dcmim2ConfigSysHighTempReset => '1.3.6.1.4.1.318.1.1.9.3.1.2',
  dcmim2ConfigSysLowTempTrip => '1.3.6.1.4.1.318.1.1.9.3.1.3',
  dcmim2ConfigSysLowTempReset => '1.3.6.1.4.1.318.1.1.9.3.1.4',
  dcmim2ConfigBattery => '1.3.6.1.4.1.318.1.1.9.3.2',
  dcmim2ConfigBattFloatVolt => '1.3.6.1.4.1.318.1.1.9.3.2.1',
  dcmim2ConfigBattMaxRecharge => '1.3.6.1.4.1.318.1.1.9.3.2.2',
  dcmim2ConfigBattMfgCapacity => '1.3.6.1.4.1.318.1.1.9.3.2.3',
  dcmim2ConfigBattType => '1.3.6.1.4.1.318.1.1.9.3.2.4',
  dcmim2ConfigBattFunctTestDuration => '1.3.6.1.4.1.318.1.1.9.3.2.5',
  dcmim2ConfigBattFunctTestThresh => '1.3.6.1.4.1.318.1.1.9.3.2.6',
  dcmim2ConfigBattCapacityTestPercent => '1.3.6.1.4.1.318.1.1.9.3.2.7',
  dcmim2ConfigBattCapacityTestEndThresh => '1.3.6.1.4.1.318.1.1.9.3.2.8',
  dcmim2ConfigBattCapacityTestCurrent => '1.3.6.1.4.1.318.1.1.9.3.2.9',
  dcmim2ConfigLVD => '1.3.6.1.4.1.318.1.1.9.3.3',
  dcmim2ConfigLVDTableSize => '1.3.6.1.4.1.318.1.1.9.3.3.1',
  dcmim2ConfigLVDTable => '1.3.6.1.4.1.318.1.1.9.3.3.2',
  dcmim2ConfigLVDEntry => '1.3.6.1.4.1.318.1.1.9.3.3.2.1',
  dcmim2ConfigLVDIndex => '1.3.6.1.4.1.318.1.1.9.3.3.2.1.1',
  dcmim2ConfigLVDTrip => '1.3.6.1.4.1.318.1.1.9.3.3.2.1.2',
  dcmim2ConfigLVDReset => '1.3.6.1.4.1.318.1.1.9.3.3.2.1.3',
  dcmim2ConfigLVDState => '1.3.6.1.4.1.318.1.1.9.3.3.2.1.4',
  dcmim2ConfigLVDStateDefinition => 'PowerNet-MIB::dcmim2ConfigLVDState',
  dcmim2Status => '1.3.6.1.4.1.318.1.1.9.4',
  dcmim2StatusSystem => '1.3.6.1.4.1.318.1.1.9.4.1',
  dcmim2StatusSysRectCurrent => '1.3.6.1.4.1.318.1.1.9.4.1.1',
  dcmim2StatusSysLoadCurrent => '1.3.6.1.4.1.318.1.1.9.4.1.2',
  dcmim2StatusSysBusVoltage => '1.3.6.1.4.1.318.1.1.9.4.1.3',
  dcmim2StatusSysAmbientTemp => '1.3.6.1.4.1.318.1.1.9.4.1.4',
  dcmim2StatusSysUpTime => '1.3.6.1.4.1.318.1.1.9.4.1.5',
  dcmim2StatusSysTempUnits => '1.3.6.1.4.1.318.1.1.9.4.1.6',
  dcmim2StatusSysTempUnitsDefinition => 'PowerNet-MIB::dcmim2StatusSysTempUnits',
  dcmim2StatusRectifier => '1.3.6.1.4.1.318.1.1.9.4.2',
  dcmim2StatusRectTableSize => '1.3.6.1.4.1.318.1.1.9.4.2.1',
  dcmim2StatusRectTable => '1.3.6.1.4.1.318.1.1.9.4.2.2',
  dcmim2StatusRectEntry => '1.3.6.1.4.1.318.1.1.9.4.2.2.1',
  dcmim2StatusRectIndex => '1.3.6.1.4.1.318.1.1.9.4.2.2.1.1',
  dcmim2StatusRectDevType => '1.3.6.1.4.1.318.1.1.9.4.2.2.1.2',
  dcmim2StatusRectID => '1.3.6.1.4.1.318.1.1.9.4.2.2.1.3',
  dcmim2StatusRectPhyAddr => '1.3.6.1.4.1.318.1.1.9.4.2.2.1.4',
  dcmim2StatusRectFail => '1.3.6.1.4.1.318.1.1.9.4.2.2.1.5',
  dcmim2StatusRectFailDefinition => 'PowerNet-MIB::dcmim2StatusRectFail',
  dcmim2StatusRectCurrent => '1.3.6.1.4.1.318.1.1.9.4.2.2.1.6',
  dcmim2StatusBattery => '1.3.6.1.4.1.318.1.1.9.4.3',
  dcmim2StatusBattFloatVolt => '1.3.6.1.4.1.318.1.1.9.4.3.1',
  dcmim2StatusBattCurrent => '1.3.6.1.4.1.318.1.1.9.4.3.2',
  dcmim2StatusBattTemp => '1.3.6.1.4.1.318.1.1.9.4.3.3',
  dcmim2StatusBattMfgCapacity => '1.3.6.1.4.1.318.1.1.9.4.3.4',
  dcmim2StatusBattTestCapacity => '1.3.6.1.4.1.318.1.1.9.4.3.5',
  dcmim2StatusBattFunctTestResult => '1.3.6.1.4.1.318.1.1.9.4.3.6',
  dcmim2StatusBattFunctTestResultDefinition => 'PowerNet-MIB::dcmim2StatusBattFunctTestResult',
  dcmim2StatusBattCapacityTestResult => '1.3.6.1.4.1.318.1.1.9.4.3.7',
  dcmim2StatusBattCapacityTestResultDefinition => 'PowerNet-MIB::dcmim2StatusBattCapacityTestResult',
  dcmim2StatusLVD => '1.3.6.1.4.1.318.1.1.9.4.4',
  dcmim2StatusLVDTableSize => '1.3.6.1.4.1.318.1.1.9.4.4.1',
  dcmim2StatusLVDTable => '1.3.6.1.4.1.318.1.1.9.4.4.2',
  dcmim2StatusLVDEntry => '1.3.6.1.4.1.318.1.1.9.4.4.2.1',
  dcmim2StatusLVDIndex => '1.3.6.1.4.1.318.1.1.9.4.4.2.1.1',
  dcmim2StatusLVDState => '1.3.6.1.4.1.318.1.1.9.4.4.2.1.2',
  dcmim2StatusLVDStateDefinition => 'PowerNet-MIB::dcmim2StatusLVDState',
  dcmim2StatusAlarms => '1.3.6.1.4.1.318.1.1.9.4.5',
  dcmim2StatusAlarmsTableSize => '1.3.6.1.4.1.318.1.1.9.4.5.1',
  dcmim2StatusAlarmsTable => '1.3.6.1.4.1.318.1.1.9.4.5.2',
  dcmim2StatusAlarmsEntry => '1.3.6.1.4.1.318.1.1.9.4.5.2.1',
  dcmim2StatusAlarmsIndex => '1.3.6.1.4.1.318.1.1.9.4.5.2.1.1',
  dcmim2StatusAlarmsText => '1.3.6.1.4.1.318.1.1.9.4.5.2.1.2',
  environmentalMonitor => '1.3.6.1.4.1.318.1.1.10',
  external => '1.3.6.1.4.1.318.1.1.10.1',
  emIdent => '1.3.6.1.4.1.318.1.1.10.1.1',
  emIdentFirmwareRevision => '1.3.6.1.4.1.318.1.1.10.1.1.1',
  emConfig => '1.3.6.1.4.1.318.1.1.10.1.2',
  emConfigProbesNumProbes => '1.3.6.1.4.1.318.1.1.10.1.2.1',
  emConfigProbesTable => '1.3.6.1.4.1.318.1.1.10.1.2.2',
  emConfigProbesEntry => '1.3.6.1.4.1.318.1.1.10.1.2.2.1',
  emConfigProbeNumber => '1.3.6.1.4.1.318.1.1.10.1.2.2.1.1',
  emConfigProbeName => '1.3.6.1.4.1.318.1.1.10.1.2.2.1.2',
  emConfigProbeHighTempThreshold => '1.3.6.1.4.1.318.1.1.10.1.2.2.1.3',
  emConfigProbeLowTempThreshold => '1.3.6.1.4.1.318.1.1.10.1.2.2.1.4',
  emConfigProbeTempUnits => '1.3.6.1.4.1.318.1.1.10.1.2.2.1.5',
  emConfigProbeTempUnitsDefinition => 'PowerNet-MIB::emConfigProbeTempUnits',
  emConfigProbeHighHumidThreshold => '1.3.6.1.4.1.318.1.1.10.1.2.2.1.6',
  emConfigProbeLowHumidThreshold => '1.3.6.1.4.1.318.1.1.10.1.2.2.1.7',
  emConfigProbeHighTempEnable => '1.3.6.1.4.1.318.1.1.10.1.2.2.1.8',
  emConfigProbeHighTempEnableDefinition => 'PowerNet-MIB::emConfigProbeHighTempEnable',
  emConfigProbeLowTempEnable => '1.3.6.1.4.1.318.1.1.10.1.2.2.1.9',
  emConfigProbeLowTempEnableDefinition => 'PowerNet-MIB::emConfigProbeLowTempEnable',
  emConfigProbeHighHumidEnable => '1.3.6.1.4.1.318.1.1.10.1.2.2.1.10',
  emConfigProbeHighHumidEnableDefinition => 'PowerNet-MIB::emConfigProbeHighHumidEnable',
  emConfigProbeLowHumidEnable => '1.3.6.1.4.1.318.1.1.10.1.2.2.1.11',
  emConfigProbeLowHumidEnableDefinition => 'PowerNet-MIB::emConfigProbeLowHumidEnable',
  emConfigProbeMaxTempThreshold => '1.3.6.1.4.1.318.1.1.10.1.2.2.1.12',
  emConfigProbeMinTempThreshold => '1.3.6.1.4.1.318.1.1.10.1.2.2.1.13',
  emConfigProbeMaxHumidThreshold => '1.3.6.1.4.1.318.1.1.10.1.2.2.1.14',
  emConfigProbeMinHumidThreshold => '1.3.6.1.4.1.318.1.1.10.1.2.2.1.15',
  emConfigProbeMaxTempEnable => '1.3.6.1.4.1.318.1.1.10.1.2.2.1.16',
  emConfigProbeMaxTempEnableDefinition => 'PowerNet-MIB::emConfigProbeMaxTempEnable',
  emConfigProbeMinTempEnable => '1.3.6.1.4.1.318.1.1.10.1.2.2.1.17',
  emConfigProbeMinTempEnableDefinition => 'PowerNet-MIB::emConfigProbeMinTempEnable',
  emConfigProbeMaxHumidEnable => '1.3.6.1.4.1.318.1.1.10.1.2.2.1.18',
  emConfigProbeMaxHumidEnableDefinition => 'PowerNet-MIB::emConfigProbeMaxHumidEnable',
  emConfigProbeMinHumidEnable => '1.3.6.1.4.1.318.1.1.10.1.2.2.1.19',
  emConfigProbeMinHumidEnableDefinition => 'PowerNet-MIB::emConfigProbeMinHumidEnable',
  emConfigProbeTempHysteresis => '1.3.6.1.4.1.318.1.1.10.1.2.2.1.20',
  emConfigProbeHumidHysteresis => '1.3.6.1.4.1.318.1.1.10.1.2.2.1.21',
  emConfigProbeLocation => '1.3.6.1.4.1.318.1.1.10.1.2.2.1.22',
  emConfigContactsNumContacts => '1.3.6.1.4.1.318.1.1.10.1.2.3',
  emConfigContactsTable => '1.3.6.1.4.1.318.1.1.10.1.2.4',
  emConfigContactsEntry => '1.3.6.1.4.1.318.1.1.10.1.2.4.1',
  emConfigContactNumber => '1.3.6.1.4.1.318.1.1.10.1.2.4.1.1',
  emConfigContactName => '1.3.6.1.4.1.318.1.1.10.1.2.4.1.2',
  emConfigContactEnable => '1.3.6.1.4.1.318.1.1.10.1.2.4.1.3',
  emConfigContactEnableDefinition => 'PowerNet-MIB::emConfigContactEnable',
  emConfigContactSeverity => '1.3.6.1.4.1.318.1.1.10.1.2.4.1.4',
  emConfigContactSeverityDefinition => 'PowerNet-MIB::emConfigContactSeverity',
  emConfigContactNormalState => '1.3.6.1.4.1.318.1.1.10.1.2.4.1.5',
  emConfigContactNormalStateDefinition => 'PowerNet-MIB::emConfigContactNormalState',
  emConfigContactLocation => '1.3.6.1.4.1.318.1.1.10.1.2.4.1.6',
  emStatus => '1.3.6.1.4.1.318.1.1.10.1.3',
  emStatusCommStatus => '1.3.6.1.4.1.318.1.1.10.1.3.1',
  emStatusCommStatusDefinition => 'PowerNet-MIB::emStatusCommStatus',
  emStatusProbesNumProbes => '1.3.6.1.4.1.318.1.1.10.1.3.2',
  emStatusProbesTable => '1.3.6.1.4.1.318.1.1.10.1.3.3',
  emStatusProbesEntry => '1.3.6.1.4.1.318.1.1.10.1.3.3.1',
  emStatusProbeNumber => '1.3.6.1.4.1.318.1.1.10.1.3.3.1.1',
  emStatusProbeName => '1.3.6.1.4.1.318.1.1.10.1.3.3.1.2',
  emStatusProbeStatus => '1.3.6.1.4.1.318.1.1.10.1.3.3.1.3',
  emStatusProbeStatusDefinition => 'PowerNet-MIB::emStatusProbeStatus',
  emStatusProbeCurrentTemp => '1.3.6.1.4.1.318.1.1.10.1.3.3.1.4',
  emStatusProbeTempUnits => '1.3.6.1.4.1.318.1.1.10.1.3.3.1.5',
  emStatusProbeTempUnitsDefinition => 'PowerNet-MIB::emStatusProbeTempUnits',
  emStatusProbeCurrentHumid => '1.3.6.1.4.1.318.1.1.10.1.3.3.1.6',
  emStatusProbeHighTempViolation => '1.3.6.1.4.1.318.1.1.10.1.3.3.1.7',
  emStatusProbeHighTempViolationDefinition => 'PowerNet-MIB::emStatusProbeHighTempViolation',
  emStatusProbeLowTempViolation => '1.3.6.1.4.1.318.1.1.10.1.3.3.1.8',
  emStatusProbeLowTempViolationDefinition => 'PowerNet-MIB::emStatusProbeLowTempViolation',
  emStatusProbeHighHumidViolation => '1.3.6.1.4.1.318.1.1.10.1.3.3.1.9',
  emStatusProbeHighHumidViolationDefinition => 'PowerNet-MIB::emStatusProbeHighHumidViolation',
  emStatusProbeLowHumidViolation => '1.3.6.1.4.1.318.1.1.10.1.3.3.1.10',
  emStatusProbeLowHumidViolationDefinition => 'PowerNet-MIB::emStatusProbeLowHumidViolation',
  emStatusProbeMaxTempViolation => '1.3.6.1.4.1.318.1.1.10.1.3.3.1.11',
  emStatusProbeMaxTempViolationDefinition => 'PowerNet-MIB::emStatusProbeMaxTempViolation',
  emStatusProbeMinTempViolation => '1.3.6.1.4.1.318.1.1.10.1.3.3.1.12',
  emStatusProbeMinTempViolationDefinition => 'PowerNet-MIB::emStatusProbeMinTempViolation',
  emStatusProbeMaxHumidViolation => '1.3.6.1.4.1.318.1.1.10.1.3.3.1.13',
  emStatusProbeMaxHumidViolationDefinition => 'PowerNet-MIB::emStatusProbeMaxHumidViolation',
  emStatusProbeMinHumidViolation => '1.3.6.1.4.1.318.1.1.10.1.3.3.1.14',
  emStatusProbeMinHumidViolationDefinition => 'PowerNet-MIB::emStatusProbeMinHumidViolation',
  emStatusContactsNumContacts => '1.3.6.1.4.1.318.1.1.10.1.3.4',
  emStatusContactsTable => '1.3.6.1.4.1.318.1.1.10.1.3.5',
  emStatusContactsEntry => '1.3.6.1.4.1.318.1.1.10.1.3.5.1',
  emStatusContactNumber => '1.3.6.1.4.1.318.1.1.10.1.3.5.1.1',
  emStatusContactName => '1.3.6.1.4.1.318.1.1.10.1.3.5.1.2',
  emStatusContactStatus => '1.3.6.1.4.1.318.1.1.10.1.3.5.1.3',
  emStatusContactStatusDefinition => 'PowerNet-MIB::emStatusContactStatus',
  integrated => '1.3.6.1.4.1.318.1.1.10.2',
  iemIdent => '1.3.6.1.4.1.318.1.1.10.2.1',
  iemIdentHardwareRevision => '1.3.6.1.4.1.318.1.1.10.2.1.1',
  iemConfig => '1.3.6.1.4.1.318.1.1.10.2.2',
  iemConfigProbesNumProbes => '1.3.6.1.4.1.318.1.1.10.2.2.1',
  iemConfigProbesTable => '1.3.6.1.4.1.318.1.1.10.2.2.2',
  iemConfigProbesEntry => '1.3.6.1.4.1.318.1.1.10.2.2.2.1',
  iemConfigProbeNumber => '1.3.6.1.4.1.318.1.1.10.2.2.2.1.1',
  iemConfigProbeName => '1.3.6.1.4.1.318.1.1.10.2.2.2.1.2',
  iemConfigProbeHighTempThreshold => '1.3.6.1.4.1.318.1.1.10.2.2.2.1.3',
  iemConfigProbeLowTempThreshold => '1.3.6.1.4.1.318.1.1.10.2.2.2.1.4',
  iemConfigProbeTempUnits => '1.3.6.1.4.1.318.1.1.10.2.2.2.1.5',
  iemConfigProbeTempUnitsDefinition => 'PowerNet-MIB::iemConfigProbeTempUnits',
  iemConfigProbeHighHumidThreshold => '1.3.6.1.4.1.318.1.1.10.2.2.2.1.6',
  iemConfigProbeLowHumidThreshold => '1.3.6.1.4.1.318.1.1.10.2.2.2.1.7',
  iemConfigProbeHighTempEnable => '1.3.6.1.4.1.318.1.1.10.2.2.2.1.8',
  iemConfigProbeHighTempEnableDefinition => 'PowerNet-MIB::iemConfigProbeHighTempEnable',
  iemConfigProbeLowTempEnable => '1.3.6.1.4.1.318.1.1.10.2.2.2.1.9',
  iemConfigProbeLowTempEnableDefinition => 'PowerNet-MIB::iemConfigProbeLowTempEnable',
  iemConfigProbeHighHumidEnable => '1.3.6.1.4.1.318.1.1.10.2.2.2.1.10',
  iemConfigProbeHighHumidEnableDefinition => 'PowerNet-MIB::iemConfigProbeHighHumidEnable',
  iemConfigProbeLowHumidEnable => '1.3.6.1.4.1.318.1.1.10.2.2.2.1.11',
  iemConfigProbeLowHumidEnableDefinition => 'PowerNet-MIB::iemConfigProbeLowHumidEnable',
  iemConfigProbeMaxTempThreshold => '1.3.6.1.4.1.318.1.1.10.2.2.2.1.12',
  iemConfigProbeMinTempThreshold => '1.3.6.1.4.1.318.1.1.10.2.2.2.1.13',
  iemConfigProbeMaxHumidThreshold => '1.3.6.1.4.1.318.1.1.10.2.2.2.1.14',
  iemConfigProbeMinHumidThreshold => '1.3.6.1.4.1.318.1.1.10.2.2.2.1.15',
  iemConfigProbeMaxTempEnable => '1.3.6.1.4.1.318.1.1.10.2.2.2.1.16',
  iemConfigProbeMaxTempEnableDefinition => 'PowerNet-MIB::iemConfigProbeMaxTempEnable',
  iemConfigProbeMinTempEnable => '1.3.6.1.4.1.318.1.1.10.2.2.2.1.17',
  iemConfigProbeMinTempEnableDefinition => 'PowerNet-MIB::iemConfigProbeMinTempEnable',
  iemConfigProbeMaxHumidEnable => '1.3.6.1.4.1.318.1.1.10.2.2.2.1.18',
  iemConfigProbeMaxHumidEnableDefinition => 'PowerNet-MIB::iemConfigProbeMaxHumidEnable',
  iemConfigProbeMinHumidEnable => '1.3.6.1.4.1.318.1.1.10.2.2.2.1.19',
  iemConfigProbeMinHumidEnableDefinition => 'PowerNet-MIB::iemConfigProbeMinHumidEnable',
  iemConfigProbeTempHysteresis => '1.3.6.1.4.1.318.1.1.10.2.2.2.1.20',
  iemConfigProbeHumidHysteresis => '1.3.6.1.4.1.318.1.1.10.2.2.2.1.21',
  iemConfigProbeLocation => '1.3.6.1.4.1.318.1.1.10.2.2.2.1.22',
  iemConfigContactsNumContacts => '1.3.6.1.4.1.318.1.1.10.2.2.3',
  iemConfigContactsTable => '1.3.6.1.4.1.318.1.1.10.2.2.4',
  iemConfigContactsEntry => '1.3.6.1.4.1.318.1.1.10.2.2.4.1',
  iemConfigContactNumber => '1.3.6.1.4.1.318.1.1.10.2.2.4.1.1',
  iemConfigContactName => '1.3.6.1.4.1.318.1.1.10.2.2.4.1.2',
  iemConfigContactEnable => '1.3.6.1.4.1.318.1.1.10.2.2.4.1.3',
  iemConfigContactEnableDefinition => 'PowerNet-MIB::iemConfigContactEnable',
  iemConfigContactSeverity => '1.3.6.1.4.1.318.1.1.10.2.2.4.1.4',
  iemConfigContactSeverityDefinition => 'PowerNet-MIB::iemConfigContactSeverity',
  iemConfigContactNormalState => '1.3.6.1.4.1.318.1.1.10.2.2.4.1.5',
  iemConfigContactNormalStateDefinition => 'PowerNet-MIB::iemConfigContactNormalState',
  iemConfigContactLocation => '1.3.6.1.4.1.318.1.1.10.2.2.4.1.6',
  iemConfigConfigRelaysNumRelays => '1.3.6.1.4.1.318.1.1.10.2.2.5',
  iemConfigRelaysTable => '1.3.6.1.4.1.318.1.1.10.2.2.6',
  iemConfigRelaysEntry => '1.3.6.1.4.1.318.1.1.10.2.2.6.1',
  iemConfigRelayNumber => '1.3.6.1.4.1.318.1.1.10.2.2.6.1.1',
  iemConfigRelayName => '1.3.6.1.4.1.318.1.1.10.2.2.6.1.2',
  iemConfigRelayNormalState => '1.3.6.1.4.1.318.1.1.10.2.2.6.1.3',
  iemConfigRelayNormalStateDefinition => 'PowerNet-MIB::iemConfigRelayNormalState',
  iemConfigRelayFaultCondition => '1.3.6.1.4.1.318.1.1.10.2.2.6.1.4',
  iemStatus => '1.3.6.1.4.1.318.1.1.10.2.3',
  iemStatusProbesNumProbes => '1.3.6.1.4.1.318.1.1.10.2.3.1',
  iemStatusProbesTable => '1.3.6.1.4.1.318.1.1.10.2.3.2',
  iemStatusProbesEntry => '1.3.6.1.4.1.318.1.1.10.2.3.2.1',
  iemStatusProbeNumber => '1.3.6.1.4.1.318.1.1.10.2.3.2.1.1',
  iemStatusProbeName => '1.3.6.1.4.1.318.1.1.10.2.3.2.1.2',
  iemStatusProbeStatus => '1.3.6.1.4.1.318.1.1.10.2.3.2.1.3',
  iemStatusProbeStatusDefinition => 'PowerNet-MIB::iemStatusProbeStatus',
  iemStatusProbeCurrentTemp => '1.3.6.1.4.1.318.1.1.10.2.3.2.1.4',
  iemStatusProbeTempUnits => '1.3.6.1.4.1.318.1.1.10.2.3.2.1.5',
  iemStatusProbeTempUnitsDefinition => 'PowerNet-MIB::iemStatusProbeTempUnits',
  iemStatusProbeCurrentHumid => '1.3.6.1.4.1.318.1.1.10.2.3.2.1.6',
  iemStatusProbeHighTempViolation => '1.3.6.1.4.1.318.1.1.10.2.3.2.1.7',
  iemStatusProbeHighTempViolationDefinition => 'PowerNet-MIB::iemStatusProbeHighTempViolation',
  iemStatusProbeLowTempViolation => '1.3.6.1.4.1.318.1.1.10.2.3.2.1.8',
  iemStatusProbeLowTempViolationDefinition => 'PowerNet-MIB::iemStatusProbeLowTempViolation',
  iemStatusProbeHighHumidViolation => '1.3.6.1.4.1.318.1.1.10.2.3.2.1.9',
  iemStatusProbeHighHumidViolationDefinition => 'PowerNet-MIB::iemStatusProbeHighHumidViolation',
  iemStatusProbeLowHumidViolation => '1.3.6.1.4.1.318.1.1.10.2.3.2.1.10',
  iemStatusProbeLowHumidViolationDefinition => 'PowerNet-MIB::iemStatusProbeLowHumidViolation',
  iemStatusProbeMaxTempViolation => '1.3.6.1.4.1.318.1.1.10.2.3.2.1.11',
  iemStatusProbeMaxTempViolationDefinition => 'PowerNet-MIB::iemStatusProbeMaxTempViolation',
  iemStatusProbeMinTempViolation => '1.3.6.1.4.1.318.1.1.10.2.3.2.1.12',
  iemStatusProbeMinTempViolationDefinition => 'PowerNet-MIB::iemStatusProbeMinTempViolation',
  iemStatusProbeMaxHumidViolation => '1.3.6.1.4.1.318.1.1.10.2.3.2.1.13',
  iemStatusProbeMaxHumidViolationDefinition => 'PowerNet-MIB::iemStatusProbeMaxHumidViolation',
  iemStatusProbeMinHumidViolation => '1.3.6.1.4.1.318.1.1.10.2.3.2.1.14',
  iemStatusProbeMinHumidViolationDefinition => 'PowerNet-MIB::iemStatusProbeMinHumidViolation',
  iemStatusProbeLocation => '1.3.6.1.4.1.318.1.1.10.2.3.2.1.15',
  iemStatusContactsNumContacts => '1.3.6.1.4.1.318.1.1.10.2.3.3',
  iemStatusContactsTable => '1.3.6.1.4.1.318.1.1.10.2.3.4',
  iemStatusContactsEntry => '1.3.6.1.4.1.318.1.1.10.2.3.4.1',
  iemStatusContactNumber => '1.3.6.1.4.1.318.1.1.10.2.3.4.1.1',
  iemStatusContactName => '1.3.6.1.4.1.318.1.1.10.2.3.4.1.2',
  iemStatusContactStatus => '1.3.6.1.4.1.318.1.1.10.2.3.4.1.3',
  iemStatusContactStatusDefinition => 'PowerNet-MIB::iemStatusContactStatus',
  iemStatusRelaysNumRelays => '1.3.6.1.4.1.318.1.1.10.2.3.6',
  iemStatusRelaysTable => '1.3.6.1.4.1.318.1.1.10.2.3.7',
  iemStatusRelaysEntry => '1.3.6.1.4.1.318.1.1.10.2.3.7.1',
  iemStatusRelayNumber => '1.3.6.1.4.1.318.1.1.10.2.3.7.1.1',
  iemStatusRelayName => '1.3.6.1.4.1.318.1.1.10.2.3.7.1.2',
  iemStatusRelayStatus => '1.3.6.1.4.1.318.1.1.10.2.3.7.1.3',
  iemStatusRelayStatusDefinition => 'PowerNet-MIB::iemStatusRelayStatus',
  envMgtSystem => '1.3.6.1.4.1.318.1.1.10.3',
  emsIdent => '1.3.6.1.4.1.318.1.1.10.3.1',
  emsIdentEMSName => '1.3.6.1.4.1.318.1.1.10.3.1.1',
  emsIdentProductNumber => '1.3.6.1.4.1.318.1.1.10.3.1.2',
  emsIdentFirmwareRev => '1.3.6.1.4.1.318.1.1.10.3.1.3',
  emsIdentHardwareRev => '1.3.6.1.4.1.318.1.1.10.3.1.4',
  emsIdentDateOfManufacture => '1.3.6.1.4.1.318.1.1.10.3.1.5',
  emsIdentSerialNumber => '1.3.6.1.4.1.318.1.1.10.3.1.6',
  emsOutputRelayControl => '1.3.6.1.4.1.318.1.1.10.3.2',
  emsOutputRelayControlTable => '1.3.6.1.4.1.318.1.1.10.3.2.1',
  emsOutputRelayControlEntry => '1.3.6.1.4.1.318.1.1.10.3.2.1.1',
  emsOutputRelayControlOutputRelayIndex => '1.3.6.1.4.1.318.1.1.10.3.2.1.1.1',
  emsOutputRelayControlOutputRelayName => '1.3.6.1.4.1.318.1.1.10.3.2.1.1.2',
  emsOutputRelayControlOutputRelayCommand => '1.3.6.1.4.1.318.1.1.10.3.2.1.1.3',
  emsOutputRelayControlOutputRelayCommandDefinition => 'PowerNet-MIB::emsOutputRelayControlOutputRelayCommand',
  emsOutletControl => '1.3.6.1.4.1.318.1.1.10.3.3',
  emsOutletControlTable => '1.3.6.1.4.1.318.1.1.10.3.3.1',
  emsOutletControlEntry => '1.3.6.1.4.1.318.1.1.10.3.3.1.1',
  emsOutletControlOutletIndex => '1.3.6.1.4.1.318.1.1.10.3.3.1.1.1',
  emsOutletControlOutletName => '1.3.6.1.4.1.318.1.1.10.3.3.1.1.2',
  emsOutletControlOutletCommand => '1.3.6.1.4.1.318.1.1.10.3.3.1.1.3',
  emsOutletControlOutletCommandDefinition => 'PowerNet-MIB::emsOutletControlOutletCommand',
  emsSensorControl => '1.3.6.1.4.1.318.1.1.10.3.4',
  emsSensorControlTable => '1.3.6.1.4.1.318.1.1.10.3.4.1',
  emsSensorControlEntry => '1.3.6.1.4.1.318.1.1.10.3.4.1.1',
  emsSensorControlSensorIndex => '1.3.6.1.4.1.318.1.1.10.3.4.1.1.1',
  emsSensorControlSensorSystemName => '1.3.6.1.4.1.318.1.1.10.3.4.1.1.2',
  emsSensorControlSensorUserName => '1.3.6.1.4.1.318.1.1.10.3.4.1.1.3',
  emsSensorControlSensorCommand => '1.3.6.1.4.1.318.1.1.10.3.4.1.1.4',
  emsSensorControlSensorCommandDefinition => 'PowerNet-MIB::emsSensorControlSensorCommand',
  emsAlarmDeviceControl => '1.3.6.1.4.1.318.1.1.10.3.5',
  emsAlarmDeviceControlTable => '1.3.6.1.4.1.318.1.1.10.3.5.1',
  emsAlarmDeviceControlEntry => '1.3.6.1.4.1.318.1.1.10.3.5.1.1',
  emsAlarmDeviceControlDeviceIndex => '1.3.6.1.4.1.318.1.1.10.3.5.1.1.1',
  emsAlarmDeviceControlDeviceName => '1.3.6.1.4.1.318.1.1.10.3.5.1.1.2',
  emsAlarmDeviceControlDeviceCommand => '1.3.6.1.4.1.318.1.1.10.3.5.1.1.3',
  emsAlarmDeviceControlDeviceCommandDefinition => 'PowerNet-MIB::emsAlarmDeviceControlDeviceCommand',
  emsConfig => '1.3.6.1.4.1.318.1.1.10.3.6',
  emsConfigName => '1.3.6.1.4.1.318.1.1.10.3.6.1',
  emsConfigCheckLogLight => '1.3.6.1.4.1.318.1.1.10.3.6.2',
  emsConfigCheckLogLightDefinition => 'PowerNet-MIB::emsConfigCheckLogLight',
  emsProbeConfig => '1.3.6.1.4.1.318.1.1.10.3.7',
  emsProbeConfigTable => '1.3.6.1.4.1.318.1.1.10.3.7.1',
  emsProbeConfigEntry => '1.3.6.1.4.1.318.1.1.10.3.7.1.1',
  emsProbeConfigProbeIndex => '1.3.6.1.4.1.318.1.1.10.3.7.1.1.1',
  emsProbeConfigProbeName => '1.3.6.1.4.1.318.1.1.10.3.7.1.1.2',
  emsProbeConfigProbeHighTempThresh => '1.3.6.1.4.1.318.1.1.10.3.7.1.1.3',
  emsProbeConfigProbeLowTempThresh => '1.3.6.1.4.1.318.1.1.10.3.7.1.1.4',
  emsProbeConfigProbeHighHumidityThresh => '1.3.6.1.4.1.318.1.1.10.3.7.1.1.5',
  emsProbeConfigProbeLowHumidityThresh => '1.3.6.1.4.1.318.1.1.10.3.7.1.1.6',
  emsProbeConfigProbeMaxTempThresh => '1.3.6.1.4.1.318.1.1.10.3.7.1.1.7',
  emsProbeConfigProbeMinTempThresh => '1.3.6.1.4.1.318.1.1.10.3.7.1.1.8',
  emsProbeConfigProbeDeltaTemp => '1.3.6.1.4.1.318.1.1.10.3.7.1.1.9',
  emsProbeConfigProbeMaxHumidityThresh => '1.3.6.1.4.1.318.1.1.10.3.7.1.1.10',
  emsProbeConfigProbeMinHumidityThresh => '1.3.6.1.4.1.318.1.1.10.3.7.1.1.11',
  emsProbeConfigProbeDeltaHumidity => '1.3.6.1.4.1.318.1.1.10.3.7.1.1.12',
  emsProbeConfigProbeSTIncTempVariance => '1.3.6.1.4.1.318.1.1.10.3.7.1.1.13',
  emsProbeConfigProbeSTIncTempTime => '1.3.6.1.4.1.318.1.1.10.3.7.1.1.14',
  emsProbeConfigProbeSTDecTempVariance => '1.3.6.1.4.1.318.1.1.10.3.7.1.1.15',
  emsProbeConfigProbeSTDecTempTime => '1.3.6.1.4.1.318.1.1.10.3.7.1.1.16',
  emsProbeConfigProbeLTIncTempVariance => '1.3.6.1.4.1.318.1.1.10.3.7.1.1.17',
  emsProbeConfigProbeLTIncTempTime => '1.3.6.1.4.1.318.1.1.10.3.7.1.1.18',
  emsProbeConfigProbeLTDecTempVariance => '1.3.6.1.4.1.318.1.1.10.3.7.1.1.19',
  emsProbeConfigProbeLTDecTempTime => '1.3.6.1.4.1.318.1.1.10.3.7.1.1.20',
  emsInputContactConfig => '1.3.6.1.4.1.318.1.1.10.3.8',
  emsInputContactConfigTable => '1.3.6.1.4.1.318.1.1.10.3.8.1',
  emsInputContactConfigEntry => '1.3.6.1.4.1.318.1.1.10.3.8.1.1',
  emsInputContactConfigInputContactIndex => '1.3.6.1.4.1.318.1.1.10.3.8.1.1.1',
  emsInputContactConfigInputContactName => '1.3.6.1.4.1.318.1.1.10.3.8.1.1.2',
  emsInputContactConfigInputContactNormalState => '1.3.6.1.4.1.318.1.1.10.3.8.1.1.3',
  emsInputContactConfigInputContactNormalStateDefinition => 'PowerNet-MIB::emsInputContactConfigInputContactNormalState',
  emsOutputRelayConfig => '1.3.6.1.4.1.318.1.1.10.3.9',
  emsOutputRelayConfigTable => '1.3.6.1.4.1.318.1.1.10.3.9.1',
  emsOutputRelayConfigEntry => '1.3.6.1.4.1.318.1.1.10.3.9.1.1',
  emsOutputRelayConfigOutputRelayIndex => '1.3.6.1.4.1.318.1.1.10.3.9.1.1.1',
  emsOutputRelayConfigOutputRelayName => '1.3.6.1.4.1.318.1.1.10.3.9.1.1.2',
  emsOutputRelayConfigOutputRelayNormalState => '1.3.6.1.4.1.318.1.1.10.3.9.1.1.3',
  emsOutputRelayConfigOutputRelayNormalStateDefinition => 'PowerNet-MIB::emsOutputRelayConfigOutputRelayNormalState',
  emsOutletConfig => '1.3.6.1.4.1.318.1.1.10.3.10',
  emsOutletConfigTable => '1.3.6.1.4.1.318.1.1.10.3.10.1',
  emsOutletConfigEntry => '1.3.6.1.4.1.318.1.1.10.3.10.1.1',
  emsOutletConfigOutletIndex => '1.3.6.1.4.1.318.1.1.10.3.10.1.1.1',
  emsOutletConfigOutletName => '1.3.6.1.4.1.318.1.1.10.3.10.1.1.2',
  emsOutletConfigOutletNormalState => '1.3.6.1.4.1.318.1.1.10.3.10.1.1.3',
  emsOutletConfigOutletNormalStateDefinition => 'PowerNet-MIB::emsOutletConfigOutletNormalState',
  emsSensorConfig => '1.3.6.1.4.1.318.1.1.10.3.11',
  emsSensorConfigTable => '1.3.6.1.4.1.318.1.1.10.3.11.1',
  emsSensorConfigEntry => '1.3.6.1.4.1.318.1.1.10.3.11.1.1',
  emsSensorConfigSensorIndex => '1.3.6.1.4.1.318.1.1.10.3.11.1.1.1',
  emsSensorConfigSensorSystemName => '1.3.6.1.4.1.318.1.1.10.3.11.1.1.2',
  emsSensorConfigSensorUserName => '1.3.6.1.4.1.318.1.1.10.3.11.1.1.3',
  emsSensorConfigSensorNormalState => '1.3.6.1.4.1.318.1.1.10.3.11.1.1.4',
  emsSensorConfigSensorNormalStateDefinition => 'PowerNet-MIB::emsSensorConfigSensorNormalState',
  emsSensorConfigSensorAlarmDelay => '1.3.6.1.4.1.318.1.1.10.3.11.1.1.5',
  emsStatus => '1.3.6.1.4.1.318.1.1.10.3.12',
  emsStatusEMSName => '1.3.6.1.4.1.318.1.1.10.3.12.1',
  emsStatusCommStatus => '1.3.6.1.4.1.318.1.1.10.3.12.2',
  emsStatusCommStatusDefinition => 'PowerNet-MIB::emsStatusCommStatus',
  emsStatusProbeCount => '1.3.6.1.4.1.318.1.1.10.3.12.3',
  emsStatusInputContactCount => '1.3.6.1.4.1.318.1.1.10.3.12.4',
  emsStatusOutputRelayCount => '1.3.6.1.4.1.318.1.1.10.3.12.5',
  emsStatusOutletCount => '1.3.6.1.4.1.318.1.1.10.3.12.6',
  emsStatusSensorCount => '1.3.6.1.4.1.318.1.1.10.3.12.7',
  emsStatusAlinkAruDeviceCount => '1.3.6.1.4.1.318.1.1.10.3.12.8',
  emsStatusAlinkProbeDeviceCount => '1.3.6.1.4.1.318.1.1.10.3.12.9',
  emsStatusAlarmDeviceCount => '1.3.6.1.4.1.318.1.1.10.3.12.10',
  emsStatusSysTempUnits => '1.3.6.1.4.1.318.1.1.10.3.12.11',
  emsStatusSysTempUnitsDefinition => 'PowerNet-MIB::emsStatusSysTempUnits',
  emsStatusCheckLogLight => '1.3.6.1.4.1.318.1.1.10.3.12.12',
  emsStatusCheckLogLightDefinition => 'PowerNet-MIB::emsStatusCheckLogLight',
  emsStatusHardwareStatus => '1.3.6.1.4.1.318.1.1.10.3.12.13',
  emsProbeStatus => '1.3.6.1.4.1.318.1.1.10.3.13',
  emsProbeStatusTable => '1.3.6.1.4.1.318.1.1.10.3.13.1',
  emsProbeStatusEntry => '1.3.6.1.4.1.318.1.1.10.3.13.1.1',
  emsProbeStatusProbeIndex => '1.3.6.1.4.1.318.1.1.10.3.13.1.1.1',
  emsProbeStatusProbeName => '1.3.6.1.4.1.318.1.1.10.3.13.1.1.2',
  emsProbeStatusProbeTemperature => '1.3.6.1.4.1.318.1.1.10.3.13.1.1.3',
  emsProbeStatusProbeHighTempThresh => '1.3.6.1.4.1.318.1.1.10.3.13.1.1.4',
  emsProbeStatusProbeLowTempThresh => '1.3.6.1.4.1.318.1.1.10.3.13.1.1.5',
  emsProbeStatusProbeHumidity => '1.3.6.1.4.1.318.1.1.10.3.13.1.1.6',
  emsProbeStatusProbeHighHumidityThresh => '1.3.6.1.4.1.318.1.1.10.3.13.1.1.7',
  emsProbeStatusProbeLowHumidityThresh => '1.3.6.1.4.1.318.1.1.10.3.13.1.1.8',
  emsProbeStatusProbeSerialNumber => '1.3.6.1.4.1.318.1.1.10.3.13.1.1.9',
  emsProbeStatusProbeCommStatus => '1.3.6.1.4.1.318.1.1.10.3.13.1.1.10',
  emsProbeStatusProbeCommStatusDefinition => 'PowerNet-MIB::emsProbeStatusProbeCommStatus',
  emsProbeStatusProbeAlarmStatus => '1.3.6.1.4.1.318.1.1.10.3.13.1.1.11',
  emsProbeStatusProbeMaxTempThresh => '1.3.6.1.4.1.318.1.1.10.3.13.1.1.12',
  emsProbeStatusProbeMinTempThresh => '1.3.6.1.4.1.318.1.1.10.3.13.1.1.13',
  emsProbeStatusProbeMaxHumidityThresh => '1.3.6.1.4.1.318.1.1.10.3.13.1.1.14',
  emsProbeStatusProbeMinHumidityThresh => '1.3.6.1.4.1.318.1.1.10.3.13.1.1.15',
  emsInputContactStatus => '1.3.6.1.4.1.318.1.1.10.3.14',
  emsInputContactStatusTable => '1.3.6.1.4.1.318.1.1.10.3.14.1',
  emsInputContactStatusEntry => '1.3.6.1.4.1.318.1.1.10.3.14.1.1',
  emsInputContactStatusInputContactIndex => '1.3.6.1.4.1.318.1.1.10.3.14.1.1.1',
  emsInputContactStatusInputContactName => '1.3.6.1.4.1.318.1.1.10.3.14.1.1.2',
  emsInputContactStatusInputContactState => '1.3.6.1.4.1.318.1.1.10.3.14.1.1.3',
  emsInputContactStatusInputContactStateDefinition => 'PowerNet-MIB::emsInputContactStatusInputContactState',
  emsInputContactStatusInputContactNormalState => '1.3.6.1.4.1.318.1.1.10.3.14.1.1.4',
  emsInputContactStatusInputContactNormalStateDefinition => 'PowerNet-MIB::emsInputContactStatusInputContactNormalState',
  emsOutputRelayStatus => '1.3.6.1.4.1.318.1.1.10.3.15',
  emsOutputRelayStatusTable => '1.3.6.1.4.1.318.1.1.10.3.15.1',
  emsOutputRelayStatusEntry => '1.3.6.1.4.1.318.1.1.10.3.15.1.1',
  emsOutputRelayStatusOutputRelayIndex => '1.3.6.1.4.1.318.1.1.10.3.15.1.1.1',
  emsOutputRelayStatusOutputRelayName => '1.3.6.1.4.1.318.1.1.10.3.15.1.1.2',
  emsOutputRelayStatusOutputRelayState => '1.3.6.1.4.1.318.1.1.10.3.15.1.1.3',
  emsOutputRelayStatusOutputRelayStateDefinition => 'PowerNet-MIB::emsOutputRelayStatusOutputRelayState',
  emsOutputRelayStatusOutputRelayNormalState => '1.3.6.1.4.1.318.1.1.10.3.15.1.1.4',
  emsOutputRelayStatusOutputRelayNormalStateDefinition => 'PowerNet-MIB::emsOutputRelayStatusOutputRelayNormalState',
  emsOutletStatus => '1.3.6.1.4.1.318.1.1.10.3.16',
  emsOutletStatusTable => '1.3.6.1.4.1.318.1.1.10.3.16.1',
  emsOutletStatusEntry => '1.3.6.1.4.1.318.1.1.10.3.16.1.1',
  emsOutletStatusOutletIndex => '1.3.6.1.4.1.318.1.1.10.3.16.1.1.1',
  emsOutletStatusOutletName => '1.3.6.1.4.1.318.1.1.10.3.16.1.1.2',
  emsOutletStatusOutletState => '1.3.6.1.4.1.318.1.1.10.3.16.1.1.3',
  emsOutletStatusOutletStateDefinition => 'PowerNet-MIB::emsOutletStatusOutletState',
  emsOutletStatusOutletNormalState => '1.3.6.1.4.1.318.1.1.10.3.16.1.1.4',
  emsOutletStatusOutletNormalStateDefinition => 'PowerNet-MIB::emsOutletStatusOutletNormalState',
  emsAlarmDeviceStatus => '1.3.6.1.4.1.318.1.1.10.3.17',
  emsAlarmDeviceStatusTable => '1.3.6.1.4.1.318.1.1.10.3.17.1',
  emsAlarmDeviceStatusEntry => '1.3.6.1.4.1.318.1.1.10.3.17.1.1',
  emsAlarmDeviceStatusDeviceIndex => '1.3.6.1.4.1.318.1.1.10.3.17.1.1.1',
  emsAlarmDeviceStatusDeviceName => '1.3.6.1.4.1.318.1.1.10.3.17.1.1.2',
  emsAlarmDeviceStatusDeviceState => '1.3.6.1.4.1.318.1.1.10.3.17.1.1.3',
  emsAlarmDeviceStatusDeviceStateDefinition => 'PowerNet-MIB::emsAlarmDeviceStatusDeviceState',
  emsSensorStatus => '1.3.6.1.4.1.318.1.1.10.3.18',
  emsSensorStatusTable => '1.3.6.1.4.1.318.1.1.10.3.18.1',
  emsSensorStatusEntry => '1.3.6.1.4.1.318.1.1.10.3.18.1.1',
  emsSensorStatusSensorIndex => '1.3.6.1.4.1.318.1.1.10.3.18.1.1.1',
  emsSensorStatusSensorSystemName => '1.3.6.1.4.1.318.1.1.10.3.18.1.1.2',
  emsSensorStatusSensorName => '1.3.6.1.4.1.318.1.1.10.3.18.1.1.3',
  emsSensorStatusSensorState => '1.3.6.1.4.1.318.1.1.10.3.18.1.1.4',
  emsSensorStatusSensorStateDefinition => 'PowerNet-MIB::emsSensorStatusSensorState',
  emsSensorStatusSensorNormalState => '1.3.6.1.4.1.318.1.1.10.3.18.1.1.5',
  emsSensorStatusSensorNormalStateDefinition => 'PowerNet-MIB::emsSensorStatusSensorNormalState',
  emsSensorStatusSensorAlarmDelay => '1.3.6.1.4.1.318.1.1.10.3.18.1.1.6',
  modEnvMgr => '1.3.6.1.4.1.318.1.1.10.4',
  memModules => '1.3.6.1.4.1.318.1.1.10.4.1',
  memModulesStatusTableSize => '1.3.6.1.4.1.318.1.1.10.4.1.1',
  memModulesStatusTable => '1.3.6.1.4.1.318.1.1.10.4.1.2',
  memModulesStatusEntry => '1.3.6.1.4.1.318.1.1.10.4.1.2.1',
  memModulesStatusModuleNumber => '1.3.6.1.4.1.318.1.1.10.4.1.2.1.1',
  memModulesStatusModuleName => '1.3.6.1.4.1.318.1.1.10.4.1.2.1.2',
  memModulesStatusModuleLocation => '1.3.6.1.4.1.318.1.1.10.4.1.2.1.3',
  memModulesStatusModelNumber => '1.3.6.1.4.1.318.1.1.10.4.1.2.1.4',
  memModulesStatusSerialNumber => '1.3.6.1.4.1.318.1.1.10.4.1.2.1.5',
  memModulesStatusFirmwareRev => '1.3.6.1.4.1.318.1.1.10.4.1.2.1.6',
  memModulesStatusHardwareRev => '1.3.6.1.4.1.318.1.1.10.4.1.2.1.7',
  memModulesConfigTableSize => '1.3.6.1.4.1.318.1.1.10.4.1.3',
  memModulesConfigTable => '1.3.6.1.4.1.318.1.1.10.4.1.4',
  memModulesConfigEntry => '1.3.6.1.4.1.318.1.1.10.4.1.4.1',
  memModulesConfigModuleNumber => '1.3.6.1.4.1.318.1.1.10.4.1.4.1.1',
  memModulesConfigModuleName => '1.3.6.1.4.1.318.1.1.10.4.1.4.1.2',
  memModulesConfigModuleLocation => '1.3.6.1.4.1.318.1.1.10.4.1.4.1.3',
  memSensors => '1.3.6.1.4.1.318.1.1.10.4.2',
  memSensorsStatusSysTempUnits => '1.3.6.1.4.1.318.1.1.10.4.2.1',
  memSensorsStatusSysTempUnitsDefinition => 'PowerNet-MIB::memSensorsStatusSysTempUnits',
  memSensorsStatusTableSize => '1.3.6.1.4.1.318.1.1.10.4.2.2',
  memSensorsStatusTable => '1.3.6.1.4.1.318.1.1.10.4.2.3',
  memSensorsStatusEntry => '1.3.6.1.4.1.318.1.1.10.4.2.3.1',
  memSensorsStatusModuleNumber => '1.3.6.1.4.1.318.1.1.10.4.2.3.1.1',
  memSensorsStatusSensorNumber => '1.3.6.1.4.1.318.1.1.10.4.2.3.1.2',
  memSensorsStatusSensorName => '1.3.6.1.4.1.318.1.1.10.4.2.3.1.3',
  memSensorsStatusSensorLocation => '1.3.6.1.4.1.318.1.1.10.4.2.3.1.4',
  memSensorsTemperature => '1.3.6.1.4.1.318.1.1.10.4.2.3.1.5',
  memSensorsHumidity => '1.3.6.1.4.1.318.1.1.10.4.2.3.1.6',
  memSensorsCommStatus => '1.3.6.1.4.1.318.1.1.10.4.2.3.1.7',
  memSensorsCommStatusDefinition => 'PowerNet-MIB::memSensorsCommStatus',
  memSensorsAlarmStatus => '1.3.6.1.4.1.318.1.1.10.4.2.3.1.8',
  memSensorsAlarmStatusDefinition => 'PowerNet-MIB::memSensorsAlarmStatus',
  memSensorsConfigTableSize => '1.3.6.1.4.1.318.1.1.10.4.2.4',
  memSensorsConfigTable => '1.3.6.1.4.1.318.1.1.10.4.2.5',
  memSensorsConfigEntry => '1.3.6.1.4.1.318.1.1.10.4.2.5.1',
  memSensorsConfigModuleNumber => '1.3.6.1.4.1.318.1.1.10.4.2.5.1.1',
  memSensorsConfigSensorNumber => '1.3.6.1.4.1.318.1.1.10.4.2.5.1.2',
  memSensorsName => '1.3.6.1.4.1.318.1.1.10.4.2.5.1.3',
  memSensorsLocation => '1.3.6.1.4.1.318.1.1.10.4.2.5.1.4',
  memSensorsAlarmGeneration => '1.3.6.1.4.1.318.1.1.10.4.2.5.1.5',
  memSensorsAlarmGenerationDefinition => 'PowerNet-MIB::memSensorsAlarmGeneration',
  memSensorsTempMaxThresh => '1.3.6.1.4.1.318.1.1.10.4.2.5.1.6',
  memSensorsTempHighThresh => '1.3.6.1.4.1.318.1.1.10.4.2.5.1.7',
  memSensorsTempLowThresh => '1.3.6.1.4.1.318.1.1.10.4.2.5.1.8',
  memSensorsTempMinThresh => '1.3.6.1.4.1.318.1.1.10.4.2.5.1.9',
  memSensorsTempThreshHysteresis => '1.3.6.1.4.1.318.1.1.10.4.2.5.1.10',
  memSensorsTempShortDecRateThreshValue => '1.3.6.1.4.1.318.1.1.10.4.2.5.1.11',
  memSensorsTempShortDecRateThreshTime => '1.3.6.1.4.1.318.1.1.10.4.2.5.1.12',
  memSensorsTempShortIncRateThreshValue => '1.3.6.1.4.1.318.1.1.10.4.2.5.1.13',
  memSensorsTempShortIncRateThreshTime => '1.3.6.1.4.1.318.1.1.10.4.2.5.1.14',
  memSensorsTempLongDecRateThreshValue => '1.3.6.1.4.1.318.1.1.10.4.2.5.1.15',
  memSensorsTempLongDecRateThreshTime => '1.3.6.1.4.1.318.1.1.10.4.2.5.1.16',
  memSensorsTempLongIncRateThreshValue => '1.3.6.1.4.1.318.1.1.10.4.2.5.1.17',
  memSensorsTempLongIncRateThreshTime => '1.3.6.1.4.1.318.1.1.10.4.2.5.1.18',
  memSensorsHumidityMaxThresh => '1.3.6.1.4.1.318.1.1.10.4.2.5.1.19',
  memSensorsHumidityHighThresh => '1.3.6.1.4.1.318.1.1.10.4.2.5.1.20',
  memSensorsHumidityLowThresh => '1.3.6.1.4.1.318.1.1.10.4.2.5.1.21',
  memSensorsHumidityMinThresh => '1.3.6.1.4.1.318.1.1.10.4.2.5.1.22',
  memSensorsHumidityThreshHysteresis => '1.3.6.1.4.1.318.1.1.10.4.2.5.1.23',
  memInputs => '1.3.6.1.4.1.318.1.1.10.4.3',
  memInputsStatusTableSize => '1.3.6.1.4.1.318.1.1.10.4.3.1',
  memInputsStatusTable => '1.3.6.1.4.1.318.1.1.10.4.3.2',
  memInputsStatusEntry => '1.3.6.1.4.1.318.1.1.10.4.3.2.1',
  memInputsStatusModuleNumber => '1.3.6.1.4.1.318.1.1.10.4.3.2.1.1',
  memInputsStatusInputNumber => '1.3.6.1.4.1.318.1.1.10.4.3.2.1.2',
  memInputsStatusInputName => '1.3.6.1.4.1.318.1.1.10.4.3.2.1.3',
  memInputsStatusInputLocation => '1.3.6.1.4.1.318.1.1.10.4.3.2.1.4',
  memInputsStatusCurrentState => '1.3.6.1.4.1.318.1.1.10.4.3.2.1.5',
  memInputsStatusCurrentStateDefinition => 'PowerNet-MIB::memInputsStatusCurrentState',
  memInputsStatusCurrentAnalogValue => '1.3.6.1.4.1.318.1.1.10.4.3.2.1.6',
  memInputsStatusAlarmStatus => '1.3.6.1.4.1.318.1.1.10.4.3.2.1.7',
  memInputsStatusAlarmStatusDefinition => 'PowerNet-MIB::memInputsStatusAlarmStatus',
  memInputsCommStatus => '1.3.6.1.4.1.318.1.1.10.4.3.2.1.8',
  memInputsCommStatusDefinition => 'PowerNet-MIB::memInputsCommStatus',
  memInputsConfigTableSize => '1.3.6.1.4.1.318.1.1.10.4.3.3',
  memInputsConfigTable => '1.3.6.1.4.1.318.1.1.10.4.3.4',
  memInputsConfigEntry => '1.3.6.1.4.1.318.1.1.10.4.3.4.1',
  memInputsConfigModuleNumber => '1.3.6.1.4.1.318.1.1.10.4.3.4.1.1',
  memInputsConfigInputNumber => '1.3.6.1.4.1.318.1.1.10.4.3.4.1.2',
  memInputName => '1.3.6.1.4.1.318.1.1.10.4.3.4.1.3',
  memInputLocation => '1.3.6.1.4.1.318.1.1.10.4.3.4.1.4',
  memInputType => '1.3.6.1.4.1.318.1.1.10.4.3.4.1.5',
  memInputTypeDefinition => 'PowerNet-MIB::memInputType',
  memInputAlarmGeneration => '1.3.6.1.4.1.318.1.1.10.4.3.4.1.6',
  memInputAlarmGenerationDefinition => 'PowerNet-MIB::memInputAlarmGeneration',
  memInputNormalState => '1.3.6.1.4.1.318.1.1.10.4.3.4.1.7',
  memInputNormalStateDefinition => 'PowerNet-MIB::memInputNormalState',
  memInputAbnormalSeverity => '1.3.6.1.4.1.318.1.1.10.4.3.4.1.8',
  memInputAbnormalSeverityDefinition => 'PowerNet-MIB::memInputAbnormalSeverity',
  memInputNumberCalibrationPoints => '1.3.6.1.4.1.318.1.1.10.4.3.4.1.9',
  memInputAnalogCalibrationPoint1 => '1.3.6.1.4.1.318.1.1.10.4.3.4.1.10',
  memInputAnalogCalibrationPoint2 => '1.3.6.1.4.1.318.1.1.10.4.3.4.1.11',
  memInputAnalogCalibrationPoint3 => '1.3.6.1.4.1.318.1.1.10.4.3.4.1.12',
  memInputAnalogCalibrationPoint4 => '1.3.6.1.4.1.318.1.1.10.4.3.4.1.13',
  memInputAnalogCalibrationPoint5 => '1.3.6.1.4.1.318.1.1.10.4.3.4.1.14',
  memInputAnalogCalibrationPoint1Value => '1.3.6.1.4.1.318.1.1.10.4.3.4.1.15',
  memInputAnalogCalibrationPoint2Value => '1.3.6.1.4.1.318.1.1.10.4.3.4.1.16',
  memInputAnalogCalibrationPoint3Value => '1.3.6.1.4.1.318.1.1.10.4.3.4.1.17',
  memInputAnalogCalibrationPoint4Value => '1.3.6.1.4.1.318.1.1.10.4.3.4.1.18',
  memInputAnalogCalibrationPoint5Value => '1.3.6.1.4.1.318.1.1.10.4.3.4.1.19',
  memInputAnalogMeasurementUnits => '1.3.6.1.4.1.318.1.1.10.4.3.4.1.20',
  memInputAnalogMaxThresh => '1.3.6.1.4.1.318.1.1.10.4.3.4.1.21',
  memInputAnalogHighThresh => '1.3.6.1.4.1.318.1.1.10.4.3.4.1.22',
  memInputAnalogLowThresh => '1.3.6.1.4.1.318.1.1.10.4.3.4.1.23',
  memInputAnalogMinThresh => '1.3.6.1.4.1.318.1.1.10.4.3.4.1.24',
  memInputAnalogThreshHysteresis => '1.3.6.1.4.1.318.1.1.10.4.3.4.1.25',
  memOutputs => '1.3.6.1.4.1.318.1.1.10.4.4',
  memOutputStatusTableSize => '1.3.6.1.4.1.318.1.1.10.4.4.1',
  memOutputStatusTable => '1.3.6.1.4.1.318.1.1.10.4.4.2',
  memOutputStatusEntry => '1.3.6.1.4.1.318.1.1.10.4.4.2.1',
  memOutputStatusModuleNumber => '1.3.6.1.4.1.318.1.1.10.4.4.2.1.1',
  memOutputStatusOutputNumber => '1.3.6.1.4.1.318.1.1.10.4.4.2.1.2',
  memOutputStatusOutputName => '1.3.6.1.4.1.318.1.1.10.4.4.2.1.3',
  memOutputStatusOutputLocation => '1.3.6.1.4.1.318.1.1.10.4.4.2.1.4',
  memOutputStatusCurrentState => '1.3.6.1.4.1.318.1.1.10.4.4.2.1.5',
  memOutputStatusCurrentStateDefinition => 'PowerNet-MIB::memOutputStatusCurrentState',
  memOutputConfigTableSize => '1.3.6.1.4.1.318.1.1.10.4.4.3',
  memOutputConfigTable => '1.3.6.1.4.1.318.1.1.10.4.4.4',
  memOutputConfigEntry => '1.3.6.1.4.1.318.1.1.10.4.4.4.1',
  memOutputConfigModuleNumber => '1.3.6.1.4.1.318.1.1.10.4.4.4.1.1',
  memOutputConfigOutputNumber => '1.3.6.1.4.1.318.1.1.10.4.4.4.1.2',
  memOutputName => '1.3.6.1.4.1.318.1.1.10.4.4.4.1.3',
  memOutputLocation => '1.3.6.1.4.1.318.1.1.10.4.4.4.1.4',
  memOutputNormalState => '1.3.6.1.4.1.318.1.1.10.4.4.4.1.5',
  memOutputNormalStateDefinition => 'PowerNet-MIB::memOutputNormalState',
  memOutputAction => '1.3.6.1.4.1.318.1.1.10.4.4.4.1.6',
  memOutputActionDefinition => 'PowerNet-MIB::memOutputAction',
  memOutlets => '1.3.6.1.4.1.318.1.1.10.4.5',
  memOutletStatusTableSize => '1.3.6.1.4.1.318.1.1.10.4.5.1',
  memOutletStatusTable => '1.3.6.1.4.1.318.1.1.10.4.5.2',
  memOutletStatusEntry => '1.3.6.1.4.1.318.1.1.10.4.5.2.1',
  memOutletStatusModuleNumber => '1.3.6.1.4.1.318.1.1.10.4.5.2.1.1',
  memOutletStatusOutletNumber => '1.3.6.1.4.1.318.1.1.10.4.5.2.1.2',
  memOutletStatusOutletName => '1.3.6.1.4.1.318.1.1.10.4.5.2.1.3',
  memOutletStatusOutletLocation => '1.3.6.1.4.1.318.1.1.10.4.5.2.1.4',
  memOutletStatusCurrentState => '1.3.6.1.4.1.318.1.1.10.4.5.2.1.5',
  memOutletStatusCurrentStateDefinition => 'PowerNet-MIB::memOutletStatusCurrentState',
  memOutletConfigTableSize => '1.3.6.1.4.1.318.1.1.10.4.5.3',
  memOutletConfigTable => '1.3.6.1.4.1.318.1.1.10.4.5.4',
  memOutletConfigEntry => '1.3.6.1.4.1.318.1.1.10.4.5.4.1',
  memOutletConfigModuleNumber => '1.3.6.1.4.1.318.1.1.10.4.5.4.1.1',
  memOutletConfigOutletNumber => '1.3.6.1.4.1.318.1.1.10.4.5.4.1.2',
  memOutletName => '1.3.6.1.4.1.318.1.1.10.4.5.4.1.3',
  memOutletLocation => '1.3.6.1.4.1.318.1.1.10.4.5.4.1.4',
  memOutletNormalState => '1.3.6.1.4.1.318.1.1.10.4.5.4.1.5',
  memOutletNormalStateDefinition => 'PowerNet-MIB::memOutletNormalState',
  memOutletAction => '1.3.6.1.4.1.318.1.1.10.4.5.4.1.6',
  memOutletActionDefinition => 'PowerNet-MIB::memOutletAction',
  memBeacons => '1.3.6.1.4.1.318.1.1.10.4.6',
  memBeaconStatusTableSize => '1.3.6.1.4.1.318.1.1.10.4.6.1',
  memBeaconStatusTable => '1.3.6.1.4.1.318.1.1.10.4.6.2',
  memBeaconStatusEntry => '1.3.6.1.4.1.318.1.1.10.4.6.2.1',
  memBeaconStatusModuleNumber => '1.3.6.1.4.1.318.1.1.10.4.6.2.1.1',
  memBeaconStatusBeaconNumber => '1.3.6.1.4.1.318.1.1.10.4.6.2.1.2',
  memBeaconStatusBeaconName => '1.3.6.1.4.1.318.1.1.10.4.6.2.1.3',
  memBeaconStatusBeaconLocation => '1.3.6.1.4.1.318.1.1.10.4.6.2.1.4',
  memBeaconStatusCurrentState => '1.3.6.1.4.1.318.1.1.10.4.6.2.1.5',
  memBeaconStatusCurrentStateDefinition => 'PowerNet-MIB::memBeaconStatusCurrentState',
  memBeaconConfigTableSize => '1.3.6.1.4.1.318.1.1.10.4.6.3',
  memBeaconConfigTable => '1.3.6.1.4.1.318.1.1.10.4.6.4',
  memBeaconConfigEntry => '1.3.6.1.4.1.318.1.1.10.4.6.4.1',
  memBeaconConfigModuleNumber => '1.3.6.1.4.1.318.1.1.10.4.6.4.1.1',
  memBeaconConfigBeaconNumber => '1.3.6.1.4.1.318.1.1.10.4.6.4.1.2',
  memBeaconConfigName => '1.3.6.1.4.1.318.1.1.10.4.6.4.1.3',
  memBeaconConfigLocation => '1.3.6.1.4.1.318.1.1.10.4.6.4.1.4',
  memBeaconAction => '1.3.6.1.4.1.318.1.1.10.4.6.4.1.5',
  memBeaconActionDefinition => 'PowerNet-MIB::memBeaconAction',
  netlock => '1.3.6.1.4.1.318.1.1.11',
  nlIdent => '1.3.6.1.4.1.318.1.1.11.1',
  nlStatus => '1.3.6.1.4.1.318.1.1.11.2',
  rPDU => '1.3.6.1.4.1.318.1.1.12',
  rPDUIdent => '1.3.6.1.4.1.318.1.1.12.1',
  rPDUIdentName => '1.3.6.1.4.1.318.1.1.12.1.1',
  rPDUIdentHardwareRev => '1.3.6.1.4.1.318.1.1.12.1.2',
  rPDUIdentFirmwareRev => '1.3.6.1.4.1.318.1.1.12.1.3',
  rPDUIdentDateOfManufacture => '1.3.6.1.4.1.318.1.1.12.1.4',
  rPDUIdentModelNumber => '1.3.6.1.4.1.318.1.1.12.1.5',
  rPDUIdentSerialNumber => '1.3.6.1.4.1.318.1.1.12.1.6',
  rPDUIdentDeviceRating => '1.3.6.1.4.1.318.1.1.12.1.7',
  rPDUIdentDeviceNumOutlets => '1.3.6.1.4.1.318.1.1.12.1.8',
  rPDUIdentDeviceNumPhases => '1.3.6.1.4.1.318.1.1.12.1.9',
  rPDUIdentDeviceNumBreakers => '1.3.6.1.4.1.318.1.1.12.1.10',
  rPDUIdentDeviceBreakerRating => '1.3.6.1.4.1.318.1.1.12.1.11',
  rPDUIdentDeviceOrientation => '1.3.6.1.4.1.318.1.1.12.1.12',
  rPDUIdentDeviceOrientationDefinition => 'PowerNet-MIB::rPDUIdentDeviceOrientation',
  rPDUIdentDeviceOutletLayout => '1.3.6.1.4.1.318.1.1.12.1.13',
  rPDUIdentDeviceOutletLayoutDefinition => 'PowerNet-MIB::rPDUIdentDeviceOutletLayout',
  rPDUIdentDeviceDisplayOrientation => '1.3.6.1.4.1.318.1.1.12.1.14',
  rPDUIdentDeviceDisplayOrientationDefinition => 'PowerNet-MIB::rPDUIdentDeviceDisplayOrientation',
  rPDUIdentDeviceLinetoLineVoltage => '1.3.6.1.4.1.318.1.1.12.1.15',
  rPDUIdentDevicePowerWatts => '1.3.6.1.4.1.318.1.1.12.1.16',
  rPDUIdentDevicePowerFactor => '1.3.6.1.4.1.318.1.1.12.1.17',
  rPDUIdentDevicePowerVA => '1.3.6.1.4.1.318.1.1.12.1.18',
  rPDUIdentDeviceLinetoNeutralVoltage => '1.3.6.1.4.1.318.1.1.12.1.19',
  rPDULoad => '1.3.6.1.4.1.318.1.1.12.2',
  rPDULoadDevice => '1.3.6.1.4.1.318.1.1.12.2.1',
  rPDULoadDevMaxPhaseLoad => '1.3.6.1.4.1.318.1.1.12.2.1.1',
  rPDULoadDevNumPhases => '1.3.6.1.4.1.318.1.1.12.2.1.2',
  rPDULoadDevMaxBankLoad => '1.3.6.1.4.1.318.1.1.12.2.1.3',
  rPDULoadDevNumBanks => '1.3.6.1.4.1.318.1.1.12.2.1.4',
  rPDULoadDevBankTableSize => '1.3.6.1.4.1.318.1.1.12.2.1.5',
  rPDULoadDevBankTable => '1.3.6.1.4.1.318.1.1.12.2.1.6',
  rPDULoadDevBankEntry => '1.3.6.1.4.1.318.1.1.12.2.1.6.1',
  rPDULoadDevBankIndex => '1.3.6.1.4.1.318.1.1.12.2.1.6.1.1',
  rPDULoadDevBankNumber => '1.3.6.1.4.1.318.1.1.12.2.1.6.1.2',
  rPDULoadDevBankMaxLoad => '1.3.6.1.4.1.318.1.1.12.2.1.6.1.3',
  rPDULoadDevMaxOutletTableSize => '1.3.6.1.4.1.318.1.1.12.2.1.7',
  rPDULoadDevMaxOutletTable => '1.3.6.1.4.1.318.1.1.12.2.1.8',
  rPDULoadDevMaxOutletEntry => '1.3.6.1.4.1.318.1.1.12.2.1.8.1',
  rPDULoadDevOutletIndex => '1.3.6.1.4.1.318.1.1.12.2.1.8.1.1',
  rPDULoadDevOutletNumber => '1.3.6.1.4.1.318.1.1.12.2.1.8.1.2',
  rPDULoadDevMaxOutletLoad => '1.3.6.1.4.1.318.1.1.12.2.1.8.1.3',
  rPDULoadPhaseConfig => '1.3.6.1.4.1.318.1.1.12.2.2',
  rPDULoadPhaseConfigTable => '1.3.6.1.4.1.318.1.1.12.2.2.1',
  rPDULoadPhaseConfigEntry => '1.3.6.1.4.1.318.1.1.12.2.2.1.1',
  rPDULoadPhaseConfigIndex => '1.3.6.1.4.1.318.1.1.12.2.2.1.1.1',
  rPDULoadPhaseConfigIndexDefinition => 'PowerNet-MIB::rPDULoadPhaseConfigIndex',
  rPDULoadPhaseConfigLowLoadThreshold => '1.3.6.1.4.1.318.1.1.12.2.2.1.1.2',
  rPDULoadPhaseConfigNearOverloadThreshold => '1.3.6.1.4.1.318.1.1.12.2.2.1.1.3',
  rPDULoadPhaseConfigOverloadThreshold => '1.3.6.1.4.1.318.1.1.12.2.2.1.1.4',
  rPDULoadPhaseConfigAlarm => '1.3.6.1.4.1.318.1.1.12.2.2.1.1.5',
  rPDULoadPhaseConfigAlarmDefinition => 'PowerNet-MIB::rPDULoadPhaseConfigAlarm',
  rPDULoadStatus => '1.3.6.1.4.1.318.1.1.12.2.3',
  rPDULoadStatusTable => '1.3.6.1.4.1.318.1.1.12.2.3.1',
  rPDULoadStatusEntry => '1.3.6.1.4.1.318.1.1.12.2.3.1.1',
  rPDULoadStatusIndex => '1.3.6.1.4.1.318.1.1.12.2.3.1.1.1',
  rPDULoadStatusLoad => '1.3.6.1.4.1.318.1.1.12.2.3.1.1.2',
  rPDULoadStatusLoadState => '1.3.6.1.4.1.318.1.1.12.2.3.1.1.3',
  rPDULoadStatusLoadStateDefinition => 'PowerNet-MIB::rPDULoadStatusLoadState',
  rPDULoadStatusPhaseNumber => '1.3.6.1.4.1.318.1.1.12.2.3.1.1.4',
  rPDULoadStatusBankNumber => '1.3.6.1.4.1.318.1.1.12.2.3.1.1.5',
  rPDULoadBankConfig => '1.3.6.1.4.1.318.1.1.12.2.4',
  rPDULoadBankConfigTable => '1.3.6.1.4.1.318.1.1.12.2.4.1',
  rPDULoadBankConfigEntry => '1.3.6.1.4.1.318.1.1.12.2.4.1.1',
  rPDULoadBankConfigIndex => '1.3.6.1.4.1.318.1.1.12.2.4.1.1.1',
  rPDULoadBankConfigLowLoadThreshold => '1.3.6.1.4.1.318.1.1.12.2.4.1.1.2',
  rPDULoadBankConfigNearOverloadThreshold => '1.3.6.1.4.1.318.1.1.12.2.4.1.1.3',
  rPDULoadBankConfigOverloadThreshold => '1.3.6.1.4.1.318.1.1.12.2.4.1.1.4',
  rPDULoadBankConfigAlarm => '1.3.6.1.4.1.318.1.1.12.2.4.1.1.5',
  rPDULoadBankConfigAlarmDefinition => 'PowerNet-MIB::rPDULoadBankConfigAlarm',
  rPDUOutlet => '1.3.6.1.4.1.318.1.1.12.3',
  rPDUOutletDevice => '1.3.6.1.4.1.318.1.1.12.3.1',
  rPDUOutletDevCommand => '1.3.6.1.4.1.318.1.1.12.3.1.1',
  rPDUOutletDevCommandDefinition => 'PowerNet-MIB::rPDUOutletDevCommand',
  rPDUOutletDevColdstartDelay => '1.3.6.1.4.1.318.1.1.12.3.1.2',
  rPDUOutletDevNumCntrlOutlets => '1.3.6.1.4.1.318.1.1.12.3.1.3',
  rPDUOutletDevNumTotalOutlets => '1.3.6.1.4.1.318.1.1.12.3.1.4',
  rPDUOutletDevMonitoredOutlets => '1.3.6.1.4.1.318.1.1.12.3.1.5',
  rPDUOutletPhase => '1.3.6.1.4.1.318.1.1.12.3.2',
  rPDUOutletPhaseTable => '1.3.6.1.4.1.318.1.1.12.3.2.1',
  rPDUOutletPhaseEntry => '1.3.6.1.4.1.318.1.1.12.3.2.1.1',
  rPDUOutletPhaseIndex => '1.3.6.1.4.1.318.1.1.12.3.2.1.1.1',
  rPDUOutletPhaseIndexDefinition => 'PowerNet-MIB::rPDUOutletPhaseIndex',
  rPDUOutletPhaseOverloadRestriction => '1.3.6.1.4.1.318.1.1.12.3.2.1.1.2',
  rPDUOutletPhaseOverloadRestrictionDefinition => 'PowerNet-MIB::rPDUOutletPhaseOverloadRestriction',
  rPDUOutletControl => '1.3.6.1.4.1.318.1.1.12.3.3',
  rPDUOutletControlTable => '1.3.6.1.4.1.318.1.1.12.3.3.1',
  rPDUOutletControlEntry => '1.3.6.1.4.1.318.1.1.12.3.3.1.1',
  rPDUOutletControlIndex => '1.3.6.1.4.1.318.1.1.12.3.3.1.1.1',
  rPDUOutletControlOutletName => '1.3.6.1.4.1.318.1.1.12.3.3.1.1.2',
  rPDUOutletControlOutletPhase => '1.3.6.1.4.1.318.1.1.12.3.3.1.1.3',
  rPDUOutletControlOutletPhaseDefinition => 'PowerNet-MIB::rPDUOutletControlOutletPhase',
  rPDUOutletControlOutletCommand => '1.3.6.1.4.1.318.1.1.12.3.3.1.1.4',
  rPDUOutletControlOutletCommandDefinition => 'PowerNet-MIB::rPDUOutletControlOutletCommand',
  rPDUOutletControlOutletBank => '1.3.6.1.4.1.318.1.1.12.3.3.1.1.5',
  rPDUOutletConfig => '1.3.6.1.4.1.318.1.1.12.3.4',
  rPDUOutletConfigTable => '1.3.6.1.4.1.318.1.1.12.3.4.1',
  rPDUOutletConfigEntry => '1.3.6.1.4.1.318.1.1.12.3.4.1.1',
  rPDUOutletConfigIndex => '1.3.6.1.4.1.318.1.1.12.3.4.1.1.1',
  rPDUOutletConfigOutletName => '1.3.6.1.4.1.318.1.1.12.3.4.1.1.2',
  rPDUOutletConfigOutletPhase => '1.3.6.1.4.1.318.1.1.12.3.4.1.1.3',
  rPDUOutletConfigOutletPhaseDefinition => 'PowerNet-MIB::rPDUOutletConfigOutletPhase',
  rPDUOutletConfigPowerOnTime => '1.3.6.1.4.1.318.1.1.12.3.4.1.1.4',
  rPDUOutletConfigPowerOffTime => '1.3.6.1.4.1.318.1.1.12.3.4.1.1.5',
  rPDUOutletConfigRebootDuration => '1.3.6.1.4.1.318.1.1.12.3.4.1.1.6',
  rPDUOutletConfigOutletBank => '1.3.6.1.4.1.318.1.1.12.3.4.1.1.7',
  rPDUOutletConfigMonitoredTableSize => '1.3.6.1.4.1.318.1.1.12.3.4.2',
  rPDUOutletConfigMonitoredTable => '1.3.6.1.4.1.318.1.1.12.3.4.3',
  rPDUOutletConfigMonitoredEntry => '1.3.6.1.4.1.318.1.1.12.3.4.3.1',
  rPDUOutletConfigMonitoredIndex => '1.3.6.1.4.1.318.1.1.12.3.4.3.1.1',
  rPDUOutletConfigMonitoredName => '1.3.6.1.4.1.318.1.1.12.3.4.3.1.2',
  rPDUOutletConfigMonitoredNumber => '1.3.6.1.4.1.318.1.1.12.3.4.3.1.3',
  rPDUOutletConfigMonitoredLowLoadThreshold => '1.3.6.1.4.1.318.1.1.12.3.4.3.1.4',
  rPDUOutletConfigMonitoredNearOverloadThreshold => '1.3.6.1.4.1.318.1.1.12.3.4.3.1.5',
  rPDUOutletConfigMonitoredOverloadThreshold => '1.3.6.1.4.1.318.1.1.12.3.4.3.1.6',
  rPDUOutletStatus => '1.3.6.1.4.1.318.1.1.12.3.5',
  rPDUOutletStatusTable => '1.3.6.1.4.1.318.1.1.12.3.5.1',
  rPDUOutletStatusEntry => '1.3.6.1.4.1.318.1.1.12.3.5.1.1',
  rPDUOutletStatusIndex => '1.3.6.1.4.1.318.1.1.12.3.5.1.1.1',
  rPDUOutletStatusOutletName => '1.3.6.1.4.1.318.1.1.12.3.5.1.1.2',
  rPDUOutletStatusOutletPhase => '1.3.6.1.4.1.318.1.1.12.3.5.1.1.3',
  rPDUOutletStatusOutletPhaseDefinition => 'PowerNet-MIB::rPDUOutletStatusOutletPhase',
  rPDUOutletStatusOutletState => '1.3.6.1.4.1.318.1.1.12.3.5.1.1.4',
  rPDUOutletStatusOutletStateDefinition => 'PowerNet-MIB::rPDUOutletStatusOutletState',
  rPDUOutletStatusCommandPending => '1.3.6.1.4.1.318.1.1.12.3.5.1.1.5',
  rPDUOutletStatusCommandPendingDefinition => 'PowerNet-MIB::rPDUOutletStatusCommandPending',
  rPDUOutletStatusOutletBank => '1.3.6.1.4.1.318.1.1.12.3.5.1.1.6',
  rPDUOutletStatusLoad => '1.3.6.1.4.1.318.1.1.12.3.5.1.1.7',
  rPDUOutletBank => '1.3.6.1.4.1.318.1.1.12.3.6',
  rPDUOutletBankTable => '1.3.6.1.4.1.318.1.1.12.3.6.1',
  rPDUOutletBankEntry => '1.3.6.1.4.1.318.1.1.12.3.6.1.1',
  rPDUOutletBankIndex => '1.3.6.1.4.1.318.1.1.12.3.6.1.1.1',
  rPDUOutletBankOverloadRestriction => '1.3.6.1.4.1.318.1.1.12.3.6.1.1.2',
  rPDUOutletBankOverloadRestrictionDefinition => 'PowerNet-MIB::rPDUOutletBankOverloadRestriction',
  rPDUPowerSupply => '1.3.6.1.4.1.318.1.1.12.4',
  rPDUPowerSupplyDevice => '1.3.6.1.4.1.318.1.1.12.4.1',
  rPDUPowerSupply1Status => '1.3.6.1.4.1.318.1.1.12.4.1.1',
  rPDUPowerSupply1StatusDefinition => 'PowerNet-MIB::rPDUPowerSupply1Status',
  rPDUPowerSupply2Status => '1.3.6.1.4.1.318.1.1.12.4.1.2',
  rPDUPowerSupply2StatusDefinition => 'PowerNet-MIB::rPDUPowerSupply2Status',
  rPDUPowerSupplyAlarm => '1.3.6.1.4.1.318.1.1.12.4.1.3',
  rPDUPowerSupplyAlarmDefinition => 'PowerNet-MIB::rPDUPowerSupplyAlarm',
  rPDUStatus => '1.3.6.1.4.1.318.1.1.12.5',
  rPDUStatusBankTableSize => '1.3.6.1.4.1.318.1.1.12.5.1',
  rPDUStatusBankTable => '1.3.6.1.4.1.318.1.1.12.5.2',
  rPDUStatusBankEntry => '1.3.6.1.4.1.318.1.1.12.5.2.1',
  rPDUStatusBankIndex => '1.3.6.1.4.1.318.1.1.12.5.2.1.1',
  rPDUStatusBankNumber => '1.3.6.1.4.1.318.1.1.12.5.2.1.2',
  rPDUStatusBankState => '1.3.6.1.4.1.318.1.1.12.5.2.1.3',
  rPDUStatusBankStateDefinition => 'PowerNet-MIB::rPDUStatusBankState',
  rPDUStatusPhaseTableSize => '1.3.6.1.4.1.318.1.1.12.5.3',
  rPDUStatusPhaseTable => '1.3.6.1.4.1.318.1.1.12.5.4',
  rPDUStatusPhaseEntry => '1.3.6.1.4.1.318.1.1.12.5.4.1',
  rPDUStatusPhaseIndex => '1.3.6.1.4.1.318.1.1.12.5.4.1.1',
  rPDUStatusPhaseNumber => '1.3.6.1.4.1.318.1.1.12.5.4.1.2',
  rPDUStatusPhaseState => '1.3.6.1.4.1.318.1.1.12.5.4.1.3',
  rPDUStatusPhaseStateDefinition => 'PowerNet-MIB::rPDUStatusPhaseState',
  rPDUStatusOutletTableSize => '1.3.6.1.4.1.318.1.1.12.5.5',
  rPDUStatusOutletTable => '1.3.6.1.4.1.318.1.1.12.5.6',
  rPDUStatusOutletEntry => '1.3.6.1.4.1.318.1.1.12.5.6.1',
  rPDUStatusOutletIndex => '1.3.6.1.4.1.318.1.1.12.5.6.1.1',
  rPDUStatusOutletNumber => '1.3.6.1.4.1.318.1.1.12.5.6.1.2',
  rPDUStatusOutletState => '1.3.6.1.4.1.318.1.1.12.5.6.1.3',
  rPDUStatusOutletStateDefinition => 'PowerNet-MIB::rPDUStatusOutletState',
  airConditioners => '1.3.6.1.4.1.318.1.1.13',
  airFM => '1.3.6.1.4.1.318.1.1.13.1',
  airFMIdent => '1.3.6.1.4.1.318.1.1.13.1.1',
  airFMIdentName => '1.3.6.1.4.1.318.1.1.13.1.1.1',
  airFMIdentTableSize => '1.3.6.1.4.1.318.1.1.13.1.1.2',
  airFMIdentTable => '1.3.6.1.4.1.318.1.1.13.1.1.3',
  airFMIdentEntry => '1.3.6.1.4.1.318.1.1.13.1.1.3.1',
  airFMIdentModuleIndex => '1.3.6.1.4.1.318.1.1.13.1.1.3.1.1',
  airFMIdentModuleModelNumber => '1.3.6.1.4.1.318.1.1.13.1.1.3.1.2',
  airFMIdentModuleDateOfMfg => '1.3.6.1.4.1.318.1.1.13.1.1.3.1.3',
  airFMIdentModuleSerialNumber => '1.3.6.1.4.1.318.1.1.13.1.1.3.1.4',
  airFMIdentModuleFirmwareRev => '1.3.6.1.4.1.318.1.1.13.1.1.3.1.5',
  airFMIdentModuleHardwareRev => '1.3.6.1.4.1.318.1.1.13.1.1.3.1.6',
  airFMIdentLocation => '1.3.6.1.4.1.318.1.1.13.1.1.4',
  airFMIdentContact => '1.3.6.1.4.1.318.1.1.13.1.1.5',
  airFMStatus => '1.3.6.1.4.1.318.1.1.13.1.2',
  airFMStatusSystemOn => '1.3.6.1.4.1.318.1.1.13.1.2.1',
  airFMStatusSystemOnDefinition => 'PowerNet-MIB::airFMStatusSystemOn',
  airFMStatusSystemAverageRetTempC => '1.3.6.1.4.1.318.1.1.13.1.2.2',
  airFMStatusSystemAverageRetTempF => '1.3.6.1.4.1.318.1.1.13.1.2.3',
  airFMStatusSystemAverageRetHum => '1.3.6.1.4.1.318.1.1.13.1.2.4',
  airFMStatusSystemActionTempC => '1.3.6.1.4.1.318.1.1.13.1.2.5',
  airFMStatusSystemActionTempF => '1.3.6.1.4.1.318.1.1.13.1.2.6',
  airFMStatusSystemActionHum => '1.3.6.1.4.1.318.1.1.13.1.2.7',
  airFMStatusSystemRemoteHighTempC => '1.3.6.1.4.1.318.1.1.13.1.2.8',
  airFMStatusSystemRemoteHighTempF => '1.3.6.1.4.1.318.1.1.13.1.2.9',
  airFMStatusSystemRemoteAvgTempC => '1.3.6.1.4.1.318.1.1.13.1.2.10',
  airFMStatusSystemRemoteAvgTempF => '1.3.6.1.4.1.318.1.1.13.1.2.11',
  airFMStatusSystemRemoteAvgHum => '1.3.6.1.4.1.318.1.1.13.1.2.12',
  airFMStatusSystemRemoteLowTempC => '1.3.6.1.4.1.318.1.1.13.1.2.13',
  airFMStatusSystemRemoteLowTempF => '1.3.6.1.4.1.318.1.1.13.1.2.14',
  airFMStatusSystemCoolingEnabled => '1.3.6.1.4.1.318.1.1.13.1.2.15',
  airFMStatusSystemCoolingEnabledDefinition => 'PowerNet-MIB::airFMStatusSystemCoolingEnabled',
  airFMStatusSystemReheatingEnabled => '1.3.6.1.4.1.318.1.1.13.1.2.16',
  airFMStatusSystemReheatingEnabledDefinition => 'PowerNet-MIB::airFMStatusSystemReheatingEnabled',
  airFMStatusSystemHumidifyEnabled => '1.3.6.1.4.1.318.1.1.13.1.2.17',
  airFMStatusSystemHumidifyEnabledDefinition => 'PowerNet-MIB::airFMStatusSystemHumidifyEnabled',
  airFMStatusSystemDehumidifyEnabled => '1.3.6.1.4.1.318.1.1.13.1.2.18',
  airFMStatusSystemDehumidifyEnabledDefinition => 'PowerNet-MIB::airFMStatusSystemDehumidifyEnabled',
  airFMStatusModuleTableSize => '1.3.6.1.4.1.318.1.1.13.1.2.19',
  airFMStatusModuleTable => '1.3.6.1.4.1.318.1.1.13.1.2.20',
  airFMStatusModuleEntry => '1.3.6.1.4.1.318.1.1.13.1.2.20.1',
  airFMStatusModuleIndex => '1.3.6.1.4.1.318.1.1.13.1.2.20.1.1',
  airFMStatusModuleOutputCapacity => '1.3.6.1.4.1.318.1.1.13.1.2.20.1.2',
  airFMStatusModuleSupplyTempC => '1.3.6.1.4.1.318.1.1.13.1.2.20.1.3',
  airFMStatusModuleSupplyTempF => '1.3.6.1.4.1.318.1.1.13.1.2.20.1.4',
  airFMStatusModuleSupplyHum => '1.3.6.1.4.1.318.1.1.13.1.2.20.1.5',
  airFMStatusModuleReturnTempC => '1.3.6.1.4.1.318.1.1.13.1.2.20.1.6',
  airFMStatusModuleReturnTempF => '1.3.6.1.4.1.318.1.1.13.1.2.20.1.7',
  airFMStatusModuleReturnHum => '1.3.6.1.4.1.318.1.1.13.1.2.20.1.8',
  airFMGroup => '1.3.6.1.4.1.318.1.1.13.1.3',
  airFMGroupSysStatus => '1.3.6.1.4.1.318.1.1.13.1.3.1',
  airFMGroupSysStatusDefinition => 'PowerNet-MIB::airFMGroupSysStatus',
  airFMGroupSysRuntime => '1.3.6.1.4.1.318.1.1.13.1.3.2',
  airFMGroupSysRole => '1.3.6.1.4.1.318.1.1.13.1.3.3',
  airFMGroupSysRoleDefinition => 'PowerNet-MIB::airFMGroupSysRole',
  airFMGroupSysRoles => '1.3.6.1.4.1.318.1.1.13.1.3.4',
  airFMGroupSysRolesTableSize => '1.3.6.1.4.1.318.1.1.13.1.3.4.1',
  airFMGroupSysRolesTable => '1.3.6.1.4.1.318.1.1.13.1.3.4.2',
  airFMGroupSysRolesEntry => '1.3.6.1.4.1.318.1.1.13.1.3.4.2.1',
  airFMGroupSysIndex => '1.3.6.1.4.1.318.1.1.13.1.3.4.2.1.1',
  airFMGroupSysRoleStatus => '1.3.6.1.4.1.318.1.1.13.1.3.4.2.1.2',
  airFMGroupSysRoleStatusDefinition => 'PowerNet-MIB::airFMGroupSysRoleStatus',
  airFMGroupSysPresentRole => '1.3.6.1.4.1.318.1.1.13.1.3.4.2.1.3',
  airFMGroupSysPresentRoleDefinition => 'PowerNet-MIB::airFMGroupSysPresentRole',
  airFMGroupSysManualRoleSetting => '1.3.6.1.4.1.318.1.1.13.1.3.4.2.1.4',
  airFMGroupSysManualRoleSettingDefinition => 'PowerNet-MIB::airFMGroupSysManualRoleSetting',
  airFMGroupSysRunHours => '1.3.6.1.4.1.318.1.1.13.1.3.4.2.1.5',
  airFMGroupSysComm => '1.3.6.1.4.1.318.1.1.13.1.3.4.2.1.6',
  airFMGroupSysCommDefinition => 'PowerNet-MIB::airFMGroupSysComm',
  airFMGroupSysIPAddress => '1.3.6.1.4.1.318.1.1.13.1.3.4.2.1.7',
  airFMGroupSysRoleAssignment => '1.3.6.1.4.1.318.1.1.13.1.3.4.3',
  airFMGroupSysRoleAssignmentDefinition => 'PowerNet-MIB::airFMGroupSysRoleAssignment',
  airFMGroupAutoRoleNumPrimary => '1.3.6.1.4.1.318.1.1.13.1.3.4.4',
  airFMGroupAutoRoleNumPrimaryDefinition => 'PowerNet-MIB::airFMGroupAutoRoleNumPrimary',
  airFMGroupCfg => '1.3.6.1.4.1.318.1.1.13.1.3.5',
  airFMGroupCfgName => '1.3.6.1.4.1.318.1.1.13.1.3.5.1',
  airFMGroupCfgNumSystems => '1.3.6.1.4.1.318.1.1.13.1.3.5.2',
  airFMGroupCfgNumSystemsDefinition => 'PowerNet-MIB::airFMGroupCfgNumSystems',
  airFMGroupCfgIdleBlower => '1.3.6.1.4.1.318.1.1.13.1.3.5.3',
  airFMGroupCfgIdleBlowerDefinition => 'PowerNet-MIB::airFMGroupCfgIdleBlower',
  airFMGroupCfgShutdownSmoke => '1.3.6.1.4.1.318.1.1.13.1.3.5.4',
  airFMGroupCfgShutdownSmokeDefinition => 'PowerNet-MIB::airFMGroupCfgShutdownSmoke',
  airFMGroupCfgShutdownFire => '1.3.6.1.4.1.318.1.1.13.1.3.5.5',
  airFMGroupCfgShutdownFireDefinition => 'PowerNet-MIB::airFMGroupCfgShutdownFire',
  airFMGroupCfgFailoverCommLoss => '1.3.6.1.4.1.318.1.1.13.1.3.5.6',
  airFMGroupCfgFailoverCommLossDefinition => 'PowerNet-MIB::airFMGroupCfgFailoverCommLoss',
  airFMGroupCfgDmdFightStatus => '1.3.6.1.4.1.318.1.1.13.1.3.5.7',
  airFMGroupCfgDmdFightStatusDefinition => 'PowerNet-MIB::airFMGroupCfgDmdFightStatus',
  airFMGroupCfgDmdFightSetting => '1.3.6.1.4.1.318.1.1.13.1.3.5.8',
  airFMGroupCfgDmdFightSettingDefinition => 'PowerNet-MIB::airFMGroupCfgDmdFightSetting',
  airFMGroupCfgSetpointShareStatus => '1.3.6.1.4.1.318.1.1.13.1.3.5.9',
  airFMGroupCfgSetpointShareStatusDefinition => 'PowerNet-MIB::airFMGroupCfgSetpointShareStatus',
  airFMGroupCfgSetpointShareSetting => '1.3.6.1.4.1.318.1.1.13.1.3.5.10',
  airFMGroupCfgSetpointShareSettingDefinition => 'PowerNet-MIB::airFMGroupCfgSetpointShareSetting',
  airFMGroupCfgResetFieldServiceDefaults => '1.3.6.1.4.1.318.1.1.13.1.3.5.11',
  airFMGroupCfgResetFieldServiceDefaultsDefinition => 'PowerNet-MIB::airFMGroupCfgResetFieldServiceDefaults',
  airFMGroupLoadShare => '1.3.6.1.4.1.318.1.1.13.1.3.6',
  airFMGroupLoadShareCoolRequests => '1.3.6.1.4.1.318.1.1.13.1.3.6.1',
  airFMGroupLoadShareCoolRequestsDefinition => 'PowerNet-MIB::airFMGroupLoadShareCoolRequests',
  airFMGroupLoadShareCoolThreshC => '1.3.6.1.4.1.318.1.1.13.1.3.6.2',
  airFMGroupLoadShareCoolThreshF => '1.3.6.1.4.1.318.1.1.13.1.3.6.3',
  airFMGroupLoadShareReheatRequests => '1.3.6.1.4.1.318.1.1.13.1.3.6.4',
  airFMGroupLoadShareReheatRequestsDefinition => 'PowerNet-MIB::airFMGroupLoadShareReheatRequests',
  airFMGroupLoadShareReheatThreshC => '1.3.6.1.4.1.318.1.1.13.1.3.6.5',
  airFMGroupLoadShareReheatThreshF => '1.3.6.1.4.1.318.1.1.13.1.3.6.6',
  airFMGroupLoadShareHumRequests => '1.3.6.1.4.1.318.1.1.13.1.3.6.7',
  airFMGroupLoadShareHumRequestsDefinition => 'PowerNet-MIB::airFMGroupLoadShareHumRequests',
  airFMGroupLoadShareHumThresh => '1.3.6.1.4.1.318.1.1.13.1.3.6.8',
  airFMGroupLoadShareDehumRequests => '1.3.6.1.4.1.318.1.1.13.1.3.6.9',
  airFMGroupLoadShareDehumRequestsDefinition => 'PowerNet-MIB::airFMGroupLoadShareDehumRequests',
  airFMGroupLoadShareDehumThresh => '1.3.6.1.4.1.318.1.1.13.1.3.6.10',
  airFMGroupFailover => '1.3.6.1.4.1.318.1.1.13.1.3.7',
  airFMGroupFailoverSys => '1.3.6.1.4.1.318.1.1.13.1.3.7.1',
  airFMGroupFailoverSysAnyMinorAlarm => '1.3.6.1.4.1.318.1.1.13.1.3.7.1.1',
  airFMGroupFailoverSysAnyMinorAlarmDefinition => 'PowerNet-MIB::airFMGroupFailoverSysAnyMinorAlarm',
  airFMGroupFailoverSysAnyMajorAlarm => '1.3.6.1.4.1.318.1.1.13.1.3.7.1.2',
  airFMGroupFailoverSysAnyMajorAlarmDefinition => 'PowerNet-MIB::airFMGroupFailoverSysAnyMajorAlarm',
  airFMGroupFailoverSysHighEnvTemp => '1.3.6.1.4.1.318.1.1.13.1.3.7.1.3',
  airFMGroupFailoverSysHighEnvTempDefinition => 'PowerNet-MIB::airFMGroupFailoverSysHighEnvTemp',
  airFMGroupFailoverSysLowEnvTemp => '1.3.6.1.4.1.318.1.1.13.1.3.7.1.4',
  airFMGroupFailoverSysLowEnvTempDefinition => 'PowerNet-MIB::airFMGroupFailoverSysLowEnvTemp',
  airFMGroupFailoverSysHighEnvHum => '1.3.6.1.4.1.318.1.1.13.1.3.7.1.5',
  airFMGroupFailoverSysHighEnvHumDefinition => 'PowerNet-MIB::airFMGroupFailoverSysHighEnvHum',
  airFMGroupFailoverSysLowEnvHum => '1.3.6.1.4.1.318.1.1.13.1.3.7.1.6',
  airFMGroupFailoverSysLowEnvHumDefinition => 'PowerNet-MIB::airFMGroupFailoverSysLowEnvHum',
  airFMGroupFailoverSysFireAlarm => '1.3.6.1.4.1.318.1.1.13.1.3.7.1.7',
  airFMGroupFailoverSysFireAlarmDefinition => 'PowerNet-MIB::airFMGroupFailoverSysFireAlarm',
  airFMGroupFailoverSysSmokeAlarm => '1.3.6.1.4.1.318.1.1.13.1.3.7.1.8',
  airFMGroupFailoverSysSmokeAlarmDefinition => 'PowerNet-MIB::airFMGroupFailoverSysSmokeAlarm',
  airFMGroupFailoverSysCommLost => '1.3.6.1.4.1.318.1.1.13.1.3.7.1.9',
  airFMGroupFailoverSysCommLostDefinition => 'PowerNet-MIB::airFMGroupFailoverSysCommLost',
  airFMGroupFailoverSysSupplySensorFail => '1.3.6.1.4.1.318.1.1.13.1.3.7.1.10',
  airFMGroupFailoverSysSupplySensorFailDefinition => 'PowerNet-MIB::airFMGroupFailoverSysSupplySensorFail',
  airFMGroupFailoverSysReturnSensorFail => '1.3.6.1.4.1.318.1.1.13.1.3.7.1.11',
  airFMGroupFailoverSysReturnSensorFailDefinition => 'PowerNet-MIB::airFMGroupFailoverSysReturnSensorFail',
  airFMGroupFailoverSysPrimarySensorFail => '1.3.6.1.4.1.318.1.1.13.1.3.7.1.12',
  airFMGroupFailoverSysPrimarySensorFailDefinition => 'PowerNet-MIB::airFMGroupFailoverSysPrimarySensorFail',
  airFMGroupFailoverSysSecondarySensorFail => '1.3.6.1.4.1.318.1.1.13.1.3.7.1.13',
  airFMGroupFailoverSysSecondarySensorFailDefinition => 'PowerNet-MIB::airFMGroupFailoverSysSecondarySensorFail',
  airFMGroupFailoverSysNoSensorsAvailable => '1.3.6.1.4.1.318.1.1.13.1.3.7.1.14',
  airFMGroupFailoverSysNoSensorsAvailableDefinition => 'PowerNet-MIB::airFMGroupFailoverSysNoSensorsAvailable',
  airFMGroupFailoverMod => '1.3.6.1.4.1.318.1.1.13.1.3.7.2',
  airFMGroupFailoverModMaintRequired => '1.3.6.1.4.1.318.1.1.13.1.3.7.2.1',
  airFMGroupFailoverModMaintRequiredDefinition => 'PowerNet-MIB::airFMGroupFailoverModMaintRequired',
  airFMGroupFailoverModCoolFail => '1.3.6.1.4.1.318.1.1.13.1.3.7.2.2',
  airFMGroupFailoverModCoolFailDefinition => 'PowerNet-MIB::airFMGroupFailoverModCoolFail',
  airFMGroupFailoverModHumFail => '1.3.6.1.4.1.318.1.1.13.1.3.7.2.3',
  airFMGroupFailoverModHumFailDefinition => 'PowerNet-MIB::airFMGroupFailoverModHumFail',
  airFMGroupFailoverModBlwrCntrl1Fail => '1.3.6.1.4.1.318.1.1.13.1.3.7.2.4',
  airFMGroupFailoverModBlwrCntrl1FailDefinition => 'PowerNet-MIB::airFMGroupFailoverModBlwrCntrl1Fail',
  airFMGroupFailoverModBlwrCntrl2Fail => '1.3.6.1.4.1.318.1.1.13.1.3.7.2.5',
  airFMGroupFailoverModBlwrCntrl2FailDefinition => 'PowerNet-MIB::airFMGroupFailoverModBlwrCntrl2Fail',
  airFMGroupFailoverModHighFilterDP => '1.3.6.1.4.1.318.1.1.13.1.3.7.2.6',
  airFMGroupFailoverModHighFilterDPDefinition => 'PowerNet-MIB::airFMGroupFailoverModHighFilterDP',
  airFMGroupFailoverModHighSupplyTemp => '1.3.6.1.4.1.318.1.1.13.1.3.7.2.7',
  airFMGroupFailoverModHighSupplyTempDefinition => 'PowerNet-MIB::airFMGroupFailoverModHighSupplyTemp',
  airFMGroupFailoverModLowSupplyTemp => '1.3.6.1.4.1.318.1.1.13.1.3.7.2.8',
  airFMGroupFailoverModLowSupplyTempDefinition => 'PowerNet-MIB::airFMGroupFailoverModLowSupplyTemp',
  airFMGroupFailoverModLossOrLowAirFlow => '1.3.6.1.4.1.318.1.1.13.1.3.7.2.9',
  airFMGroupFailoverModLossOrLowAirFlowDefinition => 'PowerNet-MIB::airFMGroupFailoverModLossOrLowAirFlow',
  airFMGroupFailoverModHumReplaceCylinder => '1.3.6.1.4.1.318.1.1.13.1.3.7.2.10',
  airFMGroupFailoverModHumReplaceCylinderDefinition => 'PowerNet-MIB::airFMGroupFailoverModHumReplaceCylinder',
  airFMGroupFailoverModAirBlockInterlockOpen => '1.3.6.1.4.1.318.1.1.13.1.3.7.2.11',
  airFMGroupFailoverModAirBlockInterlockOpenDefinition => 'PowerNet-MIB::airFMGroupFailoverModAirBlockInterlockOpen',
  airFMGroupFailoverModWaterDetected => '1.3.6.1.4.1.318.1.1.13.1.3.7.2.12',
  airFMGroupFailoverModWaterDetectedDefinition => 'PowerNet-MIB::airFMGroupFailoverModWaterDetected',
  airFMGroupFailoverModCondensatePumpFail => '1.3.6.1.4.1.318.1.1.13.1.3.7.2.13',
  airFMGroupFailoverModCondensatePumpFailDefinition => 'PowerNet-MIB::airFMGroupFailoverModCondensatePumpFail',
  airFMSystem => '1.3.6.1.4.1.318.1.1.13.1.4',
  airFMSysStatus => '1.3.6.1.4.1.318.1.1.13.1.4.1',
  airFMSysNumber => '1.3.6.1.4.1.318.1.1.13.1.4.1.1',
  airFMSysNumberDefinition => 'PowerNet-MIB::airFMSysNumber',
  airFMSysPresentStatus => '1.3.6.1.4.1.318.1.1.13.1.4.1.2',
  airFMSysPresentStatusDefinition => 'PowerNet-MIB::airFMSysPresentStatus',
  airFMSysPresentRole => '1.3.6.1.4.1.318.1.1.13.1.4.1.3',
  airFMSysPresentRoleDefinition => 'PowerNet-MIB::airFMSysPresentRole',
  airFMSysRunHours => '1.3.6.1.4.1.318.1.1.13.1.4.1.4',
  airFMSysCoilFluidTempC => '1.3.6.1.4.1.318.1.1.13.1.4.1.5',
  airFMSysCoilFluidTempF => '1.3.6.1.4.1.318.1.1.13.1.4.1.6',
  airFMSysHotWaterTempC => '1.3.6.1.4.1.318.1.1.13.1.4.1.7',
  airFMSysHotWaterTempF => '1.3.6.1.4.1.318.1.1.13.1.4.1.8',
  airFMSysAvgReturnTempC => '1.3.6.1.4.1.318.1.1.13.1.4.1.9',
  airFMSysAvgReturnTempF => '1.3.6.1.4.1.318.1.1.13.1.4.1.10',
  airFMSysAvgReturnHum => '1.3.6.1.4.1.318.1.1.13.1.4.1.11',
  airFMSysAvgRemoteTempC => '1.3.6.1.4.1.318.1.1.13.1.4.1.12',
  airFMSysAvgRemoteTempF => '1.3.6.1.4.1.318.1.1.13.1.4.1.13',
  airFMSysAvgRemoteHum => '1.3.6.1.4.1.318.1.1.13.1.4.1.14',
  airFMSysMaxRemoteTempC => '1.3.6.1.4.1.318.1.1.13.1.4.1.15',
  airFMSysMaxRemoteTempF => '1.3.6.1.4.1.318.1.1.13.1.4.1.16',
  airFMSysMinRemoteTempC => '1.3.6.1.4.1.318.1.1.13.1.4.1.17',
  airFMSysMinRemoteTempF => '1.3.6.1.4.1.318.1.1.13.1.4.1.18',
  airFMSysTempCtrlMethod => '1.3.6.1.4.1.318.1.1.13.1.4.1.19',
  airFMSysTempCtrlMethodDefinition => 'PowerNet-MIB::airFMSysTempCtrlMethod',
  airFMSysActualTempCtrlMethod => '1.3.6.1.4.1.318.1.1.13.1.4.1.20',
  airFMSysActualTempCtrlMethodDefinition => 'PowerNet-MIB::airFMSysActualTempCtrlMethod',
  airFMSysHumCtrlMethod => '1.3.6.1.4.1.318.1.1.13.1.4.1.21',
  airFMSysHumCtrlMethodDefinition => 'PowerNet-MIB::airFMSysHumCtrlMethod',
  airFMSysActualHumCtrlMethod => '1.3.6.1.4.1.318.1.1.13.1.4.1.22',
  airFMSysActualHumCtrlMethodDefinition => 'PowerNet-MIB::airFMSysActualHumCtrlMethod',
  airFMSysCtrlTempC => '1.3.6.1.4.1.318.1.1.13.1.4.1.23',
  airFMSysCtrlTempF => '1.3.6.1.4.1.318.1.1.13.1.4.1.24',
  airFMSysCtrlHum => '1.3.6.1.4.1.318.1.1.13.1.4.1.25',
  airFMSysDemands => '1.3.6.1.4.1.318.1.1.13.1.4.2',
  airFMSysDXCoolingDmd => '1.3.6.1.4.1.318.1.1.13.1.4.2.1',
  airFMSysDXDehumDmd => '1.3.6.1.4.1.318.1.1.13.1.4.2.2',
  airFMSysDXActualCoolDehum => '1.3.6.1.4.1.318.1.1.13.1.4.2.3',
  airFMSysCoilFluidCoolDmd => '1.3.6.1.4.1.318.1.1.13.1.4.2.4',
  airFMSysCoilFluidDehumDmd => '1.3.6.1.4.1.318.1.1.13.1.4.2.5',
  airFMSysCoilFluidActualCoolDehum => '1.3.6.1.4.1.318.1.1.13.1.4.2.6',
  airFMSysElectricReheatDmd => '1.3.6.1.4.1.318.1.1.13.1.4.2.7',
  airFMSysActualElectricReheat => '1.3.6.1.4.1.318.1.1.13.1.4.2.8',
  airFMSysSteamHotGasReheatDmd => '1.3.6.1.4.1.318.1.1.13.1.4.2.9',
  airFMSysSteamHotGasReheatDmdDefinition => 'PowerNet-MIB::airFMSysSteamHotGasReheatDmd',
  airFMSysActualSteamHotGasReheat => '1.3.6.1.4.1.318.1.1.13.1.4.2.10',
  airFMSysActualSteamHotGasReheatDefinition => 'PowerNet-MIB::airFMSysActualSteamHotGasReheat',
  airFMSysSteamElectrodeHumDmd => '1.3.6.1.4.1.318.1.1.13.1.4.2.11',
  airFMSysActualSteamElectrodeHum => '1.3.6.1.4.1.318.1.1.13.1.4.2.12',
  airFMSysSteamHumDmd => '1.3.6.1.4.1.318.1.1.13.1.4.2.13',
  airFMSysSteamHumDmdDefinition => 'PowerNet-MIB::airFMSysSteamHumDmd',
  airFMSysActualSteamHum => '1.3.6.1.4.1.318.1.1.13.1.4.2.14',
  airFMSysActualSteamHumDefinition => 'PowerNet-MIB::airFMSysActualSteamHum',
  airFMSysSetup => '1.3.6.1.4.1.318.1.1.13.1.4.3',
  airFMSysNumModules => '1.3.6.1.4.1.318.1.1.13.1.4.3.1',
  airFMSysNumModulesDefinition => 'PowerNet-MIB::airFMSysNumModules',
  airFMSysNumPCIOMs => '1.3.6.1.4.1.318.1.1.13.1.4.3.2',
  airFMSysNumPCIOMsDefinition => 'PowerNet-MIB::airFMSysNumPCIOMs',
  airFMSysMainsVlt => '1.3.6.1.4.1.318.1.1.13.1.4.3.3',
  airFMSysUPSVlt => '1.3.6.1.4.1.318.1.1.13.1.4.3.4',
  airFMSysCoilCfg => '1.3.6.1.4.1.318.1.1.13.1.4.3.5',
  airFMSysCoilCfgDefinition => 'PowerNet-MIB::airFMSysCoilCfg',
  airFMSysRefrigType => '1.3.6.1.4.1.318.1.1.13.1.4.3.6',
  airFMSysRefrigTypeDefinition => 'PowerNet-MIB::airFMSysRefrigType',
  airFMSysHeatRejection => '1.3.6.1.4.1.318.1.1.13.1.4.3.7',
  airFMSysHeatRejectionDefinition => 'PowerNet-MIB::airFMSysHeatRejection',
  airFMSysDischAirPtrn => '1.3.6.1.4.1.318.1.1.13.1.4.3.8',
  airFMSysDischAirPtrnDefinition => 'PowerNet-MIB::airFMSysDischAirPtrn',
  airFMSysAirFltr => '1.3.6.1.4.1.318.1.1.13.1.4.3.9',
  airFMSysAirFltrDefinition => 'PowerNet-MIB::airFMSysAirFltr',
  airFMSysFlowSwitch => '1.3.6.1.4.1.318.1.1.13.1.4.3.10',
  airFMSysFlowSwitchDefinition => 'PowerNet-MIB::airFMSysFlowSwitch',
  airFMSysCoilFluidVlvAct => '1.3.6.1.4.1.318.1.1.13.1.4.3.11',
  airFMSysCoilFluidVlvActDefinition => 'PowerNet-MIB::airFMSysCoilFluidVlvAct',
  airFMSysCoilFluidVlvType => '1.3.6.1.4.1.318.1.1.13.1.4.3.12',
  airFMSysCoilFluidVlvTypeDefinition => 'PowerNet-MIB::airFMSysCoilFluidVlvType',
  airFMSysCndsrFluidVlvAct => '1.3.6.1.4.1.318.1.1.13.1.4.3.13',
  airFMSysCndsrFluidVlvActDefinition => 'PowerNet-MIB::airFMSysCndsrFluidVlvAct',
  airFMSysCndsrFluidVlvType => '1.3.6.1.4.1.318.1.1.13.1.4.3.14',
  airFMSysCndsrFluidVlvTypeDefinition => 'PowerNet-MIB::airFMSysCndsrFluidVlvType',
  airFMSysHotWaterVlvAct => '1.3.6.1.4.1.318.1.1.13.1.4.3.15',
  airFMSysHotWaterVlvActDefinition => 'PowerNet-MIB::airFMSysHotWaterVlvAct',
  airFMSysNumRemoteSensors => '1.3.6.1.4.1.318.1.1.13.1.4.3.16',
  airFMSysConfig => '1.3.6.1.4.1.318.1.1.13.1.4.4',
  airFMSysPrimaryControlSensor => '1.3.6.1.4.1.318.1.1.13.1.4.4.1',
  airFMSysPrimaryControlSensorDefinition => 'PowerNet-MIB::airFMSysPrimaryControlSensor',
  airFMSysRemoteSensorData => '1.3.6.1.4.1.318.1.1.13.1.4.4.2',
  airFMSysRemoteSensorDataDefinition => 'PowerNet-MIB::airFMSysRemoteSensorData',
  airFMSysFastStartup => '1.3.6.1.4.1.318.1.1.13.1.4.4.3',
  airFMSysFastStartupDefinition => 'PowerNet-MIB::airFMSysFastStartup',
  airFMSysStartupDelay => '1.3.6.1.4.1.318.1.1.13.1.4.4.4',
  airFMSysModeDelay => '1.3.6.1.4.1.318.1.1.13.1.4.4.5',
  airFMSysCommLossShutdownDelay => '1.3.6.1.4.1.318.1.1.13.1.4.4.6',
  airFMSysResetSysFailure => '1.3.6.1.4.1.318.1.1.13.1.4.4.7',
  airFMSysResetSysFailureDefinition => 'PowerNet-MIB::airFMSysResetSysFailure',
  airFMSysResetUserDflts => '1.3.6.1.4.1.318.1.1.13.1.4.4.8',
  airFMSysResetUserDfltsDefinition => 'PowerNet-MIB::airFMSysResetUserDflts',
  airFMSysResetFldSrvcDflts => '1.3.6.1.4.1.318.1.1.13.1.4.4.9',
  airFMSysResetFldSrvcDfltsDefinition => 'PowerNet-MIB::airFMSysResetFldSrvcDflts',
  airFMSysResetRunHours => '1.3.6.1.4.1.318.1.1.13.1.4.4.10',
  airFMSysResetRunHoursDefinition => 'PowerNet-MIB::airFMSysResetRunHours',
  airFMSysCooling => '1.3.6.1.4.1.318.1.1.13.1.4.5',
  airFMSysCompMinOnTime => '1.3.6.1.4.1.318.1.1.13.1.4.5.1',
  airFMSysCompMinOffTime => '1.3.6.1.4.1.318.1.1.13.1.4.5.2',
  airFMSysCompRotPeriod => '1.3.6.1.4.1.318.1.1.13.1.4.5.3',
  airFMSysEconIsolVlvOpenDelay => '1.3.6.1.4.1.318.1.1.13.1.4.5.4',
  airFMSysEconIsolVlvCloseDelay => '1.3.6.1.4.1.318.1.1.13.1.4.5.5',
  airFMSysCndsrFluidVlvCloseDelay => '1.3.6.1.4.1.318.1.1.13.1.4.5.6',
  airFMSysInterstageDelay => '1.3.6.1.4.1.318.1.1.13.1.4.5.7',
  airFMSysCoolState => '1.3.6.1.4.1.318.1.1.13.1.4.5.8',
  airFMSysCoolStateDefinition => 'PowerNet-MIB::airFMSysCoolState',
  airFMSysCoolEssFunction => '1.3.6.1.4.1.318.1.1.13.1.4.5.9',
  airFMSysCoolEssFunctionDefinition => 'PowerNet-MIB::airFMSysCoolEssFunction',
  airFMSysCoolSetpointC => '1.3.6.1.4.1.318.1.1.13.1.4.5.10',
  airFMSysCoolSetpointF => '1.3.6.1.4.1.318.1.1.13.1.4.5.11',
  airFMSysCoolDeadbandC => '1.3.6.1.4.1.318.1.1.13.1.4.5.12',
  airFMSysCoolDeadbandF => '1.3.6.1.4.1.318.1.1.13.1.4.5.13',
  airFMSysCoolEconIsolFunction => '1.3.6.1.4.1.318.1.1.13.1.4.5.14',
  airFMSysCoolEconIsolFunctionDefinition => 'PowerNet-MIB::airFMSysCoolEconIsolFunction',
  airFMSysSuctPresCompensation => '1.3.6.1.4.1.318.1.1.13.1.4.5.15',
  airFMSysSuctPresCompensationDefinition => 'PowerNet-MIB::airFMSysSuctPresCompensation',
  airFMSysCoilFluidActivThreshC => '1.3.6.1.4.1.318.1.1.13.1.4.5.16',
  airFMSysCoilFluidActivThreshF => '1.3.6.1.4.1.318.1.1.13.1.4.5.17',
  airFMSysCoilFluidActivDeadbandC => '1.3.6.1.4.1.318.1.1.13.1.4.5.18',
  airFMSysCoilFluidActivDeadbandF => '1.3.6.1.4.1.318.1.1.13.1.4.5.19',
  airFMSysCoolPIDMethod => '1.3.6.1.4.1.318.1.1.13.1.4.5.20',
  airFMSysCoolPIDMethodDefinition => 'PowerNet-MIB::airFMSysCoolPIDMethod',
  airFMSysCoolPIDGainP => '1.3.6.1.4.1.318.1.1.13.1.4.5.21',
  airFMSysCoolPIDResetRateI => '1.3.6.1.4.1.318.1.1.13.1.4.5.22',
  airFMSysCoolPIDDerivativeD => '1.3.6.1.4.1.318.1.1.13.1.4.5.23',
  airFMSysHumidify => '1.3.6.1.4.1.318.1.1.13.1.4.6',
  airFMSysHumState => '1.3.6.1.4.1.318.1.1.13.1.4.6.1',
  airFMSysHumStateDefinition => 'PowerNet-MIB::airFMSysHumState',
  airFMSysHumEssFunction => '1.3.6.1.4.1.318.1.1.13.1.4.6.2',
  airFMSysHumEssFunctionDefinition => 'PowerNet-MIB::airFMSysHumEssFunction',
  airFMSysHumSetpoint => '1.3.6.1.4.1.318.1.1.13.1.4.6.3',
  airFMSysHumDeadband => '1.3.6.1.4.1.318.1.1.13.1.4.6.4',
  airFMSysHumCtrlSetting => '1.3.6.1.4.1.318.1.1.13.1.4.6.5',
  airFMSysHumCtrlSettingDefinition => 'PowerNet-MIB::airFMSysHumCtrlSetting',
  airFMSysActualHumCtrl => '1.3.6.1.4.1.318.1.1.13.1.4.6.6',
  airFMSysActualHumCtrlDefinition => 'PowerNet-MIB::airFMSysActualHumCtrl',
  airFMSysHumSensBand => '1.3.6.1.4.1.318.1.1.13.1.4.6.7',
  airFMSysDehumidify => '1.3.6.1.4.1.318.1.1.13.1.4.7',
  airFMSysDehumState => '1.3.6.1.4.1.318.1.1.13.1.4.7.1',
  airFMSysDehumStateDefinition => 'PowerNet-MIB::airFMSysDehumState',
  airFMSysDehumEssFunction => '1.3.6.1.4.1.318.1.1.13.1.4.7.2',
  airFMSysDehumEssFunctionDefinition => 'PowerNet-MIB::airFMSysDehumEssFunction',
  airFMSysDehumSetpoint => '1.3.6.1.4.1.318.1.1.13.1.4.7.3',
  airFMSysDehumDeadband => '1.3.6.1.4.1.318.1.1.13.1.4.7.4',
  airFMSysDehumCapacity => '1.3.6.1.4.1.318.1.1.13.1.4.7.5',
  airFMSysDehumCapacityDefinition => 'PowerNet-MIB::airFMSysDehumCapacity',
  airFMSysDehumPIDMethod => '1.3.6.1.4.1.318.1.1.13.1.4.7.6',
  airFMSysDehumPIDMethodDefinition => 'PowerNet-MIB::airFMSysDehumPIDMethod',
  airFMSysDehumPIDGainP => '1.3.6.1.4.1.318.1.1.13.1.4.7.7',
  airFMSysDehumPIDResetRateI => '1.3.6.1.4.1.318.1.1.13.1.4.7.8',
  airFMSysDehumPIDDerivativeD => '1.3.6.1.4.1.318.1.1.13.1.4.7.9',
  airFMSysReheat => '1.3.6.1.4.1.318.1.1.13.1.4.8',
  airFMSysReheatState => '1.3.6.1.4.1.318.1.1.13.1.4.8.1',
  airFMSysReheatStateDefinition => 'PowerNet-MIB::airFMSysReheatState',
  airFMSysReheatEssFunction => '1.3.6.1.4.1.318.1.1.13.1.4.8.2',
  airFMSysReheatEssFunctionDefinition => 'PowerNet-MIB::airFMSysReheatEssFunction',
  airFMSysReheatSetpointC => '1.3.6.1.4.1.318.1.1.13.1.4.8.3',
  airFMSysReheatSetpointF => '1.3.6.1.4.1.318.1.1.13.1.4.8.4',
  airFMSysReheatDeadbandC => '1.3.6.1.4.1.318.1.1.13.1.4.8.5',
  airFMSysReheatDeadbandF => '1.3.6.1.4.1.318.1.1.13.1.4.8.6',
  airFMSysReheatPIDMethod => '1.3.6.1.4.1.318.1.1.13.1.4.8.7',
  airFMSysReheatPIDMethodDefinition => 'PowerNet-MIB::airFMSysReheatPIDMethod',
  airFMSysReheatPIDGainP => '1.3.6.1.4.1.318.1.1.13.1.4.8.8',
  airFMSysReheatPIDResetRateI => '1.3.6.1.4.1.318.1.1.13.1.4.8.9',
  airFMSysReheatPIDDerivativeD => '1.3.6.1.4.1.318.1.1.13.1.4.8.10',
  airFMSysThresholds => '1.3.6.1.4.1.318.1.1.13.1.4.9',
  airFMSysHighSplyTempC => '1.3.6.1.4.1.318.1.1.13.1.4.9.1',
  airFMSysHighSplyTempF => '1.3.6.1.4.1.318.1.1.13.1.4.9.2',
  airFMSysLowSplyTempC => '1.3.6.1.4.1.318.1.1.13.1.4.9.3',
  airFMSysLowSplyTempF => '1.3.6.1.4.1.318.1.1.13.1.4.9.4',
  airFMSysHighCoilFluidTempC => '1.3.6.1.4.1.318.1.1.13.1.4.9.5',
  airFMSysHighCoilFluidTempF => '1.3.6.1.4.1.318.1.1.13.1.4.9.6',
  airFMSysLowCoilFluidTempC => '1.3.6.1.4.1.318.1.1.13.1.4.9.7',
  airFMSysLowCoilFluidTempF => '1.3.6.1.4.1.318.1.1.13.1.4.9.8',
  airFMSysHighCtrlTempC => '1.3.6.1.4.1.318.1.1.13.1.4.9.9',
  airFMSysHighCtrlTempF => '1.3.6.1.4.1.318.1.1.13.1.4.9.10',
  airFMSysLowCtrlTempC => '1.3.6.1.4.1.318.1.1.13.1.4.9.11',
  airFMSysLowCtrlTempF => '1.3.6.1.4.1.318.1.1.13.1.4.9.12',
  airFMSysHighCtrlHum => '1.3.6.1.4.1.318.1.1.13.1.4.9.13',
  airFMSysLowCtrlHum => '1.3.6.1.4.1.318.1.1.13.1.4.9.14',
  airFMSysTempAlarmDelay => '1.3.6.1.4.1.318.1.1.13.1.4.9.15',
  airFMSysHumAlarmDelay => '1.3.6.1.4.1.318.1.1.13.1.4.9.16',
  airFMSysInputs => '1.3.6.1.4.1.318.1.1.13.1.4.10',
  airFMSysInputTableSize => '1.3.6.1.4.1.318.1.1.13.1.4.10.1',
  airFMSysInputTable => '1.3.6.1.4.1.318.1.1.13.1.4.10.2',
  airFMSysInputEntry => '1.3.6.1.4.1.318.1.1.13.1.4.10.2.1',
  airFMSysInputIndex => '1.3.6.1.4.1.318.1.1.13.1.4.10.2.1.1',
  airFMSysInputName => '1.3.6.1.4.1.318.1.1.13.1.4.10.2.1.2',
  airFMSysInputStatus => '1.3.6.1.4.1.318.1.1.13.1.4.10.2.1.3',
  airFMSysInputStatusDefinition => 'PowerNet-MIB::airFMSysInputStatus',
  airFMSysInputNormalState => '1.3.6.1.4.1.318.1.1.13.1.4.10.2.1.4',
  airFMSysInputNormalStateDefinition => 'PowerNet-MIB::airFMSysInputNormalState',
  airFMSysInputDelay => '1.3.6.1.4.1.318.1.1.13.1.4.10.2.1.5',
  airFMSysInputAlarmAction => '1.3.6.1.4.1.318.1.1.13.1.4.10.2.1.6',
  airFMSysInputAlarmActionDefinition => 'PowerNet-MIB::airFMSysInputAlarmAction',
  airFMSysOutputs => '1.3.6.1.4.1.318.1.1.13.1.4.11',
  airFMSysOutputTableSize => '1.3.6.1.4.1.318.1.1.13.1.4.11.1',
  airFMSysOutputTable => '1.3.6.1.4.1.318.1.1.13.1.4.11.2',
  airFMSysOutputEntry => '1.3.6.1.4.1.318.1.1.13.1.4.11.2.1',
  airFMSysOutputIndex => '1.3.6.1.4.1.318.1.1.13.1.4.11.2.1.1',
  airFMSysOutputStatus => '1.3.6.1.4.1.318.1.1.13.1.4.11.2.1.2',
  airFMSysOutputStatusDefinition => 'PowerNet-MIB::airFMSysOutputStatus',
  airFMSysOutputNormalState => '1.3.6.1.4.1.318.1.1.13.1.4.11.2.1.3',
  airFMSysOutputNormalStateDefinition => 'PowerNet-MIB::airFMSysOutputNormalState',
  airFMSysAlarmMap => '1.3.6.1.4.1.318.1.1.13.1.4.12',
  airFMSysAlarmMapSys => '1.3.6.1.4.1.318.1.1.13.1.4.12.1',
  airFMSysAlarmMapSysTableSize => '1.3.6.1.4.1.318.1.1.13.1.4.12.1.1',
  airFMSysAlarmMapSysTable => '1.3.6.1.4.1.318.1.1.13.1.4.12.1.2',
  airFMSysAlarmMapSysEntry => '1.3.6.1.4.1.318.1.1.13.1.4.12.1.2.1',
  airFMSysAlarmMapSysOutputIndex => '1.3.6.1.4.1.318.1.1.13.1.4.12.1.2.1.1',
  airFMSysAlarmMapSysAnyAlarm => '1.3.6.1.4.1.318.1.1.13.1.4.12.1.2.1.2',
  airFMSysAlarmMapSysAnyAlarmDefinition => 'PowerNet-MIB::airFMSysAlarmMapSysAnyAlarm',
  airFMSysAlarmMapSystemOn => '1.3.6.1.4.1.318.1.1.13.1.4.12.1.2.1.3',
  airFMSysAlarmMapSystemOnDefinition => 'PowerNet-MIB::airFMSysAlarmMapSystemOn',
  airFMSysAlarmMapSystemOffline => '1.3.6.1.4.1.318.1.1.13.1.4.12.1.2.1.4',
  airFMSysAlarmMapSystemOfflineDefinition => 'PowerNet-MIB::airFMSysAlarmMapSystemOffline',
  airFMSysAlarmMapSysHighEnvTemp => '1.3.6.1.4.1.318.1.1.13.1.4.12.1.2.1.5',
  airFMSysAlarmMapSysHighEnvTempDefinition => 'PowerNet-MIB::airFMSysAlarmMapSysHighEnvTemp',
  airFMSysAlarmMapSysLowEnvTemp => '1.3.6.1.4.1.318.1.1.13.1.4.12.1.2.1.6',
  airFMSysAlarmMapSysLowEnvTempDefinition => 'PowerNet-MIB::airFMSysAlarmMapSysLowEnvTemp',
  airFMSysAlarmMapSysHighEnvHum => '1.3.6.1.4.1.318.1.1.13.1.4.12.1.2.1.7',
  airFMSysAlarmMapSysHighEnvHumDefinition => 'PowerNet-MIB::airFMSysAlarmMapSysHighEnvHum',
  airFMSysAlarmMapSysLowEnvHum => '1.3.6.1.4.1.318.1.1.13.1.4.12.1.2.1.8',
  airFMSysAlarmMapSysLowEnvHumDefinition => 'PowerNet-MIB::airFMSysAlarmMapSysLowEnvHum',
  airFMSysAlarmMapSysFireDet => '1.3.6.1.4.1.318.1.1.13.1.4.12.1.2.1.9',
  airFMSysAlarmMapSysFireDetDefinition => 'PowerNet-MIB::airFMSysAlarmMapSysFireDet',
  airFMSysAlarmMapSysSmokeDet => '1.3.6.1.4.1.318.1.1.13.1.4.12.1.2.1.10',
  airFMSysAlarmMapSysSmokeDetDefinition => 'PowerNet-MIB::airFMSysAlarmMapSysSmokeDet',
  airFMSysAlarmMapSysEconIsol => '1.3.6.1.4.1.318.1.1.13.1.4.12.1.2.1.11',
  airFMSysAlarmMapSysEconIsolDefinition => 'PowerNet-MIB::airFMSysAlarmMapSysEconIsol',
  airFMSysAlarmMapSysSupplySensFail => '1.3.6.1.4.1.318.1.1.13.1.4.12.1.2.1.12',
  airFMSysAlarmMapSysSupplySensFailDefinition => 'PowerNet-MIB::airFMSysAlarmMapSysSupplySensFail',
  airFMSysAlarmMapSysReturnSensFail => '1.3.6.1.4.1.318.1.1.13.1.4.12.1.2.1.13',
  airFMSysAlarmMapSysReturnSensFailDefinition => 'PowerNet-MIB::airFMSysAlarmMapSysReturnSensFail',
  airFMSysAlarmMapSysRemSensRemoved => '1.3.6.1.4.1.318.1.1.13.1.4.12.1.2.1.14',
  airFMSysAlarmMapSysRemSensRemovedDefinition => 'PowerNet-MIB::airFMSysAlarmMapSysRemSensRemoved',
  airFMSysAlarmMapSysPrimSensFail => '1.3.6.1.4.1.318.1.1.13.1.4.12.1.2.1.15',
  airFMSysAlarmMapSysPrimSensFailDefinition => 'PowerNet-MIB::airFMSysAlarmMapSysPrimSensFail',
  airFMSysAlarmMapSysSecSensFail => '1.3.6.1.4.1.318.1.1.13.1.4.12.1.2.1.16',
  airFMSysAlarmMapSysSecSensFailDefinition => 'PowerNet-MIB::airFMSysAlarmMapSysSecSensFail',
  airFMSysAlarmMapSysSecSensActive => '1.3.6.1.4.1.318.1.1.13.1.4.12.1.2.1.17',
  airFMSysAlarmMapSysSecSensActiveDefinition => 'PowerNet-MIB::airFMSysAlarmMapSysSecSensActive',
  airFMSysAlarmMapMainMod => '1.3.6.1.4.1.318.1.1.13.1.4.12.2',
  airFMSysAlarmMapMainModTableSize => '1.3.6.1.4.1.318.1.1.13.1.4.12.2.1',
  airFMSysAlarmMapMainModTable => '1.3.6.1.4.1.318.1.1.13.1.4.12.2.2',
  airFMSysAlarmMapMainModEntry => '1.3.6.1.4.1.318.1.1.13.1.4.12.2.2.1',
  airFMSysAlarmMapMainModOutputIndex => '1.3.6.1.4.1.318.1.1.13.1.4.12.2.2.1.1',
  airFMSysAlarmMapMainModAnyAlarm => '1.3.6.1.4.1.318.1.1.13.1.4.12.2.2.1.2',
  airFMSysAlarmMapMainModAnyAlarmDefinition => 'PowerNet-MIB::airFMSysAlarmMapMainModAnyAlarm',
  airFMSysAlarmMapMainModMaintReq => '1.3.6.1.4.1.318.1.1.13.1.4.12.2.2.1.3',
  airFMSysAlarmMapMainModMaintReqDefinition => 'PowerNet-MIB::airFMSysAlarmMapMainModMaintReq',
  airFMSysAlarmMapMainModCoolFail => '1.3.6.1.4.1.318.1.1.13.1.4.12.2.2.1.4',
  airFMSysAlarmMapMainModCoolFailDefinition => 'PowerNet-MIB::airFMSysAlarmMapMainModCoolFail',
  airFMSysAlarmMapMainModHighSupplyTemp => '1.3.6.1.4.1.318.1.1.13.1.4.12.2.2.1.5',
  airFMSysAlarmMapMainModHighSupplyTempDefinition => 'PowerNet-MIB::airFMSysAlarmMapMainModHighSupplyTemp',
  airFMSysAlarmMapMainModLowSupplyTemp => '1.3.6.1.4.1.318.1.1.13.1.4.12.2.2.1.6',
  airFMSysAlarmMapMainModLowSupplyTempDefinition => 'PowerNet-MIB::airFMSysAlarmMapMainModLowSupplyTemp',
  airFMSysAlarmMapMainModHumFail => '1.3.6.1.4.1.318.1.1.13.1.4.12.2.2.1.7',
  airFMSysAlarmMapMainModHumFailDefinition => 'PowerNet-MIB::airFMSysAlarmMapMainModHumFail',
  airFMSysAlarmMapMainModHumReplCyl => '1.3.6.1.4.1.318.1.1.13.1.4.12.2.2.1.8',
  airFMSysAlarmMapMainModHumReplCylDefinition => 'PowerNet-MIB::airFMSysAlarmMapMainModHumReplCyl',
  airFMSysAlarmMapMainModCondPumpFail => '1.3.6.1.4.1.318.1.1.13.1.4.12.2.2.1.9',
  airFMSysAlarmMapMainModCondPumpFailDefinition => 'PowerNet-MIB::airFMSysAlarmMapMainModCondPumpFail',
  airFMSysAlarmMapMainModBlwrCntl1Fail => '1.3.6.1.4.1.318.1.1.13.1.4.12.2.2.1.10',
  airFMSysAlarmMapMainModBlwrCntl1FailDefinition => 'PowerNet-MIB::airFMSysAlarmMapMainModBlwrCntl1Fail',
  airFMSysAlarmMapMainModBlwrCntl2Fail => '1.3.6.1.4.1.318.1.1.13.1.4.12.2.2.1.11',
  airFMSysAlarmMapMainModBlwrCntl2FailDefinition => 'PowerNet-MIB::airFMSysAlarmMapMainModBlwrCntl2Fail',
  airFMSysAlarmMapMainModHighFltrDP => '1.3.6.1.4.1.318.1.1.13.1.4.12.2.2.1.12',
  airFMSysAlarmMapMainModHighFltrDPDefinition => 'PowerNet-MIB::airFMSysAlarmMapMainModHighFltrDP',
  airFMSysAlarmMapMainModLowAirFlow => '1.3.6.1.4.1.318.1.1.13.1.4.12.2.2.1.13',
  airFMSysAlarmMapMainModLowAirFlowDefinition => 'PowerNet-MIB::airFMSysAlarmMapMainModLowAirFlow',
  airFMSysAlarmMapMainModAirBlckIntOpen => '1.3.6.1.4.1.318.1.1.13.1.4.12.2.2.1.14',
  airFMSysAlarmMapMainModAirBlckIntOpenDefinition => 'PowerNet-MIB::airFMSysAlarmMapMainModAirBlckIntOpen',
  airFMSysAlarmMapMainModWaterDetected => '1.3.6.1.4.1.318.1.1.13.1.4.12.2.2.1.15',
  airFMSysAlarmMapMainModWaterDetectedDefinition => 'PowerNet-MIB::airFMSysAlarmMapMainModWaterDetected',
  airFMSysAlarmMapExpMod1 => '1.3.6.1.4.1.318.1.1.13.1.4.12.3',
  airFMSysAlarmMapExpMod1TableSize => '1.3.6.1.4.1.318.1.1.13.1.4.12.3.1',
  airFMSysAlarmMapExpMod1Table => '1.3.6.1.4.1.318.1.1.13.1.4.12.3.2',
  airFMSysAlarmMapExpMod1Entry => '1.3.6.1.4.1.318.1.1.13.1.4.12.3.2.1',
  airFMSysAlarmMapExpMod1OutputIndex => '1.3.6.1.4.1.318.1.1.13.1.4.12.3.2.1.1',
  airFMSysAlarmMapExpMod1AnyAlarm => '1.3.6.1.4.1.318.1.1.13.1.4.12.3.2.1.2',
  airFMSysAlarmMapExpMod1AnyAlarmDefinition => 'PowerNet-MIB::airFMSysAlarmMapExpMod1AnyAlarm',
  airFMSysAlarmMapExpMod1MaintReq => '1.3.6.1.4.1.318.1.1.13.1.4.12.3.2.1.3',
  airFMSysAlarmMapExpMod1MaintReqDefinition => 'PowerNet-MIB::airFMSysAlarmMapExpMod1MaintReq',
  airFMSysAlarmMapExpMod1CoolFail => '1.3.6.1.4.1.318.1.1.13.1.4.12.3.2.1.4',
  airFMSysAlarmMapExpMod1CoolFailDefinition => 'PowerNet-MIB::airFMSysAlarmMapExpMod1CoolFail',
  airFMSysAlarmMapExpMod1HighSupplyTemp => '1.3.6.1.4.1.318.1.1.13.1.4.12.3.2.1.5',
  airFMSysAlarmMapExpMod1HighSupplyTempDefinition => 'PowerNet-MIB::airFMSysAlarmMapExpMod1HighSupplyTemp',
  airFMSysAlarmMapExpMod1LowSupplyTemp => '1.3.6.1.4.1.318.1.1.13.1.4.12.3.2.1.6',
  airFMSysAlarmMapExpMod1LowSupplyTempDefinition => 'PowerNet-MIB::airFMSysAlarmMapExpMod1LowSupplyTemp',
  airFMSysAlarmMapExpMod1HumFail => '1.3.6.1.4.1.318.1.1.13.1.4.12.3.2.1.7',
  airFMSysAlarmMapExpMod1HumFailDefinition => 'PowerNet-MIB::airFMSysAlarmMapExpMod1HumFail',
  airFMSysAlarmMapExpMod1HumReplCyl => '1.3.6.1.4.1.318.1.1.13.1.4.12.3.2.1.8',
  airFMSysAlarmMapExpMod1HumReplCylDefinition => 'PowerNet-MIB::airFMSysAlarmMapExpMod1HumReplCyl',
  airFMSysAlarmMapExpMod1CondPumpFail => '1.3.6.1.4.1.318.1.1.13.1.4.12.3.2.1.9',
  airFMSysAlarmMapExpMod1CondPumpFailDefinition => 'PowerNet-MIB::airFMSysAlarmMapExpMod1CondPumpFail',
  airFMSysAlarmMapExpMod1BlwrCntl1Fail => '1.3.6.1.4.1.318.1.1.13.1.4.12.3.2.1.10',
  airFMSysAlarmMapExpMod1BlwrCntl1FailDefinition => 'PowerNet-MIB::airFMSysAlarmMapExpMod1BlwrCntl1Fail',
  airFMSysAlarmMapExpMod1BlwrCntl2Fail => '1.3.6.1.4.1.318.1.1.13.1.4.12.3.2.1.11',
  airFMSysAlarmMapExpMod1BlwrCntl2FailDefinition => 'PowerNet-MIB::airFMSysAlarmMapExpMod1BlwrCntl2Fail',
  airFMSysAlarmMapExpMod1HighFltrDP => '1.3.6.1.4.1.318.1.1.13.1.4.12.3.2.1.12',
  airFMSysAlarmMapExpMod1HighFltrDPDefinition => 'PowerNet-MIB::airFMSysAlarmMapExpMod1HighFltrDP',
  airFMSysAlarmMapExpMod1LowAirFlow => '1.3.6.1.4.1.318.1.1.13.1.4.12.3.2.1.13',
  airFMSysAlarmMapExpMod1LowAirFlowDefinition => 'PowerNet-MIB::airFMSysAlarmMapExpMod1LowAirFlow',
  airFMSysAlarmMapExpMod1AirBlckIntOpen => '1.3.6.1.4.1.318.1.1.13.1.4.12.3.2.1.14',
  airFMSysAlarmMapExpMod1AirBlckIntOpenDefinition => 'PowerNet-MIB::airFMSysAlarmMapExpMod1AirBlckIntOpen',
  airFMSysAlarmMapExpMod1WaterDetected => '1.3.6.1.4.1.318.1.1.13.1.4.12.3.2.1.15',
  airFMSysAlarmMapExpMod1WaterDetectedDefinition => 'PowerNet-MIB::airFMSysAlarmMapExpMod1WaterDetected',
  airFMSysAlarmMapExpMod2 => '1.3.6.1.4.1.318.1.1.13.1.4.12.4',
  airFMSysAlarmMapExpMod2TableSize => '1.3.6.1.4.1.318.1.1.13.1.4.12.4.1',
  airFMSysAlarmMapExpMod2Table => '1.3.6.1.4.1.318.1.1.13.1.4.12.4.2',
  airFMSysAlarmMapExpMod2Entry => '1.3.6.1.4.1.318.1.1.13.1.4.12.4.2.1',
  airFMSysAlarmMapExpMod2OutputIndex => '1.3.6.1.4.1.318.1.1.13.1.4.12.4.2.1.1',
  airFMSysAlarmMapExpMod2AnyAlarm => '1.3.6.1.4.1.318.1.1.13.1.4.12.4.2.1.2',
  airFMSysAlarmMapExpMod2AnyAlarmDefinition => 'PowerNet-MIB::airFMSysAlarmMapExpMod2AnyAlarm',
  airFMSysAlarmMapExpMod2MaintReq => '1.3.6.1.4.1.318.1.1.13.1.4.12.4.2.1.3',
  airFMSysAlarmMapExpMod2MaintReqDefinition => 'PowerNet-MIB::airFMSysAlarmMapExpMod2MaintReq',
  airFMSysAlarmMapExpMod2CoolFail => '1.3.6.1.4.1.318.1.1.13.1.4.12.4.2.1.4',
  airFMSysAlarmMapExpMod2CoolFailDefinition => 'PowerNet-MIB::airFMSysAlarmMapExpMod2CoolFail',
  airFMSysAlarmMapExpMod2HighSupplyTemp => '1.3.6.1.4.1.318.1.1.13.1.4.12.4.2.1.5',
  airFMSysAlarmMapExpMod2HighSupplyTempDefinition => 'PowerNet-MIB::airFMSysAlarmMapExpMod2HighSupplyTemp',
  airFMSysAlarmMapExpMod2LowSupplyTemp => '1.3.6.1.4.1.318.1.1.13.1.4.12.4.2.1.6',
  airFMSysAlarmMapExpMod2LowSupplyTempDefinition => 'PowerNet-MIB::airFMSysAlarmMapExpMod2LowSupplyTemp',
  airFMSysAlarmMapExpMod2HumFail => '1.3.6.1.4.1.318.1.1.13.1.4.12.4.2.1.7',
  airFMSysAlarmMapExpMod2HumFailDefinition => 'PowerNet-MIB::airFMSysAlarmMapExpMod2HumFail',
  airFMSysAlarmMapExpMod2HumReplCyl => '1.3.6.1.4.1.318.1.1.13.1.4.12.4.2.1.8',
  airFMSysAlarmMapExpMod2HumReplCylDefinition => 'PowerNet-MIB::airFMSysAlarmMapExpMod2HumReplCyl',
  airFMSysAlarmMapExpMod2CondPumpFail => '1.3.6.1.4.1.318.1.1.13.1.4.12.4.2.1.9',
  airFMSysAlarmMapExpMod2CondPumpFailDefinition => 'PowerNet-MIB::airFMSysAlarmMapExpMod2CondPumpFail',
  airFMSysAlarmMapExpMod2BlwrCntl1Fail => '1.3.6.1.4.1.318.1.1.13.1.4.12.4.2.1.10',
  airFMSysAlarmMapExpMod2BlwrCntl1FailDefinition => 'PowerNet-MIB::airFMSysAlarmMapExpMod2BlwrCntl1Fail',
  airFMSysAlarmMapExpMod2BlwrCntl2Fail => '1.3.6.1.4.1.318.1.1.13.1.4.12.4.2.1.11',
  airFMSysAlarmMapExpMod2BlwrCntl2FailDefinition => 'PowerNet-MIB::airFMSysAlarmMapExpMod2BlwrCntl2Fail',
  airFMSysAlarmMapExpMod2HighFltrDP => '1.3.6.1.4.1.318.1.1.13.1.4.12.4.2.1.12',
  airFMSysAlarmMapExpMod2HighFltrDPDefinition => 'PowerNet-MIB::airFMSysAlarmMapExpMod2HighFltrDP',
  airFMSysAlarmMapExpMod2LowAirFlow => '1.3.6.1.4.1.318.1.1.13.1.4.12.4.2.1.13',
  airFMSysAlarmMapExpMod2LowAirFlowDefinition => 'PowerNet-MIB::airFMSysAlarmMapExpMod2LowAirFlow',
  airFMSysAlarmMapExpMod2AirBlckIntOpen => '1.3.6.1.4.1.318.1.1.13.1.4.12.4.2.1.14',
  airFMSysAlarmMapExpMod2AirBlckIntOpenDefinition => 'PowerNet-MIB::airFMSysAlarmMapExpMod2AirBlckIntOpen',
  airFMSysAlarmMapExpMod2WaterDetected => '1.3.6.1.4.1.318.1.1.13.1.4.12.4.2.1.15',
  airFMSysAlarmMapExpMod2WaterDetectedDefinition => 'PowerNet-MIB::airFMSysAlarmMapExpMod2WaterDetected',
  airFMSysAlarmMapInput => '1.3.6.1.4.1.318.1.1.13.1.4.12.5',
  airFMSysAlarmMapInputTableSize => '1.3.6.1.4.1.318.1.1.13.1.4.12.5.1',
  airFMSysAlarmMapInputTable => '1.3.6.1.4.1.318.1.1.13.1.4.12.5.2',
  airFMSysAlarmMapInputEntry => '1.3.6.1.4.1.318.1.1.13.1.4.12.5.2.1',
  airFMSysAlarmMapInputOutputIndex => '1.3.6.1.4.1.318.1.1.13.1.4.12.5.2.1.1',
  airFMSysAlarmMapInput1 => '1.3.6.1.4.1.318.1.1.13.1.4.12.5.2.1.2',
  airFMSysAlarmMapInput1Definition => 'PowerNet-MIB::airFMSysAlarmMapInput1',
  airFMSysAlarmMapInput2 => '1.3.6.1.4.1.318.1.1.13.1.4.12.5.2.1.3',
  airFMSysAlarmMapInput2Definition => 'PowerNet-MIB::airFMSysAlarmMapInput2',
  airFMSysAlarmMapInput3 => '1.3.6.1.4.1.318.1.1.13.1.4.12.5.2.1.4',
  airFMSysAlarmMapInput3Definition => 'PowerNet-MIB::airFMSysAlarmMapInput3',
  airFMSysAlarmMapInput4 => '1.3.6.1.4.1.318.1.1.13.1.4.12.5.2.1.5',
  airFMSysAlarmMapInput4Definition => 'PowerNet-MIB::airFMSysAlarmMapInput4',
  airFMSysAlarmMapInput5 => '1.3.6.1.4.1.318.1.1.13.1.4.12.5.2.1.6',
  airFMSysAlarmMapInput5Definition => 'PowerNet-MIB::airFMSysAlarmMapInput5',
  airFMSysAlarmMapInput6 => '1.3.6.1.4.1.318.1.1.13.1.4.12.5.2.1.7',
  airFMSysAlarmMapInput6Definition => 'PowerNet-MIB::airFMSysAlarmMapInput6',
  airFMSysAlarmMapInput7 => '1.3.6.1.4.1.318.1.1.13.1.4.12.5.2.1.8',
  airFMSysAlarmMapInput7Definition => 'PowerNet-MIB::airFMSysAlarmMapInput7',
  airFMSysAlarmMapInput8 => '1.3.6.1.4.1.318.1.1.13.1.4.12.5.2.1.9',
  airFMSysAlarmMapInput8Definition => 'PowerNet-MIB::airFMSysAlarmMapInput8',
  airFMSysAlarmMapInput9 => '1.3.6.1.4.1.318.1.1.13.1.4.12.5.2.1.10',
  airFMSysAlarmMapInput9Definition => 'PowerNet-MIB::airFMSysAlarmMapInput9',
  airFMSysAlarmMapInput10 => '1.3.6.1.4.1.318.1.1.13.1.4.12.5.2.1.11',
  airFMSysAlarmMapInput10Definition => 'PowerNet-MIB::airFMSysAlarmMapInput10',
  airFMSysAlarmMapInput11 => '1.3.6.1.4.1.318.1.1.13.1.4.12.5.2.1.12',
  airFMSysAlarmMapInput11Definition => 'PowerNet-MIB::airFMSysAlarmMapInput11',
  airFMSysAlarmMapInput12 => '1.3.6.1.4.1.318.1.1.13.1.4.12.5.2.1.13',
  airFMSysAlarmMapInput12Definition => 'PowerNet-MIB::airFMSysAlarmMapInput12',
  airFMSysAlarmMapInput13 => '1.3.6.1.4.1.318.1.1.13.1.4.12.5.2.1.14',
  airFMSysAlarmMapInput13Definition => 'PowerNet-MIB::airFMSysAlarmMapInput13',
  airFMSysAlarmMapInput14 => '1.3.6.1.4.1.318.1.1.13.1.4.12.5.2.1.15',
  airFMSysAlarmMapInput14Definition => 'PowerNet-MIB::airFMSysAlarmMapInput14',
  airFMSysAlarmMapInput15 => '1.3.6.1.4.1.318.1.1.13.1.4.12.5.2.1.16',
  airFMSysAlarmMapInput15Definition => 'PowerNet-MIB::airFMSysAlarmMapInput15',
  airFMSysAlarmMapInput16 => '1.3.6.1.4.1.318.1.1.13.1.4.12.5.2.1.17',
  airFMSysAlarmMapInput16Definition => 'PowerNet-MIB::airFMSysAlarmMapInput16',
  airFMSysAlarmMapOutput => '1.3.6.1.4.1.318.1.1.13.1.4.12.6',
  airFMSysAlarmMapOutputTableSize => '1.3.6.1.4.1.318.1.1.13.1.4.12.6.1',
  airFMSysAlarmMapOutputTable => '1.3.6.1.4.1.318.1.1.13.1.4.12.6.2',
  airFMSysAlarmMapOutputEntry => '1.3.6.1.4.1.318.1.1.13.1.4.12.6.2.1',
  airFMSysAlarmMapOutputIndex => '1.3.6.1.4.1.318.1.1.13.1.4.12.6.2.1.1',
  airFMSysAlarmMapOutput1 => '1.3.6.1.4.1.318.1.1.13.1.4.12.6.2.1.2',
  airFMSysAlarmMapOutput1Definition => 'PowerNet-MIB::airFMSysAlarmMapOutput1',
  airFMSysAlarmMapOutput2 => '1.3.6.1.4.1.318.1.1.13.1.4.12.6.2.1.3',
  airFMSysAlarmMapOutput2Definition => 'PowerNet-MIB::airFMSysAlarmMapOutput2',
  airFMSysAlarmMapOutput3 => '1.3.6.1.4.1.318.1.1.13.1.4.12.6.2.1.4',
  airFMSysAlarmMapOutput3Definition => 'PowerNet-MIB::airFMSysAlarmMapOutput3',
  airFMSysAlarmMapOutput4 => '1.3.6.1.4.1.318.1.1.13.1.4.12.6.2.1.5',
  airFMSysAlarmMapOutput4Definition => 'PowerNet-MIB::airFMSysAlarmMapOutput4',
  airFMSysAlarmMapOutput5 => '1.3.6.1.4.1.318.1.1.13.1.4.12.6.2.1.6',
  airFMSysAlarmMapOutput5Definition => 'PowerNet-MIB::airFMSysAlarmMapOutput5',
  airFMSysAlarmMapOutput6 => '1.3.6.1.4.1.318.1.1.13.1.4.12.6.2.1.7',
  airFMSysAlarmMapOutput6Definition => 'PowerNet-MIB::airFMSysAlarmMapOutput6',
  airFMSysAlarmMapOutput7 => '1.3.6.1.4.1.318.1.1.13.1.4.12.6.2.1.8',
  airFMSysAlarmMapOutput7Definition => 'PowerNet-MIB::airFMSysAlarmMapOutput7',
  airFMSysAlarmMapOutput8 => '1.3.6.1.4.1.318.1.1.13.1.4.12.6.2.1.9',
  airFMSysAlarmMapOutput8Definition => 'PowerNet-MIB::airFMSysAlarmMapOutput8',
  airFMSysAlarmMapOutput9 => '1.3.6.1.4.1.318.1.1.13.1.4.12.6.2.1.10',
  airFMSysAlarmMapOutput9Definition => 'PowerNet-MIB::airFMSysAlarmMapOutput9',
  airFMSysAlarmMapOutput10 => '1.3.6.1.4.1.318.1.1.13.1.4.12.6.2.1.11',
  airFMSysAlarmMapOutput10Definition => 'PowerNet-MIB::airFMSysAlarmMapOutput10',
  airFMSysAlarmMapOutput11 => '1.3.6.1.4.1.318.1.1.13.1.4.12.6.2.1.12',
  airFMSysAlarmMapOutput11Definition => 'PowerNet-MIB::airFMSysAlarmMapOutput11',
  airFMSysAlarmMapOutput12 => '1.3.6.1.4.1.318.1.1.13.1.4.12.6.2.1.13',
  airFMSysAlarmMapOutput12Definition => 'PowerNet-MIB::airFMSysAlarmMapOutput12',
  airFMSysAlarmMapOutput13 => '1.3.6.1.4.1.318.1.1.13.1.4.12.6.2.1.14',
  airFMSysAlarmMapOutput13Definition => 'PowerNet-MIB::airFMSysAlarmMapOutput13',
  airFMSysAlarmMapOutput14 => '1.3.6.1.4.1.318.1.1.13.1.4.12.6.2.1.15',
  airFMSysAlarmMapOutput14Definition => 'PowerNet-MIB::airFMSysAlarmMapOutput14',
  airFMSysAlarmMapOutput15 => '1.3.6.1.4.1.318.1.1.13.1.4.12.6.2.1.16',
  airFMSysAlarmMapOutput15Definition => 'PowerNet-MIB::airFMSysAlarmMapOutput15',
  airFMSysAlarmMapOutput16 => '1.3.6.1.4.1.318.1.1.13.1.4.12.6.2.1.17',
  airFMSysAlarmMapOutput16Definition => 'PowerNet-MIB::airFMSysAlarmMapOutput16',
  airFMModule => '1.3.6.1.4.1.318.1.1.13.1.5',
  airFMModIdent => '1.3.6.1.4.1.318.1.1.13.1.5.1',
  airFMModIdentTableSize => '1.3.6.1.4.1.318.1.1.13.1.5.1.1',
  airFMModIdentTable => '1.3.6.1.4.1.318.1.1.13.1.5.1.2',
  airFMModIdentEntry => '1.3.6.1.4.1.318.1.1.13.1.5.1.2.1',
  airFMModIdentModuleIndex => '1.3.6.1.4.1.318.1.1.13.1.5.1.2.1.1',
  airFMModModelNumber => '1.3.6.1.4.1.318.1.1.13.1.5.1.2.1.2',
  airFMModSerialNumber => '1.3.6.1.4.1.318.1.1.13.1.5.1.2.1.3',
  airFMModManufactureDate => '1.3.6.1.4.1.318.1.1.13.1.5.1.2.1.4',
  airFMModFirmwareRev => '1.3.6.1.4.1.318.1.1.13.1.5.1.2.1.5',
  airFMModHardwareRev => '1.3.6.1.4.1.318.1.1.13.1.5.1.2.1.6',
  airFMModStatus => '1.3.6.1.4.1.318.1.1.13.1.5.2',
  airFMModStatusTableSize => '1.3.6.1.4.1.318.1.1.13.1.5.2.1',
  airFMModStatusTable => '1.3.6.1.4.1.318.1.1.13.1.5.2.2',
  airFMModStatusEntry => '1.3.6.1.4.1.318.1.1.13.1.5.2.2.1',
  airFMModStatusModuleIndex => '1.3.6.1.4.1.318.1.1.13.1.5.2.2.1.1',
  airFMModSupplyTempC => '1.3.6.1.4.1.318.1.1.13.1.5.2.2.1.2',
  airFMModSupplyTempF => '1.3.6.1.4.1.318.1.1.13.1.5.2.2.1.3',
  airFMModSupplyHum => '1.3.6.1.4.1.318.1.1.13.1.5.2.2.1.4',
  airFMModReturnTempC => '1.3.6.1.4.1.318.1.1.13.1.5.2.2.1.5',
  airFMModReturnTempF => '1.3.6.1.4.1.318.1.1.13.1.5.2.2.1.6',
  airFMModReturnHum => '1.3.6.1.4.1.318.1.1.13.1.5.2.2.1.7',
  airFMModFilterDiffPresPa => '1.3.6.1.4.1.318.1.1.13.1.5.2.2.1.8',
  airFMModFilterDiffPresInWC => '1.3.6.1.4.1.318.1.1.13.1.5.2.2.1.9',
  airFMModCoilDiffPresPa => '1.3.6.1.4.1.318.1.1.13.1.5.2.2.1.10',
  airFMModCoilDiffPresInWC => '1.3.6.1.4.1.318.1.1.13.1.5.2.2.1.11',
  airFMModProperties => '1.3.6.1.4.1.318.1.1.13.1.5.3',
  airFMModPropTableSize => '1.3.6.1.4.1.318.1.1.13.1.5.3.1',
  airFMModPropTable => '1.3.6.1.4.1.318.1.1.13.1.5.3.2',
  airFMModPropEntry => '1.3.6.1.4.1.318.1.1.13.1.5.3.2.1',
  airFMModPropModuleIndex => '1.3.6.1.4.1.318.1.1.13.1.5.3.2.1.1',
  airFMModOutputCapacity => '1.3.6.1.4.1.318.1.1.13.1.5.3.2.1.2',
  airFMModOutputCapacityDefinition => 'PowerNet-MIB::airFMModOutputCapacity',
  airFMModCapacityCtrl => '1.3.6.1.4.1.318.1.1.13.1.5.3.2.1.3',
  airFMModCapacityCtrlDefinition => 'PowerNet-MIB::airFMModCapacityCtrl',
  airFMModHeaterType => '1.3.6.1.4.1.318.1.1.13.1.5.3.2.1.4',
  airFMModHeaterTypeDefinition => 'PowerNet-MIB::airFMModHeaterType',
  airFMModElectricHeaterType => '1.3.6.1.4.1.318.1.1.13.1.5.3.2.1.5',
  airFMModElectricHeaterTypeDefinition => 'PowerNet-MIB::airFMModElectricHeaterType',
  airFMModHumidifierType => '1.3.6.1.4.1.318.1.1.13.1.5.3.2.1.6',
  airFMModHumidifierTypeDefinition => 'PowerNet-MIB::airFMModHumidifierType',
  airFMModBlwrFreqSetting => '1.3.6.1.4.1.318.1.1.13.1.5.3.2.1.7',
  airFMModNomCoilDiffPresPa => '1.3.6.1.4.1.318.1.1.13.1.5.3.2.1.8',
  airFMModNomCoilDiffPresInWC => '1.3.6.1.4.1.318.1.1.13.1.5.3.2.1.9',
  airFMModCondPump => '1.3.6.1.4.1.318.1.1.13.1.5.3.2.1.10',
  airFMModCondPumpDefinition => 'PowerNet-MIB::airFMModCondPump',
  airFMModFireDetector => '1.3.6.1.4.1.318.1.1.13.1.5.3.2.1.11',
  airFMModFireDetectorDefinition => 'PowerNet-MIB::airFMModFireDetector',
  airFMModSmokeDetector => '1.3.6.1.4.1.318.1.1.13.1.5.3.2.1.12',
  airFMModSmokeDetectorDefinition => 'PowerNet-MIB::airFMModSmokeDetector',
  airFMModWaterDetector => '1.3.6.1.4.1.318.1.1.13.1.5.3.2.1.13',
  airFMModWaterDetectorDefinition => 'PowerNet-MIB::airFMModWaterDetector',
  airFMModCooling => '1.3.6.1.4.1.318.1.1.13.1.5.4',
  airFMModCoolTableSize => '1.3.6.1.4.1.318.1.1.13.1.5.4.1',
  airFMModCoolTable => '1.3.6.1.4.1.318.1.1.13.1.5.4.2',
  airFMModCoolEntry => '1.3.6.1.4.1.318.1.1.13.1.5.4.2.1',
  airFMModCoolModuleIndex => '1.3.6.1.4.1.318.1.1.13.1.5.4.2.1.1',
  airFMModComp1 => '1.3.6.1.4.1.318.1.1.13.1.5.4.2.1.2',
  airFMModComp1Definition => 'PowerNet-MIB::airFMModComp1',
  airFMModComp2 => '1.3.6.1.4.1.318.1.1.13.1.5.4.2.1.3',
  airFMModComp2Definition => 'PowerNet-MIB::airFMModComp2',
  airFMModSuctPresKPa => '1.3.6.1.4.1.318.1.1.13.1.5.4.2.1.4',
  airFMModSuctPresPSI => '1.3.6.1.4.1.318.1.1.13.1.5.4.2.1.5',
  airFMModDischPresKPa => '1.3.6.1.4.1.318.1.1.13.1.5.4.2.1.6',
  airFMModDischPresPSI => '1.3.6.1.4.1.318.1.1.13.1.5.4.2.1.7',
  airFMModCondFluidVlvPos => '1.3.6.1.4.1.318.1.1.13.1.5.4.2.1.8',
  airFMModCoilFluidVlvPos => '1.3.6.1.4.1.318.1.1.13.1.5.4.2.1.9',
  airFMModHumidity => '1.3.6.1.4.1.318.1.1.13.1.5.5',
  airFMModHumTableSize => '1.3.6.1.4.1.318.1.1.13.1.5.5.1',
  airFMModHumTable => '1.3.6.1.4.1.318.1.1.13.1.5.5.2',
  airFMModHumEntry => '1.3.6.1.4.1.318.1.1.13.1.5.5.2.1',
  airFMModHumModuleIndex => '1.3.6.1.4.1.318.1.1.13.1.5.5.2.1.1',
  airFMModHumidifier => '1.3.6.1.4.1.318.1.1.13.1.5.5.2.1.2',
  airFMModHumidifierDefinition => 'PowerNet-MIB::airFMModHumidifier',
  airFMModElectrodeCurrent => '1.3.6.1.4.1.318.1.1.13.1.5.5.2.1.3',
  airFMModHumActualOutput => '1.3.6.1.4.1.318.1.1.13.1.5.5.2.1.4',
  airFMModWaterConductivity => '1.3.6.1.4.1.318.1.1.13.1.5.5.2.1.5',
  airFMModHotWaterVlvPos => '1.3.6.1.4.1.318.1.1.13.1.5.5.2.1.6',
  airFMModStmElectHumMode => '1.3.6.1.4.1.318.1.1.13.1.5.5.2.1.7',
  airFMModStmElectHumModeDefinition => 'PowerNet-MIB::airFMModStmElectHumMode',
  airFMModBlower1 => '1.3.6.1.4.1.318.1.1.13.1.5.6',
  airFMModBlwr1TableSize => '1.3.6.1.4.1.318.1.1.13.1.5.6.1',
  airFMModBlwr1Table => '1.3.6.1.4.1.318.1.1.13.1.5.6.2',
  airFMModBlwr1Entry => '1.3.6.1.4.1.318.1.1.13.1.5.6.2.1',
  airFMModBlwr1ModuleIndex => '1.3.6.1.4.1.318.1.1.13.1.5.6.2.1.1',
  airFMModBlwr1CtrlType => '1.3.6.1.4.1.318.1.1.13.1.5.6.2.1.2',
  airFMModBlwr1CtrlTypeDefinition => 'PowerNet-MIB::airFMModBlwr1CtrlType',
  airFMModBlwr1CmdFreq => '1.3.6.1.4.1.318.1.1.13.1.5.6.2.1.3',
  airFMModBlwr1ActFreq => '1.3.6.1.4.1.318.1.1.13.1.5.6.2.1.4',
  airFMModBlwr1Poles => '1.3.6.1.4.1.318.1.1.13.1.5.6.2.1.5',
  airFMModBlwr1RatedHorsePower => '1.3.6.1.4.1.318.1.1.13.1.5.6.2.1.6',
  airFMModBlwr1RatedCurrent => '1.3.6.1.4.1.318.1.1.13.1.5.6.2.1.7',
  airFMModBlwr1ActTorq => '1.3.6.1.4.1.318.1.1.13.1.5.6.2.1.8',
  airFMModBlwr1Current => '1.3.6.1.4.1.318.1.1.13.1.5.6.2.1.9',
  airFMModBlwr1Vlt => '1.3.6.1.4.1.318.1.1.13.1.5.6.2.1.10',
  airFMModBlwr1DCLinkVlt => '1.3.6.1.4.1.318.1.1.13.1.5.6.2.1.11',
  airFMModBlwr1AccTime => '1.3.6.1.4.1.318.1.1.13.1.5.6.2.1.12',
  airFMModBlwr1DecTime => '1.3.6.1.4.1.318.1.1.13.1.5.6.2.1.13',
  airFMModBlwr1CapLife => '1.3.6.1.4.1.318.1.1.13.1.5.6.2.1.14',
  airFMModBlwr1CtrlCoolFanLife => '1.3.6.1.4.1.318.1.1.13.1.5.6.2.1.15',
  airFMModBlwr1ElOvMode => '1.3.6.1.4.1.318.1.1.13.1.5.6.2.1.16',
  airFMModBlwr1ElOvModeDefinition => 'PowerNet-MIB::airFMModBlwr1ElOvMode',
  airFMModBlwr1ElOvSetting => '1.3.6.1.4.1.318.1.1.13.1.5.6.2.1.17',
  airFMModBlwr1ElOvTimeConst => '1.3.6.1.4.1.318.1.1.13.1.5.6.2.1.18',
  airFMModBlwr1FanPower => '1.3.6.1.4.1.318.1.1.13.1.5.6.2.1.19',
  airFMModBlwr1HeatsinkTempC => '1.3.6.1.4.1.318.1.1.13.1.5.6.2.1.20',
  airFMModBlwr1HeatsinkTempF => '1.3.6.1.4.1.318.1.1.13.1.5.6.2.1.21',
  airFMModBlwr1ChokeTempC => '1.3.6.1.4.1.318.1.1.13.1.5.6.2.1.22',
  airFMModBlwr1ChokeTempF => '1.3.6.1.4.1.318.1.1.13.1.5.6.2.1.23',
  airFMModBlwr1InverterTempC => '1.3.6.1.4.1.318.1.1.13.1.5.6.2.1.24',
  airFMModBlwr1InverterTempF => '1.3.6.1.4.1.318.1.1.13.1.5.6.2.1.25',
  airFMModBlower2 => '1.3.6.1.4.1.318.1.1.13.1.5.7',
  airFMModBlwr2TableSize => '1.3.6.1.4.1.318.1.1.13.1.5.7.1',
  airFMModBlwr2Table => '1.3.6.1.4.1.318.1.1.13.1.5.7.2',
  airFMModBlwr2Entry => '1.3.6.1.4.1.318.1.1.13.1.5.7.2.1',
  airFMModBlwr2ModuleIndex => '1.3.6.1.4.1.318.1.1.13.1.5.7.2.1.1',
  airFMModBlwr2CtrlType => '1.3.6.1.4.1.318.1.1.13.1.5.7.2.1.2',
  airFMModBlwr2CtrlTypeDefinition => 'PowerNet-MIB::airFMModBlwr2CtrlType',
  airFMModBlwr2CmdFreq => '1.3.6.1.4.1.318.1.1.13.1.5.7.2.1.3',
  airFMModBlwr2ActFreq => '1.3.6.1.4.1.318.1.1.13.1.5.7.2.1.4',
  airFMModBlwr2Poles => '1.3.6.1.4.1.318.1.1.13.1.5.7.2.1.5',
  airFMModBlwr2RatedHorsePower => '1.3.6.1.4.1.318.1.1.13.1.5.7.2.1.6',
  airFMModBlwr2RatedCurrent => '1.3.6.1.4.1.318.1.1.13.1.5.7.2.1.7',
  airFMModBlwr2ActTorq => '1.3.6.1.4.1.318.1.1.13.1.5.7.2.1.8',
  airFMModBlwr2Current => '1.3.6.1.4.1.318.1.1.13.1.5.7.2.1.9',
  airFMModBlwr2Vlt => '1.3.6.1.4.1.318.1.1.13.1.5.7.2.1.10',
  airFMModBlwr2DCLinkVlt => '1.3.6.1.4.1.318.1.1.13.1.5.7.2.1.11',
  airFMModBlwr2AccTime => '1.3.6.1.4.1.318.1.1.13.1.5.7.2.1.12',
  airFMModBlwr2DecTime => '1.3.6.1.4.1.318.1.1.13.1.5.7.2.1.13',
  airFMModBlwr2CapLife => '1.3.6.1.4.1.318.1.1.13.1.5.7.2.1.14',
  airFMModBlwr2CtrlCoolFanLife => '1.3.6.1.4.1.318.1.1.13.1.5.7.2.1.15',
  airFMModBlwr2ElOvMode => '1.3.6.1.4.1.318.1.1.13.1.5.7.2.1.16',
  airFMModBlwr2ElOvModeDefinition => 'PowerNet-MIB::airFMModBlwr2ElOvMode',
  airFMModBlwr2ElOvSetting => '1.3.6.1.4.1.318.1.1.13.1.5.7.2.1.17',
  airFMModBlwr2ElOvTimeConst => '1.3.6.1.4.1.318.1.1.13.1.5.7.2.1.18',
  airFMModBlwr2FanPower => '1.3.6.1.4.1.318.1.1.13.1.5.7.2.1.19',
  airFMModBlwr2HeatsinkTempC => '1.3.6.1.4.1.318.1.1.13.1.5.7.2.1.20',
  airFMModBlwr2HeatsinkTempF => '1.3.6.1.4.1.318.1.1.13.1.5.7.2.1.21',
  airFMModBlwr2ChokeTempC => '1.3.6.1.4.1.318.1.1.13.1.5.7.2.1.22',
  airFMModBlwr2ChokeTempF => '1.3.6.1.4.1.318.1.1.13.1.5.7.2.1.23',
  airFMModBlwr2InverterTempC => '1.3.6.1.4.1.318.1.1.13.1.5.7.2.1.24',
  airFMModBlwr2InverterTempF => '1.3.6.1.4.1.318.1.1.13.1.5.7.2.1.25',
  airFMModRunHours => '1.3.6.1.4.1.318.1.1.13.1.5.8',
  airFMModRHTableSize => '1.3.6.1.4.1.318.1.1.13.1.5.8.1',
  airFMModRHTable => '1.3.6.1.4.1.318.1.1.13.1.5.8.2',
  airFMModRHEntry => '1.3.6.1.4.1.318.1.1.13.1.5.8.2.1',
  airFMModRHModuleIndex => '1.3.6.1.4.1.318.1.1.13.1.5.8.2.1.1',
  airFMModRHComp1 => '1.3.6.1.4.1.318.1.1.13.1.5.8.2.1.2',
  airFMModRHComp2 => '1.3.6.1.4.1.318.1.1.13.1.5.8.2.1.3',
  airFMModRHHeater => '1.3.6.1.4.1.318.1.1.13.1.5.8.2.1.4',
  airFMModRHHum => '1.3.6.1.4.1.318.1.1.13.1.5.8.2.1.5',
  airFMModRHBlwr1 => '1.3.6.1.4.1.318.1.1.13.1.5.8.2.1.6',
  airFMModRHBlwr2 => '1.3.6.1.4.1.318.1.1.13.1.5.8.2.1.7',
  airFMModRHBlwrCtrl1 => '1.3.6.1.4.1.318.1.1.13.1.5.8.2.1.8',
  airFMModRHBlwrCtrl2 => '1.3.6.1.4.1.318.1.1.13.1.5.8.2.1.9',
  airFMModRHComp1Reset => '1.3.6.1.4.1.318.1.1.13.1.5.8.2.1.10',
  airFMModRHComp1ResetDefinition => 'PowerNet-MIB::airFMModRHComp1Reset',
  airFMModRHComp2Reset => '1.3.6.1.4.1.318.1.1.13.1.5.8.2.1.11',
  airFMModRHComp2ResetDefinition => 'PowerNet-MIB::airFMModRHComp2Reset',
  airFMModRHHeaterReset => '1.3.6.1.4.1.318.1.1.13.1.5.8.2.1.12',
  airFMModRHHeaterResetDefinition => 'PowerNet-MIB::airFMModRHHeaterReset',
  airFMModRHHumReset => '1.3.6.1.4.1.318.1.1.13.1.5.8.2.1.13',
  airFMModRHHumResetDefinition => 'PowerNet-MIB::airFMModRHHumReset',
  airFMModRHBlwr1Reset => '1.3.6.1.4.1.318.1.1.13.1.5.8.2.1.14',
  airFMModRHBlwr1ResetDefinition => 'PowerNet-MIB::airFMModRHBlwr1Reset',
  airFMModRHBlwr2Reset => '1.3.6.1.4.1.318.1.1.13.1.5.8.2.1.15',
  airFMModRHBlwr2ResetDefinition => 'PowerNet-MIB::airFMModRHBlwr2Reset',
  airFMModServIntervals => '1.3.6.1.4.1.318.1.1.13.1.5.9',
  airFMModServIntComp1 => '1.3.6.1.4.1.318.1.1.13.1.5.9.1',
  airFMModServIntComp2 => '1.3.6.1.4.1.318.1.1.13.1.5.9.2',
  airFMModServIntHeater => '1.3.6.1.4.1.318.1.1.13.1.5.9.3',
  airFMModServIntHum => '1.3.6.1.4.1.318.1.1.13.1.5.9.4',
  airFMModServIntBlwr1 => '1.3.6.1.4.1.318.1.1.13.1.5.9.5',
  airFMModServIntBlwr2 => '1.3.6.1.4.1.318.1.1.13.1.5.9.6',
  airFMModServIntBlwrCtrl1 => '1.3.6.1.4.1.318.1.1.13.1.5.9.7',
  airFMModServIntBlwrCtrl2 => '1.3.6.1.4.1.318.1.1.13.1.5.9.8',
  airFMModServIntResets => '1.3.6.1.4.1.318.1.1.13.1.5.10',
  airFMModServIntResetTableSize => '1.3.6.1.4.1.318.1.1.13.1.5.10.1',
  airFMModServIntResetTable => '1.3.6.1.4.1.318.1.1.13.1.5.10.2',
  airFMModServIntResetEntry => '1.3.6.1.4.1.318.1.1.13.1.5.10.2.1',
  airFMModServIntResetModuleIndex => '1.3.6.1.4.1.318.1.1.13.1.5.10.2.1.1',
  airFMModServIntComp1Reset => '1.3.6.1.4.1.318.1.1.13.1.5.10.2.1.2',
  airFMModServIntComp1ResetDefinition => 'PowerNet-MIB::airFMModServIntComp1Reset',
  airFMModServIntComp2Reset => '1.3.6.1.4.1.318.1.1.13.1.5.10.2.1.3',
  airFMModServIntComp2ResetDefinition => 'PowerNet-MIB::airFMModServIntComp2Reset',
  airFMModServIntHeaterReset => '1.3.6.1.4.1.318.1.1.13.1.5.10.2.1.4',
  airFMModServIntHeaterResetDefinition => 'PowerNet-MIB::airFMModServIntHeaterReset',
  airFMModServIntHumReset => '1.3.6.1.4.1.318.1.1.13.1.5.10.2.1.5',
  airFMModServIntHumResetDefinition => 'PowerNet-MIB::airFMModServIntHumReset',
  airFMModServIntBlwr1Reset => '1.3.6.1.4.1.318.1.1.13.1.5.10.2.1.6',
  airFMModServIntBlwr1ResetDefinition => 'PowerNet-MIB::airFMModServIntBlwr1Reset',
  airFMModServIntBlwr2Reset => '1.3.6.1.4.1.318.1.1.13.1.5.10.2.1.7',
  airFMModServIntBlwr2ResetDefinition => 'PowerNet-MIB::airFMModServIntBlwr2Reset',
  airFMModServIntBlwrCtrl1Reset => '1.3.6.1.4.1.318.1.1.13.1.5.10.2.1.8',
  airFMModServIntBlwrCtrl1ResetDefinition => 'PowerNet-MIB::airFMModServIntBlwrCtrl1Reset',
  airFMModServIntBlwrCtrl2Reset => '1.3.6.1.4.1.318.1.1.13.1.5.10.2.1.9',
  airFMModServIntBlwrCtrl2ResetDefinition => 'PowerNet-MIB::airFMModServIntBlwrCtrl2Reset',
  airFMAlarms => '1.3.6.1.4.1.318.1.1.13.1.6',
  airFMAlarmClearActiveGroupAlarms => '1.3.6.1.4.1.318.1.1.13.1.6.1',
  airFMAlarmClearActiveGroupAlarmsDefinition => 'PowerNet-MIB::airFMAlarmClearActiveGroupAlarms',
  airFMAlarmClearActiveSysModAlarms => '1.3.6.1.4.1.318.1.1.13.1.6.2',
  airFMAlarmClearActiveSysModAlarmsDefinition => 'PowerNet-MIB::airFMAlarmClearActiveSysModAlarms',
  airFMAlarmConditionsTableSize => '1.3.6.1.4.1.318.1.1.13.1.6.3',
  airFMAlarmConditionsTable => '1.3.6.1.4.1.318.1.1.13.1.6.4',
  airFMAlarmConditionsEntry => '1.3.6.1.4.1.318.1.1.13.1.6.4.1',
  airFMAlarmConditionsIndex => '1.3.6.1.4.1.318.1.1.13.1.6.4.1.1',
  airFMAlarmSeverity => '1.3.6.1.4.1.318.1.1.13.1.6.4.1.2',
  airFMAlarmSeverityDefinition => 'PowerNet-MIB::airFMAlarmSeverity',
  airFMAlarmType => '1.3.6.1.4.1.318.1.1.13.1.6.4.1.3',
  airFMAlarmTypeDefinition => 'PowerNet-MIB::airFMAlarmType',
  airFMEventCode => '1.3.6.1.4.1.318.1.1.13.1.6.4.1.4',
  airFMAlarmDate => '1.3.6.1.4.1.318.1.1.13.1.6.4.1.5',
  airFMAlarmTime => '1.3.6.1.4.1.318.1.1.13.1.6.4.1.6',
  airFMAlarmDescription => '1.3.6.1.4.1.318.1.1.13.1.6.4.1.7',
  airPA => '1.3.6.1.4.1.318.1.1.13.2',
  airPAIdent => '1.3.6.1.4.1.318.1.1.13.2.1',
  airPAIdentName => '1.3.6.1.4.1.318.1.1.13.2.1.1',
  airPAModelNumber => '1.3.6.1.4.1.318.1.1.13.2.1.2',
  airPADateOfManufacture => '1.3.6.1.4.1.318.1.1.13.2.1.3',
  airPASerialNumber => '1.3.6.1.4.1.318.1.1.13.2.1.4',
  airPAFirmwareRevision => '1.3.6.1.4.1.318.1.1.13.2.1.5',
  airPAHardwareRevision => '1.3.6.1.4.1.318.1.1.13.2.1.6',
  airPAStatus => '1.3.6.1.4.1.318.1.1.13.2.2',
  airPASystemPower => '1.3.6.1.4.1.318.1.1.13.2.2.1',
  airPASystemPowerDefinition => 'PowerNet-MIB::airPASystemPower',
  airPAOperatingMode => '1.3.6.1.4.1.318.1.1.13.2.2.2',
  airPAOperatingModeDefinition => 'PowerNet-MIB::airPAOperatingMode',
  airPASetpointTempF => '1.3.6.1.4.1.318.1.1.13.2.2.3',
  airPASetpointTempC => '1.3.6.1.4.1.318.1.1.13.2.2.4',
  airPABlowerSpeed => '1.3.6.1.4.1.318.1.1.13.2.2.5',
  airPABlowerSpeedDefinition => 'PowerNet-MIB::airPABlowerSpeed',
  airPACompressor => '1.3.6.1.4.1.318.1.1.13.2.2.6',
  airPACompressorDefinition => 'PowerNet-MIB::airPACompressor',
  airPACondenserFan => '1.3.6.1.4.1.318.1.1.13.2.2.7',
  airPACondenserFanDefinition => 'PowerNet-MIB::airPACondenserFan',
  airPACondensatePump => '1.3.6.1.4.1.318.1.1.13.2.2.8',
  airPACondensatePumpDefinition => 'PowerNet-MIB::airPACondensatePump',
  airPASupplyTempF => '1.3.6.1.4.1.318.1.1.13.2.2.9',
  airPASupplyTempC => '1.3.6.1.4.1.318.1.1.13.2.2.10',
  airPAReturnTempF => '1.3.6.1.4.1.318.1.1.13.2.2.11',
  airPAReturnTempC => '1.3.6.1.4.1.318.1.1.13.2.2.12',
  airPARemoteTempF => '1.3.6.1.4.1.318.1.1.13.2.2.13',
  airPARemoteTempC => '1.3.6.1.4.1.318.1.1.13.2.2.14',
  airPARemoteHumidity => '1.3.6.1.4.1.318.1.1.13.2.2.15',
  airIR => '1.3.6.1.4.1.318.1.1.13.3',
  airIRAlarms => '1.3.6.1.4.1.318.1.1.13.3.1',
  airIRAlarmConditionsTableSize => '1.3.6.1.4.1.318.1.1.13.3.1.1',
  airIRAlarmConditionsTable => '1.3.6.1.4.1.318.1.1.13.3.1.2',
  airIRAlarmConditionsEntry => '1.3.6.1.4.1.318.1.1.13.3.1.2.1',
  airIRAlarmConditionsIndex => '1.3.6.1.4.1.318.1.1.13.3.1.2.1.1',
  airIREventCode => '1.3.6.1.4.1.318.1.1.13.3.1.2.1.2',
  airIRAlarmDescription => '1.3.6.1.4.1.318.1.1.13.3.1.2.1.3',
  airIRRC => '1.3.6.1.4.1.318.1.1.13.3.2',
  airIRRCGroup => '1.3.6.1.4.1.318.1.1.13.3.2.1',
  airIRRCGroupStatus => '1.3.6.1.4.1.318.1.1.13.3.2.1.1',
  airIRRCGroupStatusCoolOutput => '1.3.6.1.4.1.318.1.1.13.3.2.1.1.1',
  airIRRCGroupStatusCoolDemand => '1.3.6.1.4.1.318.1.1.13.3.2.1.1.2',
  airIRRCGroupStatusAirFlowUS => '1.3.6.1.4.1.318.1.1.13.3.2.1.1.3',
  airIRRCGroupStatusAirFlowMetric => '1.3.6.1.4.1.318.1.1.13.3.2.1.1.4',
  airIRRCGroupStatusMaxRackInletTempUS => '1.3.6.1.4.1.318.1.1.13.3.2.1.1.5',
  airIRRCGroupStatusMaxRackInletTempMetric => '1.3.6.1.4.1.318.1.1.13.3.2.1.1.6',
  airIRRCGroupStatusMinRackInletTempUS => '1.3.6.1.4.1.318.1.1.13.3.2.1.1.7',
  airIRRCGroupStatusMinRackInletTempMetric => '1.3.6.1.4.1.318.1.1.13.3.2.1.1.8',
  airIRRCGroupStatusActiveFlowControlStatus => '1.3.6.1.4.1.318.1.1.13.3.2.1.1.9',
  airIRRCGroupStatusActiveFlowControlStatusDefinition => 'PowerNet-MIB::airIRRCGroupStatusActiveFlowControlStatus',
  airIRRCGroupSetpoints => '1.3.6.1.4.1.318.1.1.13.3.2.1.2',
  airIRRCGroupSetpointsCoolUS => '1.3.6.1.4.1.318.1.1.13.3.2.1.2.1',
  airIRRCGroupSetpointsCoolMetric => '1.3.6.1.4.1.318.1.1.13.3.2.1.2.2',
  airIRRCGroupSetpointsSupplyAirUS => '1.3.6.1.4.1.318.1.1.13.3.2.1.2.3',
  airIRRCGroupSetpointsSupplyAirMetric => '1.3.6.1.4.1.318.1.1.13.3.2.1.2.4',
  airIRRCGroupSetpointsFanSpeedPreference => '1.3.6.1.4.1.318.1.1.13.3.2.1.2.5',
  airIRRCGroupSetpointsFanSpeedPreferenceDefinition => 'PowerNet-MIB::airIRRCGroupSetpointsFanSpeedPreference',
  airIRRCGroupSetpointsFanSpeedControl => '1.3.6.1.4.1.318.1.1.13.3.2.1.2.6',
  airIRRCGroupSetpointsFanSpeedControlDefinition => 'PowerNet-MIB::airIRRCGroupSetpointsFanSpeedControl',
  airIRRCGroupSetpointsActiveFlowControlBias => '1.3.6.1.4.1.318.1.1.13.3.2.1.2.7',
  airIRRCGroupSetpointsActiveFlowControlBiasDefinition => 'PowerNet-MIB::airIRRCGroupSetpointsActiveFlowControlBias',
  airIRRCGroupConfig => '1.3.6.1.4.1.318.1.1.13.3.2.1.3',
  airIRRCGroupConfigNumberofCoolingUnits => '1.3.6.1.4.1.318.1.1.13.3.2.1.3.1',
  airIRRCGroupConfigConfigurationType => '1.3.6.1.4.1.318.1.1.13.3.2.1.3.2',
  airIRRCGroupConfigConfigurationTypeDefinition => 'PowerNet-MIB::airIRRCGroupConfigConfigurationType',
  airIRRCGroupConfigPctGlycol => '1.3.6.1.4.1.318.1.1.13.3.2.1.3.3',
  airIRRCGroupConfigCoolGainP => '1.3.6.1.4.1.318.1.1.13.3.2.1.3.4',
  airIRRCGroupConfigCoolResetRateI => '1.3.6.1.4.1.318.1.1.13.3.2.1.3.5',
  airIRRCGroupConfigCoolDerivativeD => '1.3.6.1.4.1.318.1.1.13.3.2.1.3.6',
  airIRRCGroupConfigMaxFanSpeed => '1.3.6.1.4.1.318.1.1.13.3.2.1.3.7',
  airIRRCGroupConfigNumberOfActiveFlowControllers => '1.3.6.1.4.1.318.1.1.13.3.2.1.3.8',
  airIRRCGroupConfigActiveFlowControllerLampTest => '1.3.6.1.4.1.318.1.1.13.3.2.1.3.9',
  airIRRCGroupConfigActiveFlowControllerLampTestDefinition => 'PowerNet-MIB::airIRRCGroupConfigActiveFlowControllerLampTest',
  airIRRCGroupConfigAltitudeUS => '1.3.6.1.4.1.318.1.1.13.3.2.1.3.10',
  airIRRCGroupConfigAltitudeMetric => '1.3.6.1.4.1.318.1.1.13.3.2.1.3.11',
  airIRRCUnit => '1.3.6.1.4.1.318.1.1.13.3.2.2',
  airIRRCUnitIdent => '1.3.6.1.4.1.318.1.1.13.3.2.2.1',
  airIRRCUnitIdentID => '1.3.6.1.4.1.318.1.1.13.3.2.2.1.1',
  airIRRCUnitIdentName => '1.3.6.1.4.1.318.1.1.13.3.2.2.1.2',
  airIRRCUnitIdentLocation => '1.3.6.1.4.1.318.1.1.13.3.2.2.1.3',
  airIRRCUnitIdentModelNumber => '1.3.6.1.4.1.318.1.1.13.3.2.2.1.4',
  airIRRCUnitIdentSerialNumber => '1.3.6.1.4.1.318.1.1.13.3.2.2.1.5',
  airIRRCUnitIdentFirmwareRevision => '1.3.6.1.4.1.318.1.1.13.3.2.2.1.6',
  airIRRCUnitIdentHardwareRevision => '1.3.6.1.4.1.318.1.1.13.3.2.2.1.7',
  airIRRCUnitIdentManufactureDate => '1.3.6.1.4.1.318.1.1.13.3.2.2.1.8',
  airIRRCUnitStatus => '1.3.6.1.4.1.318.1.1.13.3.2.2.2',
  airIRRCUnitStatusOperateMode => '1.3.6.1.4.1.318.1.1.13.3.2.2.2.1',
  airIRRCUnitStatusOperateModeDefinition => 'PowerNet-MIB::airIRRCUnitStatusOperateMode',
  airIRRCUnitStatusCoolOutput => '1.3.6.1.4.1.318.1.1.13.3.2.2.2.2',
  airIRRCUnitStatusCoolDemand => '1.3.6.1.4.1.318.1.1.13.3.2.2.2.3',
  airIRRCUnitStatusAirFlowUS => '1.3.6.1.4.1.318.1.1.13.3.2.2.2.4',
  airIRRCUnitStatusAirFlowMetric => '1.3.6.1.4.1.318.1.1.13.3.2.2.2.5',
  airIRRCUnitStatusRackInletTempUS => '1.3.6.1.4.1.318.1.1.13.3.2.2.2.6',
  airIRRCUnitStatusRackInletTempMetric => '1.3.6.1.4.1.318.1.1.13.3.2.2.2.7',
  airIRRCUnitStatusSupplyAirTempUS => '1.3.6.1.4.1.318.1.1.13.3.2.2.2.8',
  airIRRCUnitStatusSupplyAirTempMetric => '1.3.6.1.4.1.318.1.1.13.3.2.2.2.9',
  airIRRCUnitStatusReturnAirTempUS => '1.3.6.1.4.1.318.1.1.13.3.2.2.2.10',
  airIRRCUnitStatusReturnAirTempMetric => '1.3.6.1.4.1.318.1.1.13.3.2.2.2.11',
  airIRRCUnitStatusContainmtDPUS => '1.3.6.1.4.1.318.1.1.13.3.2.2.2.12',
  airIRRCUnitStatusContainmtDPMetric => '1.3.6.1.4.1.318.1.1.13.3.2.2.2.13',
  airIRRCUnitStatusFilterDPUS => '1.3.6.1.4.1.318.1.1.13.3.2.2.2.14',
  airIRRCUnitStatusFilterDPMetric => '1.3.6.1.4.1.318.1.1.13.3.2.2.2.15',
  airIRRCUnitStatusFanSpeed => '1.3.6.1.4.1.318.1.1.13.3.2.2.2.16',
  airIRRCUnitStatusInputState => '1.3.6.1.4.1.318.1.1.13.3.2.2.2.17',
  airIRRCUnitStatusInputStateDefinition => 'PowerNet-MIB::airIRRCUnitStatusInputState',
  airIRRCUnitStatusOutputState => '1.3.6.1.4.1.318.1.1.13.3.2.2.2.18',
  airIRRCUnitStatusOutputStateDefinition => 'PowerNet-MIB::airIRRCUnitStatusOutputState',
  airIRRCUnitStatusActivePowerSource => '1.3.6.1.4.1.318.1.1.13.3.2.2.2.19',
  airIRRCUnitStatusActivePowerSourceDefinition => 'PowerNet-MIB::airIRRCUnitStatusActivePowerSource',
  airIRRCUnitStatusFluidValvePosition => '1.3.6.1.4.1.318.1.1.13.3.2.2.2.20',
  airIRRCUnitStatusFluidFlowUS => '1.3.6.1.4.1.318.1.1.13.3.2.2.2.21',
  airIRRCUnitStatusFluidFlowMetric => '1.3.6.1.4.1.318.1.1.13.3.2.2.2.22',
  airIRRCUnitStatusEnteringFluidTemperatureUS => '1.3.6.1.4.1.318.1.1.13.3.2.2.2.23',
  airIRRCUnitStatusEnteringFluidTemperatureMetric => '1.3.6.1.4.1.318.1.1.13.3.2.2.2.24',
  airIRRCUnitStatusLeavingFluidTemperatureUS => '1.3.6.1.4.1.318.1.1.13.3.2.2.2.25',
  airIRRCUnitStatusLeavingFluidTemperatureMetric => '1.3.6.1.4.1.318.1.1.13.3.2.2.2.26',
  airIRRCUnitRunHours => '1.3.6.1.4.1.318.1.1.13.3.2.2.3',
  airIRRCUnitRunHoursAirFilter => '1.3.6.1.4.1.318.1.1.13.3.2.2.3.1',
  airIRRCUnitRunHoursFan1 => '1.3.6.1.4.1.318.1.1.13.3.2.2.3.2',
  airIRRCUnitRunHoursFan2 => '1.3.6.1.4.1.318.1.1.13.3.2.2.3.3',
  airIRRCUnitRunHoursFan3 => '1.3.6.1.4.1.318.1.1.13.3.2.2.3.4',
  airIRRCUnitRunHoursFan4 => '1.3.6.1.4.1.318.1.1.13.3.2.2.3.5',
  airIRRCUnitRunHoursFan5 => '1.3.6.1.4.1.318.1.1.13.3.2.2.3.6',
  airIRRCUnitRunHoursFan6 => '1.3.6.1.4.1.318.1.1.13.3.2.2.3.7',
  airIRRCUnitRunHoursFan7 => '1.3.6.1.4.1.318.1.1.13.3.2.2.3.8',
  airIRRCUnitRunHoursFan8 => '1.3.6.1.4.1.318.1.1.13.3.2.2.3.9',
  airIRRCUnitRunHoursFanPowerSupplyLeft => '1.3.6.1.4.1.318.1.1.13.3.2.2.3.10',
  airIRRCUnitRunHoursFanPowerSupplyRight => '1.3.6.1.4.1.318.1.1.13.3.2.2.3.11',
  airIRRCUnitRunHoursCondensatePump => '1.3.6.1.4.1.318.1.1.13.3.2.2.3.12',
  airIRRCUnitRunHoursFanPowerSupplyFeedALeft => '1.3.6.1.4.1.318.1.1.13.3.2.2.3.13',
  airIRRCUnitRunHoursFanPowerSupplyFeedARight => '1.3.6.1.4.1.318.1.1.13.3.2.2.3.14',
  airIRRCUnitRunHoursFanPowerSupplyFeedBLeft => '1.3.6.1.4.1.318.1.1.13.3.2.2.3.15',
  airIRRCUnitRunHoursFanPowerSupplyFeedBRight => '1.3.6.1.4.1.318.1.1.13.3.2.2.3.16',
  airIRRCUnitServiceIntervals => '1.3.6.1.4.1.318.1.1.13.3.2.2.4',
  airIRRCUnitServiceIntervalsAirFilter => '1.3.6.1.4.1.318.1.1.13.3.2.2.4.1',
  airIRRCUnitServiceIntervalsAirFilterAlarm => '1.3.6.1.4.1.318.1.1.13.3.2.2.4.2',
  airIRRCUnitServiceIntervalsAirFilterAlarmDefinition => 'PowerNet-MIB::airIRRCUnitServiceIntervalsAirFilterAlarm',
  airIRRCUnitThresholds => '1.3.6.1.4.1.318.1.1.13.3.2.2.5',
  airIRRCUnitThresholdsRackInletHighTempUS => '1.3.6.1.4.1.318.1.1.13.3.2.2.5.1',
  airIRRCUnitThresholdsRackInletHighTempMetric => '1.3.6.1.4.1.318.1.1.13.3.2.2.5.2',
  airIRRCUnitThresholdsSupplyAirHighTempUS => '1.3.6.1.4.1.318.1.1.13.3.2.2.5.3',
  airIRRCUnitThresholdsSupplyAirHighTempMetric => '1.3.6.1.4.1.318.1.1.13.3.2.2.5.4',
  airIRRCUnitThresholdsReturnAirHighTempUS => '1.3.6.1.4.1.318.1.1.13.3.2.2.5.5',
  airIRRCUnitThresholdsReturnAirHighTempMetric => '1.3.6.1.4.1.318.1.1.13.3.2.2.5.6',
  airIRRCUnitThresholdsEnteringFluidHighTempUS => '1.3.6.1.4.1.318.1.1.13.3.2.2.5.7',
  airIRRCUnitThresholdsEnteringFluidHighTempMetric => '1.3.6.1.4.1.318.1.1.13.3.2.2.5.8',
  airIRRCUnitConfig => '1.3.6.1.4.1.318.1.1.13.3.2.2.6',
  airIRRCUnitConfigCoolCapacity => '1.3.6.1.4.1.318.1.1.13.3.2.2.6.1',
  airIRRCUnitConfigCoolCapacityDefinition => 'PowerNet-MIB::airIRRCUnitConfigCoolCapacity',
  airIRRCUnitConfigStartupDelay => '1.3.6.1.4.1.318.1.1.13.3.2.2.6.2',
  airIRRCUnitConfigIdleOnLeakDetect => '1.3.6.1.4.1.318.1.1.13.3.2.2.6.3',
  airIRRCUnitConfigIdleOnLeakDetectDefinition => 'PowerNet-MIB::airIRRCUnitConfigIdleOnLeakDetect',
  airIRRCUnitConfigPowerSource => '1.3.6.1.4.1.318.1.1.13.3.2.2.6.4',
  airIRRCUnitConfigPowerSourceDefinition => 'PowerNet-MIB::airIRRCUnitConfigPowerSource',
  airIRRCUnitConfigInputNormalState => '1.3.6.1.4.1.318.1.1.13.3.2.2.6.5',
  airIRRCUnitConfigInputNormalStateDefinition => 'PowerNet-MIB::airIRRCUnitConfigInputNormalState',
  airIRRCUnitConfigOutputNormalState => '1.3.6.1.4.1.318.1.1.13.3.2.2.6.6',
  airIRRCUnitConfigOutputNormalStateDefinition => 'PowerNet-MIB::airIRRCUnitConfigOutputNormalState',
  airIRRCUnitConfigOutputSource => '1.3.6.1.4.1.318.1.1.13.3.2.2.6.7',
  airIRRCUnitConfigOutputSourceDefinition => 'PowerNet-MIB::airIRRCUnitConfigOutputSource',
  airIRRCUnitConfigIdleOnCoolFail => '1.3.6.1.4.1.318.1.1.13.3.2.2.6.8',
  airIRRCUnitConfigIdleOnCoolFailDefinition => 'PowerNet-MIB::airIRRCUnitConfigIdleOnCoolFail',
  airIRRP => '1.3.6.1.4.1.318.1.1.13.3.3',
  airIRRP100 => '1.3.6.1.4.1.318.1.1.13.3.3.1',
  airIRRP100Group => '1.3.6.1.4.1.318.1.1.13.3.3.1.1',
  airIRRP100GroupStatus => '1.3.6.1.4.1.318.1.1.13.3.3.1.1.1',
  airIRRP100GroupStatusAirFlowUS => '1.3.6.1.4.1.318.1.1.13.3.3.1.1.1.1',
  airIRRP100GroupStatusAirFlowMetric => '1.3.6.1.4.1.318.1.1.13.3.3.1.1.1.2',
  airIRRP100GroupStatusMaxRackInletTempUS => '1.3.6.1.4.1.318.1.1.13.3.3.1.1.1.3',
  airIRRP100GroupStatusMaxRackInletTempMetric => '1.3.6.1.4.1.318.1.1.13.3.3.1.1.1.4',
  airIRRP100GroupStatusMinRackInletTempUS => '1.3.6.1.4.1.318.1.1.13.3.3.1.1.1.5',
  airIRRP100GroupStatusMinRackInletTempMetric => '1.3.6.1.4.1.318.1.1.13.3.3.1.1.1.6',
  airIRRP100GroupStatusCoolDemand => '1.3.6.1.4.1.318.1.1.13.3.3.1.1.1.7',
  airIRRP100GroupStatusCoolOutput => '1.3.6.1.4.1.318.1.1.13.3.3.1.1.1.8',
  airIRRP100GroupStatusHumidifyDemand => '1.3.6.1.4.1.318.1.1.13.3.3.1.1.1.9',
  airIRRP100GroupStatusHumidifyOutput => '1.3.6.1.4.1.318.1.1.13.3.3.1.1.1.10',
  airIRRP100GroupStatusDehumidifyDemand => '1.3.6.1.4.1.318.1.1.13.3.3.1.1.1.11',
  airIRRP100GroupStatusDehumidifyOutput => '1.3.6.1.4.1.318.1.1.13.3.3.1.1.1.12',
  airIRRP100GroupStatusReheatDemand => '1.3.6.1.4.1.318.1.1.13.3.3.1.1.1.13',
  airIRRP100GroupStatusReheatOutput => '1.3.6.1.4.1.318.1.1.13.3.3.1.1.1.14',
  airIRRP100GroupStatusActiveFlowControlStatus => '1.3.6.1.4.1.318.1.1.13.3.3.1.1.1.15',
  airIRRP100GroupStatusActiveFlowControlStatusDefinition => 'PowerNet-MIB::airIRRP100GroupStatusActiveFlowControlStatus',
  airIRRP100GroupStatusDewPointTempUS => '1.3.6.1.4.1.318.1.1.13.3.3.1.1.1.16',
  airIRRP100GroupStatusDewPointTempMetric => '1.3.6.1.4.1.318.1.1.13.3.3.1.1.1.17',
  airIRRP100GroupSetpoints => '1.3.6.1.4.1.318.1.1.13.3.3.1.1.2',
  airIRRP100GroupSetpointsCoolUS => '1.3.6.1.4.1.318.1.1.13.3.3.1.1.2.1',
  airIRRP100GroupSetpointsCoolMetric => '1.3.6.1.4.1.318.1.1.13.3.3.1.1.2.2',
  airIRRP100GroupSetpointsSupplyAirUS => '1.3.6.1.4.1.318.1.1.13.3.3.1.1.2.3',
  airIRRP100GroupSetpointsSupplyAirMetric => '1.3.6.1.4.1.318.1.1.13.3.3.1.1.2.4',
  airIRRP100GroupSetpointsHumidify => '1.3.6.1.4.1.318.1.1.13.3.3.1.1.2.5',
  airIRRP100GroupSetpointsDehumidify => '1.3.6.1.4.1.318.1.1.13.3.3.1.1.2.6',
  airIRRP100GroupSetpointsDehumidifyDeadband => '1.3.6.1.4.1.318.1.1.13.3.3.1.1.2.7',
  airIRRP100GroupSetpointsReheatUS => '1.3.6.1.4.1.318.1.1.13.3.3.1.1.2.8',
  airIRRP100GroupSetpointsReheatMetric => '1.3.6.1.4.1.318.1.1.13.3.3.1.1.2.9',
  airIRRP100GroupSetpointsFanSpeedPreference => '1.3.6.1.4.1.318.1.1.13.3.3.1.1.2.10',
  airIRRP100GroupSetpointsFanSpeedPreferenceDefinition => 'PowerNet-MIB::airIRRP100GroupSetpointsFanSpeedPreference',
  airIRRP100GroupSetpointsFanSpeedControl => '1.3.6.1.4.1.318.1.1.13.3.3.1.1.2.11',
  airIRRP100GroupSetpointsFanSpeedControlDefinition => 'PowerNet-MIB::airIRRP100GroupSetpointsFanSpeedControl',
  airIRRP100GroupSetpointsActiveFlowControlBias => '1.3.6.1.4.1.318.1.1.13.3.3.1.1.2.12',
  airIRRP100GroupSetpointsActiveFlowControlBiasDefinition => 'PowerNet-MIB::airIRRP100GroupSetpointsActiveFlowControlBias',
  airIRRP100GroupConfig => '1.3.6.1.4.1.318.1.1.13.3.3.1.1.3',
  airIRRP100GroupConfigNumberofCoolingUnits => '1.3.6.1.4.1.318.1.1.13.3.3.1.1.3.1',
  airIRRP100GroupConfigConfigurationType => '1.3.6.1.4.1.318.1.1.13.3.3.1.1.3.2',
  airIRRP100GroupConfigConfigurationTypeDefinition => 'PowerNet-MIB::airIRRP100GroupConfigConfigurationType',
  airIRRP100GroupConfigCoolGainP => '1.3.6.1.4.1.318.1.1.13.3.3.1.1.3.3',
  airIRRP100GroupConfigCoolResetRateI => '1.3.6.1.4.1.318.1.1.13.3.3.1.1.3.4',
  airIRRP100GroupConfigCoolDerivativeD => '1.3.6.1.4.1.318.1.1.13.3.3.1.1.3.5',
  airIRRP100GroupConfigHumidifySensitivityBand => '1.3.6.1.4.1.318.1.1.13.3.3.1.1.3.6',
  airIRRP100GroupConfigReheatGainP => '1.3.6.1.4.1.318.1.1.13.3.3.1.1.3.7',
  airIRRP100GroupConfigReheatResetRateI => '1.3.6.1.4.1.318.1.1.13.3.3.1.1.3.8',
  airIRRP100GroupConfigReheatDerivativeD => '1.3.6.1.4.1.318.1.1.13.3.3.1.1.3.9',
  airIRRP100GroupConfigNumberofBackupUnits => '1.3.6.1.4.1.318.1.1.13.3.3.1.1.3.10',
  airIRRP100GroupConfigRuntimeBalancingEnable => '1.3.6.1.4.1.318.1.1.13.3.3.1.1.3.11',
  airIRRP100GroupConfigRuntimeBalancingEnableDefinition => 'PowerNet-MIB::airIRRP100GroupConfigRuntimeBalancingEnable',
  airIRRP100GroupConfigLoadAssistEnable => '1.3.6.1.4.1.318.1.1.13.3.3.1.1.3.12',
  airIRRP100GroupConfigLoadAssistEnableDefinition => 'PowerNet-MIB::airIRRP100GroupConfigLoadAssistEnable',
  airIRRP100GroupConfigFullRPBackups => '1.3.6.1.4.1.318.1.1.13.3.3.1.1.3.13',
  airIRRP100GroupConfigMaxFanSpeed => '1.3.6.1.4.1.318.1.1.13.3.3.1.1.3.14',
  airIRRP100GroupConfigNumberOfActiveFlowControllers => '1.3.6.1.4.1.318.1.1.13.3.3.1.1.3.15',
  airIRRP100GroupConfigActiveFlowControllerLampTest => '1.3.6.1.4.1.318.1.1.13.3.3.1.1.3.16',
  airIRRP100GroupConfigActiveFlowControllerLampTestDefinition => 'PowerNet-MIB::airIRRP100GroupConfigActiveFlowControllerLampTest',
  airIRRP100GroupConfigAltitudeUS => '1.3.6.1.4.1.318.1.1.13.3.3.1.1.3.17',
  airIRRP100GroupConfigAltitudeMetric => '1.3.6.1.4.1.318.1.1.13.3.3.1.1.3.18',
  airIRRP100Unit => '1.3.6.1.4.1.318.1.1.13.3.3.1.2',
  airIRRP100UnitIdent => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.1',
  airIRRP100UnitIdentID => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.1.1',
  airIRRP100UnitIdentName => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.1.2',
  airIRRP100UnitIdentLocation => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.1.3',
  airIRRP100UnitIdentModelNumber => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.1.4',
  airIRRP100UnitIdentSerialNumber => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.1.5',
  airIRRP100UnitIdentFirmwareRevision => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.1.6',
  airIRRP100UnitIdentHardwareRevision => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.1.7',
  airIRRP100UnitIdentManufactureDate => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.1.8',
  airIRRP100UnitStatus => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.2',
  airIRRP100UnitStatusOperateMode => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.2.1',
  airIRRP100UnitStatusOperateModeDefinition => 'PowerNet-MIB::airIRRP100UnitStatusOperateMode',
  airIRRP100UnitStatusRackInletTempUS => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.2.2',
  airIRRP100UnitStatusRackInletTempMetric => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.2.3',
  airIRRP100UnitStatusSupplyAirTempUS => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.2.4',
  airIRRP100UnitStatusSupplyAirTempMetric => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.2.5',
  airIRRP100UnitStatusReturnAirTempUS => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.2.6',
  airIRRP100UnitStatusReturnAirTempMetric => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.2.7',
  airIRRP100UnitStatusSupplyHumidity => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.2.8',
  airIRRP100UnitStatusReturnHumidity => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.2.9',
  airIRRP100UnitStatusAirFlowUS => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.2.10',
  airIRRP100UnitStatusAirFlowMetric => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.2.11',
  airIRRP100UnitStatusFanSpeed => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.2.12',
  airIRRP100UnitStatusCoolDemand => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.2.13',
  airIRRP100UnitStatusCoolOutput => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.2.14',
  airIRRP100UnitStatusHumidifyDemand => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.2.15',
  airIRRP100UnitStatusHumidifyOutput => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.2.16',
  airIRRP100UnitStatusDehumidifyDemand => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.2.17',
  airIRRP100UnitStatusDehumidifyOutput => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.2.18',
  airIRRP100UnitStatusReheatDemand => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.2.19',
  airIRRP100UnitStatusReheatOutput => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.2.20',
  airIRRP100UnitStatusInputState => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.2.21',
  airIRRP100UnitStatusInputStateDefinition => 'PowerNet-MIB::airIRRP100UnitStatusInputState',
  airIRRP100UnitStatusOutputState => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.2.22',
  airIRRP100UnitStatusOutputStateDefinition => 'PowerNet-MIB::airIRRP100UnitStatusOutputState',
  airIRRP100UnitStatusRackInletTemperature1US => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.2.23',
  airIRRP100UnitStatusRackInletTemperature1Metric => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.2.24',
  airIRRP100UnitStatusRackInletTemperature2US => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.2.25',
  airIRRP100UnitStatusRackInletTemperature2Metric => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.2.26',
  airIRRP100UnitStatusRackInletTemperature3US => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.2.27',
  airIRRP100UnitStatusRackInletTemperature3Metric => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.2.28',
  airIRRP100UnitStatusFilterDPUS => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.2.29',
  airIRRP100UnitStatusFilterDPMetric => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.2.30',
  airIRRP100UnitStatusContainmtDPUS => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.2.31',
  airIRRP100UnitStatusContainmtDPMetric => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.2.32',
  airIRRP100UnitStatusHumidifierCurrent => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.2.33',
  airIRRP100UnitStatusHumidifierWaterConductivity => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.2.34',
  airIRRP100UnitStatusCompressorDriveSpeed => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.2.35',
  airIRRP100UnitStatusCompressorDrivePower => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.2.36',
  airIRRP100UnitStatusCompressorDriveVoltage => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.2.37',
  airIRRP100UnitStatusCompressorDriveCurrent => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.2.38',
  airIRRP100UnitStatusCompressorDriveDCLinkVoltage => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.2.39',
  airIRRP100UnitStatusCompressorDriveHeatSinkTempUS => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.2.40',
  airIRRP100UnitStatusCompressorDriveHeatSinkTempMetric => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.2.41',
  airIRRP100UnitStatusCompressorDriveControlCardTempUS => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.2.42',
  airIRRP100UnitStatusCompressorDriveControlCardTempMetric => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.2.43',
  airIRRP100UnitStatusCompressorDriveWarningStatus => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.2.44',
  airIRRP100UnitStatusCompressorDriveAlarmStatus => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.2.45',
  airIRRP100UnitStatusSuctionPressureUS => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.2.46',
  airIRRP100UnitStatusSuctionPressureMetric => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.2.47',
  airIRRP100UnitStatusDischargePressureUS => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.2.48',
  airIRRP100UnitStatusDischargePressureMetric => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.2.49',
  airIRRP100UnitStatusLeakSensor => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.2.50',
  airIRRP100UnitStatusLeakSensorDefinition => 'PowerNet-MIB::airIRRP100UnitStatusLeakSensor',
  airIRRP100UnitRunHours => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.3',
  airIRRP100UnitRunHoursAirFilter => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.3.1',
  airIRRP100UnitRunHoursCondensatePump => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.3.2',
  airIRRP100UnitRunHoursHumidifier => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.3.3',
  airIRRP100UnitRunHoursFan1 => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.3.4',
  airIRRP100UnitRunHoursHeater1 => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.3.5',
  airIRRP100UnitRunHoursFan2 => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.3.6',
  airIRRP100UnitRunHoursHeater2 => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.3.7',
  airIRRP100UnitRunHoursCompressor => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.3.8',
  airIRRP100UnitRunHoursSystem => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.3.9',
  airIRRP100UnitServiceIntervals => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.4',
  airIRRP100UnitServiceIntervalAirFilter => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.4.1',
  airIRRP100UnitServiceIntervalAirFilterAlarm => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.4.2',
  airIRRP100UnitServiceIntervalAirFilterAlarmDefinition => 'PowerNet-MIB::airIRRP100UnitServiceIntervalAirFilterAlarm',
  airIRRP100UnitServiceIntervalHumidifier => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.4.3',
  airIRRP100UnitServiceIntervalHumidifierAlarm => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.4.4',
  airIRRP100UnitServiceIntervalHumidifierAlarmDefinition => 'PowerNet-MIB::airIRRP100UnitServiceIntervalHumidifierAlarm',
  airIRRP100UnitServiceIntervalHeater => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.4.5',
  airIRRP100UnitServiceIntervalHeaterAlarm => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.4.6',
  airIRRP100UnitServiceIntervalHeaterAlarmDefinition => 'PowerNet-MIB::airIRRP100UnitServiceIntervalHeaterAlarm',
  airIRRP100UnitServiceIntervalCompressor => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.4.7',
  airIRRP100UnitServiceIntervalCompressorAlarm => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.4.8',
  airIRRP100UnitServiceIntervalCompressorAlarmDefinition => 'PowerNet-MIB::airIRRP100UnitServiceIntervalCompressorAlarm',
  airIRRP100UnitServiceIntervalCondensatePump => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.4.9',
  airIRRP100UnitServiceIntervalCondensatePumpAlarm => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.4.10',
  airIRRP100UnitServiceIntervalCondensatePumpAlarmDefinition => 'PowerNet-MIB::airIRRP100UnitServiceIntervalCondensatePumpAlarm',
  airIRRP100UnitServiceIntervalFans => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.4.11',
  airIRRP100UnitServiceIntervalFansAlarm => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.4.12',
  airIRRP100UnitServiceIntervalFansAlarmDefinition => 'PowerNet-MIB::airIRRP100UnitServiceIntervalFansAlarm',
  airIRRP100UnitThresholds => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.5',
  airIRRP100UnitThresholdsRackInletHighTempUS => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.5.1',
  airIRRP100UnitThresholdsRackInletHighTempMetric => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.5.2',
  airIRRP100UnitThresholdsSupplyAirHighTempUS => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.5.3',
  airIRRP100UnitThresholdsSupplyAirHighTempMetric => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.5.4',
  airIRRP100UnitThresholdsReturnAirHighTempUS => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.5.5',
  airIRRP100UnitThresholdsReturnAirHighTempMetric => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.5.6',
  airIRRP100UnitThresholdsSupplyHumidityHigh => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.5.7',
  airIRRP100UnitThresholdsSupplyHumidityLow => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.5.8',
  airIRRP100UnitConfig => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.6',
  airIRRP100UnitConfigStartupDelay => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.6.1',
  airIRRP100UnitConfigCoolCapacity => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.6.2',
  airIRRP100UnitConfigCoolCapacityDefinition => 'PowerNet-MIB::airIRRP100UnitConfigCoolCapacity',
  airIRRP100UnitConfigIdleOnLeakDetect => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.6.3',
  airIRRP100UnitConfigIdleOnLeakDetectDefinition => 'PowerNet-MIB::airIRRP100UnitConfigIdleOnLeakDetect',
  airIRRP100UnitConfigInputNormalState => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.6.4',
  airIRRP100UnitConfigInputNormalStateDefinition => 'PowerNet-MIB::airIRRP100UnitConfigInputNormalState',
  airIRRP100UnitConfigOutputNormalState => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.6.5',
  airIRRP100UnitConfigOutputNormalStateDefinition => 'PowerNet-MIB::airIRRP100UnitConfigOutputNormalState',
  airIRRP100UnitConfigOutputSource => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.6.6',
  airIRRP100UnitConfigOutputSourceDefinition => 'PowerNet-MIB::airIRRP100UnitConfigOutputSource',
  airIRRP100UnitConfigHumidifyEnable => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.6.7',
  airIRRP100UnitConfigHumidifyEnableDefinition => 'PowerNet-MIB::airIRRP100UnitConfigHumidifyEnable',
  airIRRP100UnitConfigHumidifierControl => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.6.8',
  airIRRP100UnitConfigHumidifierControlDefinition => 'PowerNet-MIB::airIRRP100UnitConfigHumidifierControl',
  airIRRP100UnitConfigDehumidifyEnable => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.6.9',
  airIRRP100UnitConfigDehumidifyEnableDefinition => 'PowerNet-MIB::airIRRP100UnitConfigDehumidifyEnable',
  airIRRP100UnitConfigReheatEnable => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.6.10',
  airIRRP100UnitConfigReheatEnableDefinition => 'PowerNet-MIB::airIRRP100UnitConfigReheatEnable',
  airIRRP100UnitConfigHeatAssistEnable => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.6.11',
  airIRRP100UnitConfigHeatAssistEnableDefinition => 'PowerNet-MIB::airIRRP100UnitConfigHeatAssistEnable',
  airIRRP100UnitConfigPowerSourceConfig => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.6.12',
  airIRRP100UnitConfigPowerSourceConfigDefinition => 'PowerNet-MIB::airIRRP100UnitConfigPowerSourceConfig',
  airIRRP100UnitConfigUnitRoleOverride => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.6.13',
  airIRRP100UnitConfigUnitRoleOverrideDefinition => 'PowerNet-MIB::airIRRP100UnitConfigUnitRoleOverride',
  airIRRP100UnitConfigSecondaryPowerFeedCapability => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.6.14',
  airIRRP100UnitConfigSecondaryPowerFeedCapabilityDefinition => 'PowerNet-MIB::airIRRP100UnitConfigSecondaryPowerFeedCapability',
  airIRRP100UnitConfigIdleOnCoolFail => '1.3.6.1.4.1.318.1.1.13.3.3.1.2.6.15',
  airIRRP100UnitConfigIdleOnCoolFailDefinition => 'PowerNet-MIB::airIRRP100UnitConfigIdleOnCoolFail',
  airIRRP500 => '1.3.6.1.4.1.318.1.1.13.3.3.2',
  airIRRP500Group => '1.3.6.1.4.1.318.1.1.13.3.3.2.1',
  airIRRP500GroupStatus => '1.3.6.1.4.1.318.1.1.13.3.3.2.1.1',
  airIRRP500GroupStatusAirFlowUS => '1.3.6.1.4.1.318.1.1.13.3.3.2.1.1.1',
  airIRRP500GroupStatusAirFlowMetric => '1.3.6.1.4.1.318.1.1.13.3.3.2.1.1.2',
  airIRRP500GroupStatusMaxRackInletTempUS => '1.3.6.1.4.1.318.1.1.13.3.3.2.1.1.3',
  airIRRP500GroupStatusMaxRackInletTempMetric => '1.3.6.1.4.1.318.1.1.13.3.3.2.1.1.4',
  airIRRP500GroupStatusMinRackInletTempUS => '1.3.6.1.4.1.318.1.1.13.3.3.2.1.1.5',
  airIRRP500GroupStatusMinRackInletTempMetric => '1.3.6.1.4.1.318.1.1.13.3.3.2.1.1.6',
  airIRRP500GroupStatusCoolDemand => '1.3.6.1.4.1.318.1.1.13.3.3.2.1.1.7',
  airIRRP500GroupStatusCoolOutput => '1.3.6.1.4.1.318.1.1.13.3.3.2.1.1.8',
  airIRRP500GroupStatusHumidifyDemand => '1.3.6.1.4.1.318.1.1.13.3.3.2.1.1.9',
  airIRRP500GroupStatusHumidifyOutput => '1.3.6.1.4.1.318.1.1.13.3.3.2.1.1.10',
  airIRRP500GroupStatusDehumidifyDemand => '1.3.6.1.4.1.318.1.1.13.3.3.2.1.1.11',
  airIRRP500GroupStatusDehumidifyOutput => '1.3.6.1.4.1.318.1.1.13.3.3.2.1.1.12',
  airIRRP500GroupStatusReheatDemand => '1.3.6.1.4.1.318.1.1.13.3.3.2.1.1.13',
  airIRRP500GroupStatusReheatOutput => '1.3.6.1.4.1.318.1.1.13.3.3.2.1.1.14',
  airIRRP500GroupStatusActiveFlowControlStatus => '1.3.6.1.4.1.318.1.1.13.3.3.2.1.1.15',
  airIRRP500GroupStatusActiveFlowControlStatusDefinition => 'PowerNet-MIB::airIRRP500GroupStatusActiveFlowControlStatus',
  airIRRP500GroupStatusDewPointTempUS => '1.3.6.1.4.1.318.1.1.13.3.3.2.1.1.16',
  airIRRP500GroupStatusDewPointTempMetric => '1.3.6.1.4.1.318.1.1.13.3.3.2.1.1.17',
  airIRRP500GroupSetpoints => '1.3.6.1.4.1.318.1.1.13.3.3.2.1.2',
  airIRRP500GroupSetpointsCoolUS => '1.3.6.1.4.1.318.1.1.13.3.3.2.1.2.1',
  airIRRP500GroupSetpointsCoolMetric => '1.3.6.1.4.1.318.1.1.13.3.3.2.1.2.2',
  airIRRP500GroupSetpointsSupplyAirUS => '1.3.6.1.4.1.318.1.1.13.3.3.2.1.2.3',
  airIRRP500GroupSetpointsSupplyAirMetric => '1.3.6.1.4.1.318.1.1.13.3.3.2.1.2.4',
  airIRRP500GroupSetpointsHumidify => '1.3.6.1.4.1.318.1.1.13.3.3.2.1.2.5',
  airIRRP500GroupSetpointsDehumidify => '1.3.6.1.4.1.318.1.1.13.3.3.2.1.2.6',
  airIRRP500GroupSetpointsDehumidifyDeadband => '1.3.6.1.4.1.318.1.1.13.3.3.2.1.2.7',
  airIRRP500GroupSetpointsReheatUS => '1.3.6.1.4.1.318.1.1.13.3.3.2.1.2.8',
  airIRRP500GroupSetpointsReheatMetric => '1.3.6.1.4.1.318.1.1.13.3.3.2.1.2.9',
  airIRRP500GroupSetpointsFanSpeedPreference => '1.3.6.1.4.1.318.1.1.13.3.3.2.1.2.10',
  airIRRP500GroupSetpointsFanSpeedPreferenceDefinition => 'PowerNet-MIB::airIRRP500GroupSetpointsFanSpeedPreference',
  airIRRP500GroupSetpointsFanSpeedControl => '1.3.6.1.4.1.318.1.1.13.3.3.2.1.2.11',
  airIRRP500GroupSetpointsFanSpeedControlDefinition => 'PowerNet-MIB::airIRRP500GroupSetpointsFanSpeedControl',
  airIRRP500GroupSetpointsActiveFlowControlBias => '1.3.6.1.4.1.318.1.1.13.3.3.2.1.2.12',
  airIRRP500GroupSetpointsActiveFlowControlBiasDefinition => 'PowerNet-MIB::airIRRP500GroupSetpointsActiveFlowControlBias',
  airIRRP500GroupConfig => '1.3.6.1.4.1.318.1.1.13.3.3.2.1.3',
  airIRRP500GroupConfigNumberofCoolingUnits => '1.3.6.1.4.1.318.1.1.13.3.3.2.1.3.1',
  airIRRP500GroupConfigConfigurationType => '1.3.6.1.4.1.318.1.1.13.3.3.2.1.3.2',
  airIRRP500GroupConfigConfigurationTypeDefinition => 'PowerNet-MIB::airIRRP500GroupConfigConfigurationType',
  airIRRP500GroupConfigPercentGlycol => '1.3.6.1.4.1.318.1.1.13.3.3.2.1.3.3',
  airIRRP500GroupConfigCoolGainP => '1.3.6.1.4.1.318.1.1.13.3.3.2.1.3.4',
  airIRRP500GroupConfigCoolResetRateI => '1.3.6.1.4.1.318.1.1.13.3.3.2.1.3.5',
  airIRRP500GroupConfigCoolDerivativeD => '1.3.6.1.4.1.318.1.1.13.3.3.2.1.3.6',
  airIRRP500GroupConfigHumidifySensitivityBand => '1.3.6.1.4.1.318.1.1.13.3.3.2.1.3.7',
  airIRRP500GroupConfigReheatGainP => '1.3.6.1.4.1.318.1.1.13.3.3.2.1.3.8',
  airIRRP500GroupConfigReheatResetRateI => '1.3.6.1.4.1.318.1.1.13.3.3.2.1.3.9',
  airIRRP500GroupConfigReheatDerivativeD => '1.3.6.1.4.1.318.1.1.13.3.3.2.1.3.10',
  airIRRP500GroupConfigMaxFanSpeed => '1.3.6.1.4.1.318.1.1.13.3.3.2.1.3.11',
  airIRRP500GroupConfigNumberofBackupUnits => '1.3.6.1.4.1.318.1.1.13.3.3.2.1.3.12',
  airIRRP500GroupConfigRuntimeBalancingEnable => '1.3.6.1.4.1.318.1.1.13.3.3.2.1.3.13',
  airIRRP500GroupConfigRuntimeBalancingEnableDefinition => 'PowerNet-MIB::airIRRP500GroupConfigRuntimeBalancingEnable',
  airIRRP500GroupConfigLoadAssistEnable => '1.3.6.1.4.1.318.1.1.13.3.3.2.1.3.14',
  airIRRP500GroupConfigLoadAssistEnableDefinition => 'PowerNet-MIB::airIRRP500GroupConfigLoadAssistEnable',
  airIRRP500GroupConfigFullRPBackups => '1.3.6.1.4.1.318.1.1.13.3.3.2.1.3.15',
  airIRRP500GroupConfigNumberOfActiveFlowControllers => '1.3.6.1.4.1.318.1.1.13.3.3.2.1.3.16',
  airIRRP500GroupConfigActiveFlowControllerLampTest => '1.3.6.1.4.1.318.1.1.13.3.3.2.1.3.17',
  airIRRP500GroupConfigActiveFlowControllerLampTestDefinition => 'PowerNet-MIB::airIRRP500GroupConfigActiveFlowControllerLampTest',
  airIRRP500GroupConfigAltitudeUS => '1.3.6.1.4.1.318.1.1.13.3.3.2.1.3.18',
  airIRRP500GroupConfigAltitudeMetric => '1.3.6.1.4.1.318.1.1.13.3.3.2.1.3.19',
  airIRRP500Unit => '1.3.6.1.4.1.318.1.1.13.3.3.2.2',
  airIRRP500UnitIdent => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.1',
  airIRRP500UnitIdentID => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.1.1',
  airIRRP500UnitIdentName => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.1.2',
  airIRRP500UnitIdentLocation => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.1.3',
  airIRRP500UnitIdentModelNumber => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.1.4',
  airIRRP500UnitIdentSerialNumber => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.1.5',
  airIRRP500UnitIdentFirmwareRevision => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.1.6',
  airIRRP500UnitIdentHardwareRevision => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.1.7',
  airIRRP500UnitIdentManufactureDate => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.1.8',
  airIRRP500UnitStatus => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.2',
  airIRRP500UnitStatusOperateMode => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.2.1',
  airIRRP500UnitStatusOperateModeDefinition => 'PowerNet-MIB::airIRRP500UnitStatusOperateMode',
  airIRRP500UnitStatusMaximumRackInletTempUS => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.2.2',
  airIRRP500UnitStatusMaximumRackInletTempMetric => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.2.3',
  airIRRP500UnitStatusSupplyAirTempUS => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.2.4',
  airIRRP500UnitStatusSupplyAirTempMetric => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.2.5',
  airIRRP500UnitStatusReturnAirTempUS => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.2.6',
  airIRRP500UnitStatusReturnAirTempMetric => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.2.7',
  airIRRP500UnitStatusSupplyHumidity => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.2.8',
  airIRRP500UnitStatusReturnHumidity => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.2.9',
  airIRRP500UnitStatusAirFlowUS => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.2.10',
  airIRRP500UnitStatusAirFlowMetric => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.2.11',
  airIRRP500UnitStatusFanSpeed => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.2.12',
  airIRRP500UnitStatusCoolDemand => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.2.13',
  airIRRP500UnitStatusCoolOutput => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.2.14',
  airIRRP500UnitStatusHumidifyDemand => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.2.15',
  airIRRP500UnitStatusHumidifyOutput => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.2.16',
  airIRRP500UnitStatusDehumidifyDemand => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.2.17',
  airIRRP500UnitStatusDehumidifyOutput => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.2.18',
  airIRRP500UnitStatusReheatDemand => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.2.19',
  airIRRP500UnitStatusReheatOutput => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.2.20',
  airIRRP500UnitStatusInputState => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.2.21',
  airIRRP500UnitStatusInputStateDefinition => 'PowerNet-MIB::airIRRP500UnitStatusInputState',
  airIRRP500UnitStatusOutputState => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.2.22',
  airIRRP500UnitStatusOutputStateDefinition => 'PowerNet-MIB::airIRRP500UnitStatusOutputState',
  airIRRP500UnitStatusRackInletTemperature1US => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.2.23',
  airIRRP500UnitStatusRackInletTemperature1Metric => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.2.24',
  airIRRP500UnitStatusRackInletTemperature2US => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.2.25',
  airIRRP500UnitStatusRackInletTemperature2Metric => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.2.26',
  airIRRP500UnitStatusRackInletTemperature3US => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.2.27',
  airIRRP500UnitStatusRackInletTemperature3Metric => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.2.28',
  airIRRP500UnitStatusContainmtDPUS => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.2.29',
  airIRRP500UnitStatusContainmtDPMetric => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.2.30',
  airIRRP500UnitStatusFilterDPUS => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.2.31',
  airIRRP500UnitStatusFilterDPMetric => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.2.32',
  airIRRP500UnitStatusHumidifierCurrent => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.2.33',
  airIRRP500UnitStatusHumidifierWaterConductivity => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.2.34',
  airIRRP500UnitStatusActivePowerSource => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.2.35',
  airIRRP500UnitStatusActivePowerSourceDefinition => 'PowerNet-MIB::airIRRP500UnitStatusActivePowerSource',
  airIRRP500UnitStatusFluidValvePosition => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.2.36',
  airIRRP500UnitStatusFluidFlowUS => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.2.37',
  airIRRP500UnitStatusFluidFlowMetric => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.2.38',
  airIRRP500UnitStatusEnteringFluidTemperatureUS => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.2.39',
  airIRRP500UnitStatusEnteringFluidTemperatureMetric => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.2.40',
  airIRRP500UnitStatusLeavingFluidTemperatureUS => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.2.41',
  airIRRP500UnitStatusLeavingFluidTemperatureMetric => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.2.42',
  airIRRP500UnitStatusLeakSensor => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.2.43',
  airIRRP500UnitStatusLeakSensorDefinition => 'PowerNet-MIB::airIRRP500UnitStatusLeakSensor',
  airIRRP500UnitRunHours => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.3',
  airIRRP500UnitRunHoursAirFilter => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.3.1',
  airIRRP500UnitRunHoursCondensatePump => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.3.2',
  airIRRP500UnitRunHoursHumidifier => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.3.3',
  airIRRP500UnitRunHoursFan1 => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.3.4',
  airIRRP500UnitRunHoursHeater1 => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.3.5',
  airIRRP500UnitRunHoursFan2 => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.3.6',
  airIRRP500UnitRunHoursHeater2 => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.3.7',
  airIRRP500UnitRunHoursFan3 => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.3.8',
  airIRRP500UnitRunHoursHeater3 => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.3.9',
  airIRRP500UnitRunHoursSystem => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.3.10',
  airIRRP500UnitServiceIntervals => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.4',
  airIRRP500UnitServiceIntervalAirFilter => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.4.1',
  airIRRP500UnitServiceIntervalAirFilterAlarm => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.4.2',
  airIRRP500UnitServiceIntervalAirFilterAlarmDefinition => 'PowerNet-MIB::airIRRP500UnitServiceIntervalAirFilterAlarm',
  airIRRP500UnitServiceIntervalHumidifier => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.4.3',
  airIRRP500UnitServiceIntervalHumidifierAlarm => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.4.4',
  airIRRP500UnitServiceIntervalHumidifierAlarmDefinition => 'PowerNet-MIB::airIRRP500UnitServiceIntervalHumidifierAlarm',
  airIRRP500UnitServiceIntervalHeater => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.4.5',
  airIRRP500UnitServiceIntervalHeaterAlarm => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.4.6',
  airIRRP500UnitServiceIntervalHeaterAlarmDefinition => 'PowerNet-MIB::airIRRP500UnitServiceIntervalHeaterAlarm',
  airIRRP500UnitServiceIntervalCondensatePump => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.4.7',
  airIRRP500UnitServiceIntervalCondensatePumpAlarm => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.4.8',
  airIRRP500UnitServiceIntervalCondensatePumpAlarmDefinition => 'PowerNet-MIB::airIRRP500UnitServiceIntervalCondensatePumpAlarm',
  airIRRP500UnitServiceIntervalFans => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.4.9',
  airIRRP500UnitServiceIntervalFansAlarm => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.4.10',
  airIRRP500UnitServiceIntervalFansAlarmDefinition => 'PowerNet-MIB::airIRRP500UnitServiceIntervalFansAlarm',
  airIRRP500UnitThresholds => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.5',
  airIRRP500UnitThresholdsRackInletHighTempUS => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.5.1',
  airIRRP500UnitThresholdsRackInletHighTempMetric => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.5.2',
  airIRRP500UnitThresholdsSupplyAirHighTempUS => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.5.3',
  airIRRP500UnitThresholdsSupplyAirHighTempMetric => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.5.4',
  airIRRP500UnitThresholdsReturnAirHighTempUS => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.5.5',
  airIRRP500UnitThresholdsReturnAirHighTempMetric => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.5.6',
  airIRRP500UnitThresholdsSupplyHumidityHigh => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.5.7',
  airIRRP500UnitThresholdsSupplyHumidityLow => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.5.8',
  airIRRP500UnitThresholdsEnteringFluidHighTempUS => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.5.9',
  airIRRP500UnitThresholdsEnteringFluidHighTempMetric => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.5.10',
  airIRRP500UnitConfig => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.6',
  airIRRP500UnitConfigStartupDelay => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.6.1',
  airIRRP500UnitConfigCoolCapacity => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.6.2',
  airIRRP500UnitConfigCoolCapacityDefinition => 'PowerNet-MIB::airIRRP500UnitConfigCoolCapacity',
  airIRRP500UnitConfigIdleOnLeakDetect => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.6.3',
  airIRRP500UnitConfigIdleOnLeakDetectDefinition => 'PowerNet-MIB::airIRRP500UnitConfigIdleOnLeakDetect',
  airIRRP500UnitConfigInputNormalState => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.6.4',
  airIRRP500UnitConfigInputNormalStateDefinition => 'PowerNet-MIB::airIRRP500UnitConfigInputNormalState',
  airIRRP500UnitConfigOutputNormalState => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.6.5',
  airIRRP500UnitConfigOutputNormalStateDefinition => 'PowerNet-MIB::airIRRP500UnitConfigOutputNormalState',
  airIRRP500UnitConfigOutputSource => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.6.6',
  airIRRP500UnitConfigOutputSourceDefinition => 'PowerNet-MIB::airIRRP500UnitConfigOutputSource',
  airIRRP500UnitConfigHumidifyEnable => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.6.7',
  airIRRP500UnitConfigHumidifyEnableDefinition => 'PowerNet-MIB::airIRRP500UnitConfigHumidifyEnable',
  airIRRP500UnitConfigHumidifierControl => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.6.8',
  airIRRP500UnitConfigHumidifierControlDefinition => 'PowerNet-MIB::airIRRP500UnitConfigHumidifierControl',
  airIRRP500UnitConfigDehumidifyEnable => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.6.9',
  airIRRP500UnitConfigDehumidifyEnableDefinition => 'PowerNet-MIB::airIRRP500UnitConfigDehumidifyEnable',
  airIRRP500UnitConfigReheatEnable => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.6.10',
  airIRRP500UnitConfigReheatEnableDefinition => 'PowerNet-MIB::airIRRP500UnitConfigReheatEnable',
  airIRRP500UnitConfigHeatAssistEnable => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.6.11',
  airIRRP500UnitConfigHeatAssistEnableDefinition => 'PowerNet-MIB::airIRRP500UnitConfigHeatAssistEnable',
  airIRRP500UnitConfigPowerSourceConfig => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.6.12',
  airIRRP500UnitConfigPowerSourceConfigDefinition => 'PowerNet-MIB::airIRRP500UnitConfigPowerSourceConfig',
  airIRRP500UnitConfigUnitRoleOverride => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.6.13',
  airIRRP500UnitConfigUnitRoleOverrideDefinition => 'PowerNet-MIB::airIRRP500UnitConfigUnitRoleOverride',
  airIRRP500UnitConfigSecondaryPowerFeedCapability => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.6.14',
  airIRRP500UnitConfigSecondaryPowerFeedCapabilityDefinition => 'PowerNet-MIB::airIRRP500UnitConfigSecondaryPowerFeedCapability',
  airIRRP500UnitConfigIdleOnCoolFail => '1.3.6.1.4.1.318.1.1.13.3.3.2.2.6.15',
  airIRRP500UnitConfigIdleOnCoolFailDefinition => 'PowerNet-MIB::airIRRP500UnitConfigIdleOnCoolFail',
  airIRSC => '1.3.6.1.4.1.318.1.1.13.3.4',
  airIRSCUnit => '1.3.6.1.4.1.318.1.1.13.3.4.1',
  airIRSCUnitIdent => '1.3.6.1.4.1.318.1.1.13.3.4.1.1',
  airIRSCUnitIdentName => '1.3.6.1.4.1.318.1.1.13.3.4.1.1.1',
  airIRSCUnitIdentLocation => '1.3.6.1.4.1.318.1.1.13.3.4.1.1.2',
  airIRSCUnitIdentModelNumber => '1.3.6.1.4.1.318.1.1.13.3.4.1.1.3',
  airIRSCUnitIdentSerialNumber => '1.3.6.1.4.1.318.1.1.13.3.4.1.1.4',
  airIRSCUnitIdentFirmwareRevision => '1.3.6.1.4.1.318.1.1.13.3.4.1.1.5',
  airIRSCUnitIdentHardwareRevision => '1.3.6.1.4.1.318.1.1.13.3.4.1.1.6',
  airIRSCUnitIdentManufactureDate => '1.3.6.1.4.1.318.1.1.13.3.4.1.1.7',
  airIRSCUnitStatus => '1.3.6.1.4.1.318.1.1.13.3.4.1.2',
  airIRSCUnitStatusOperateMode => '1.3.6.1.4.1.318.1.1.13.3.4.1.2.1',
  airIRSCUnitStatusOperateModeDefinition => 'PowerNet-MIB::airIRSCUnitStatusOperateMode',
  airIRSCUnitStatusCoolOutput => '1.3.6.1.4.1.318.1.1.13.3.4.1.2.2',
  airIRSCUnitStatusCoolDemand => '1.3.6.1.4.1.318.1.1.13.3.4.1.2.3',
  airIRSCUnitStatusAirFlowUS => '1.3.6.1.4.1.318.1.1.13.3.4.1.2.4',
  airIRSCUnitStatusAirFlowMetric => '1.3.6.1.4.1.318.1.1.13.3.4.1.2.5',
  airIRSCUnitStatusRackInletTempUS => '1.3.6.1.4.1.318.1.1.13.3.4.1.2.6',
  airIRSCUnitStatusRackInletTempMetric => '1.3.6.1.4.1.318.1.1.13.3.4.1.2.7',
  airIRSCUnitStatusSupplyAirTempUS => '1.3.6.1.4.1.318.1.1.13.3.4.1.2.8',
  airIRSCUnitStatusSupplyAirTempMetric => '1.3.6.1.4.1.318.1.1.13.3.4.1.2.9',
  airIRSCUnitStatusReturnAirTempUS => '1.3.6.1.4.1.318.1.1.13.3.4.1.2.10',
  airIRSCUnitStatusReturnAirTempMetric => '1.3.6.1.4.1.318.1.1.13.3.4.1.2.11',
  airIRSCUnitStatusSuctionTempUS => '1.3.6.1.4.1.318.1.1.13.3.4.1.2.12',
  airIRSCUnitStatusSuctionTempMetric => '1.3.6.1.4.1.318.1.1.13.3.4.1.2.13',
  airIRSCUnitStatusSuperheatTempUS => '1.3.6.1.4.1.318.1.1.13.3.4.1.2.14',
  airIRSCUnitStatusSuperheatTempMetric => '1.3.6.1.4.1.318.1.1.13.3.4.1.2.15',
  airIRSCUnitStatusContainmtDPUS => '1.3.6.1.4.1.318.1.1.13.3.4.1.2.16',
  airIRSCUnitStatusContainmtDPMetric => '1.3.6.1.4.1.318.1.1.13.3.4.1.2.17',
  airIRSCUnitStatusFilterDPUS => '1.3.6.1.4.1.318.1.1.13.3.4.1.2.18',
  airIRSCUnitStatusFilterDPMetric => '1.3.6.1.4.1.318.1.1.13.3.4.1.2.19',
  airIRSCUnitStatusSuctionPressureUS => '1.3.6.1.4.1.318.1.1.13.3.4.1.2.20',
  airIRSCUnitStatusSuctionPressureMetric => '1.3.6.1.4.1.318.1.1.13.3.4.1.2.21',
  airIRSCUnitStatusDischargePressureUS => '1.3.6.1.4.1.318.1.1.13.3.4.1.2.22',
  airIRSCUnitStatusDischargePressureMetric => '1.3.6.1.4.1.318.1.1.13.3.4.1.2.23',
  airIRSCUnitStatusEvaporatorFanSpeed => '1.3.6.1.4.1.318.1.1.13.3.4.1.2.24',
  airIRSCUnitStatusCondenserFanSpeed => '1.3.6.1.4.1.318.1.1.13.3.4.1.2.25',
  airIRSCUnitStatusInputState => '1.3.6.1.4.1.318.1.1.13.3.4.1.2.26',
  airIRSCUnitStatusInputStateDefinition => 'PowerNet-MIB::airIRSCUnitStatusInputState',
  airIRSCUnitStatusOutputState => '1.3.6.1.4.1.318.1.1.13.3.4.1.2.27',
  airIRSCUnitStatusOutputStateDefinition => 'PowerNet-MIB::airIRSCUnitStatusOutputState',
  airIRSCUnitStatusCondOutletTempUS => '1.3.6.1.4.1.318.1.1.13.3.4.1.2.28',
  airIRSCUnitStatusCondOutletTempMetric => '1.3.6.1.4.1.318.1.1.13.3.4.1.2.29',
  airIRSCUnitStatusCondInletTempUS => '1.3.6.1.4.1.318.1.1.13.3.4.1.2.30',
  airIRSCUnitStatusCondInletTempMetric => '1.3.6.1.4.1.318.1.1.13.3.4.1.2.31',
  airIRSCUnitStatusCompressor => '1.3.6.1.4.1.318.1.1.13.3.4.1.2.32',
  airIRSCUnitStatusCompressorDefinition => 'PowerNet-MIB::airIRSCUnitStatusCompressor',
  airIRSCUnitStatusLeakSensor => '1.3.6.1.4.1.318.1.1.13.3.4.1.2.33',
  airIRSCUnitStatusLeakSensorDefinition => 'PowerNet-MIB::airIRSCUnitStatusLeakSensor',
  airIRSCUnitRunHours => '1.3.6.1.4.1.318.1.1.13.3.4.1.3',
  airIRSCUnitRunHoursAirFilter => '1.3.6.1.4.1.318.1.1.13.3.4.1.3.1',
  airIRSCUnitRunHoursEvaporatorFan1 => '1.3.6.1.4.1.318.1.1.13.3.4.1.3.2',
  airIRSCUnitRunHoursEvaporatorFan2 => '1.3.6.1.4.1.318.1.1.13.3.4.1.3.3',
  airIRSCUnitRunHoursEvaporatorFan3 => '1.3.6.1.4.1.318.1.1.13.3.4.1.3.4',
  airIRSCUnitRunHoursCondenserFan1 => '1.3.6.1.4.1.318.1.1.13.3.4.1.3.5',
  airIRSCUnitRunHoursCondenserFan2 => '1.3.6.1.4.1.318.1.1.13.3.4.1.3.6',
  airIRSCUnitRunHoursCondenserFan3 => '1.3.6.1.4.1.318.1.1.13.3.4.1.3.7',
  airIRSCUnitRunHoursFanPowerSupplyLeft => '1.3.6.1.4.1.318.1.1.13.3.4.1.3.8',
  airIRSCUnitRunHoursFanPowerSupplyRight => '1.3.6.1.4.1.318.1.1.13.3.4.1.3.9',
  airIRSCUnitRunHoursCondensatePump => '1.3.6.1.4.1.318.1.1.13.3.4.1.3.10',
  airIRSCUnitRunHoursCompressor => '1.3.6.1.4.1.318.1.1.13.3.4.1.3.11',
  airIRSCUnitServiceIntervals => '1.3.6.1.4.1.318.1.1.13.3.4.1.4',
  airIRSCUnitServiceIntervalsAirFilter => '1.3.6.1.4.1.318.1.1.13.3.4.1.4.1',
  airIRSCUnitServiceIntervalsAirFilterAlarm => '1.3.6.1.4.1.318.1.1.13.3.4.1.4.2',
  airIRSCUnitServiceIntervalsAirFilterAlarmDefinition => 'PowerNet-MIB::airIRSCUnitServiceIntervalsAirFilterAlarm',
  airIRSCUnitThresholds => '1.3.6.1.4.1.318.1.1.13.3.4.1.5',
  airIRSCUnitThresholdsRackInletHighTempUS => '1.3.6.1.4.1.318.1.1.13.3.4.1.5.1',
  airIRSCUnitThresholdsRackInletHighTempMetric => '1.3.6.1.4.1.318.1.1.13.3.4.1.5.2',
  airIRSCUnitThresholdsSupplyAirHighTempUS => '1.3.6.1.4.1.318.1.1.13.3.4.1.5.3',
  airIRSCUnitThresholdsSupplyAirHighTempMetric => '1.3.6.1.4.1.318.1.1.13.3.4.1.5.4',
  airIRSCUnitThresholdsReturnAirHighTempUS => '1.3.6.1.4.1.318.1.1.13.3.4.1.5.5',
  airIRSCUnitThresholdsReturnAirHighTempMetric => '1.3.6.1.4.1.318.1.1.13.3.4.1.5.6',
  airIRSCUnitSetpoints => '1.3.6.1.4.1.318.1.1.13.3.4.1.6',
  airIRSCUnitSetptsCoolSetpointUS => '1.3.6.1.4.1.318.1.1.13.3.4.1.6.1',
  airIRSCUnitSetptsCoolSetpointMetric => '1.3.6.1.4.1.318.1.1.13.3.4.1.6.2',
  airIRSCUnitSetptsCoolDeadbandUS => '1.3.6.1.4.1.318.1.1.13.3.4.1.6.3',
  airIRSCUnitSetptsCoolDeadbandMetric => '1.3.6.1.4.1.318.1.1.13.3.4.1.6.4',
  airIRSCUnitSetptsFanSpeedPreference => '1.3.6.1.4.1.318.1.1.13.3.4.1.6.5',
  airIRSCUnitSetptsFanSpeedPreferenceDefinition => 'PowerNet-MIB::AirIRSCFanSpeedPreference',
  airIRSCUnitSetptsSupplyAirSetpointUS => '1.3.6.1.4.1.318.1.1.13.3.4.1.6.6',
  airIRSCUnitSetptsSupplyAirSetpointMetric => '1.3.6.1.4.1.318.1.1.13.3.4.1.6.7',
  airIRSCUnitConfig => '1.3.6.1.4.1.318.1.1.13.3.4.1.7',
  airIRSCUnitConfigConfigurationType => '1.3.6.1.4.1.318.1.1.13.3.4.1.7.1',
  airIRSCUnitConfigConfigurationTypeDefinition => 'PowerNet-MIB::AirIRSCConfigType',
  airIRSCUnitConfigCapacityControlType => '1.3.6.1.4.1.318.1.1.13.3.4.1.7.2',
  airIRSCUnitConfigCapacityControlTypeDefinition => 'PowerNet-MIB::AirIRSCCapacityControlType',
  airIRSCUnitConfigStartupDelay => '1.3.6.1.4.1.318.1.1.13.3.4.1.7.3',
  airIRSCUnitConfigIdleOnLeakDetect => '1.3.6.1.4.1.318.1.1.13.3.4.1.7.4',
  airIRSCUnitConfigIdleOnLeakDetectDefinition => 'PowerNet-MIB::airIRSCUnitConfigIdleOnLeakDetect',
  airIRSCUnitConfigInputNormalState => '1.3.6.1.4.1.318.1.1.13.3.4.1.7.5',
  airIRSCUnitConfigInputNormalStateDefinition => 'PowerNet-MIB::airIRSCUnitConfigInputNormalState',
  airIRSCUnitConfigOutputNormalState => '1.3.6.1.4.1.318.1.1.13.3.4.1.7.6',
  airIRSCUnitConfigOutputNormalStateDefinition => 'PowerNet-MIB::airIRSCUnitConfigOutputNormalState',
  airIRSCUnitConfigOutputSource => '1.3.6.1.4.1.318.1.1.13.3.4.1.7.7',
  airIRSCUnitConfigOutputSourceDefinition => 'PowerNet-MIB::airIRSCUnitConfigOutputSource',
  airIRSCUnitConfigAltitudeUS => '1.3.6.1.4.1.318.1.1.13.3.4.1.7.8',
  airIRSCUnitConfigAltitudeMetric => '1.3.6.1.4.1.318.1.1.13.3.4.1.7.9',
  airIRSCUnitConfigOpControl => '1.3.6.1.4.1.318.1.1.13.3.4.1.7.10',
  airIRSCUnitConfigOpControlDefinition => 'PowerNet-MIB::airIRSCUnitConfigOpControl',
  airIRSCGroup => '1.3.6.1.4.1.318.1.1.13.3.4.2',
  airIRSCGroupStatus => '1.3.6.1.4.1.318.1.1.13.3.4.2.1',
  airIRSCGroupStatusCoolOutput => '1.3.6.1.4.1.318.1.1.13.3.4.2.1.1',
  airIRSCGroupStatusCoolDemand => '1.3.6.1.4.1.318.1.1.13.3.4.2.1.2',
  airIRSCGroupStatusAirFlowUS => '1.3.6.1.4.1.318.1.1.13.3.4.2.1.3',
  airIRSCGroupStatusAirFlowMetric => '1.3.6.1.4.1.318.1.1.13.3.4.2.1.4',
  airIRSCGroupStatusMaxRackInletTempUS => '1.3.6.1.4.1.318.1.1.13.3.4.2.1.5',
  airIRSCGroupStatusMaxRackInletTempMetric => '1.3.6.1.4.1.318.1.1.13.3.4.2.1.6',
  airIRSCGroupStatusMinRackInletTempUS => '1.3.6.1.4.1.318.1.1.13.3.4.2.1.7',
  airIRSCGroupStatusMinRackInletTempMetric => '1.3.6.1.4.1.318.1.1.13.3.4.2.1.8',
  airIRSCGroupStatusMaxReturnAirTempUS => '1.3.6.1.4.1.318.1.1.13.3.4.2.1.9',
  airIRSCGroupStatusMaxReturnAirTempMetric => '1.3.6.1.4.1.318.1.1.13.3.4.2.1.10',
  airIRSCGroupStatusMinReturnAirTempUS => '1.3.6.1.4.1.318.1.1.13.3.4.2.1.11',
  airIRSCGroupStatusMinReturnAirTempMetric => '1.3.6.1.4.1.318.1.1.13.3.4.2.1.12',
  airIRSCGroupStatusActiveFlowControlStatus => '1.3.6.1.4.1.318.1.1.13.3.4.2.1.13',
  airIRSCGroupStatusActiveFlowControlStatusDefinition => 'PowerNet-MIB::airIRSCGroupStatusActiveFlowControlStatus',
  airIRSCGroupSetpoints => '1.3.6.1.4.1.318.1.1.13.3.4.2.2',
  airIRSCGroupSetptsCoolSetpointUS => '1.3.6.1.4.1.318.1.1.13.3.4.2.2.1',
  airIRSCGroupSetptsCoolSetpointMetric => '1.3.6.1.4.1.318.1.1.13.3.4.2.2.2',
  airIRSCGroupSetptsCoolDeadbandUS => '1.3.6.1.4.1.318.1.1.13.3.4.2.2.3',
  airIRSCGroupSetptsCoolDeadbandMetric => '1.3.6.1.4.1.318.1.1.13.3.4.2.2.4',
  airIRSCGroupSetptsFanSpeedPreference => '1.3.6.1.4.1.318.1.1.13.3.4.2.2.5',
  airIRSCGroupSetptsFanSpeedPreferenceDefinition => 'PowerNet-MIB::AirIRSCFanSpeedPreference',
  airIRSCGroupSetptsSupplyAirSetpointUS => '1.3.6.1.4.1.318.1.1.13.3.4.2.2.6',
  airIRSCGroupSetptsSupplyAirSetpointMetric => '1.3.6.1.4.1.318.1.1.13.3.4.2.2.7',
  airIRSCGroupSetpointsActiveFlowControlBias => '1.3.6.1.4.1.318.1.1.13.3.4.2.2.8',
  airIRSCGroupSetpointsActiveFlowControlBiasDefinition => 'PowerNet-MIB::airIRSCGroupSetpointsActiveFlowControlBias',
  airIRSCGroupConfig => '1.3.6.1.4.1.318.1.1.13.3.4.2.3',
  airIRSCGroupConfigNumberofCoolingUnits => '1.3.6.1.4.1.318.1.1.13.3.4.2.3.1',
  airIRSCGroupConfigConfigurationType => '1.3.6.1.4.1.318.1.1.13.3.4.2.3.2',
  airIRSCGroupConfigConfigurationTypeDefinition => 'PowerNet-MIB::AirIRSCConfigType',
  airIRSCGroupConfigCapacityControlType => '1.3.6.1.4.1.318.1.1.13.3.4.2.3.3',
  airIRSCGroupConfigCapacityControlTypeDefinition => 'PowerNet-MIB::AirIRSCCapacityControlType',
  airIRSCGroupConfigAltitudeUS => '1.3.6.1.4.1.318.1.1.13.3.4.2.3.4',
  airIRSCGroupConfigAltitudeMetric => '1.3.6.1.4.1.318.1.1.13.3.4.2.3.5',
  airIRSCGroupConfigFanSpeedControl => '1.3.6.1.4.1.318.1.1.13.3.4.2.3.6',
  airIRSCGroupConfigFanSpeedControlDefinition => 'PowerNet-MIB::AirIRSCFanSpeedControl',
  airIRSCGroupConfigNumberOfActiveFlowControllers => '1.3.6.1.4.1.318.1.1.13.3.4.2.3.7',
  airIRSCGroupConfigActiveFlowControllerLampTest => '1.3.6.1.4.1.318.1.1.13.3.4.2.3.8',
  airIRSCGroupConfigActiveFlowControllerLampTestDefinition => 'PowerNet-MIB::airIRSCGroupConfigActiveFlowControllerLampTest',
  airIRGen2 => '1.3.6.1.4.1.318.1.1.13.4',
  airIRG2Ident => '1.3.6.1.4.1.318.1.1.13.4.1',
  airIRG2IdentName => '1.3.6.1.4.1.318.1.1.13.4.1.1',
  airIRG2IdentLocation => '1.3.6.1.4.1.318.1.1.13.4.1.2',
  airIRG2IdentModelNumber => '1.3.6.1.4.1.318.1.1.13.4.1.3',
  airIRG2IdentSerialNumber => '1.3.6.1.4.1.318.1.1.13.4.1.4',
  airIRG2IdentFirmwareRevision => '1.3.6.1.4.1.318.1.1.13.4.1.5',
  airIRG2IdentHardwareRevision => '1.3.6.1.4.1.318.1.1.13.4.1.6',
  airIRG2IdentManufactureDate => '1.3.6.1.4.1.318.1.1.13.4.1.7',
  airIRG2IdentUnitSysOID => '1.3.6.1.4.1.318.1.1.13.4.1.8',
  airIRG2IdentGroupSysOID => '1.3.6.1.4.1.318.1.1.13.4.1.9',
  airIRG2Group => '1.3.6.1.4.1.318.1.1.13.4.2',
  airIRG2GroupStatus => '1.3.6.1.4.1.318.1.1.13.4.2.1',
  airIRG2GroupStatusCoolOutput => '1.3.6.1.4.1.318.1.1.13.4.2.1.1',
  airIRG2GroupStatusCoolDemand => '1.3.6.1.4.1.318.1.1.13.4.2.1.2',
  airIRG2GroupStatusAirFlowUS => '1.3.6.1.4.1.318.1.1.13.4.2.1.3',
  airIRG2GroupStatusAirFlowMetric => '1.3.6.1.4.1.318.1.1.13.4.2.1.4',
  airIRG2GroupStatusMaxRackInletTempUS => '1.3.6.1.4.1.318.1.1.13.4.2.1.5',
  airIRG2GroupStatusMaxRackInletTempMetric => '1.3.6.1.4.1.318.1.1.13.4.2.1.6',
  airIRG2GroupStatusMinRackInletTempUS => '1.3.6.1.4.1.318.1.1.13.4.2.1.7',
  airIRG2GroupStatusMinRackInletTempMetric => '1.3.6.1.4.1.318.1.1.13.4.2.1.8',
  airIRG2GroupStatusMaxReturnAirTempUS => '1.3.6.1.4.1.318.1.1.13.4.2.1.9',
  airIRG2GroupStatusMaxReturnAirTempMetric => '1.3.6.1.4.1.318.1.1.13.4.2.1.10',
  airIRG2GroupStatusMinReturnAirTempUS => '1.3.6.1.4.1.318.1.1.13.4.2.1.11',
  airIRG2GroupStatusMinReturnAirTempMetric => '1.3.6.1.4.1.318.1.1.13.4.2.1.12',
  airIRG2GroupStatusActiveFlowControlStatus => '1.3.6.1.4.1.318.1.1.13.4.2.1.13',
  airIRG2GroupStatusActiveFlowControlStatusDefinition => 'PowerNet-MIB::airIRG2GroupStatusActiveFlowControlStatus',
  airIRG2GroupSetpoints => '1.3.6.1.4.1.318.1.1.13.4.2.2',
  airIRG2GroupSetptsCoolSetpointUS => '1.3.6.1.4.1.318.1.1.13.4.2.2.1',
  airIRG2GroupSetptsCoolSetpointMetric => '1.3.6.1.4.1.318.1.1.13.4.2.2.2',
  airIRG2GroupSetptsCoolDeadbandUS => '1.3.6.1.4.1.318.1.1.13.4.2.2.3',
  airIRG2GroupSetptsCoolDeadbandMetric => '1.3.6.1.4.1.318.1.1.13.4.2.2.4',
  airIRG2GroupSetptsFanSpeedPreference => '1.3.6.1.4.1.318.1.1.13.4.2.2.5',
  airIRG2GroupSetptsFanSpeedPreferenceDefinition => 'PowerNet-MIB::airIRG2GroupSetptsFanSpeedPreference',
  airIRG2GroupSetptsSupplyAirSetpointUS => '1.3.6.1.4.1.318.1.1.13.4.2.2.6',
  airIRG2GroupSetptsSupplyAirSetpointMetric => '1.3.6.1.4.1.318.1.1.13.4.2.2.7',
  airIRG2GroupSetpointsActiveFlowControlBias => '1.3.6.1.4.1.318.1.1.13.4.2.2.8',
  airIRG2GroupSetpointsActiveFlowControlBiasDefinition => 'PowerNet-MIB::airIRG2GroupSetpointsActiveFlowControlBias',
  airIRG2GroupConfig => '1.3.6.1.4.1.318.1.1.13.4.2.3',
  airIRG2GroupConfigNumberofCoolingUnits => '1.3.6.1.4.1.318.1.1.13.4.2.3.1',
  airIRG2GroupConfigConfigurationType => '1.3.6.1.4.1.318.1.1.13.4.2.3.2',
  airIRG2GroupConfigConfigurationTypeDefinition => 'PowerNet-MIB::airIRG2GroupConfigConfigurationType',
  airIRG2GroupConfigCapacityControlType => '1.3.6.1.4.1.318.1.1.13.4.2.3.3',
  airIRG2GroupConfigCapacityControlTypeDefinition => 'PowerNet-MIB::airIRG2GroupConfigCapacityControlType',
  airIRG2GroupConfigFanSpeedControl => '1.3.6.1.4.1.318.1.1.13.4.2.3.4',
  airIRG2GroupConfigFanSpeedControlDefinition => 'PowerNet-MIB::airIRG2GroupConfigFanSpeedControl',
  airIRG2GroupConfigCoolGainP => '1.3.6.1.4.1.318.1.1.13.4.2.3.5',
  airIRG2GroupConfigCoolResetRateI => '1.3.6.1.4.1.318.1.1.13.4.2.3.6',
  airIRG2GroupConfigCoolDerivativeD => '1.3.6.1.4.1.318.1.1.13.4.2.3.7',
  airIRG2GroupConfigCoolPIDReset => '1.3.6.1.4.1.318.1.1.13.4.2.3.8',
  airIRG2GroupConfigCoolPIDResetDefinition => 'PowerNet-MIB::airIRG2GroupConfigCoolPIDReset',
  airIRG2GroupConfigNumberofBackupUnits => '1.3.6.1.4.1.318.1.1.13.4.2.3.9',
  airIRG2GroupConfigRuntimeBalancingEnable => '1.3.6.1.4.1.318.1.1.13.4.2.3.10',
  airIRG2GroupConfigRuntimeBalancingEnableDefinition => 'PowerNet-MIB::airIRG2GroupConfigRuntimeBalancingEnable',
  airIRG2GroupConfigLoadAssistEnable => '1.3.6.1.4.1.318.1.1.13.4.2.3.11',
  airIRG2GroupConfigLoadAssistEnableDefinition => 'PowerNet-MIB::airIRG2GroupConfigLoadAssistEnable',
  airIRG2GroupConfigNumberOfActiveFlowControllers => '1.3.6.1.4.1.318.1.1.13.4.2.3.12',
  airIRG2GroupConfigActiveFlowControllerLampTest => '1.3.6.1.4.1.318.1.1.13.4.2.3.13',
  airIRG2GroupConfigActiveFlowControllerLampTestDefinition => 'PowerNet-MIB::airIRG2GroupConfigActiveFlowControllerLampTest',
  airIRG2GroupConfigAltitudeUS => '1.3.6.1.4.1.318.1.1.13.4.2.3.14',
  airIRG2GroupConfigAltitudeMetric => '1.3.6.1.4.1.318.1.1.13.4.2.3.15',
  airIRG2Alarms => '1.3.6.1.4.1.318.1.1.13.4.3',
  airIRG2AlarmsTableSize => '1.3.6.1.4.1.318.1.1.13.4.3.1',
  airIRG2AlarmsTable => '1.3.6.1.4.1.318.1.1.13.4.3.2',
  airIRG2AlarmsEntry => '1.3.6.1.4.1.318.1.1.13.4.3.2.1',
  airIRG2AlarmsIndex => '1.3.6.1.4.1.318.1.1.13.4.3.2.1.1',
  airIRG2AlarmsEventCode => '1.3.6.1.4.1.318.1.1.13.4.3.2.1.2',
  airIRG2AlarmsDescription => '1.3.6.1.4.1.318.1.1.13.4.3.2.1.3',
  airIRG2RC => '1.3.6.1.4.1.318.1.1.13.4.4',
  airIRG2RD => '1.3.6.1.4.1.318.1.1.13.4.5',
  airIRG2RDType1 => '1.3.6.1.4.1.318.1.1.13.4.5.1',
  airIRG2RDType2 => '1.3.6.1.4.1.318.1.1.13.4.5.2',
  airIRG2RDT2Status => '1.3.6.1.4.1.318.1.1.13.4.5.2.1',
  airIRG2RDT2StatusOperateMode => '1.3.6.1.4.1.318.1.1.13.4.5.2.1.1',
  airIRG2RDT2StatusOperateModeDefinition => 'PowerNet-MIB::airIRG2RDT2StatusOperateMode',
  airIRG2RDT2StatusCoolOutput => '1.3.6.1.4.1.318.1.1.13.4.5.2.1.2',
  airIRG2RDT2StatusCoolDemand => '1.3.6.1.4.1.318.1.1.13.4.5.2.1.3',
  airIRG2RDT2StatusAirFlowUS => '1.3.6.1.4.1.318.1.1.13.4.5.2.1.4',
  airIRG2RDT2StatusAirFlowMetric => '1.3.6.1.4.1.318.1.1.13.4.5.2.1.5',
  airIRG2RDT2StatusRackInletTempUS => '1.3.6.1.4.1.318.1.1.13.4.5.2.1.6',
  airIRG2RDT2StatusRackInletTempMetric => '1.3.6.1.4.1.318.1.1.13.4.5.2.1.7',
  airIRG2RDT2StatusSupplyAirTempUS => '1.3.6.1.4.1.318.1.1.13.4.5.2.1.8',
  airIRG2RDT2StatusSupplyAirTempMetric => '1.3.6.1.4.1.318.1.1.13.4.5.2.1.9',
  airIRG2RDT2StatusReturnAirTempUS => '1.3.6.1.4.1.318.1.1.13.4.5.2.1.10',
  airIRG2RDT2StatusReturnAirTempMetric => '1.3.6.1.4.1.318.1.1.13.4.5.2.1.11',
  airIRG2RDT2StatusSuctionTempUS => '1.3.6.1.4.1.318.1.1.13.4.5.2.1.12',
  airIRG2RDT2StatusSuctionTempMetric => '1.3.6.1.4.1.318.1.1.13.4.5.2.1.13',
  airIRG2RDT2StatusSuperheatTempUS => '1.3.6.1.4.1.318.1.1.13.4.5.2.1.14',
  airIRG2RDT2StatusSuperheatTempMetric => '1.3.6.1.4.1.318.1.1.13.4.5.2.1.15',
  airIRG2RDT2StatusFilterDPUS => '1.3.6.1.4.1.318.1.1.13.4.5.2.1.16',
  airIRG2RDT2StatusFilterDPMetric => '1.3.6.1.4.1.318.1.1.13.4.5.2.1.17',
  airIRG2RDT2StatusSuctionPressureUS => '1.3.6.1.4.1.318.1.1.13.4.5.2.1.18',
  airIRG2RDT2StatusSuctionPressureMetric => '1.3.6.1.4.1.318.1.1.13.4.5.2.1.19',
  airIRG2RDT2StatusDischargePressureUS => '1.3.6.1.4.1.318.1.1.13.4.5.2.1.20',
  airIRG2RDT2StatusDischargePressureMetric => '1.3.6.1.4.1.318.1.1.13.4.5.2.1.21',
  airIRG2RDT2StatusEvaporatorFanSpeed => '1.3.6.1.4.1.318.1.1.13.4.5.2.1.22',
  airIRG2RDT2StatusInputState => '1.3.6.1.4.1.318.1.1.13.4.5.2.1.23',
  airIRG2RDT2StatusInputStateDefinition => 'PowerNet-MIB::AirIRG2RDType2IOState',
  airIRG2RDT2StatusOutputState => '1.3.6.1.4.1.318.1.1.13.4.5.2.1.24',
  airIRG2RDT2StatusOutputStateDefinition => 'PowerNet-MIB::AirIRG2RDType2IOState',
  airIRG2RDT2StatusOHEInputState => '1.3.6.1.4.1.318.1.1.13.4.5.2.1.25',
  airIRG2RDT2StatusOHEInputStateDefinition => 'PowerNet-MIB::AirIRG2RDType2IOState',
  airIRG2RDT2StatusOHEOutputState => '1.3.6.1.4.1.318.1.1.13.4.5.2.1.26',
  airIRG2RDT2StatusOHEOutputStateDefinition => 'PowerNet-MIB::AirIRG2RDType2IOState',
  airIRG2RDT2StatusCompressor => '1.3.6.1.4.1.318.1.1.13.4.5.2.1.27',
  airIRG2RDT2StatusCompressorDefinition => 'PowerNet-MIB::airIRG2RDT2StatusCompressor',
  airIRG2RDT2StatusFluidValvePos => '1.3.6.1.4.1.318.1.1.13.4.5.2.1.28',
  airIRG2RDT2StatusHotGasBypassValvePos => '1.3.6.1.4.1.318.1.1.13.4.5.2.1.29',
  airIRG2RDT2StatusLeakSensor => '1.3.6.1.4.1.318.1.1.13.4.5.2.1.30',
  airIRG2RDT2StatusLeakSensorDefinition => 'PowerNet-MIB::airIRG2RDT2StatusLeakSensor',
  airIRG2RDT2RunHours => '1.3.6.1.4.1.318.1.1.13.4.5.2.2',
  airIRG2RDT2RunHoursAirFilter => '1.3.6.1.4.1.318.1.1.13.4.5.2.2.1',
  airIRG2RDT2RunHoursCondensatePump => '1.3.6.1.4.1.318.1.1.13.4.5.2.2.2',
  airIRG2RDT2RunHoursCompressor => '1.3.6.1.4.1.318.1.1.13.4.5.2.2.3',
  airIRG2RDT2RunHoursFanPSTableSize => '1.3.6.1.4.1.318.1.1.13.4.5.2.2.4',
  airIRG2RDT2RunHoursFanPSTable => '1.3.6.1.4.1.318.1.1.13.4.5.2.2.5',
  airIRG2RDT2RunHoursFanPSEntry => '1.3.6.1.4.1.318.1.1.13.4.5.2.2.5.1',
  airIRG2RDT2RunHoursFanPSIndex => '1.3.6.1.4.1.318.1.1.13.4.5.2.2.5.1.1',
  airIRG2RDT2RunHoursFanPSHours => '1.3.6.1.4.1.318.1.1.13.4.5.2.2.5.1.2',
  airIRG2RDT2RunHoursFanPSPosition => '1.3.6.1.4.1.318.1.1.13.4.5.2.2.5.1.3',
  airIRG2RDT2RunHoursFanPSPositionDefinition => 'PowerNet-MIB::airIRG2RDT2RunHoursFanPSPosition',
  airIRG2RDT2RunHoursEvapFanTableSize => '1.3.6.1.4.1.318.1.1.13.4.5.2.2.6',
  airIRG2RDT2RunHoursEvapFanTable => '1.3.6.1.4.1.318.1.1.13.4.5.2.2.7',
  airIRG2RDT2RunHoursEvapFanEntry => '1.3.6.1.4.1.318.1.1.13.4.5.2.2.7.1',
  airIRG2RDT2RunHoursEvapFanIndex => '1.3.6.1.4.1.318.1.1.13.4.5.2.2.7.1.1',
  airIRG2RDT2RunHoursEvapFanHours => '1.3.6.1.4.1.318.1.1.13.4.5.2.2.7.1.2',
  airIRG2RDT2RunHoursUnit => '1.3.6.1.4.1.318.1.1.13.4.5.2.2.8',
  airIRG2RDT2ServiceIntervals => '1.3.6.1.4.1.318.1.1.13.4.5.2.3',
  airIRG2RDT2ServiceIntervalsAirFilter => '1.3.6.1.4.1.318.1.1.13.4.5.2.3.1',
  airIRG2RDT2ServiceIntervalsAirFilterAlarm => '1.3.6.1.4.1.318.1.1.13.4.5.2.3.2',
  airIRG2RDT2ServiceIntervalsAirFilterAlarmDefinition => 'PowerNet-MIB::airIRG2RDT2ServiceIntervalsAirFilterAlarm',
  airIRG2RDT2Thresholds => '1.3.6.1.4.1.318.1.1.13.4.5.2.4',
  airIRG2RDT2ThresholdsRackInletHighTempUS => '1.3.6.1.4.1.318.1.1.13.4.5.2.4.1',
  airIRG2RDT2ThresholdsRackInletHighTempMetric => '1.3.6.1.4.1.318.1.1.13.4.5.2.4.2',
  airIRG2RDT2ThresholdsSupplyAirHighTempUS => '1.3.6.1.4.1.318.1.1.13.4.5.2.4.3',
  airIRG2RDT2ThresholdsSupplyAirHighTempMetric => '1.3.6.1.4.1.318.1.1.13.4.5.2.4.4',
  airIRG2RDT2ThresholdsReturnAirHighTempUS => '1.3.6.1.4.1.318.1.1.13.4.5.2.4.5',
  airIRG2RDT2ThresholdsReturnAirHighTempMetric => '1.3.6.1.4.1.318.1.1.13.4.5.2.4.6',
  airIRG2RDT2Setpoints => '1.3.6.1.4.1.318.1.1.13.4.5.2.5',
  airIRG2RDT2Config => '1.3.6.1.4.1.318.1.1.13.4.5.2.6',
  airIRG2RDT2ConfigUnitType => '1.3.6.1.4.1.318.1.1.13.4.5.2.6.1',
  airIRG2RDT2ConfigUnitTypeDefinition => 'PowerNet-MIB::airIRG2RDT2ConfigUnitType',
  airIRG2RDT2ConfigStartupDelay => '1.3.6.1.4.1.318.1.1.13.4.5.2.6.2',
  airIRG2RDT2ConfigIdleOnLeakDetect => '1.3.6.1.4.1.318.1.1.13.4.5.2.6.3',
  airIRG2RDT2ConfigIdleOnLeakDetectDefinition => 'PowerNet-MIB::airIRG2RDT2ConfigIdleOnLeakDetect',
  airIRG2RDT2ConfigInputNormalState => '1.3.6.1.4.1.318.1.1.13.4.5.2.6.4',
  airIRG2RDT2ConfigInputNormalStateDefinition => 'PowerNet-MIB::AirIRG2RDType2IOState',
  airIRG2RDT2ConfigOutputNormalState => '1.3.6.1.4.1.318.1.1.13.4.5.2.6.5',
  airIRG2RDT2ConfigOutputNormalStateDefinition => 'PowerNet-MIB::AirIRG2RDType2IOState',
  airIRG2RDT2ConfigOutputSource => '1.3.6.1.4.1.318.1.1.13.4.5.2.6.6',
  airIRG2RDT2ConfigOutputSourceDefinition => 'PowerNet-MIB::airIRG2RDT2ConfigOutputSource',
  airIRG2RDT2ConfigOHEInputNormalState => '1.3.6.1.4.1.318.1.1.13.4.5.2.6.7',
  airIRG2RDT2ConfigOHEInputNormalStateDefinition => 'PowerNet-MIB::AirIRG2RDType2IOState',
  airIRG2RDT2ConfigUnitRoleOverride => '1.3.6.1.4.1.318.1.1.13.4.5.2.6.8',
  airIRG2RDT2ConfigUnitRoleOverrideDefinition => 'PowerNet-MIB::airIRG2RDT2ConfigUnitRoleOverride',
  airIRG2RDT2ConfigUnitIdleOnCoolFail => '1.3.6.1.4.1.318.1.1.13.4.5.2.6.9',
  airIRG2RDT2ConfigUnitIdleOnCoolFailDefinition => 'PowerNet-MIB::airIRG2RDT2ConfigUnitIdleOnCoolFail',
  airIRG2SC => '1.3.6.1.4.1.318.1.1.13.4.6',
  airIRG2RA => '1.3.6.1.4.1.318.1.1.13.4.7',
  airInRoom => '1.3.6.1.4.1.318.1.1.13.5',
  airIRmIdent => '1.3.6.1.4.1.318.1.1.13.5.1',
  airIRmIdentName => '1.3.6.1.4.1.318.1.1.13.5.1.1',
  airIRmIdentLocation => '1.3.6.1.4.1.318.1.1.13.5.1.2',
  airIRmIdentModelNumber => '1.3.6.1.4.1.318.1.1.13.5.1.3',
  airIRmIdentSerialNumber => '1.3.6.1.4.1.318.1.1.13.5.1.4',
  airIRmIdentFirmwareRevision => '1.3.6.1.4.1.318.1.1.13.5.1.5',
  airIRmIdentHardwareRevision => '1.3.6.1.4.1.318.1.1.13.5.1.6',
  airIRmIdentManufactureDate => '1.3.6.1.4.1.318.1.1.13.5.1.7',
  airIRmIdentSysOID => '1.3.6.1.4.1.318.1.1.13.5.1.8',
  airIRmAlarms => '1.3.6.1.4.1.318.1.1.13.5.2',
  airIRmAlarmsTableSize => '1.3.6.1.4.1.318.1.1.13.5.2.1',
  airIRmAlarmsTable => '1.3.6.1.4.1.318.1.1.13.5.2.2',
  airIRmAlarmsEntry => '1.3.6.1.4.1.318.1.1.13.5.2.2.1',
  airIRmAlarmsIndex => '1.3.6.1.4.1.318.1.1.13.5.2.2.1.1',
  airIRmAlarmsEventCode => '1.3.6.1.4.1.318.1.1.13.5.2.2.1.2',
  airIRmAlarmsDescription => '1.3.6.1.4.1.318.1.1.13.5.2.2.1.3',
  airIRmPerimeter => '1.3.6.1.4.1.318.1.1.13.5.3',
  airIRmPmCommon1 => '1.3.6.1.4.1.318.1.1.13.5.3.2',
  airIRmPmUnitType => '1.3.6.1.4.1.318.1.1.13.5.3.2.1',
  airIRmPmUnitTypeDefinition => 'PowerNet-MIB::airIRmPmUnitType',
  airIRmPmSwVersion => '1.3.6.1.4.1.318.1.1.13.5.3.2.3',
  airIRmPmBusAddress => '1.3.6.1.4.1.318.1.1.13.5.3.2.5',
  airIRmPmControllerType => '1.3.6.1.4.1.318.1.1.13.5.3.2.7',
  airIRmPmControllerTypeDefinition => 'PowerNet-MIB::airIRmPmControllerType',
  airIRmPmGeneralError => '1.3.6.1.4.1.318.1.1.13.5.3.2.8',
  airIRmPmGeneralErrorDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmErrorOnBus => '1.3.6.1.4.1.318.1.1.13.5.3.2.9',
  airIRmPmErrorOnBusDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmCommon2 => '1.3.6.1.4.1.318.1.1.13.5.3.3',
  airIRmPmPCStop => '1.3.6.1.4.1.318.1.1.13.5.3.3.1',
  airIRmPmPCStopDefinition => 'PowerNet-MIB::AirIRmStopState',
  airIRmPmRemoteStop => '1.3.6.1.4.1.318.1.1.13.5.3.3.2',
  airIRmPmRemoteStopDefinition => 'PowerNet-MIB::AirIRmStopState',
  airIRmPmLocalStop => '1.3.6.1.4.1.318.1.1.13.5.3.3.3',
  airIRmPmLocalStopDefinition => 'PowerNet-MIB::AirIRmStopState',
  airIRmPmTimerStop => '1.3.6.1.4.1.318.1.1.13.5.3.3.4',
  airIRmPmTimerStopDefinition => 'PowerNet-MIB::AirIRmStopState',
  airIRmPmSeqStop => '1.3.6.1.4.1.318.1.1.13.5.3.3.5',
  airIRmPmSeqStopDefinition => 'PowerNet-MIB::AirIRmStopState',
  airIRmPmRemoteUPS => '1.3.6.1.4.1.318.1.1.13.5.3.3.7',
  airIRmPmRemoteUPSDefinition => 'PowerNet-MIB::airIRmPmRemoteUPS',
  airIRmPmLocalUPS => '1.3.6.1.4.1.318.1.1.13.5.3.3.8',
  airIRmPmLocalUPSDefinition => 'PowerNet-MIB::AirIRmActivityState',
  airIRmPmCommonAlarm => '1.3.6.1.4.1.318.1.1.13.5.3.3.11',
  airIRmPmCommonAlarmDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmResetAllAlarms => '1.3.6.1.4.1.318.1.1.13.5.3.3.12',
  airIRmPmResetAllAlarmsDefinition => 'PowerNet-MIB::airIRmPmResetAllAlarms',
  airIRmPmUnitOnOff => '1.3.6.1.4.1.318.1.1.13.5.3.3.14',
  airIRmPmUnitOnOffDefinition => 'PowerNet-MIB::AirIRmControlState',
  airIRmPmMaintenance => '1.3.6.1.4.1.318.1.1.13.5.3.3.15',
  airIRmPmMaintenanceDefinition => 'PowerNet-MIB::airIRmPmMaintenance',
  airIRmPmUnitTemperatureScale => '1.3.6.1.4.1.318.1.1.13.5.3.3.23',
  airIRmPmUnitTemperatureScaleDefinition => 'PowerNet-MIB::airIRmPmUnitTemperatureScale',
  airIRmPmUnitWinterMode => '1.3.6.1.4.1.318.1.1.13.5.3.3.24',
  airIRmPmUnitWinterModeDefinition => 'PowerNet-MIB::airIRmPmUnitWinterMode',
  airIRmPmDayNightMode => '1.3.6.1.4.1.318.1.1.13.5.3.3.25',
  airIRmPmDayNightModeDefinition => 'PowerNet-MIB::airIRmPmDayNightMode',
  airIRmPmCommon3 => '1.3.6.1.4.1.318.1.1.13.5.3.4',
  airIRmPmLastMaintenanceYear => '1.3.6.1.4.1.318.1.1.13.5.3.4.1',
  airIRmPmLastMaintenanceMonth => '1.3.6.1.4.1.318.1.1.13.5.3.4.2',
  airIRmPmLastMaintenanceDay => '1.3.6.1.4.1.318.1.1.13.5.3.4.3',
  airIRmPmUnitMaintenanceInterval => '1.3.6.1.4.1.318.1.1.13.5.3.4.4',
  airIRmPmRuntimeUnit => '1.3.6.1.4.1.318.1.1.13.5.3.4.5',
  airIRmPmStoptimeUnit => '1.3.6.1.4.1.318.1.1.13.5.3.4.6',
  airIRmPmRuntimeCooling => '1.3.6.1.4.1.318.1.1.13.5.3.4.7',
  airIRmPmRuntimeHeating => '1.3.6.1.4.1.318.1.1.13.5.3.4.8',
  airIRmPmRuntimeHumidification => '1.3.6.1.4.1.318.1.1.13.5.3.4.9',
  airIRmPmRuntimeDehumidification => '1.3.6.1.4.1.318.1.1.13.5.3.4.10',
  airIRmPmUnitTemperature => '1.3.6.1.4.1.318.1.1.13.5.3.4.11',
  airIRmPmUnitTemperatureC => '1.3.6.1.4.1.318.1.1.13.5.3.4.11.1',
  airIRmPmUnitTemperatureF => '1.3.6.1.4.1.318.1.1.13.5.3.4.11.2',
  airIRmPmUnitHumidity => '1.3.6.1.4.1.318.1.1.13.5.3.4.12',
  airIRmPmSetpointTemperatureDay => '1.3.6.1.4.1.318.1.1.13.5.3.4.14',
  airIRmPmSetpointTemperatureDayC => '1.3.6.1.4.1.318.1.1.13.5.3.4.14.1',
  airIRmPmSetpointTemperatureDayF => '1.3.6.1.4.1.318.1.1.13.5.3.4.14.2',
  airIRmPmSetpointTemperatureNight => '1.3.6.1.4.1.318.1.1.13.5.3.4.15',
  airIRmPmSetpointTemperatureNightC => '1.3.6.1.4.1.318.1.1.13.5.3.4.15.1',
  airIRmPmSetpointTemperatureNightF => '1.3.6.1.4.1.318.1.1.13.5.3.4.15.2',
  airIRmPmSetpointHumidity => '1.3.6.1.4.1.318.1.1.13.5.3.4.17',
  airIRmPmUnitControlType => '1.3.6.1.4.1.318.1.1.13.5.3.4.24',
  airIRmPmUnitControlTypeDefinition => 'PowerNet-MIB::airIRmPmUnitControlType',
  airIRmPmWinterModeStartTemp => '1.3.6.1.4.1.318.1.1.13.5.3.4.29',
  airIRmPmWinterModeStartTempC => '1.3.6.1.4.1.318.1.1.13.5.3.4.29.1',
  airIRmPmWinterModeStartTempF => '1.3.6.1.4.1.318.1.1.13.5.3.4.29.2',
  airIRmPmWinterModeHysteresis => '1.3.6.1.4.1.318.1.1.13.5.3.4.30',
  airIRmPmWinterModeHysteresisK => '1.3.6.1.4.1.318.1.1.13.5.3.4.30.1',
  airIRmPmWinterModeHysteresisF => '1.3.6.1.4.1.318.1.1.13.5.3.4.30.2',
  airIRmPmWaterTemperature => '1.3.6.1.4.1.318.1.1.13.5.3.4.32',
  airIRmPmWaterTemperatureC => '1.3.6.1.4.1.318.1.1.13.5.3.4.32.1',
  airIRmPmWaterTemperatureF => '1.3.6.1.4.1.318.1.1.13.5.3.4.32.2',
  airIRmPmReturnAirTemperature => '1.3.6.1.4.1.318.1.1.13.5.3.4.33',
  airIRmPmReturnAirTemperatureC => '1.3.6.1.4.1.318.1.1.13.5.3.4.33.1',
  airIRmPmReturnAirTemperatureF => '1.3.6.1.4.1.318.1.1.13.5.3.4.33.2',
  airIRmPmSupplyAirTemperature => '1.3.6.1.4.1.318.1.1.13.5.3.4.34',
  airIRmPmSupplyAirTemperatureC => '1.3.6.1.4.1.318.1.1.13.5.3.4.34.1',
  airIRmPmSupplyAirTemperatureF => '1.3.6.1.4.1.318.1.1.13.5.3.4.34.2',
  airIRmPmReturnAirHumidity => '1.3.6.1.4.1.318.1.1.13.5.3.4.35',
  airIRmPmSupplyAirHumidity => '1.3.6.1.4.1.318.1.1.13.5.3.4.36',
  airIRmPmOutsideAirTemperature => '1.3.6.1.4.1.318.1.1.13.5.3.4.37',
  airIRmPmOutsideAirTemperatureC => '1.3.6.1.4.1.318.1.1.13.5.3.4.37.1',
  airIRmPmOutsideAirTemperatureF => '1.3.6.1.4.1.318.1.1.13.5.3.4.37.2',
  airIRmPmOutsideAirHumidity => '1.3.6.1.4.1.318.1.1.13.5.3.4.38',
  airIRmPmCoolingPriority => '1.3.6.1.4.1.318.1.1.13.5.3.4.39',
  airIRmPmCoolingPriorityDefinition => 'PowerNet-MIB::airIRmPmCoolingPriority',
  airIRmPmWaterTemperature2 => '1.3.6.1.4.1.318.1.1.13.5.3.4.43',
  airIRmPmWaterTemperature2C => '1.3.6.1.4.1.318.1.1.13.5.3.4.43.1',
  airIRmPmWaterTemperature2F => '1.3.6.1.4.1.318.1.1.13.5.3.4.43.2',
  airIRmPmRuntimeFreeCooling => '1.3.6.1.4.1.318.1.1.13.5.3.4.44',
  airIRmPmRuntimeMixedModeFreeCooling => '1.3.6.1.4.1.318.1.1.13.5.3.4.45',
  airIRmPmCommon4 => '1.3.6.1.4.1.318.1.1.13.5.3.5',
  airIRmPmNumberOfCompressors => '1.3.6.1.4.1.318.1.1.13.5.3.5.4',
  airIRmPmNumberOfSuctionValves => '1.3.6.1.4.1.318.1.1.13.5.3.5.5',
  airIRmPmNumberOfDryCoolers => '1.3.6.1.4.1.318.1.1.13.5.3.5.6',
  airIRmPmNumberOfPumps => '1.3.6.1.4.1.318.1.1.13.5.3.5.7',
  airIRmPmNumberOfElectricHeaters => '1.3.6.1.4.1.318.1.1.13.5.3.5.8',
  airIRmPmNumberOfHumidifiers => '1.3.6.1.4.1.318.1.1.13.5.3.5.9',
  airIRmPmNumberOfFans => '1.3.6.1.4.1.318.1.1.13.5.3.5.10',
  airIRmPmNumberOfLouvers => '1.3.6.1.4.1.318.1.1.13.5.3.5.11',
  airIRmPmNumberOfSensors => '1.3.6.1.4.1.318.1.1.13.5.3.5.12',
  airIRmPmNumberOfExternalAlarmInputs => '1.3.6.1.4.1.318.1.1.13.5.3.5.13',
  airIRmPmNumberOfGECWValves => '1.3.6.1.4.1.318.1.1.13.5.3.5.14',
  airIRmPmNumberOfHotGasReheat => '1.3.6.1.4.1.318.1.1.13.5.3.5.15',
  airIRmPmNumberOfPWWReheat => '1.3.6.1.4.1.318.1.1.13.5.3.5.16',
  airIRmPmNumberOfDehumidifiers => '1.3.6.1.4.1.318.1.1.13.5.3.5.17',
  airIRmPmCommon5 => '1.3.6.1.4.1.318.1.1.13.5.3.6',
  airIRmPmUnitEvaporationTemperature1 => '1.3.6.1.4.1.318.1.1.13.5.3.6.1',
  airIRmPmUnitEvaporationTemperature1C => '1.3.6.1.4.1.318.1.1.13.5.3.6.1.1',
  airIRmPmUnitEvaporationTemperature1F => '1.3.6.1.4.1.318.1.1.13.5.3.6.1.2',
  airIRmPmUnitEvaporationPressure1 => '1.3.6.1.4.1.318.1.1.13.5.3.6.2',
  airIRmPmUnitCondensationTemperature1 => '1.3.6.1.4.1.318.1.1.13.5.3.6.3',
  airIRmPmUnitCondensationTemperature1C => '1.3.6.1.4.1.318.1.1.13.5.3.6.3.1',
  airIRmPmUnitCondensationTemperature1F => '1.3.6.1.4.1.318.1.1.13.5.3.6.3.2',
  airIRmPmUnitCondensationPressure1 => '1.3.6.1.4.1.318.1.1.13.5.3.6.4',
  airIRmPmMaxLimitReturnAirTemperature => '1.3.6.1.4.1.318.1.1.13.5.3.6.8',
  airIRmPmMaxLimitReturnAirTemperatureC => '1.3.6.1.4.1.318.1.1.13.5.3.6.8.1',
  airIRmPmMaxLimitReturnAirTemperatureF => '1.3.6.1.4.1.318.1.1.13.5.3.6.8.2',
  airIRmPmMinLimitReturnAirTemperature => '1.3.6.1.4.1.318.1.1.13.5.3.6.9',
  airIRmPmMinLimitReturnAirTemperatureC => '1.3.6.1.4.1.318.1.1.13.5.3.6.9.1',
  airIRmPmMinLimitReturnAirTemperatureF => '1.3.6.1.4.1.318.1.1.13.5.3.6.9.2',
  airIRmPmMaxLimitSupplyAirTemperature => '1.3.6.1.4.1.318.1.1.13.5.3.6.10',
  airIRmPmMaxLimitSupplyAirTemperatureC => '1.3.6.1.4.1.318.1.1.13.5.3.6.10.1',
  airIRmPmMaxLimitSupplyAirTemperatureF => '1.3.6.1.4.1.318.1.1.13.5.3.6.10.2',
  airIRmPmMinLimitSupplyAirTemperature => '1.3.6.1.4.1.318.1.1.13.5.3.6.11',
  airIRmPmMinLimitSupplyAirTemperatureC => '1.3.6.1.4.1.318.1.1.13.5.3.6.11.1',
  airIRmPmMinLimitSupplyAirTemperatureF => '1.3.6.1.4.1.318.1.1.13.5.3.6.11.2',
  airIRmPmMaxLimitWaterTemperature => '1.3.6.1.4.1.318.1.1.13.5.3.6.12',
  airIRmPmMaxLimitWaterTemperatureC => '1.3.6.1.4.1.318.1.1.13.5.3.6.12.1',
  airIRmPmMaxLimitWaterTemperatureF => '1.3.6.1.4.1.318.1.1.13.5.3.6.12.2',
  airIRmPmMinLimitWaterTemperature => '1.3.6.1.4.1.318.1.1.13.5.3.6.13',
  airIRmPmMinLimitWaterTemperatureC => '1.3.6.1.4.1.318.1.1.13.5.3.6.13.1',
  airIRmPmMinLimitWaterTemperatureF => '1.3.6.1.4.1.318.1.1.13.5.3.6.13.2',
  airIRmPmMaxLimitReturnAirHumidity => '1.3.6.1.4.1.318.1.1.13.5.3.6.14',
  airIRmPmMinLimitReturnAirHumidity => '1.3.6.1.4.1.318.1.1.13.5.3.6.15',
  airIRmPmMaxLimitSupplyAirHumidity => '1.3.6.1.4.1.318.1.1.13.5.3.6.16',
  airIRmPmMinLimitSupplyAirHumidity => '1.3.6.1.4.1.318.1.1.13.5.3.6.17',
  airIRmPmLowPressureWinterDelay => '1.3.6.1.4.1.318.1.1.13.5.3.6.18',
  airIRmPmUnitCondensationPressure2 => '1.3.6.1.4.1.318.1.1.13.5.3.6.19',
  airIRmPmUnitOverloadSwitch => '1.3.6.1.4.1.318.1.1.13.5.3.6.20',
  airIRmPmUnitCondensationTemperature2 => '1.3.6.1.4.1.318.1.1.13.5.3.6.41',
  airIRmPmUnitCondensationTemperature2C => '1.3.6.1.4.1.318.1.1.13.5.3.6.41.1',
  airIRmPmUnitCondensationTemperature2F => '1.3.6.1.4.1.318.1.1.13.5.3.6.41.2',
  airIRmPmUnitEvaporationPressure2 => '1.3.6.1.4.1.318.1.1.13.5.3.6.42',
  airIRmPmUnitEvaporationTemperature2 => '1.3.6.1.4.1.318.1.1.13.5.3.6.43',
  airIRmPmUnitEvaporationTemperature2C => '1.3.6.1.4.1.318.1.1.13.5.3.6.43.1',
  airIRmPmUnitEvaporationTemperature2F => '1.3.6.1.4.1.318.1.1.13.5.3.6.43.2',
  airIRmPmCompressor1 => '1.3.6.1.4.1.318.1.1.13.5.3.7',
  airIRmPmCmp1ManOperationActive => '1.3.6.1.4.1.318.1.1.13.5.3.7.2',
  airIRmPmCmp1ManOperationActiveDefinition => 'PowerNet-MIB::airIRmPmCmp1ManOperationActive',
  airIRmPmCmp1ManOperationState => '1.3.6.1.4.1.318.1.1.13.5.3.7.3',
  airIRmPmCmp1ManOperationStateDefinition => 'PowerNet-MIB::AirIRmControlState',
  airIRmPmCmp1Running => '1.3.6.1.4.1.318.1.1.13.5.3.7.4',
  airIRmPmCmp1RunningDefinition => 'PowerNet-MIB::AirIRmActivityState',
  airIRmPmCmp1StartTempSummer => '1.3.6.1.4.1.318.1.1.13.5.3.7.17',
  airIRmPmCmp1StartTempSummerK => '1.3.6.1.4.1.318.1.1.13.5.3.7.17.1',
  airIRmPmCmp1StartTempSummerF => '1.3.6.1.4.1.318.1.1.13.5.3.7.17.2',
  airIRmPmCmp1HysteresisSummer => '1.3.6.1.4.1.318.1.1.13.5.3.7.18',
  airIRmPmCmp1HysteresisSummerK => '1.3.6.1.4.1.318.1.1.13.5.3.7.18.1',
  airIRmPmCmp1HysteresisSummerF => '1.3.6.1.4.1.318.1.1.13.5.3.7.18.2',
  airIRmPmCmp1StartTempWinter => '1.3.6.1.4.1.318.1.1.13.5.3.7.19',
  airIRmPmCmp1StartTempWinterK => '1.3.6.1.4.1.318.1.1.13.5.3.7.19.1',
  airIRmPmCmp1StartTempWinterF => '1.3.6.1.4.1.318.1.1.13.5.3.7.19.2',
  airIRmPmCmp1HysteresisWinter => '1.3.6.1.4.1.318.1.1.13.5.3.7.20',
  airIRmPmCmp1HysteresisWinterK => '1.3.6.1.4.1.318.1.1.13.5.3.7.20.1',
  airIRmPmCmp1HysteresisWinterF => '1.3.6.1.4.1.318.1.1.13.5.3.7.20.2',
  airIRmPmCmp1Runtime => '1.3.6.1.4.1.318.1.1.13.5.3.7.29',
  airIRmPmCompressor2 => '1.3.6.1.4.1.318.1.1.13.5.3.8',
  airIRmPmCmp2ManOperationActive => '1.3.6.1.4.1.318.1.1.13.5.3.8.2',
  airIRmPmCmp2ManOperationActiveDefinition => 'PowerNet-MIB::airIRmPmCmp2ManOperationActive',
  airIRmPmCmp2ManOperationState => '1.3.6.1.4.1.318.1.1.13.5.3.8.3',
  airIRmPmCmp2ManOperationStateDefinition => 'PowerNet-MIB::AirIRmControlState',
  airIRmPmCmp2Running => '1.3.6.1.4.1.318.1.1.13.5.3.8.4',
  airIRmPmCmp2RunningDefinition => 'PowerNet-MIB::AirIRmActivityState',
  airIRmPmCmp2StartTempSummer => '1.3.6.1.4.1.318.1.1.13.5.3.8.17',
  airIRmPmCmp2StartTempSummerK => '1.3.6.1.4.1.318.1.1.13.5.3.8.17.1',
  airIRmPmCmp2StartTempSummerF => '1.3.6.1.4.1.318.1.1.13.5.3.8.17.2',
  airIRmPmCmp2HysteresisSummer => '1.3.6.1.4.1.318.1.1.13.5.3.8.18',
  airIRmPmCmp2HysteresisSummerK => '1.3.6.1.4.1.318.1.1.13.5.3.8.18.1',
  airIRmPmCmp2HysteresisSummerF => '1.3.6.1.4.1.318.1.1.13.5.3.8.18.2',
  airIRmPmCmp2StartTempWinter => '1.3.6.1.4.1.318.1.1.13.5.3.8.19',
  airIRmPmCmp2StartTempWinterK => '1.3.6.1.4.1.318.1.1.13.5.3.8.19.1',
  airIRmPmCmp2StartTempWinterF => '1.3.6.1.4.1.318.1.1.13.5.3.8.19.2',
  airIRmPmCmp2HysteresisWinter => '1.3.6.1.4.1.318.1.1.13.5.3.8.20',
  airIRmPmCmp2HysteresisWinterK => '1.3.6.1.4.1.318.1.1.13.5.3.8.20.1',
  airIRmPmCmp2HysteresisWinterF => '1.3.6.1.4.1.318.1.1.13.5.3.8.20.2',
  airIRmPmCmp2Runtime => '1.3.6.1.4.1.318.1.1.13.5.3.8.29',
  airIRmPmSuctionValve1 => '1.3.6.1.4.1.318.1.1.13.5.3.9',
  airIRmPmSuctionValve2 => '1.3.6.1.4.1.318.1.1.13.5.3.10',
  airIRmPmEheating1 => '1.3.6.1.4.1.318.1.1.13.5.3.11',
  airIRmPmEheating1ManOpEnable => '1.3.6.1.4.1.318.1.1.13.5.3.11.2',
  airIRmPmEheating1ManOpEnableDefinition => 'PowerNet-MIB::AirIRmActivityState',
  airIRmPmEheating1Running => '1.3.6.1.4.1.318.1.1.13.5.3.11.4',
  airIRmPmEheating1RunningDefinition => 'PowerNet-MIB::AirIRmControlState',
  airIRmPmEheating1ManOpRunning => '1.3.6.1.4.1.318.1.1.13.5.3.11.5',
  airIRmPmEheating1ManOpRunningDefinition => 'PowerNet-MIB::AirIRmActivityState',
  airIRmPmEheating1Type => '1.3.6.1.4.1.318.1.1.13.5.3.11.9',
  airIRmPmEheating1TypeDefinition => 'PowerNet-MIB::airIRmPmEheating1Type',
  airIRmPmEheating1StartTemperature => '1.3.6.1.4.1.318.1.1.13.5.3.11.10',
  airIRmPmEheating1StartTemperatureK => '1.3.6.1.4.1.318.1.1.13.5.3.11.10.1',
  airIRmPmEheating1StartTemperatureF => '1.3.6.1.4.1.318.1.1.13.5.3.11.10.2',
  airIRmPmEheating1Hysteresis => '1.3.6.1.4.1.318.1.1.13.5.3.11.11',
  airIRmPmEheating1HysteresisK => '1.3.6.1.4.1.318.1.1.13.5.3.11.11.1',
  airIRmPmEheating1HysteresisF => '1.3.6.1.4.1.318.1.1.13.5.3.11.11.2',
  airIRmPmEheating1Runtime => '1.3.6.1.4.1.318.1.1.13.5.3.11.17',
  airIRmPmEheating2 => '1.3.6.1.4.1.318.1.1.13.5.3.12',
  airIRmPmEheating2ManOpEnable => '1.3.6.1.4.1.318.1.1.13.5.3.12.2',
  airIRmPmEheating2ManOpEnableDefinition => 'PowerNet-MIB::AirIRmActivityState',
  airIRmPmEheating2Running => '1.3.6.1.4.1.318.1.1.13.5.3.12.4',
  airIRmPmEheating2RunningDefinition => 'PowerNet-MIB::AirIRmControlState',
  airIRmPmEheating2ManOpRunning => '1.3.6.1.4.1.318.1.1.13.5.3.12.5',
  airIRmPmEheating2ManOpRunningDefinition => 'PowerNet-MIB::AirIRmActivityState',
  airIRmPmEheating2Type => '1.3.6.1.4.1.318.1.1.13.5.3.12.9',
  airIRmPmEheating2TypeDefinition => 'PowerNet-MIB::airIRmPmEheating2Type',
  airIRmPmEheating2StartTemperature => '1.3.6.1.4.1.318.1.1.13.5.3.12.10',
  airIRmPmEheating2StartTemperatureK => '1.3.6.1.4.1.318.1.1.13.5.3.12.10.1',
  airIRmPmEheating2StartTemperatureF => '1.3.6.1.4.1.318.1.1.13.5.3.12.10.2',
  airIRmPmEheating2Hysteresis => '1.3.6.1.4.1.318.1.1.13.5.3.12.11',
  airIRmPmEheating2HysteresisK => '1.3.6.1.4.1.318.1.1.13.5.3.12.11.1',
  airIRmPmEheating2HysteresisF => '1.3.6.1.4.1.318.1.1.13.5.3.12.11.2',
  airIRmPmEheating2Runtime => '1.3.6.1.4.1.318.1.1.13.5.3.12.17',
  airIRmPmEheating3 => '1.3.6.1.4.1.318.1.1.13.5.3.13',
  airIRmPmEheating3ManOpEnable => '1.3.6.1.4.1.318.1.1.13.5.3.13.2',
  airIRmPmEheating3ManOpEnableDefinition => 'PowerNet-MIB::AirIRmActivityState',
  airIRmPmEheating3Running => '1.3.6.1.4.1.318.1.1.13.5.3.13.4',
  airIRmPmEheating3RunningDefinition => 'PowerNet-MIB::AirIRmControlState',
  airIRmPmEheating3ManOpRunning => '1.3.6.1.4.1.318.1.1.13.5.3.13.5',
  airIRmPmEheating3ManOpRunningDefinition => 'PowerNet-MIB::AirIRmActivityState',
  airIRmPmEheating3Type => '1.3.6.1.4.1.318.1.1.13.5.3.13.9',
  airIRmPmEheating3TypeDefinition => 'PowerNet-MIB::airIRmPmEheating3Type',
  airIRmPmEheating3StartTemperature => '1.3.6.1.4.1.318.1.1.13.5.3.13.10',
  airIRmPmEheating3StartTemperatureK => '1.3.6.1.4.1.318.1.1.13.5.3.13.10.1',
  airIRmPmEheating3StartTemperatureF => '1.3.6.1.4.1.318.1.1.13.5.3.13.10.2',
  airIRmPmEheating3Hysteresis => '1.3.6.1.4.1.318.1.1.13.5.3.13.11',
  airIRmPmEheating3HysteresisK => '1.3.6.1.4.1.318.1.1.13.5.3.13.11.1',
  airIRmPmEheating3HysteresisF => '1.3.6.1.4.1.318.1.1.13.5.3.13.11.2',
  airIRmPmEheating3Runtime => '1.3.6.1.4.1.318.1.1.13.5.3.13.17',
  airIRmPmEheating4 => '1.3.6.1.4.1.318.1.1.13.5.3.14',
  airIRmPmEheating4ManOpEnable => '1.3.6.1.4.1.318.1.1.13.5.3.14.2',
  airIRmPmEheating4ManOpEnableDefinition => 'PowerNet-MIB::AirIRmActivityState',
  airIRmPmEheating4Running => '1.3.6.1.4.1.318.1.1.13.5.3.14.4',
  airIRmPmEheating4RunningDefinition => 'PowerNet-MIB::AirIRmControlState',
  airIRmPmEheating4ManOpRunning => '1.3.6.1.4.1.318.1.1.13.5.3.14.5',
  airIRmPmEheating4ManOpRunningDefinition => 'PowerNet-MIB::AirIRmActivityState',
  airIRmPmEheating4Type => '1.3.6.1.4.1.318.1.1.13.5.3.14.9',
  airIRmPmEheating4TypeDefinition => 'PowerNet-MIB::airIRmPmEheating4Type',
  airIRmPmEheating4StartTemperature => '1.3.6.1.4.1.318.1.1.13.5.3.14.10',
  airIRmPmEheating4StartTemperatureK => '1.3.6.1.4.1.318.1.1.13.5.3.14.10.1',
  airIRmPmEheating4StartTemperatureF => '1.3.6.1.4.1.318.1.1.13.5.3.14.10.2',
  airIRmPmEheating4Hysteresis => '1.3.6.1.4.1.318.1.1.13.5.3.14.11',
  airIRmPmEheating4HysteresisK => '1.3.6.1.4.1.318.1.1.13.5.3.14.11.1',
  airIRmPmEheating4HysteresisF => '1.3.6.1.4.1.318.1.1.13.5.3.14.11.2',
  airIRmPmEheating4Runtime => '1.3.6.1.4.1.318.1.1.13.5.3.14.17',
  airIRmPmGECWvalve => '1.3.6.1.4.1.318.1.1.13.5.3.15',
  airIRmPmGECWvalveManOpEnable => '1.3.6.1.4.1.318.1.1.13.5.3.15.2',
  airIRmPmGECWvalveStartTemperature => '1.3.6.1.4.1.318.1.1.13.5.3.15.9',
  airIRmPmGECWvalveStartTemperatureK => '1.3.6.1.4.1.318.1.1.13.5.3.15.9.1',
  airIRmPmGECWvalveStartTemperatureF => '1.3.6.1.4.1.318.1.1.13.5.3.15.9.2',
  airIRmPmGECWvalveLinearRange => '1.3.6.1.4.1.318.1.1.13.5.3.15.10',
  airIRmPmGECWvalveLinearRangeK => '1.3.6.1.4.1.318.1.1.13.5.3.15.10.1',
  airIRmPmGECWvalveLinearRangeF => '1.3.6.1.4.1.318.1.1.13.5.3.15.10.2',
  airIRmPmGECWvalveGEOffTemp => '1.3.6.1.4.1.318.1.1.13.5.3.15.12',
  airIRmPmGECWvalveGEOffTempC => '1.3.6.1.4.1.318.1.1.13.5.3.15.12.1',
  airIRmPmGECWvalveGEOffTempF => '1.3.6.1.4.1.318.1.1.13.5.3.15.12.2',
  airIRmPmGECWvalveOpeningGrade => '1.3.6.1.4.1.318.1.1.13.5.3.15.15',
  airIRmPmGECWvalveManOpOpeningGrade => '1.3.6.1.4.1.318.1.1.13.5.3.15.16',
  airIRmPmGvalve => '1.3.6.1.4.1.318.1.1.13.5.3.16',
  airIRmPmGvalveManOperationEnable => '1.3.6.1.4.1.318.1.1.13.5.3.16.2',
  airIRmPmGvalveManOperationEnableDefinition => 'PowerNet-MIB::AirIRmActivityState',
  airIRmPmGvalvePreOpeningTime => '1.3.6.1.4.1.318.1.1.13.5.3.16.11',
  airIRmPmGvalvePreOpeningGrade => '1.3.6.1.4.1.318.1.1.13.5.3.16.12',
  airIRmPmGvalveOpeningGrade => '1.3.6.1.4.1.318.1.1.13.5.3.16.13',
  airIRmPmGvalveManOpOpeningGrade => '1.3.6.1.4.1.318.1.1.13.5.3.16.14',
  airIRmPmDrycooler1 => '1.3.6.1.4.1.318.1.1.13.5.3.17',
  airIRmPmDrycooler1ManOpEnable => '1.3.6.1.4.1.318.1.1.13.5.3.17.2',
  airIRmPmDrycooler1ManOpEnableDefinition => 'PowerNet-MIB::AirIRmActivityState',
  airIRmPmDrycooler1Running => '1.3.6.1.4.1.318.1.1.13.5.3.17.3',
  airIRmPmDrycooler1RunningDefinition => 'PowerNet-MIB::AirIRmActivityState',
  airIRmPmDrycooler1ManOpRunning => '1.3.6.1.4.1.318.1.1.13.5.3.17.5',
  airIRmPmDrycooler1ManOpRunningDefinition => 'PowerNet-MIB::AirIRmActivityState',
  airIRmPmDrycooler1WinterStartTemp => '1.3.6.1.4.1.318.1.1.13.5.3.17.9',
  airIRmPmDrycooler1WinterStartTempC => '1.3.6.1.4.1.318.1.1.13.5.3.17.9.1',
  airIRmPmDrycooler1WinterStartTempF => '1.3.6.1.4.1.318.1.1.13.5.3.17.9.2',
  airIRmPmDrycooler1SummerStartTemp => '1.3.6.1.4.1.318.1.1.13.5.3.17.10',
  airIRmPmDrycooler1SummerStartTempC => '1.3.6.1.4.1.318.1.1.13.5.3.17.10.1',
  airIRmPmDrycooler1SummerStartTempF => '1.3.6.1.4.1.318.1.1.13.5.3.17.10.2',
  airIRmPmDrycooler1Hysteresis => '1.3.6.1.4.1.318.1.1.13.5.3.17.11',
  airIRmPmDrycooler1HysteresisK => '1.3.6.1.4.1.318.1.1.13.5.3.17.11.1',
  airIRmPmDrycooler1HysteresisF => '1.3.6.1.4.1.318.1.1.13.5.3.17.11.2',
  airIRmPmDrycooler1Runtime => '1.3.6.1.4.1.318.1.1.13.5.3.17.16',
  airIRmPmDrycooler2 => '1.3.6.1.4.1.318.1.1.13.5.3.18',
  airIRmPmDrycooler2ManOpEnable => '1.3.6.1.4.1.318.1.1.13.5.3.18.2',
  airIRmPmDrycooler2ManOpEnableDefinition => 'PowerNet-MIB::AirIRmActivityState',
  airIRmPmDrycooler2Running => '1.3.6.1.4.1.318.1.1.13.5.3.18.3',
  airIRmPmDrycooler2RunningDefinition => 'PowerNet-MIB::AirIRmActivityState',
  airIRmPmDrycooler2ManOpRunning => '1.3.6.1.4.1.318.1.1.13.5.3.18.5',
  airIRmPmDrycooler2ManOpRunningDefinition => 'PowerNet-MIB::AirIRmActivityState',
  airIRmPmDrycooler2WinterStartTemp => '1.3.6.1.4.1.318.1.1.13.5.3.18.9',
  airIRmPmDrycooler2WinterStartTempC => '1.3.6.1.4.1.318.1.1.13.5.3.18.9.1',
  airIRmPmDrycooler2WinterStartTempF => '1.3.6.1.4.1.318.1.1.13.5.3.18.9.2',
  airIRmPmDrycooler2SummerStartTemp => '1.3.6.1.4.1.318.1.1.13.5.3.18.10',
  airIRmPmDrycooler2SummerStartTempC => '1.3.6.1.4.1.318.1.1.13.5.3.18.10.1',
  airIRmPmDrycooler2SummerStartTempF => '1.3.6.1.4.1.318.1.1.13.5.3.18.10.2',
  airIRmPmDrycooler2Hysteresis => '1.3.6.1.4.1.318.1.1.13.5.3.18.11',
  airIRmPmDrycooler2HysteresisK => '1.3.6.1.4.1.318.1.1.13.5.3.18.11.1',
  airIRmPmDrycooler2HysteresisF => '1.3.6.1.4.1.318.1.1.13.5.3.18.11.2',
  airIRmPmDrycooler2Runtime => '1.3.6.1.4.1.318.1.1.13.5.3.18.16',
  airIRmPmDrycooler3 => '1.3.6.1.4.1.318.1.1.13.5.3.19',
  airIRmPmDrycooler3ManOpEnable => '1.3.6.1.4.1.318.1.1.13.5.3.19.2',
  airIRmPmDrycooler3ManOpEnableDefinition => 'PowerNet-MIB::AirIRmActivityState',
  airIRmPmDrycooler3Running => '1.3.6.1.4.1.318.1.1.13.5.3.19.3',
  airIRmPmDrycooler3RunningDefinition => 'PowerNet-MIB::AirIRmActivityState',
  airIRmPmDrycooler3ManOpRunning => '1.3.6.1.4.1.318.1.1.13.5.3.19.5',
  airIRmPmDrycooler3ManOpRunningDefinition => 'PowerNet-MIB::AirIRmActivityState',
  airIRmPmDrycooler3WinterStartTemp => '1.3.6.1.4.1.318.1.1.13.5.3.19.9',
  airIRmPmDrycooler3WinterStartTempC => '1.3.6.1.4.1.318.1.1.13.5.3.19.9.1',
  airIRmPmDrycooler3WinterStartTempF => '1.3.6.1.4.1.318.1.1.13.5.3.19.9.2',
  airIRmPmDrycooler3SummerStartTemp => '1.3.6.1.4.1.318.1.1.13.5.3.19.10',
  airIRmPmDrycooler3SummerStartTempC => '1.3.6.1.4.1.318.1.1.13.5.3.19.10.1',
  airIRmPmDrycooler3SummerStartTempF => '1.3.6.1.4.1.318.1.1.13.5.3.19.10.2',
  airIRmPmDrycooler3Hysteresis => '1.3.6.1.4.1.318.1.1.13.5.3.19.11',
  airIRmPmDrycooler3HysteresisK => '1.3.6.1.4.1.318.1.1.13.5.3.19.11.1',
  airIRmPmDrycooler3HysteresisF => '1.3.6.1.4.1.318.1.1.13.5.3.19.11.2',
  airIRmPmDrycooler3Runtime => '1.3.6.1.4.1.318.1.1.13.5.3.19.16',
  airIRmPmDrycooler4 => '1.3.6.1.4.1.318.1.1.13.5.3.20',
  airIRmPmDrycooler4ManOpEnable => '1.3.6.1.4.1.318.1.1.13.5.3.20.2',
  airIRmPmDrycooler4ManOpEnableDefinition => 'PowerNet-MIB::AirIRmActivityState',
  airIRmPmDrycooler4Running => '1.3.6.1.4.1.318.1.1.13.5.3.20.3',
  airIRmPmDrycooler4RunningDefinition => 'PowerNet-MIB::AirIRmActivityState',
  airIRmPmDrycooler4ManOpRunning => '1.3.6.1.4.1.318.1.1.13.5.3.20.5',
  airIRmPmDrycooler4ManOpRunningDefinition => 'PowerNet-MIB::AirIRmActivityState',
  airIRmPmDrycooler4WinterStartTemp => '1.3.6.1.4.1.318.1.1.13.5.3.20.9',
  airIRmPmDrycooler4WinterStartTempC => '1.3.6.1.4.1.318.1.1.13.5.3.20.9.1',
  airIRmPmDrycooler4WinterStartTempF => '1.3.6.1.4.1.318.1.1.13.5.3.20.9.2',
  airIRmPmDrycooler4SummerStartTemp => '1.3.6.1.4.1.318.1.1.13.5.3.20.10',
  airIRmPmDrycooler4SummerStartTempC => '1.3.6.1.4.1.318.1.1.13.5.3.20.10.1',
  airIRmPmDrycooler4SummerStartTempF => '1.3.6.1.4.1.318.1.1.13.5.3.20.10.2',
  airIRmPmDrycooler4Hysteresis => '1.3.6.1.4.1.318.1.1.13.5.3.20.11',
  airIRmPmDrycooler4HysteresisK => '1.3.6.1.4.1.318.1.1.13.5.3.20.11.1',
  airIRmPmDrycooler4HysteresisF => '1.3.6.1.4.1.318.1.1.13.5.3.20.11.2',
  airIRmPmDrycooler4Runtime => '1.3.6.1.4.1.318.1.1.13.5.3.20.16',
  airIRmPmPump1 => '1.3.6.1.4.1.318.1.1.13.5.3.21',
  airIRmPmPump1ManOpEnable => '1.3.6.1.4.1.318.1.1.13.5.3.21.2',
  airIRmPmPump1ManOpEnableDefinition => 'PowerNet-MIB::AirIRmActivityState',
  airIRmPmPump1Running => '1.3.6.1.4.1.318.1.1.13.5.3.21.3',
  airIRmPmPump1RunningDefinition => 'PowerNet-MIB::AirIRmActivityState',
  airIRmPmPump1ManOpRunning => '1.3.6.1.4.1.318.1.1.13.5.3.21.6',
  airIRmPmPump1ManOpRunningDefinition => 'PowerNet-MIB::AirIRmActivityState',
  airIRmPmPump1StartTemperature => '1.3.6.1.4.1.318.1.1.13.5.3.21.10',
  airIRmPmPump1StartTemperatureK => '1.3.6.1.4.1.318.1.1.13.5.3.21.10.1',
  airIRmPmPump1StartTemperatureF => '1.3.6.1.4.1.318.1.1.13.5.3.21.10.2',
  airIRmPmPump1Hysteresis => '1.3.6.1.4.1.318.1.1.13.5.3.21.11',
  airIRmPmPump1HysteresisK => '1.3.6.1.4.1.318.1.1.13.5.3.21.11.1',
  airIRmPmPump1HysteresisF => '1.3.6.1.4.1.318.1.1.13.5.3.21.11.2',
  airIRmPmPump1LinearRange => '1.3.6.1.4.1.318.1.1.13.5.3.21.12',
  airIRmPmPump1LinearRangeK => '1.3.6.1.4.1.318.1.1.13.5.3.21.12.1',
  airIRmPmPump1LinearRangeF => '1.3.6.1.4.1.318.1.1.13.5.3.21.12.2',
  airIRmPmPump1PressureSetpoint => '1.3.6.1.4.1.318.1.1.13.5.3.21.13',
  airIRmPmPump1Runtime => '1.3.6.1.4.1.318.1.1.13.5.3.21.21',
  airIRmPmPump1Speed => '1.3.6.1.4.1.318.1.1.13.5.3.21.22',
  airIRmPmPump1ControlCycle => '1.3.6.1.4.1.318.1.1.13.5.3.21.28',
  airIRmPmPump1MaxAdjust => '1.3.6.1.4.1.318.1.1.13.5.3.21.29',
  airIRmPmPump1ControlFactor => '1.3.6.1.4.1.318.1.1.13.5.3.21.30',
  airIRmPmPump2 => '1.3.6.1.4.1.318.1.1.13.5.3.22',
  airIRmPmPump2ManOpEnable => '1.3.6.1.4.1.318.1.1.13.5.3.22.2',
  airIRmPmPump2ManOpEnableDefinition => 'PowerNet-MIB::AirIRmActivityState',
  airIRmPmPump2Running => '1.3.6.1.4.1.318.1.1.13.5.3.22.3',
  airIRmPmPump2RunningDefinition => 'PowerNet-MIB::AirIRmActivityState',
  airIRmPmPump2ManOpRunning => '1.3.6.1.4.1.318.1.1.13.5.3.22.6',
  airIRmPmPump2ManOpRunningDefinition => 'PowerNet-MIB::AirIRmActivityState',
  airIRmPmPump2StartTemperature => '1.3.6.1.4.1.318.1.1.13.5.3.22.10',
  airIRmPmPump2StartTemperatureK => '1.3.6.1.4.1.318.1.1.13.5.3.22.10.1',
  airIRmPmPump2StartTemperatureF => '1.3.6.1.4.1.318.1.1.13.5.3.22.10.2',
  airIRmPmPump2Hysteresis => '1.3.6.1.4.1.318.1.1.13.5.3.22.11',
  airIRmPmPump2HysteresisK => '1.3.6.1.4.1.318.1.1.13.5.3.22.11.1',
  airIRmPmPump2HysteresisF => '1.3.6.1.4.1.318.1.1.13.5.3.22.11.2',
  airIRmPmPump2LinearRange => '1.3.6.1.4.1.318.1.1.13.5.3.22.12',
  airIRmPmPump2LinearRangeK => '1.3.6.1.4.1.318.1.1.13.5.3.22.12.1',
  airIRmPmPump2LinearRangeF => '1.3.6.1.4.1.318.1.1.13.5.3.22.12.2',
  airIRmPmPump2PressureSetpoint => '1.3.6.1.4.1.318.1.1.13.5.3.22.13',
  airIRmPmPump2Runtime => '1.3.6.1.4.1.318.1.1.13.5.3.22.21',
  airIRmPmPump2Speed => '1.3.6.1.4.1.318.1.1.13.5.3.22.22',
  airIRmPmPump2ControlCycle => '1.3.6.1.4.1.318.1.1.13.5.3.22.28',
  airIRmPmPump2MaxAdjust => '1.3.6.1.4.1.318.1.1.13.5.3.22.29',
  airIRmPmPump2ControlFactor => '1.3.6.1.4.1.318.1.1.13.5.3.22.30',
  airIRmPmPump3 => '1.3.6.1.4.1.318.1.1.13.5.3.23',
  airIRmPmPump3ManOpEnable => '1.3.6.1.4.1.318.1.1.13.5.3.23.2',
  airIRmPmPump3ManOpEnableDefinition => 'PowerNet-MIB::AirIRmActivityState',
  airIRmPmPump3Running => '1.3.6.1.4.1.318.1.1.13.5.3.23.3',
  airIRmPmPump3RunningDefinition => 'PowerNet-MIB::AirIRmActivityState',
  airIRmPmPump3ManOpRunning => '1.3.6.1.4.1.318.1.1.13.5.3.23.6',
  airIRmPmPump3ManOpRunningDefinition => 'PowerNet-MIB::AirIRmActivityState',
  airIRmPmPump3StartTemperature => '1.3.6.1.4.1.318.1.1.13.5.3.23.10',
  airIRmPmPump3StartTemperatureK => '1.3.6.1.4.1.318.1.1.13.5.3.23.10.1',
  airIRmPmPump3StartTemperatureF => '1.3.6.1.4.1.318.1.1.13.5.3.23.10.2',
  airIRmPmPump3Hysteresis => '1.3.6.1.4.1.318.1.1.13.5.3.23.11',
  airIRmPmPump3HysteresisK => '1.3.6.1.4.1.318.1.1.13.5.3.23.11.1',
  airIRmPmPump3HysteresisF => '1.3.6.1.4.1.318.1.1.13.5.3.23.11.2',
  airIRmPmPump3LinearRange => '1.3.6.1.4.1.318.1.1.13.5.3.23.12',
  airIRmPmPump3LinearRangeK => '1.3.6.1.4.1.318.1.1.13.5.3.23.12.1',
  airIRmPmPump3LinearRangeF => '1.3.6.1.4.1.318.1.1.13.5.3.23.12.2',
  airIRmPmPump3PressureSetpoint => '1.3.6.1.4.1.318.1.1.13.5.3.23.13',
  airIRmPmPump3Runtime => '1.3.6.1.4.1.318.1.1.13.5.3.23.21',
  airIRmPmPump3Speed => '1.3.6.1.4.1.318.1.1.13.5.3.23.22',
  airIRmPmPump3ControlCycle => '1.3.6.1.4.1.318.1.1.13.5.3.23.28',
  airIRmPmPump3MaxAdjust => '1.3.6.1.4.1.318.1.1.13.5.3.23.29',
  airIRmPmPump3ControlFactor => '1.3.6.1.4.1.318.1.1.13.5.3.23.30',
  airIRmPmPump4 => '1.3.6.1.4.1.318.1.1.13.5.3.24',
  airIRmPmPump4ManOpEnable => '1.3.6.1.4.1.318.1.1.13.5.3.24.2',
  airIRmPmPump4ManOpEnableDefinition => 'PowerNet-MIB::AirIRmActivityState',
  airIRmPmPump4Running => '1.3.6.1.4.1.318.1.1.13.5.3.24.3',
  airIRmPmPump4RunningDefinition => 'PowerNet-MIB::AirIRmActivityState',
  airIRmPmPump4ManOpRunning => '1.3.6.1.4.1.318.1.1.13.5.3.24.6',
  airIRmPmPump4ManOpRunningDefinition => 'PowerNet-MIB::AirIRmActivityState',
  airIRmPmPump4StartTemperature => '1.3.6.1.4.1.318.1.1.13.5.3.24.10',
  airIRmPmPump4StartTemperatureK => '1.3.6.1.4.1.318.1.1.13.5.3.24.10.1',
  airIRmPmPump4StartTemperatureF => '1.3.6.1.4.1.318.1.1.13.5.3.24.10.2',
  airIRmPmPump4Hysteresis => '1.3.6.1.4.1.318.1.1.13.5.3.24.11',
  airIRmPmPump4HysteresisK => '1.3.6.1.4.1.318.1.1.13.5.3.24.11.1',
  airIRmPmPump4HysteresisF => '1.3.6.1.4.1.318.1.1.13.5.3.24.11.2',
  airIRmPmPump4LinearRange => '1.3.6.1.4.1.318.1.1.13.5.3.24.12',
  airIRmPmPump4LinearRangeK => '1.3.6.1.4.1.318.1.1.13.5.3.24.12.1',
  airIRmPmPump4LinearRangeF => '1.3.6.1.4.1.318.1.1.13.5.3.24.12.2',
  airIRmPmPump4PressureSetpoint => '1.3.6.1.4.1.318.1.1.13.5.3.24.13',
  airIRmPmPump4Runtime => '1.3.6.1.4.1.318.1.1.13.5.3.24.21',
  airIRmPmPump4Speed => '1.3.6.1.4.1.318.1.1.13.5.3.24.22',
  airIRmPmPump4ControlCycle => '1.3.6.1.4.1.318.1.1.13.5.3.24.28',
  airIRmPmPump4MaxAdjust => '1.3.6.1.4.1.318.1.1.13.5.3.24.29',
  airIRmPmPump4ControlFactor => '1.3.6.1.4.1.318.1.1.13.5.3.24.30',
  airIRmPmHotgasHeating => '1.3.6.1.4.1.318.1.1.13.5.3.25',
  airIRmPmHotgasHeatRunning => '1.3.6.1.4.1.318.1.1.13.5.3.25.3',
  airIRmPmHotgasHeatRunningDefinition => 'PowerNet-MIB::AirIRmControlState',
  airIRmPmPWWHeating => '1.3.6.1.4.1.318.1.1.13.5.3.26',
  airIRmPmPWWHeatingManOpEnable => '1.3.6.1.4.1.318.1.1.13.5.3.26.2',
  airIRmPmPWWHeatingManOpEnableDefinition => 'PowerNet-MIB::AirIRmActivityState',
  airIRmPmPWWHeatingRunning => '1.3.6.1.4.1.318.1.1.13.5.3.26.3',
  airIRmPmPWWHeatingRunningDefinition => 'PowerNet-MIB::AirIRmActivityState',
  airIRmPmPWWHeatingManOpRunning => '1.3.6.1.4.1.318.1.1.13.5.3.26.4',
  airIRmPmPWWHeatingManOpRunningDefinition => 'PowerNet-MIB::AirIRmActivityState',
  airIRmPmPWWHeatingType => '1.3.6.1.4.1.318.1.1.13.5.3.26.9',
  airIRmPmPWWHeatingTypeDefinition => 'PowerNet-MIB::airIRmPmPWWHeatingType',
  airIRmPmPWWHeatingStartTemp => '1.3.6.1.4.1.318.1.1.13.5.3.26.10',
  airIRmPmPWWHeatingStartTempK => '1.3.6.1.4.1.318.1.1.13.5.3.26.10.1',
  airIRmPmPWWHeatingStartTempF => '1.3.6.1.4.1.318.1.1.13.5.3.26.10.2',
  airIRmPmPWWHeatingHysteresis => '1.3.6.1.4.1.318.1.1.13.5.3.26.12',
  airIRmPmPWWHeatingHysteresisK => '1.3.6.1.4.1.318.1.1.13.5.3.26.12.1',
  airIRmPmPWWHeatingHysteresisF => '1.3.6.1.4.1.318.1.1.13.5.3.26.12.2',
  airIRmPmPWWHeatingLinearRange => '1.3.6.1.4.1.318.1.1.13.5.3.26.13',
  airIRmPmPWWHeatingLinearRangeK => '1.3.6.1.4.1.318.1.1.13.5.3.26.13.1',
  airIRmPmPWWHeatingLinearRangeF => '1.3.6.1.4.1.318.1.1.13.5.3.26.13.2',
  airIRmPmPWWHeatingCurrentValue => '1.3.6.1.4.1.318.1.1.13.5.3.26.16',
  airIRmPmPWWHeatingManOpValue => '1.3.6.1.4.1.318.1.1.13.5.3.26.17',
  airIRmPmHumidifier1 => '1.3.6.1.4.1.318.1.1.13.5.3.27',
  airIRmPmHumidifier1ManOpEnable => '1.3.6.1.4.1.318.1.1.13.5.3.27.2',
  airIRmPmHumidifier1ManOpEnableDefinition => 'PowerNet-MIB::AirIRmActivityState',
  airIRmPmHumidifier1Running => '1.3.6.1.4.1.318.1.1.13.5.3.27.3',
  airIRmPmHumidifier1RunningDefinition => 'PowerNet-MIB::AirIRmControlState',
  airIRmPmHumidifier1ManOpRunning => '1.3.6.1.4.1.318.1.1.13.5.3.27.5',
  airIRmPmHumidifier1ManOpRunningDefinition => 'PowerNet-MIB::AirIRmActivityState',
  airIRmPmHumidifier1Type => '1.3.6.1.4.1.318.1.1.13.5.3.27.17',
  airIRmPmHumidifier1TypeDefinition => 'PowerNet-MIB::airIRmPmHumidifier1Type',
  airIRmPmHumidifier1StartHumidity => '1.3.6.1.4.1.318.1.1.13.5.3.27.18',
  airIRmPmHumidifier1Hysteresis => '1.3.6.1.4.1.318.1.1.13.5.3.27.20',
  airIRmPmHumidifier1LinearRange => '1.3.6.1.4.1.318.1.1.13.5.3.27.21',
  airIRmPmHumidifier1Runtime => '1.3.6.1.4.1.318.1.1.13.5.3.27.27',
  airIRmPmHumidifier1CurrentValue => '1.3.6.1.4.1.318.1.1.13.5.3.27.28',
  airIRmPmHumidifier1ManOpValue => '1.3.6.1.4.1.318.1.1.13.5.3.27.29',
  airIRmPmHumidifier2 => '1.3.6.1.4.1.318.1.1.13.5.3.28',
  airIRmPmHumidifier2ManOpEnable => '1.3.6.1.4.1.318.1.1.13.5.3.28.2',
  airIRmPmHumidifier2ManOpEnableDefinition => 'PowerNet-MIB::AirIRmActivityState',
  airIRmPmHumidifier2Running => '1.3.6.1.4.1.318.1.1.13.5.3.28.3',
  airIRmPmHumidifier2RunningDefinition => 'PowerNet-MIB::AirIRmControlState',
  airIRmPmHumidifier2ManOpRunning => '1.3.6.1.4.1.318.1.1.13.5.3.28.5',
  airIRmPmHumidifier2ManOpRunningDefinition => 'PowerNet-MIB::AirIRmActivityState',
  airIRmPmHumidifier2Type => '1.3.6.1.4.1.318.1.1.13.5.3.28.17',
  airIRmPmHumidifier2TypeDefinition => 'PowerNet-MIB::airIRmPmHumidifier2Type',
  airIRmPmHumidifier2StartHumidity => '1.3.6.1.4.1.318.1.1.13.5.3.28.18',
  airIRmPmHumidifier2Hysteresis => '1.3.6.1.4.1.318.1.1.13.5.3.28.20',
  airIRmPmHumidifier2LinearRange => '1.3.6.1.4.1.318.1.1.13.5.3.28.21',
  airIRmPmHumidifier2Runtime => '1.3.6.1.4.1.318.1.1.13.5.3.28.27',
  airIRmPmHumidifier2CurrentValue => '1.3.6.1.4.1.318.1.1.13.5.3.28.28',
  airIRmPmHumidifier2ManOpValue => '1.3.6.1.4.1.318.1.1.13.5.3.28.29',
  airIRmPmDehumidification => '1.3.6.1.4.1.318.1.1.13.5.3.31',
  airIRmPmDehumidificManOpEnable => '1.3.6.1.4.1.318.1.1.13.5.3.31.2',
  airIRmPmDehumidificManOpEnableDefinition => 'PowerNet-MIB::AirIRmActivityState',
  airIRmPmDehumidificRunning => '1.3.6.1.4.1.318.1.1.13.5.3.31.3',
  airIRmPmDehumidificRunningDefinition => 'PowerNet-MIB::AirIRmControlState',
  airIRmPmDehumidificManOpRunning => '1.3.6.1.4.1.318.1.1.13.5.3.31.5',
  airIRmPmDehumidificManOpRunningDefinition => 'PowerNet-MIB::AirIRmActivityState',
  airIRmPmDehumidificStartHumidity => '1.3.6.1.4.1.318.1.1.13.5.3.31.10',
  airIRmPmDehumidificHysteresis => '1.3.6.1.4.1.318.1.1.13.5.3.31.12',
  airIRmPmDehumidificMinWaterTemp => '1.3.6.1.4.1.318.1.1.13.5.3.31.18',
  airIRmPmDehumidificMinWaterTempC => '1.3.6.1.4.1.318.1.1.13.5.3.31.18.1',
  airIRmPmDehumidificMinWaterTempF => '1.3.6.1.4.1.318.1.1.13.5.3.31.18.2',
  airIRmPmDehumidificMaxWaterTemp => '1.3.6.1.4.1.318.1.1.13.5.3.31.19',
  airIRmPmDehumidificMaxWaterTempC => '1.3.6.1.4.1.318.1.1.13.5.3.31.19.1',
  airIRmPmDehumidificMaxWaterTempF => '1.3.6.1.4.1.318.1.1.13.5.3.31.19.2',
  airIRmPmDehumidificRuntime => '1.3.6.1.4.1.318.1.1.13.5.3.31.21',
  airIRmPmFan1 => '1.3.6.1.4.1.318.1.1.13.5.3.32',
  airIRmPmFan1ManOpEnable => '1.3.6.1.4.1.318.1.1.13.5.3.32.2',
  airIRmPmFan1ManOpEnableDefinition => 'PowerNet-MIB::AirIRmActivityState',
  airIRmPmFan1Running => '1.3.6.1.4.1.318.1.1.13.5.3.32.3',
  airIRmPmFan1RunningDefinition => 'PowerNet-MIB::AirIRmActivityState',
  airIRmPmFan1ManOpRunning => '1.3.6.1.4.1.318.1.1.13.5.3.32.6',
  airIRmPmFan1ManOpRunningDefinition => 'PowerNet-MIB::AirIRmActivityState',
  airIRmPmFan1Type => '1.3.6.1.4.1.318.1.1.13.5.3.32.9',
  airIRmPmFan1TypeDefinition => 'PowerNet-MIB::airIRmPmFan1Type',
  airIRmPmFan1Runtime => '1.3.6.1.4.1.318.1.1.13.5.3.32.32',
  airIRmPmFan1Speed => '1.3.6.1.4.1.318.1.1.13.5.3.32.33',
  airIRmPmFan1ManOpSpeed => '1.3.6.1.4.1.318.1.1.13.5.3.32.34',
  airIRmPmFan2 => '1.3.6.1.4.1.318.1.1.13.5.3.33',
  airIRmPmFan2ManOpEnable => '1.3.6.1.4.1.318.1.1.13.5.3.33.2',
  airIRmPmFan2ManOpEnableDefinition => 'PowerNet-MIB::AirIRmActivityState',
  airIRmPmFan2Running => '1.3.6.1.4.1.318.1.1.13.5.3.33.3',
  airIRmPmFan2RunningDefinition => 'PowerNet-MIB::AirIRmActivityState',
  airIRmPmFan2ManOpRunning => '1.3.6.1.4.1.318.1.1.13.5.3.33.6',
  airIRmPmFan2ManOpRunningDefinition => 'PowerNet-MIB::AirIRmActivityState',
  airIRmPmFan2Type => '1.3.6.1.4.1.318.1.1.13.5.3.33.9',
  airIRmPmFan2TypeDefinition => 'PowerNet-MIB::airIRmPmFan2Type',
  airIRmPmFan2Runtime => '1.3.6.1.4.1.318.1.1.13.5.3.33.32',
  airIRmPmFan2Speed => '1.3.6.1.4.1.318.1.1.13.5.3.33.33',
  airIRmPmFan2ManOpSpeed => '1.3.6.1.4.1.318.1.1.13.5.3.33.34',
  airIRmPmFan3 => '1.3.6.1.4.1.318.1.1.13.5.3.34',
  airIRmPmFan3ManOpEnable => '1.3.6.1.4.1.318.1.1.13.5.3.34.2',
  airIRmPmFan3ManOpEnableDefinition => 'PowerNet-MIB::AirIRmActivityState',
  airIRmPmFan3Running => '1.3.6.1.4.1.318.1.1.13.5.3.34.3',
  airIRmPmFan3RunningDefinition => 'PowerNet-MIB::AirIRmActivityState',
  airIRmPmFan3ManOpRunning => '1.3.6.1.4.1.318.1.1.13.5.3.34.6',
  airIRmPmFan3ManOpRunningDefinition => 'PowerNet-MIB::AirIRmActivityState',
  airIRmPmFan3Type => '1.3.6.1.4.1.318.1.1.13.5.3.34.9',
  airIRmPmFan3TypeDefinition => 'PowerNet-MIB::airIRmPmFan3Type',
  airIRmPmFan3Runtime => '1.3.6.1.4.1.318.1.1.13.5.3.34.32',
  airIRmPmFan3Speed => '1.3.6.1.4.1.318.1.1.13.5.3.34.33',
  airIRmPmFan3ManOpSpeed => '1.3.6.1.4.1.318.1.1.13.5.3.34.34',
  airIRmPmLouver1 => '1.3.6.1.4.1.318.1.1.13.5.3.35',
  airIRmPmLouver1ManOpEnable => '1.3.6.1.4.1.318.1.1.13.5.3.35.2',
  airIRmPmLouver1ManOpEnableDefinition => 'PowerNet-MIB::AirIRmActivityState',
  airIRmPmLouver1Position => '1.3.6.1.4.1.318.1.1.13.5.3.35.3',
  airIRmPmLouver1PositionDefinition => 'PowerNet-MIB::airIRmPmLouver1Position',
  airIRmPmLouver1ManOpPosition => '1.3.6.1.4.1.318.1.1.13.5.3.35.4',
  airIRmPmLouver1ManOpPositionDefinition => 'PowerNet-MIB::airIRmPmLouver1ManOpPosition',
  airIRmPmLouver2 => '1.3.6.1.4.1.318.1.1.13.5.3.36',
  airIRmPmLouver2ManOpEnable => '1.3.6.1.4.1.318.1.1.13.5.3.36.2',
  airIRmPmLouver2ManOpEnableDefinition => 'PowerNet-MIB::AirIRmActivityState',
  airIRmPmLouver2Position => '1.3.6.1.4.1.318.1.1.13.5.3.36.3',
  airIRmPmLouver2PositionDefinition => 'PowerNet-MIB::airIRmPmLouver2Position',
  airIRmPmLouver2ManOpPosition => '1.3.6.1.4.1.318.1.1.13.5.3.36.4',
  airIRmPmLouver2ManOpPositionDefinition => 'PowerNet-MIB::airIRmPmLouver2ManOpPosition',
  airIRmPmLouver3 => '1.3.6.1.4.1.318.1.1.13.5.3.37',
  airIRmPmLouver3ManOpEnable => '1.3.6.1.4.1.318.1.1.13.5.3.37.2',
  airIRmPmLouver3ManOpEnableDefinition => 'PowerNet-MIB::AirIRmActivityState',
  airIRmPmLouver3Position => '1.3.6.1.4.1.318.1.1.13.5.3.37.3',
  airIRmPmLouver3PositionDefinition => 'PowerNet-MIB::airIRmPmLouver3Position',
  airIRmPmLouver3ManOpPosition => '1.3.6.1.4.1.318.1.1.13.5.3.37.4',
  airIRmPmLouver3ManOpPositionDefinition => 'PowerNet-MIB::airIRmPmLouver3ManOpPosition',
  airIRmPmAuxAlarm1 => '1.3.6.1.4.1.318.1.1.13.5.3.38',
  airIRmPmAuxAlarm2 => '1.3.6.1.4.1.318.1.1.13.5.3.39',
  airIRmPmAuxAlarm3 => '1.3.6.1.4.1.318.1.1.13.5.3.40',
  airIRmPmAuxAlarm4 => '1.3.6.1.4.1.318.1.1.13.5.3.41',
  airIRmPmAuxAlarm5 => '1.3.6.1.4.1.318.1.1.13.5.3.42',
  airIRmPmAlarmBits => '1.3.6.1.4.1.318.1.1.13.5.3.43',
  airIRmPmFan1Failure => '1.3.6.1.4.1.318.1.1.13.5.3.43.1',
  airIRmPmFan1FailureDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmFan2Failure => '1.3.6.1.4.1.318.1.1.13.5.3.43.2',
  airIRmPmFan2FailureDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmFan3Failure => '1.3.6.1.4.1.318.1.1.13.5.3.43.3',
  airIRmPmFan3FailureDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmCompressor1Failure => '1.3.6.1.4.1.318.1.1.13.5.3.43.4',
  airIRmPmCompressor1FailureDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmCompressor2Failure => '1.3.6.1.4.1.318.1.1.13.5.3.43.5',
  airIRmPmCompressor2FailureDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmWaterDetector => '1.3.6.1.4.1.318.1.1.13.5.3.43.6',
  airIRmPmWaterDetectorDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmPhaseFailure => '1.3.6.1.4.1.318.1.1.13.5.3.43.7',
  airIRmPmPhaseFailureDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmFireSmokeDetector => '1.3.6.1.4.1.318.1.1.13.5.3.43.8',
  airIRmPmFireSmokeDetectorDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmReturnAirTemperatureTooHigh => '1.3.6.1.4.1.318.1.1.13.5.3.43.9',
  airIRmPmReturnAirTemperatureTooHighDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmReturnAirHumidityTooHigh => '1.3.6.1.4.1.318.1.1.13.5.3.43.10',
  airIRmPmReturnAirHumidityTooHighDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmSupplyAirTemperatureTooHigh => '1.3.6.1.4.1.318.1.1.13.5.3.43.11',
  airIRmPmSupplyAirTemperatureTooHighDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmSupplyAirHumidityTooHigh => '1.3.6.1.4.1.318.1.1.13.5.3.43.12',
  airIRmPmSupplyAirHumidityTooHighDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmWaterTemperatureTooHigh => '1.3.6.1.4.1.318.1.1.13.5.3.43.13',
  airIRmPmWaterTemperatureTooHighDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmReturnAirTemperatureTooLow => '1.3.6.1.4.1.318.1.1.13.5.3.43.14',
  airIRmPmReturnAirTemperatureTooLowDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmReturnAirHumidityTooLow => '1.3.6.1.4.1.318.1.1.13.5.3.43.15',
  airIRmPmReturnAirHumidityTooLowDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmSupplyAirTemperatureTooLow => '1.3.6.1.4.1.318.1.1.13.5.3.43.16',
  airIRmPmSupplyAirTemperatureTooLowDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmSupplyAirHumidityTooLow => '1.3.6.1.4.1.318.1.1.13.5.3.43.17',
  airIRmPmSupplyAirHumidityTooLowDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmWaterTemperatureTooLow => '1.3.6.1.4.1.318.1.1.13.5.3.43.18',
  airIRmPmWaterTemperatureTooLowDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmSensor1Failure => '1.3.6.1.4.1.318.1.1.13.5.3.43.19',
  airIRmPmSensor1FailureDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmSensor2Failure => '1.3.6.1.4.1.318.1.1.13.5.3.43.20',
  airIRmPmSensor2FailureDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmSensor3Failure => '1.3.6.1.4.1.318.1.1.13.5.3.43.21',
  airIRmPmSensor3FailureDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmSensor4Failure => '1.3.6.1.4.1.318.1.1.13.5.3.43.22',
  airIRmPmSensor4FailureDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmSensor5Failure => '1.3.6.1.4.1.318.1.1.13.5.3.43.23',
  airIRmPmSensor5FailureDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmSensor6Failure => '1.3.6.1.4.1.318.1.1.13.5.3.43.24',
  airIRmPmSensor6FailureDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmSensor7Failure => '1.3.6.1.4.1.318.1.1.13.5.3.43.25',
  airIRmPmSensor7FailureDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmSensor8Failure => '1.3.6.1.4.1.318.1.1.13.5.3.43.26',
  airIRmPmSensor8FailureDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmSensor9Failure => '1.3.6.1.4.1.318.1.1.13.5.3.43.27',
  airIRmPmSensor9FailureDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmSensor10Failure => '1.3.6.1.4.1.318.1.1.13.5.3.43.28',
  airIRmPmSensor10FailureDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmSensor11Failure => '1.3.6.1.4.1.318.1.1.13.5.3.43.29',
  airIRmPmSensor11FailureDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmSensor12Failure => '1.3.6.1.4.1.318.1.1.13.5.3.43.30',
  airIRmPmSensor12FailureDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmSensor13Failure => '1.3.6.1.4.1.318.1.1.13.5.3.43.31',
  airIRmPmSensor13FailureDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmSensor14Failure => '1.3.6.1.4.1.318.1.1.13.5.3.43.32',
  airIRmPmSensor14FailureDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmSensor15Failure => '1.3.6.1.4.1.318.1.1.13.5.3.43.33',
  airIRmPmSensor15FailureDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmSensor16Failure => '1.3.6.1.4.1.318.1.1.13.5.3.43.34',
  airIRmPmSensor16FailureDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmSensor17Failure => '1.3.6.1.4.1.318.1.1.13.5.3.43.35',
  airIRmPmSensor17FailureDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmSensor18Failure => '1.3.6.1.4.1.318.1.1.13.5.3.43.36',
  airIRmPmSensor18FailureDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmSensor19Failure => '1.3.6.1.4.1.318.1.1.13.5.3.43.37',
  airIRmPmSensor19FailureDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmSensor20Failure => '1.3.6.1.4.1.318.1.1.13.5.3.43.38',
  airIRmPmSensor20FailureDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmSensor21Failure => '1.3.6.1.4.1.318.1.1.13.5.3.43.39',
  airIRmPmSensor21FailureDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmSensor1Defect => '1.3.6.1.4.1.318.1.1.13.5.3.43.40',
  airIRmPmSensor1DefectDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmSensor2Defect => '1.3.6.1.4.1.318.1.1.13.5.3.43.41',
  airIRmPmSensor2DefectDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmSensor3Defect => '1.3.6.1.4.1.318.1.1.13.5.3.43.42',
  airIRmPmSensor3DefectDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmSensor4Defect => '1.3.6.1.4.1.318.1.1.13.5.3.43.43',
  airIRmPmSensor4DefectDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmSensor5Defect => '1.3.6.1.4.1.318.1.1.13.5.3.43.44',
  airIRmPmSensor5DefectDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmSensor6Defect => '1.3.6.1.4.1.318.1.1.13.5.3.43.45',
  airIRmPmSensor6DefectDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmSensor7Defect => '1.3.6.1.4.1.318.1.1.13.5.3.43.46',
  airIRmPmSensor7DefectDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmSensor8Defect => '1.3.6.1.4.1.318.1.1.13.5.3.43.47',
  airIRmPmSensor8DefectDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmSensor9Defect => '1.3.6.1.4.1.318.1.1.13.5.3.43.48',
  airIRmPmSensor9DefectDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmSensor10Defect => '1.3.6.1.4.1.318.1.1.13.5.3.43.49',
  airIRmPmSensor10DefectDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmSensor11Defect => '1.3.6.1.4.1.318.1.1.13.5.3.43.50',
  airIRmPmSensor11DefectDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmSensor12Defect => '1.3.6.1.4.1.318.1.1.13.5.3.43.51',
  airIRmPmSensor12DefectDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmSensor13Defect => '1.3.6.1.4.1.318.1.1.13.5.3.43.52',
  airIRmPmSensor13DefectDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmSensor14Defect => '1.3.6.1.4.1.318.1.1.13.5.3.43.53',
  airIRmPmSensor14DefectDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmSensor15Defect => '1.3.6.1.4.1.318.1.1.13.5.3.43.54',
  airIRmPmSensor15DefectDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmSensor16Defect => '1.3.6.1.4.1.318.1.1.13.5.3.43.55',
  airIRmPmSensor16DefectDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmSensor17Defect => '1.3.6.1.4.1.318.1.1.13.5.3.43.56',
  airIRmPmSensor17DefectDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmSensor18Defect => '1.3.6.1.4.1.318.1.1.13.5.3.43.57',
  airIRmPmSensor18DefectDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmSensor19Defect => '1.3.6.1.4.1.318.1.1.13.5.3.43.58',
  airIRmPmSensor19DefectDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmSensor20Defect => '1.3.6.1.4.1.318.1.1.13.5.3.43.59',
  airIRmPmSensor20DefectDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmSensor21Defect => '1.3.6.1.4.1.318.1.1.13.5.3.43.60',
  airIRmPmSensor21DefectDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmCompressor1Alarm => '1.3.6.1.4.1.318.1.1.13.5.3.43.61',
  airIRmPmCompressor1AlarmDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmCompressor2Alarm => '1.3.6.1.4.1.318.1.1.13.5.3.43.62',
  airIRmPmCompressor2AlarmDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmCompressor1LowPressure => '1.3.6.1.4.1.318.1.1.13.5.3.43.63',
  airIRmPmCompressor1LowPressureDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmCompressor2LowPressure => '1.3.6.1.4.1.318.1.1.13.5.3.43.64',
  airIRmPmCompressor2LowPressureDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmReheat1Failure => '1.3.6.1.4.1.318.1.1.13.5.3.43.65',
  airIRmPmReheat1FailureDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmReheat2Failure => '1.3.6.1.4.1.318.1.1.13.5.3.43.66',
  airIRmPmReheat2FailureDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmReheat3Failure => '1.3.6.1.4.1.318.1.1.13.5.3.43.67',
  airIRmPmReheat3FailureDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmReheat4Failure => '1.3.6.1.4.1.318.1.1.13.5.3.43.68',
  airIRmPmReheat4FailureDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmDrycooler1Failure => '1.3.6.1.4.1.318.1.1.13.5.3.43.69',
  airIRmPmDrycooler1FailureDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmDrycooler2Failure => '1.3.6.1.4.1.318.1.1.13.5.3.43.70',
  airIRmPmDrycooler2FailureDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmDrycooler3Failure => '1.3.6.1.4.1.318.1.1.13.5.3.43.71',
  airIRmPmDrycooler3FailureDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmDrycooler4Failure => '1.3.6.1.4.1.318.1.1.13.5.3.43.72',
  airIRmPmDrycooler4FailureDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmPump1Failure => '1.3.6.1.4.1.318.1.1.13.5.3.43.73',
  airIRmPmPump1FailureDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmPump2Failure => '1.3.6.1.4.1.318.1.1.13.5.3.43.74',
  airIRmPmPump2FailureDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmPump3Failure => '1.3.6.1.4.1.318.1.1.13.5.3.43.75',
  airIRmPmPump3FailureDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmPump4Failure => '1.3.6.1.4.1.318.1.1.13.5.3.43.76',
  airIRmPmPump4FailureDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmHumidifier1Failure => '1.3.6.1.4.1.318.1.1.13.5.3.43.77',
  airIRmPmHumidifier1FailureDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmHumidifier2Failure => '1.3.6.1.4.1.318.1.1.13.5.3.43.78',
  airIRmPmHumidifier2FailureDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmHumidifier3Failure => '1.3.6.1.4.1.318.1.1.13.5.3.43.79',
  airIRmPmHumidifier3FailureDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmHumidifier1Alarm5us => '1.3.6.1.4.1.318.1.1.13.5.3.43.80',
  airIRmPmHumidifier1Alarm5usDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmHumidifier2Alarm5us => '1.3.6.1.4.1.318.1.1.13.5.3.43.81',
  airIRmPmHumidifier2Alarm5usDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmHumidifier3Alarm5us => '1.3.6.1.4.1.318.1.1.13.5.3.43.82',
  airIRmPmHumidifier3Alarm5usDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmHumidifier1Alarm20us => '1.3.6.1.4.1.318.1.1.13.5.3.43.83',
  airIRmPmHumidifier1Alarm20usDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmHumidifier2Alarm20us => '1.3.6.1.4.1.318.1.1.13.5.3.43.84',
  airIRmPmHumidifier2Alarm20usDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmHumidifier3Alarm20us => '1.3.6.1.4.1.318.1.1.13.5.3.43.85',
  airIRmPmHumidifier3Alarm20usDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmFan1Alarm => '1.3.6.1.4.1.318.1.1.13.5.3.43.86',
  airIRmPmFan1AlarmDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmFan2Alarm => '1.3.6.1.4.1.318.1.1.13.5.3.43.87',
  airIRmPmFan2AlarmDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmFan3Alarm => '1.3.6.1.4.1.318.1.1.13.5.3.43.88',
  airIRmPmFan3AlarmDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmFilter1Clogged => '1.3.6.1.4.1.318.1.1.13.5.3.43.89',
  airIRmPmFilter1CloggedDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmFilter2Clogged => '1.3.6.1.4.1.318.1.1.13.5.3.43.90',
  airIRmPmFilter2CloggedDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmFilter3Clogged => '1.3.6.1.4.1.318.1.1.13.5.3.43.91',
  airIRmPmFilter3CloggedDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmAuxiliaryAlarm1 => '1.3.6.1.4.1.318.1.1.13.5.3.43.92',
  airIRmPmAuxiliaryAlarm1Definition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmAuxiliaryAlarm2 => '1.3.6.1.4.1.318.1.1.13.5.3.43.93',
  airIRmPmAuxiliaryAlarm2Definition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmAuxiliaryAlarm3 => '1.3.6.1.4.1.318.1.1.13.5.3.43.94',
  airIRmPmAuxiliaryAlarm3Definition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmAuxiliaryAlarm4 => '1.3.6.1.4.1.318.1.1.13.5.3.43.95',
  airIRmPmAuxiliaryAlarm4Definition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmAuxiliaryAlarm5 => '1.3.6.1.4.1.318.1.1.13.5.3.43.96',
  airIRmPmAuxiliaryAlarm5Definition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmAuxiliaryAlarm6 => '1.3.6.1.4.1.318.1.1.13.5.3.43.97',
  airIRmPmAuxiliaryAlarm6Definition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmAuxiliaryAlarm7 => '1.3.6.1.4.1.318.1.1.13.5.3.43.98',
  airIRmPmAuxiliaryAlarm7Definition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmAuxiliaryAlarm8 => '1.3.6.1.4.1.318.1.1.13.5.3.43.99',
  airIRmPmAuxiliaryAlarm8Definition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmAuxiliaryAlarm9 => '1.3.6.1.4.1.318.1.1.13.5.3.43.100',
  airIRmPmAuxiliaryAlarm9Definition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmAuxiliaryAlarm10 => '1.3.6.1.4.1.318.1.1.13.5.3.43.101',
  airIRmPmAuxiliaryAlarm10Definition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmHotGasHeatingAlarm => '1.3.6.1.4.1.318.1.1.13.5.3.43.102',
  airIRmPmHotGasHeatingAlarmDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmEEV1PressureSensorError => '1.3.6.1.4.1.318.1.1.13.5.3.43.103',
  airIRmPmEEV1PressureSensorErrorDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmEEV1TemperatureSensorError => '1.3.6.1.4.1.318.1.1.13.5.3.43.104',
  airIRmPmEEV1TemperatureSensorErrorDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmEEV1StepperMotorError => '1.3.6.1.4.1.318.1.1.13.5.3.43.105',
  airIRmPmEEV1StepperMotorErrorDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmEEV2PressureSensorError => '1.3.6.1.4.1.318.1.1.13.5.3.43.106',
  airIRmPmEEV2PressureSensorErrorDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmEEV2TemperatureSensorError => '1.3.6.1.4.1.318.1.1.13.5.3.43.107',
  airIRmPmEEV2TemperatureSensorErrorDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmEEV2StepperMotorError => '1.3.6.1.4.1.318.1.1.13.5.3.43.108',
  airIRmPmEEV2StepperMotorErrorDefinition => 'PowerNet-MIB::AirIRmAlarmState',
  airIRmPmMyZone => '1.3.6.1.4.1.318.1.1.13.5.3.44',
  airIRmPmMyZoneNumber => '1.3.6.1.4.1.318.1.1.13.5.3.44.1',
  airIRmPmMyZoneRoomTemperature => '1.3.6.1.4.1.318.1.1.13.5.3.44.2',
  airIRmPmMyZoneRoomTemperatureC => '1.3.6.1.4.1.318.1.1.13.5.3.44.2.1',
  airIRmPmMyZoneRoomTemperatureF => '1.3.6.1.4.1.318.1.1.13.5.3.44.2.2',
  airIRmPmMyZoneRoomHumidity => '1.3.6.1.4.1.318.1.1.13.5.3.44.3',
  airIRmPmMyZoneSupplyTemperature => '1.3.6.1.4.1.318.1.1.13.5.3.44.4',
  airIRmPmMyZoneSupplyTemperatureC => '1.3.6.1.4.1.318.1.1.13.5.3.44.4.1',
  airIRmPmMyZoneSupplyTemperatureF => '1.3.6.1.4.1.318.1.1.13.5.3.44.4.2',
  airIRmPmMyZoneSupplyHumidity => '1.3.6.1.4.1.318.1.1.13.5.3.44.5',
  airIRmPmMyZoneSequencingTime => '1.3.6.1.4.1.318.1.1.13.5.3.44.6',
  airIRmPmMyZoneNumberOfErrorUnits => '1.3.6.1.4.1.318.1.1.13.5.3.44.7',
  airIRmPmMyZoneEmergencyTemperature => '1.3.6.1.4.1.318.1.1.13.5.3.44.8',
  airIRmPmMyZoneEmergencyTemperatureC => '1.3.6.1.4.1.318.1.1.13.5.3.44.8.1',
  airIRmPmMyZoneEmergencyTemperatureF => '1.3.6.1.4.1.318.1.1.13.5.3.44.8.2',
  airIRmPmMyZoneCWEnergySaveMode => '1.3.6.1.4.1.318.1.1.13.5.3.44.9',
  airIRmPmMyZoneCWEnergySaveModeDefinition => 'PowerNet-MIB::AirIRmActivityState',
  airIRmPmGlobalZoneData => '1.3.6.1.4.1.318.1.1.13.5.3.45',
  airIRmPmGlobalZoneDataEmergencyOpMode => '1.3.6.1.4.1.318.1.1.13.5.3.45.1',
  airIRmPmGlobalZoneDataEmergencyOpModeDefinition => 'PowerNet-MIB::AirIRmActivityState',
  airIRGen3 => '1.3.6.1.4.1.318.1.1.13.6',
  airIRG3Ident => '1.3.6.1.4.1.318.1.1.13.6.1',
  airIRG3IdentTableSize => '1.3.6.1.4.1.318.1.1.13.6.1.1',
  airIRG3IdentTable => '1.3.6.1.4.1.318.1.1.13.6.1.2',
  airIRG3IdentEntry => '1.3.6.1.4.1.318.1.1.13.6.1.2.1',
  airIRG3IdentIndex => '1.3.6.1.4.1.318.1.1.13.6.1.2.1.1',
  airIRG3IdentName => '1.3.6.1.4.1.318.1.1.13.6.1.2.1.2',
  airIRG3IdentLocation => '1.3.6.1.4.1.318.1.1.13.6.1.2.1.3',
  airIRG3IdentModelNumber => '1.3.6.1.4.1.318.1.1.13.6.1.2.1.4',
  airIRG3IdentSerialNumber => '1.3.6.1.4.1.318.1.1.13.6.1.2.1.5',
  airIRG3IdentFirmwareRevision => '1.3.6.1.4.1.318.1.1.13.6.1.2.1.6',
  airIRG3IdentHardwareRevision => '1.3.6.1.4.1.318.1.1.13.6.1.2.1.7',
  airIRG3IdentManufactureDate => '1.3.6.1.4.1.318.1.1.13.6.1.2.1.8',
  airIRG3IdentRDUSysOID => '1.3.6.1.4.1.318.1.1.13.6.1.2.1.9',
  airIRG3IdentCMSysOID => '1.3.6.1.4.1.318.1.1.13.6.1.2.1.10',
  airIRG3IdentGroupSysOID => '1.3.6.1.4.1.318.1.1.13.6.1.2.1.11',
  airIRG3Group => '1.3.6.1.4.1.318.1.1.13.6.2',
  airIRG3GroupTableSize => '1.3.6.1.4.1.318.1.1.13.6.2.1',
  airIRG3GroupStatusTable => '1.3.6.1.4.1.318.1.1.13.6.2.2',
  airIRG3GroupStatusEntry => '1.3.6.1.4.1.318.1.1.13.6.2.2.1',
  airIRG3GroupStatusIndex => '1.3.6.1.4.1.318.1.1.13.6.2.2.1.1',
  airIRG3GroupStatusCoolOutput => '1.3.6.1.4.1.318.1.1.13.6.2.2.1.2',
  airIRG3GroupStatusCoolDemand => '1.3.6.1.4.1.318.1.1.13.6.2.2.1.3',
  airIRG3GroupStatusAirFlowUS => '1.3.6.1.4.1.318.1.1.13.6.2.2.1.4',
  airIRG3GroupStatusAirFlowMetric => '1.3.6.1.4.1.318.1.1.13.6.2.2.1.5',
  airIRG3GroupStatusMaxRackInletTempUS => '1.3.6.1.4.1.318.1.1.13.6.2.2.1.6',
  airIRG3GroupStatusMaxRackInletTempMetric => '1.3.6.1.4.1.318.1.1.13.6.2.2.1.7',
  airIRG3GroupStatusMinRackInletTempUS => '1.3.6.1.4.1.318.1.1.13.6.2.2.1.8',
  airIRG3GroupStatusMinRackInletTempMetric => '1.3.6.1.4.1.318.1.1.13.6.2.2.1.9',
  airIRG3GroupStatusMaxReturnAirTempUS => '1.3.6.1.4.1.318.1.1.13.6.2.2.1.10',
  airIRG3GroupStatusMaxReturnAirTempMetric => '1.3.6.1.4.1.318.1.1.13.6.2.2.1.11',
  airIRG3GroupStatusMinReturnAirTempUS => '1.3.6.1.4.1.318.1.1.13.6.2.2.1.12',
  airIRG3GroupStatusMinReturnAirTempMetric => '1.3.6.1.4.1.318.1.1.13.6.2.2.1.13',
  airIRG3GroupStatusAvgSupplyTempUS => '1.3.6.1.4.1.318.1.1.13.6.2.2.1.14',
  airIRG3GroupStatusAvgSupplyTempMetric => '1.3.6.1.4.1.318.1.1.13.6.2.2.1.15',
  airIRG3GroupStatusAvgReturnTempUS => '1.3.6.1.4.1.318.1.1.13.6.2.2.1.16',
  airIRG3GroupStatusAvgReturnTempMetric => '1.3.6.1.4.1.318.1.1.13.6.2.2.1.17',
  airIRG3GroupStatusAvgFanSpeed => '1.3.6.1.4.1.318.1.1.13.6.2.2.1.18',
  airIRG3GroupStatusAvgAirFlowUS => '1.3.6.1.4.1.318.1.1.13.6.2.2.1.19',
  airIRG3GroupStatusAvgAirFlowMetric => '1.3.6.1.4.1.318.1.1.13.6.2.2.1.20',
  airIRG3GroupStatusTotalAirFlowUS => '1.3.6.1.4.1.318.1.1.13.6.2.2.1.21',
  airIRG3GroupStatusTotalAirFlowMetric => '1.3.6.1.4.1.318.1.1.13.6.2.2.1.22',
  airIRG3GroupSetpointsTable => '1.3.6.1.4.1.318.1.1.13.6.2.3',
  airIRG3GroupSetpointsEntry => '1.3.6.1.4.1.318.1.1.13.6.2.3.1',
  airIRG3GroupSetpointsIndex => '1.3.6.1.4.1.318.1.1.13.6.2.3.1.1',
  airIRG3GroupSetpointsCoolSetpointUS => '1.3.6.1.4.1.318.1.1.13.6.2.3.1.2',
  airIRG3GroupSetpointsCoolSetpointMetric => '1.3.6.1.4.1.318.1.1.13.6.2.3.1.3',
  airIRG3GroupSetpointsCoolDeadbandUS => '1.3.6.1.4.1.318.1.1.13.6.2.3.1.4',
  airIRG3GroupSetpointsCoolDeadbandMetric => '1.3.6.1.4.1.318.1.1.13.6.2.3.1.5',
  airIRG3GroupSetpointsFanSpeedPreference => '1.3.6.1.4.1.318.1.1.13.6.2.3.1.6',
  airIRG3GroupSetpointsFanSpeedPreferenceDefinition => 'PowerNet-MIB::airIRG3GroupSetpointsFanSpeedPreference',
  airIRG3GroupSetpointsSupplyAirSetpointUS => '1.3.6.1.4.1.318.1.1.13.6.2.3.1.7',
  airIRG3GroupSetpointsSupplyAirSetpointMetric => '1.3.6.1.4.1.318.1.1.13.6.2.3.1.8',
  airIRG3GroupSetpointsAirFlowControl => '1.3.6.1.4.1.318.1.1.13.6.2.3.1.9',
  airIRG3GroupSetpointsAirFlowControlDefinition => 'PowerNet-MIB::airIRG3GroupSetpointsAirFlowControl',
  airIRG3GroupSetpointsLightingOnTime => '1.3.6.1.4.1.318.1.1.13.6.2.3.1.10',
  airIRG3GroupConfigTable => '1.3.6.1.4.1.318.1.1.13.6.2.4',
  airIRG3GroupConfigEntry => '1.3.6.1.4.1.318.1.1.13.6.2.4.1',
  airIRG3GroupConfigIndex => '1.3.6.1.4.1.318.1.1.13.6.2.4.1.1',
  airIRG3GroupConfigNumberofCoolingUnits => '1.3.6.1.4.1.318.1.1.13.6.2.4.1.2',
  airIRG3GroupConfigConfigurationType => '1.3.6.1.4.1.318.1.1.13.6.2.4.1.3',
  airIRG3GroupConfigConfigurationTypeDefinition => 'PowerNet-MIB::airIRG3GroupConfigConfigurationType',
  airIRG3GroupConfigCapacityControlType => '1.3.6.1.4.1.318.1.1.13.6.2.4.1.4',
  airIRG3GroupConfigCapacityControlTypeDefinition => 'PowerNet-MIB::airIRG3GroupConfigCapacityControlType',
  airIRG3GroupConfigFanSpeedControl => '1.3.6.1.4.1.318.1.1.13.6.2.4.1.5',
  airIRG3GroupConfigFanSpeedControlDefinition => 'PowerNet-MIB::airIRG3GroupConfigFanSpeedControl',
  airIRG3GroupConfigCoolGainP => '1.3.6.1.4.1.318.1.1.13.6.2.4.1.6',
  airIRG3GroupConfigCoolResetRateI => '1.3.6.1.4.1.318.1.1.13.6.2.4.1.7',
  airIRG3GroupConfigCoolDerivativeD => '1.3.6.1.4.1.318.1.1.13.6.2.4.1.8',
  airIRG3GroupConfigCoolPIDReset => '1.3.6.1.4.1.318.1.1.13.6.2.4.1.9',
  airIRG3GroupConfigCoolPIDResetDefinition => 'PowerNet-MIB::airIRG3GroupConfigCoolPIDReset',
  airIRG3GroupConfigNumberofBackupUnits => '1.3.6.1.4.1.318.1.1.13.6.2.4.1.10',
  airIRG3GroupConfigRuntimeBalancingEnable => '1.3.6.1.4.1.318.1.1.13.6.2.4.1.11',
  airIRG3GroupConfigRuntimeBalancingEnableDefinition => 'PowerNet-MIB::airIRG3GroupConfigRuntimeBalancingEnable',
  airIRG3GroupConfigLoadAssistEnable => '1.3.6.1.4.1.318.1.1.13.6.2.4.1.12',
  airIRG3GroupConfigLoadAssistEnableDefinition => 'PowerNet-MIB::airIRG3GroupConfigLoadAssistEnable',
  airIRG3Alarms => '1.3.6.1.4.1.318.1.1.13.6.3',
  airIRG3AlarmsTableSize => '1.3.6.1.4.1.318.1.1.13.6.3.1',
  airIRG3AlarmsTable => '1.3.6.1.4.1.318.1.1.13.6.3.2',
  airIRG3AlarmsEntry => '1.3.6.1.4.1.318.1.1.13.6.3.2.1',
  airIRG3AlarmsIndex => '1.3.6.1.4.1.318.1.1.13.6.3.2.1.1',
  airIRG3AlarmsEventCode => '1.3.6.1.4.1.318.1.1.13.6.3.2.1.2',
  airIRG3AlarmsDescription => '1.3.6.1.4.1.318.1.1.13.6.3.2.1.3',
  airIRG3RDU => '1.3.6.1.4.1.318.1.1.13.6.4',
  airIRG3RDUTableSize => '1.3.6.1.4.1.318.1.1.13.6.4.1',
  airIRG3RDUStatusTable => '1.3.6.1.4.1.318.1.1.13.6.4.2',
  airIRG3RDUStatusEntry => '1.3.6.1.4.1.318.1.1.13.6.4.2.1',
  airIRG3RDUStatusDeviceIndex => '1.3.6.1.4.1.318.1.1.13.6.4.2.1.1',
  airIRG3RDUID => '1.3.6.1.4.1.318.1.1.13.6.4.2.1.2',
  airIRG3RDUStatusOnReadyStandby => '1.3.6.1.4.1.318.1.1.13.6.4.2.1.3',
  airIRG3RDUStatusOnReadyStandbyDefinition => 'PowerNet-MIB::airIRG3RDUStatusOnReadyStandby',
  airIRG3RDUStatusOperatingMode => '1.3.6.1.4.1.318.1.1.13.6.4.2.1.4',
  airIRG3RDUStatusOperatingModeDefinition => 'PowerNet-MIB::airIRG3RDUStatusOperatingMode',
  airIRG3RDUStatusLeadPump => '1.3.6.1.4.1.318.1.1.13.6.4.2.1.5',
  airIRG3RDUStatusLeadPumpDefinition => 'PowerNet-MIB::airIRG3RDUStatusLeadPump',
  airIRG3RDUStatusStartupDelay => '1.3.6.1.4.1.318.1.1.13.6.4.2.1.6',
  airIRG3RDUStatusPumpChangeOverInterval => '1.3.6.1.4.1.318.1.1.13.6.4.2.1.7',
  airIRG3RDUStatusStopOnLeakDetect => '1.3.6.1.4.1.318.1.1.13.6.4.2.1.8',
  airIRG3RDUStatusStopOnLeakDetectDefinition => 'PowerNet-MIB::airIRG3RDUStatusStopOnLeakDetect',
  airIRG3RDUStatusPowerSource => '1.3.6.1.4.1.318.1.1.13.6.4.2.1.9',
  airIRG3RDUStatusPowerSourceDefinition => 'PowerNet-MIB::airIRG3RDUStatusPowerSource',
  airIRG3RDUStatusTotalRDUOutputPower => '1.3.6.1.4.1.318.1.1.13.6.4.2.1.10',
  airIRG3RDUStatusInletWaterTempUS => '1.3.6.1.4.1.318.1.1.13.6.4.2.1.11',
  airIRG3RDUStatusInletWaterTempMetric => '1.3.6.1.4.1.318.1.1.13.6.4.2.1.12',
  airIRG3RDUStatusOutletWaterTempUS => '1.3.6.1.4.1.318.1.1.13.6.4.2.1.13',
  airIRG3RDUStatusOutletWaterTempMetric => '1.3.6.1.4.1.318.1.1.13.6.4.2.1.14',
  airIRG3RDUStatusCondenserSaturationTempUS => '1.3.6.1.4.1.318.1.1.13.6.4.2.1.15',
  airIRG3RDUStatusCondenserSaturationTempMetric => '1.3.6.1.4.1.318.1.1.13.6.4.2.1.16',
  airIRG3RDUStatusDewPointTempUS => '1.3.6.1.4.1.318.1.1.13.6.4.2.1.17',
  airIRG3RDUStatusDewPointTempMetric => '1.3.6.1.4.1.318.1.1.13.6.4.2.1.18',
  airIRG3RDUStatusPumpOutletTempUS => '1.3.6.1.4.1.318.1.1.13.6.4.2.1.19',
  airIRG3RDUStatusPumpOutletTempMetric => '1.3.6.1.4.1.318.1.1.13.6.4.2.1.20',
  airIRG3RDUStatusSubcoolerOutletTempUS => '1.3.6.1.4.1.318.1.1.13.6.4.2.1.21',
  airIRG3RDUStatusSubcoolerOutletTempMetric => '1.3.6.1.4.1.318.1.1.13.6.4.2.1.22',
  airIRG3RDUStatusCondenserOutletTempUS => '1.3.6.1.4.1.318.1.1.13.6.4.2.1.23',
  airIRG3RDUStatusCondenserOutletTempMetric => '1.3.6.1.4.1.318.1.1.13.6.4.2.1.24',
  airIRG3RDUStatusCondenserInletTempUS => '1.3.6.1.4.1.318.1.1.13.6.4.2.1.25',
  airIRG3RDUStatusCondenserInletTempMetric => '1.3.6.1.4.1.318.1.1.13.6.4.2.1.26',
  airIRG3RDUStatusCondenserOutletPressureUS => '1.3.6.1.4.1.318.1.1.13.6.4.2.1.27',
  airIRG3RDUStatusCondenserOutletPressureMetric => '1.3.6.1.4.1.318.1.1.13.6.4.2.1.28',
  airIRG3RDUStatusPump1HeadPressureUS => '1.3.6.1.4.1.318.1.1.13.6.4.2.1.29',
  airIRG3RDUStatusPump1HeadPressureMetric => '1.3.6.1.4.1.318.1.1.13.6.4.2.1.30',
  airIRG3RDUStatusPump2HeadPressureUS => '1.3.6.1.4.1.318.1.1.13.6.4.2.1.31',
  airIRG3RDUStatusPump2HeadPressureMetric => '1.3.6.1.4.1.318.1.1.13.6.4.2.1.32',
  airIRG3RDUStatusPump1Speed => '1.3.6.1.4.1.318.1.1.13.6.4.2.1.33',
  airIRG3RDUStatusPump2Speed => '1.3.6.1.4.1.318.1.1.13.6.4.2.1.34',
  airIRG3RDUStatusCWValvePosition => '1.3.6.1.4.1.318.1.1.13.6.4.2.1.35',
  airIRG3RDUStatusReceiverLiquidLevel => '1.3.6.1.4.1.318.1.1.13.6.4.2.1.36',
  airIRG3RDUStatusDCPowerSupply1Current => '1.3.6.1.4.1.318.1.1.13.6.4.2.1.37',
  airIRG3RDUStatusDCPowerSupply2Current => '1.3.6.1.4.1.318.1.1.13.6.4.2.1.38',
  airIRG3RDUStatusTotalDCPowerSupplyCurrent => '1.3.6.1.4.1.318.1.1.13.6.4.2.1.39',
  airIRG3RDUStatusInputState => '1.3.6.1.4.1.318.1.1.13.6.4.2.1.40',
  airIRG3RDUStatusInputStateDefinition => 'PowerNet-MIB::airIRG3RDUStatusInputState',
  airIRG3RDUStatusOutputState => '1.3.6.1.4.1.318.1.1.13.6.4.2.1.41',
  airIRG3RDUStatusOutputStateDefinition => 'PowerNet-MIB::airIRG3RDUStatusOutputState',
  airIRG3RDUStatusByPassValvePosition => '1.3.6.1.4.1.318.1.1.13.6.4.2.1.42',
  airIRG3RDUStatusRefrigerantLeakDetector => '1.3.6.1.4.1.318.1.1.13.6.4.2.1.43',
  airIRG3RDUStatusRefrigerantLeakDetectorDefinition => 'PowerNet-MIB::airIRG3RDUStatusRefrigerantLeakDetector',
  airIRG3RDURunHoursTable => '1.3.6.1.4.1.318.1.1.13.6.4.3',
  airIRG3RDURunHoursEntry => '1.3.6.1.4.1.318.1.1.13.6.4.3.1',
  airIRG3RDURunHoursDeviceIndex => '1.3.6.1.4.1.318.1.1.13.6.4.3.1.1',
  airIRG3RDURunHoursRDUID => '1.3.6.1.4.1.318.1.1.13.6.4.3.1.2',
  airIRG3RDURunHoursPump1 => '1.3.6.1.4.1.318.1.1.13.6.4.3.1.3',
  airIRG3RDURunHoursPump2 => '1.3.6.1.4.1.318.1.1.13.6.4.3.1.4',
  airIRG3RDURunHoursPowerSupply1 => '1.3.6.1.4.1.318.1.1.13.6.4.3.1.5',
  airIRG3RDURunHoursPowerSupply2 => '1.3.6.1.4.1.318.1.1.13.6.4.3.1.6',
  airIRG3RDUServiceIntervalsTable => '1.3.6.1.4.1.318.1.1.13.6.4.4',
  airIRG3RDUServiceIntervalsEntry => '1.3.6.1.4.1.318.1.1.13.6.4.4.1',
  airIRG3RDUServiceIntervalsDeviceIndex => '1.3.6.1.4.1.318.1.1.13.6.4.4.1.1',
  airIRG3RDUServiceIntervalsRDUID => '1.3.6.1.4.1.318.1.1.13.6.4.4.1.2',
  airIRG3RDUServiceIntervalsAirFilterInterval => '1.3.6.1.4.1.318.1.1.13.6.4.4.1.3',
  airIRG3RDUServiceIntervalsAirFilterAlarm => '1.3.6.1.4.1.318.1.1.13.6.4.4.1.4',
  airIRG3RDUServiceIntervalsAirFilterAlarmDefinition => 'PowerNet-MIB::airIRG3RDUServiceIntervalsAirFilterAlarm',
  airIRG3RDUThresholdsTable => '1.3.6.1.4.1.318.1.1.13.6.4.5',
  airIRG3RDUThresholdsEntry => '1.3.6.1.4.1.318.1.1.13.6.4.5.1',
  airIRG3RDUThresholdsDeviceIndex => '1.3.6.1.4.1.318.1.1.13.6.4.5.1.1',
  airIRG3RDUThresholdsRDUID => '1.3.6.1.4.1.318.1.1.13.6.4.5.1.2',
  airIRG3RDUThresholdsEnteringFluidTempHighUS => '1.3.6.1.4.1.318.1.1.13.6.4.5.1.3',
  airIRG3RDUThresholdsEnteringFluidTempHighMetric => '1.3.6.1.4.1.318.1.1.13.6.4.5.1.4',
  airIRG3RDUSetpointsTable => '1.3.6.1.4.1.318.1.1.13.6.4.6',
  airIRG3RDUSetpointsEntry => '1.3.6.1.4.1.318.1.1.13.6.4.6.1',
  airIRG3RDUSetpointsDeviceIndex => '1.3.6.1.4.1.318.1.1.13.6.4.6.1.1',
  airIRG3RDUConfigTable => '1.3.6.1.4.1.318.1.1.13.6.4.7',
  airIRG3RDUConfigEntry => '1.3.6.1.4.1.318.1.1.13.6.4.7.1',
  airIRG3RDUConfigDeviceIndex => '1.3.6.1.4.1.318.1.1.13.6.4.7.1.1',
  airIRG3RDUConfigRDUID => '1.3.6.1.4.1.318.1.1.13.6.4.7.1.2',
  airIRG3RDUConfigStopOnLeakDetect => '1.3.6.1.4.1.318.1.1.13.6.4.7.1.3',
  airIRG3RDUConfigStopOnLeakDetectDefinition => 'PowerNet-MIB::airIRG3RDUConfigStopOnLeakDetect',
  airIRG3RDUConfigStartupDelay => '1.3.6.1.4.1.318.1.1.13.6.4.7.1.4',
  airIRG3RDUConfigPumpChangeOverInterval => '1.3.6.1.4.1.318.1.1.13.6.4.7.1.5',
  airIRG3RDUConfigPowerSource => '1.3.6.1.4.1.318.1.1.13.6.4.7.1.6',
  airIRG3RDUConfigPowerSourceDefinition => 'PowerNet-MIB::airIRG3RDUConfigPowerSource',
  airIRG3RDUConfigOutputSource => '1.3.6.1.4.1.318.1.1.13.6.4.7.1.7',
  airIRG3RDUConfigOutputSourceDefinition => 'PowerNet-MIB::airIRG3RDUConfigOutputSource',
  airIRG3RDUConfigInputNormalState => '1.3.6.1.4.1.318.1.1.13.6.4.7.1.8',
  airIRG3RDUConfigInputNormalStateDefinition => 'PowerNet-MIB::airIRG3RDUConfigInputNormalState',
  airIRG3RDUConfigOutputNormalState => '1.3.6.1.4.1.318.1.1.13.6.4.7.1.9',
  airIRG3RDUConfigOutputNormalStateDefinition => 'PowerNet-MIB::airIRG3RDUConfigOutputNormalState',
  airIRG3RDUConfigByPassValveEnabled => '1.3.6.1.4.1.318.1.1.13.6.4.7.1.10',
  airIRG3RDUConfigByPassValveEnabledDefinition => 'PowerNet-MIB::airIRG3RDUConfigByPassValveEnabled',
  airIRG3RDUConfigRefrigerantLeakDetectorEnabled => '1.3.6.1.4.1.318.1.1.13.6.4.7.1.11',
  airIRG3RDUConfigRefrigerantLeakDetectorEnabledDefinition => 'PowerNet-MIB::airIRG3RDUConfigRefrigerantLeakDetectorEnabled',
  airIRG3RDUConfigCalibrateRefrigerantLeakDetector => '1.3.6.1.4.1.318.1.1.13.6.4.7.1.12',
  airIRG3RDUConfigCalibrateRefrigerantLeakDetectorDefinition => 'PowerNet-MIB::airIRG3RDUConfigCalibrateRefrigerantLeakDetector',
  airIRG3RDUConfigOnReadyStandby => '1.3.6.1.4.1.318.1.1.13.6.4.7.1.13',
  airIRG3RDUConfigOnReadyStandbyDefinition => 'PowerNet-MIB::airIRG3RDUConfigOnReadyStandby',
  airIRG3CM => '1.3.6.1.4.1.318.1.1.13.6.5',
  airIRG3CMTableSize => '1.3.6.1.4.1.318.1.1.13.6.5.1',
  airIRG3CMStatusTable => '1.3.6.1.4.1.318.1.1.13.6.5.2',
  airIRG3CMStatusEntry => '1.3.6.1.4.1.318.1.1.13.6.5.2.1',
  airIRG3CMStatusDeviceIndex => '1.3.6.1.4.1.318.1.1.13.6.5.2.1.1',
  airIRG3CMStatusCMID => '1.3.6.1.4.1.318.1.1.13.6.5.2.1.2',
  airIRG3CMStatusOperatingMode => '1.3.6.1.4.1.318.1.1.13.6.5.2.1.3',
  airIRG3CMStatusOperatingModeDefinition => 'PowerNet-MIB::airIRG3CMStatusOperatingMode',
  airIRG3CMStatusUnitType => '1.3.6.1.4.1.318.1.1.13.6.5.2.1.4',
  airIRG3CMStatusUnitTypeDefinition => 'PowerNet-MIB::airIRG3CMStatusUnitType',
  airIRG3CMStatusRackInletTempUS => '1.3.6.1.4.1.318.1.1.13.6.5.2.1.5',
  airIRG3CMStatusRackInletTempMetric => '1.3.6.1.4.1.318.1.1.13.6.5.2.1.6',
  airIRG3CMStatusReturnAirTempUS => '1.3.6.1.4.1.318.1.1.13.6.5.2.1.7',
  airIRG3CMStatusReturnAirTempMetric => '1.3.6.1.4.1.318.1.1.13.6.5.2.1.8',
  airIRG3CMStatusLiquidTempUS => '1.3.6.1.4.1.318.1.1.13.6.5.2.1.9',
  airIRG3CMStatusLiquidTempMetric => '1.3.6.1.4.1.318.1.1.13.6.5.2.1.10',
  airIRG3CMStatusVaporTempUS => '1.3.6.1.4.1.318.1.1.13.6.5.2.1.11',
  airIRG3CMStatusVaporTempMetric => '1.3.6.1.4.1.318.1.1.13.6.5.2.1.12',
  airIRG3CMStatusEvaporatorTempUS => '1.3.6.1.4.1.318.1.1.13.6.5.2.1.13',
  airIRG3CMStatusEvaporatorTempMetric => '1.3.6.1.4.1.318.1.1.13.6.5.2.1.14',
  airIRG3CMStatusLiquidInletPressureUS => '1.3.6.1.4.1.318.1.1.13.6.5.2.1.15',
  airIRG3CMStatusLiquidInletPressureMetric => '1.3.6.1.4.1.318.1.1.13.6.5.2.1.16',
  airIRG3CMStatusVaporOutletPressureUS => '1.3.6.1.4.1.318.1.1.13.6.5.2.1.17',
  airIRG3CMStatusVaporOutletPressureMetric => '1.3.6.1.4.1.318.1.1.13.6.5.2.1.18',
  airIRG3CMStatusExpansionValvePosition => '1.3.6.1.4.1.318.1.1.13.6.5.2.1.19',
  airIRG3CMStatusEPRValvePosition => '1.3.6.1.4.1.318.1.1.13.6.5.2.1.20',
  airIRG3CMStatusLocalDisplayOnOffEnabled => '1.3.6.1.4.1.318.1.1.13.6.5.2.1.21',
  airIRG3CMStatusLocalDisplayOnOffEnabledDefinition => 'PowerNet-MIB::airIRG3CMStatusLocalDisplayOnOffEnabled',
  airIRG3CMStatusAverageFanSpeed => '1.3.6.1.4.1.318.1.1.13.6.5.2.1.22',
  airIRG3CMRunHoursTable => '1.3.6.1.4.1.318.1.1.13.6.5.3',
  airIRG3CMRunHoursEntry => '1.3.6.1.4.1.318.1.1.13.6.5.3.1',
  airIRG3CMRunHoursDeviceIndex => '1.3.6.1.4.1.318.1.1.13.6.5.3.1.1',
  airIRG3CMRunHoursCMID => '1.3.6.1.4.1.318.1.1.13.6.5.3.1.2',
  airIRG3CMRunHoursFan1 => '1.3.6.1.4.1.318.1.1.13.6.5.3.1.3',
  airIRG3CMRunHoursFan2 => '1.3.6.1.4.1.318.1.1.13.6.5.3.1.4',
  airIRG3CMRunHoursFan3 => '1.3.6.1.4.1.318.1.1.13.6.5.3.1.5',
  airIRG3CMRunHoursFan4 => '1.3.6.1.4.1.318.1.1.13.6.5.3.1.6',
  airIRG3CMRunHoursFan5 => '1.3.6.1.4.1.318.1.1.13.6.5.3.1.7',
  airIRG3CMRunHoursAirFilter => '1.3.6.1.4.1.318.1.1.13.6.5.3.1.8',
  airIRG3CMServiceIntervalsTable => '1.3.6.1.4.1.318.1.1.13.6.5.4',
  airIRG3CMServiceIntervalsEntry => '1.3.6.1.4.1.318.1.1.13.6.5.4.1',
  airIRG3CMServiceIntervalsDeviceIndex => '1.3.6.1.4.1.318.1.1.13.6.5.4.1.1',
  airIRG3CMServiceIntervalsCMID => '1.3.6.1.4.1.318.1.1.13.6.5.4.1.2',
  airIRG3CMServiceIntervalsAirFilterInterval => '1.3.6.1.4.1.318.1.1.13.6.5.4.1.3',
  airIRG3CMServiceIntervalsAirFilterAlarm => '1.3.6.1.4.1.318.1.1.13.6.5.4.1.4',
  airIRG3CMServiceIntervalsAirFilterAlarmDefinition => 'PowerNet-MIB::airIRG3CMServiceIntervalsAirFilterAlarm',
  airIRG3CMThresholdsTable => '1.3.6.1.4.1.318.1.1.13.6.5.5',
  airIRG3CMThresholdsEntry => '1.3.6.1.4.1.318.1.1.13.6.5.5.1',
  airIRG3CMThresholdsDeviceIndex => '1.3.6.1.4.1.318.1.1.13.6.5.5.1.1',
  airIRG3CMThresholdsCMID => '1.3.6.1.4.1.318.1.1.13.6.5.5.1.2',
  airIRG3CMThresholdsRackInletTempHighUS => '1.3.6.1.4.1.318.1.1.13.6.5.5.1.3',
  airIRG3CMThresholdsRackInletTempHighMetric => '1.3.6.1.4.1.318.1.1.13.6.5.5.1.4',
  airIRG3CMThresholdsSupplyAirTempHighUS => '1.3.6.1.4.1.318.1.1.13.6.5.5.1.5',
  airIRG3CMThresholdsSupplyAirTempHighMetric => '1.3.6.1.4.1.318.1.1.13.6.5.5.1.6',
  airIRG3CMThresholdsReturnAirTempHighUS => '1.3.6.1.4.1.318.1.1.13.6.5.5.1.7',
  airIRG3CMThresholdsReturnAirTempHighMetric => '1.3.6.1.4.1.318.1.1.13.6.5.5.1.8',
  airIRG3CMSetpointsTable => '1.3.6.1.4.1.318.1.1.13.6.5.6',
  airIRG3CMSetpointsEntry => '1.3.6.1.4.1.318.1.1.13.6.5.6.1',
  airIRG3CMSetpointsDeviceIndex => '1.3.6.1.4.1.318.1.1.13.6.5.6.1.1',
  airIRG3CMConfigTable => '1.3.6.1.4.1.318.1.1.13.6.5.7',
  airIRG3CMConfigEntry => '1.3.6.1.4.1.318.1.1.13.6.5.7.1',
  airIRG3CMConfigDeviceIndex => '1.3.6.1.4.1.318.1.1.13.6.5.7.1.1',
  airIRG3CMConfigCMID => '1.3.6.1.4.1.318.1.1.13.6.5.7.1.2',
  airIRG3CMConfigStopOnCoolFail => '1.3.6.1.4.1.318.1.1.13.6.5.7.1.3',
  airIRG3CMConfigStopOnCoolFailDefinition => 'PowerNet-MIB::airIRG3CMConfigStopOnCoolFail',
  airIRG3CMConfigStartupDelay => '1.3.6.1.4.1.318.1.1.13.6.5.7.1.4',
  airIRG3CMConfigRemoteOnStandby => '1.3.6.1.4.1.318.1.1.13.6.5.7.1.5',
  airIRG3CMConfigRemoteOnStandbyDefinition => 'PowerNet-MIB::airIRG3CMConfigRemoteOnStandby',
  airIRG3CMConfigPowerSource => '1.3.6.1.4.1.318.1.1.13.6.5.7.1.6',
  airIRG3CMConfigPowerSourceDefinition => 'PowerNet-MIB::airIRG3CMConfigPowerSource',
  rARU => '1.3.6.1.4.1.318.1.1.14',
  rARUIdent => '1.3.6.1.4.1.318.1.1.14.1',
  rARUIdentTable => '1.3.6.1.4.1.318.1.1.14.1.1',
  rARUIdentEntry => '1.3.6.1.4.1.318.1.1.14.1.1.1',
  rARUIdentAruIndex => '1.3.6.1.4.1.318.1.1.14.1.1.1.1',
  rARUIdentName => '1.3.6.1.4.1.318.1.1.14.1.1.1.2',
  rARUConfig => '1.3.6.1.4.1.318.1.1.14.2',
  rARUConfigTable => '1.3.6.1.4.1.318.1.1.14.2.1',
  rARUConfigEntry => '1.3.6.1.4.1.318.1.1.14.2.1.1',
  rARUConfigAruIndex => '1.3.6.1.4.1.318.1.1.14.2.1.1.1',
  rARUConfigAruName => '1.3.6.1.4.1.318.1.1.14.2.1.1.2',
  rARUConfigAruRemoteSetpoint => '1.3.6.1.4.1.318.1.1.14.2.1.1.3',
  rARUConfigAruRemoteSetpointDefinition => 'PowerNet-MIB::rARUConfigAruRemoteSetpoint',
  rARUConfigAruTempOvrdEnableDisable => '1.3.6.1.4.1.318.1.1.14.2.1.1.4',
  rARUConfigAruTempOvrdEnableDisableDefinition => 'PowerNet-MIB::rARUConfigAruTempOvrdEnableDisable',
  rARUConfigAruTempOvrdSetpoint => '1.3.6.1.4.1.318.1.1.14.2.1.1.5',
  rARUConfigAruMasterControl => '1.3.6.1.4.1.318.1.1.14.2.1.1.6',
  rARUConfigAruMasterControlDefinition => 'PowerNet-MIB::rARUConfigAruMasterControl',
  rARUStatus => '1.3.6.1.4.1.318.1.1.14.3',
  rARUStatusAruDeviceCount => '1.3.6.1.4.1.318.1.1.14.3.1',
  rARUStatusSysTempUnits => '1.3.6.1.4.1.318.1.1.14.3.2',
  rARUStatusSysTempUnitsDefinition => 'PowerNet-MIB::rARUStatusSysTempUnits',
  rARUStatusTable => '1.3.6.1.4.1.318.1.1.14.3.3',
  rARUStatusEntry => '1.3.6.1.4.1.318.1.1.14.3.3.1',
  rARUStatusAruIndex => '1.3.6.1.4.1.318.1.1.14.3.3.1.1',
  rARUStatusAruName => '1.3.6.1.4.1.318.1.1.14.3.3.1.2',
  rARUStatusAruRemoteSetpoint => '1.3.6.1.4.1.318.1.1.14.3.3.1.3',
  rARUStatusAruRemoteSetpointDefinition => 'PowerNet-MIB::rARUStatusAruRemoteSetpoint',
  rARUStatusAruManualSetpoint => '1.3.6.1.4.1.318.1.1.14.3.3.1.4',
  rARUStatusAruManualSetpointDefinition => 'PowerNet-MIB::rARUStatusAruManualSetpoint',
  rARUStatusAruTemp1 => '1.3.6.1.4.1.318.1.1.14.3.3.1.5',
  rARUStatusAruTemp2 => '1.3.6.1.4.1.318.1.1.14.3.3.1.6',
  rARUStatusAruTemp3 => '1.3.6.1.4.1.318.1.1.14.3.3.1.7',
  rARUStatusAruTempOvrdEnableDisable => '1.3.6.1.4.1.318.1.1.14.3.3.1.8',
  rARUStatusAruTempOvrdEnableDisableDefinition => 'PowerNet-MIB::rARUStatusAruTempOvrdEnableDisable',
  rARUStatusAruTempOvrdSetpoint => '1.3.6.1.4.1.318.1.1.14.3.3.1.9',
  rARUStatusAruAlarmState => '1.3.6.1.4.1.318.1.1.14.3.3.1.10',
  rARUStatusAruCommStatus => '1.3.6.1.4.1.318.1.1.14.3.3.1.11',
  rARUStatusAruCommStatusDefinition => 'PowerNet-MIB::rARUStatusAruCommStatus',
  rARUStatusAruTempOvrdStatus => '1.3.6.1.4.1.318.1.1.14.3.3.1.12',
  rARUStatusAruTempOvrdStatusDefinition => 'PowerNet-MIB::rARUStatusAruTempOvrdStatus',
  rARUStatusAruMasterControl => '1.3.6.1.4.1.318.1.1.14.3.3.1.13',
  rARUStatusAruMasterControlDefinition => 'PowerNet-MIB::rARUStatusAruMasterControl',
  rARUStatusAruTotalAirflow => '1.3.6.1.4.1.318.1.1.14.3.3.1.14',
  rARUFanStatus => '1.3.6.1.4.1.318.1.1.14.4',
  rARUFanStatusTable => '1.3.6.1.4.1.318.1.1.14.4.1',
  rARUFanStatusEntry => '1.3.6.1.4.1.318.1.1.14.4.1.1',
  rARUFanStatusAruIndex => '1.3.6.1.4.1.318.1.1.14.4.1.1.1',
  rARUFanStatusNominalFanSpeed => '1.3.6.1.4.1.318.1.1.14.4.1.1.2',
  rARUFanStatusSelectedFanLevel => '1.3.6.1.4.1.318.1.1.14.4.1.1.3',
  rARUFanStatusReplacementThreshold => '1.3.6.1.4.1.318.1.1.14.4.1.1.4',
  rARUFanStatusReplacementThresholdDefinition => 'PowerNet-MIB::rARUFanStatusReplacementThreshold',
  rARUFanStatusFanIndex => '1.3.6.1.4.1.318.1.1.14.4.1.1.5',
  rARUFanStatusFanOperatingStatus => '1.3.6.1.4.1.318.1.1.14.4.1.1.6',
  rARUFanStatusFanOperatingStatusDefinition => 'PowerNet-MIB::rARUFanStatusFanOperatingStatus',
  rARUFanStatusFanRpmSpeed => '1.3.6.1.4.1.318.1.1.14.4.1.1.7',
  rARUFanStatusFanFlowRate => '1.3.6.1.4.1.318.1.1.14.4.1.1.8',
  rARUFanStatusFanInServiceDate => '1.3.6.1.4.1.318.1.1.14.4.1.1.9',
  rARUFanStatusFanRunhourCounter => '1.3.6.1.4.1.318.1.1.14.4.1.1.10',
  rARUFanStatusFanRunhourReset => '1.3.6.1.4.1.318.1.1.14.4.1.1.11',
  rARUFanStatusFanRunhourResetDefinition => 'PowerNet-MIB::rARUFanStatusFanRunhourReset',
  rARUPower => '1.3.6.1.4.1.318.1.1.14.5',
  rARUPowerStatusTable => '1.3.6.1.4.1.318.1.1.14.5.1',
  rARUPowerStatusEntry => '1.3.6.1.4.1.318.1.1.14.5.1.1',
  rARUPowerStatusAruIndex => '1.3.6.1.4.1.318.1.1.14.5.1.1.1',
  rARUPowerStatusPrimaryAcPresent => '1.3.6.1.4.1.318.1.1.14.5.1.1.2',
  rARUPowerStatusPrimaryAcPresentDefinition => 'PowerNet-MIB::rARUPowerStatusPrimaryAcPresent',
  rARUPowerStatusAuxiliaryAcPresent => '1.3.6.1.4.1.318.1.1.14.5.1.1.3',
  rARUPowerStatusAuxiliaryAcPresentDefinition => 'PowerNet-MIB::rARUPowerStatusAuxiliaryAcPresent',
  rARUPowerStatusRedundantAcConfig => '1.3.6.1.4.1.318.1.1.14.5.1.1.4',
  rARUPowerStatusRedundantAcConfigDefinition => 'PowerNet-MIB::rARUPowerStatusRedundantAcConfig',
  rARUSensors => '1.3.6.1.4.1.318.1.1.14.6',
  rARUSensorsStatusTableSize => '1.3.6.1.4.1.318.1.1.14.6.1',
  rARUSensorsStatusTable => '1.3.6.1.4.1.318.1.1.14.6.2',
  rARUSensorsStatusEntry => '1.3.6.1.4.1.318.1.1.14.6.2.1',
  rARUSensorsStatusAruIndex => '1.3.6.1.4.1.318.1.1.14.6.2.1.1',
  rARUSensorsStatusSensorNumber => '1.3.6.1.4.1.318.1.1.14.6.2.1.2',
  rARUSensorsTemperature => '1.3.6.1.4.1.318.1.1.14.6.2.1.3',
  rARUSensorsConfigTableSize => '1.3.6.1.4.1.318.1.1.14.6.3',
  rARUSensorsConfigTable => '1.3.6.1.4.1.318.1.1.14.6.4',
  rARUSensorsConfigEntry => '1.3.6.1.4.1.318.1.1.14.6.4.1',
  rARUSensorsConfigAruIndex => '1.3.6.1.4.1.318.1.1.14.6.4.1.1',
  rARUSensorsConfigSensorNumber => '1.3.6.1.4.1.318.1.1.14.6.4.1.2',
  rARUSensorsName => '1.3.6.1.4.1.318.1.1.14.6.4.1.3',
  rARUSensorsLocation => '1.3.6.1.4.1.318.1.1.14.6.4.1.4',
  rARUSensorsTempMaxThresh => '1.3.6.1.4.1.318.1.1.14.6.4.1.5',
  rARUSensorsTempHighThresh => '1.3.6.1.4.1.318.1.1.14.6.4.1.6',
  rARUSensorsTempLowThresh => '1.3.6.1.4.1.318.1.1.14.6.4.1.7',
  rARUSensorsTempMinThresh => '1.3.6.1.4.1.318.1.1.14.6.4.1.8',
  rARUSensorsTempThreshHysteresis => '1.3.6.1.4.1.318.1.1.14.6.4.1.9',
  rARUSensorsTempShortDecRateThreshValue => '1.3.6.1.4.1.318.1.1.14.6.4.1.10',
  rARUSensorsTempShortDecRateThreshTime => '1.3.6.1.4.1.318.1.1.14.6.4.1.11',
  rARUSensorsTempShortIncRateThreshValue => '1.3.6.1.4.1.318.1.1.14.6.4.1.12',
  rARUSensorsTempShortIncRateThreshTime => '1.3.6.1.4.1.318.1.1.14.6.4.1.13',
  rARUSensorsTempLongDecRateThreshValue => '1.3.6.1.4.1.318.1.1.14.6.4.1.14',
  rARUSensorsTempLongDecRateThreshTime => '1.3.6.1.4.1.318.1.1.14.6.4.1.15',
  rARUSensorsTempLongIncRateThreshValue => '1.3.6.1.4.1.318.1.1.14.6.4.1.16',
  rARUSensorsTempLongIncRateThreshTime => '1.3.6.1.4.1.318.1.1.14.6.4.1.17',
  xPDU => '1.3.6.1.4.1.318.1.1.15',
  xPDUIdent => '1.3.6.1.4.1.318.1.1.15.1',
  xPDUIdentProductName => '1.3.6.1.4.1.318.1.1.15.1.1',
  xPDUIdentHardwareRev => '1.3.6.1.4.1.318.1.1.15.1.2',
  xPDUIdentFirmwareAppRev => '1.3.6.1.4.1.318.1.1.15.1.3',
  xPDUIdentFirmwareAppOSRev => '1.3.6.1.4.1.318.1.1.15.1.4',
  xPDUIdentFirmwareControllerRev => '1.3.6.1.4.1.318.1.1.15.1.5',
  xPDUIdentDateOfManufacture => '1.3.6.1.4.1.318.1.1.15.1.6',
  xPDUIdentModelNumber => '1.3.6.1.4.1.318.1.1.15.1.7',
  xPDUIdentSerialNumber => '1.3.6.1.4.1.318.1.1.15.1.8',
  xPDUDevice => '1.3.6.1.4.1.318.1.1.15.2',
  xPDUDeviceNominalMainInputVoltage => '1.3.6.1.4.1.318.1.1.15.2.1',
  xPDUDeviceServiceType => '1.3.6.1.4.1.318.1.1.15.2.2',
  xPDUDeviceServiceTypeDefinition => 'PowerNet-MIB::xPDUDeviceServiceType',
  xPDUDeviceNominalOutputVoltage => '1.3.6.1.4.1.318.1.1.15.2.3',
  xPDUDeviceMainInputBreakerRating => '1.3.6.1.4.1.318.1.1.15.2.4',
  xPDUDevicePanelBreakerRating => '1.3.6.1.4.1.318.1.1.15.2.5',
  xPDUDeviceTransformerPresent => '1.3.6.1.4.1.318.1.1.15.2.6',
  xPDUDeviceTransformerPresentDefinition => 'PowerNet-MIB::xPDUDeviceTransformerPresent',
  xPDUDeviceLoadTieBreakerPresent => '1.3.6.1.4.1.318.1.1.15.2.7',
  xPDUDeviceLoadTieBreakerPresentDefinition => 'PowerNet-MIB::xPDUDeviceLoadTieBreakerPresent',
  xPDUDeviceLoadTestPortPresent => '1.3.6.1.4.1.318.1.1.15.2.8',
  xPDUDeviceLoadTestPortPresentDefinition => 'PowerNet-MIB::xPDUDeviceLoadTestPortPresent',
  xPDUDeviceFusesPresent => '1.3.6.1.4.1.318.1.1.15.2.9',
  xPDUDeviceFusesPresentDefinition => 'PowerNet-MIB::xPDUDeviceFusesPresent',
  xPDUDeviceFansPresent => '1.3.6.1.4.1.318.1.1.15.2.10',
  xPDUDeviceFansPresentDefinition => 'PowerNet-MIB::xPDUDeviceFansPresent',
  xPDUDeviceBypassInputPresent => '1.3.6.1.4.1.318.1.1.15.2.11',
  xPDUDeviceBypassInputPresentDefinition => 'PowerNet-MIB::xPDUDeviceBypassInputPresent',
  xPDUDeviceCrossTieOutputPresent => '1.3.6.1.4.1.318.1.1.15.2.12',
  xPDUDeviceCrossTieOutputPresentDefinition => 'PowerNet-MIB::xPDUDeviceCrossTieOutputPresent',
  xPDUDeviceEarthGroundMonitorPresent => '1.3.6.1.4.1.318.1.1.15.2.13',
  xPDUDeviceEarthGroundMonitorPresentDefinition => 'PowerNet-MIB::xPDUDeviceEarthGroundMonitorPresent',
  xPDUDeviceInfraStruXureType => '1.3.6.1.4.1.318.1.1.15.2.14',
  xPDUDeviceInfraStruXureTypeDefinition => 'PowerNet-MIB::xPDUDeviceInfraStruXureType',
  xPDUACMonitoringPoint => '1.3.6.1.4.1.318.1.1.15.3',
  xPDUMainInput => '1.3.6.1.4.1.318.1.1.15.3.1',
  xPDUMainInputOverVoltThreshold => '1.3.6.1.4.1.318.1.1.15.3.1.1',
  xPDUMainInputUnderVoltThreshold => '1.3.6.1.4.1.318.1.1.15.3.1.2',
  xPDUMainInputVoltageTableSize => '1.3.6.1.4.1.318.1.1.15.3.1.3',
  xPDUMainInputVoltagePhaseTable => '1.3.6.1.4.1.318.1.1.15.3.1.4',
  xPDUMainInputVoltagePhaseEntry => '1.3.6.1.4.1.318.1.1.15.3.1.4.1',
  xPDUMainInputVoltagePhaseIndex => '1.3.6.1.4.1.318.1.1.15.3.1.4.1.1',
  xPDUMainInputVoltagePhaseIndexDefinition => 'PowerNet-MIB::xPDUMainInputVoltagePhaseIndex',
  xPDUMainInputVoltageLtoL => '1.3.6.1.4.1.318.1.1.15.3.1.4.1.2',
  xPDUMainInputVoltageLtoN => '1.3.6.1.4.1.318.1.1.15.3.1.4.1.3',
  xPDUBypassInput => '1.3.6.1.4.1.318.1.1.15.3.2',
  xPDUBypassInputOverVoltThreshold => '1.3.6.1.4.1.318.1.1.15.3.2.1',
  xPDUBypassInputUnderVoltThreshold => '1.3.6.1.4.1.318.1.1.15.3.2.2',
  xPDUBypassInputVoltagePhaseTableSize => '1.3.6.1.4.1.318.1.1.15.3.2.3',
  xPDUBypassInputVoltagePhaseTable => '1.3.6.1.4.1.318.1.1.15.3.2.4',
  xPDUBypassInputVoltagePhaseEntry => '1.3.6.1.4.1.318.1.1.15.3.2.4.1',
  xPDUBypassInputVoltagePhaseIndex => '1.3.6.1.4.1.318.1.1.15.3.2.4.1.1',
  xPDUBypassInputVoltagePhaseIndexDefinition => 'PowerNet-MIB::xPDUBypassInputVoltagePhaseIndex',
  xPDUBypassInputVoltageLtoL => '1.3.6.1.4.1.318.1.1.15.3.2.4.1.2',
  xPDUBypassInputVoltageLtoN => '1.3.6.1.4.1.318.1.1.15.3.2.4.1.3',
  xPDUUPSInput => '1.3.6.1.4.1.318.1.1.15.3.3',
  xPDUUPSInputVoltagePhaseTableSize => '1.3.6.1.4.1.318.1.1.15.3.3.1',
  xPDUUPSInputVoltagePhaseTable => '1.3.6.1.4.1.318.1.1.15.3.3.2',
  xPDUUPSInputVoltagePhaseEntry => '1.3.6.1.4.1.318.1.1.15.3.3.2.1',
  xPDUUPSInputVoltagePhaseIndex => '1.3.6.1.4.1.318.1.1.15.3.3.2.1.1',
  xPDUUPSInputVoltagePhaseIndexDefinition => 'PowerNet-MIB::xPDUUPSInputVoltagePhaseIndex',
  xPDUUPSInputVoltageLtoNPresent => '1.3.6.1.4.1.318.1.1.15.3.3.2.1.2',
  xPDUUPSInputVoltageLtoNPresentDefinition => 'PowerNet-MIB::xPDUUPSInputVoltageLtoNPresent',
  xPDUSystemOutput => '1.3.6.1.4.1.318.1.1.15.3.4',
  xPDUSystemOutputFrequency => '1.3.6.1.4.1.318.1.1.15.3.4.1',
  xPDUSystemOutputNeutralCurrent => '1.3.6.1.4.1.318.1.1.15.3.4.2',
  xPDUSystemOutputTotalPower => '1.3.6.1.4.1.318.1.1.15.3.4.3',
  xPDUSystemOutputTotalApparentPower => '1.3.6.1.4.1.318.1.1.15.3.4.4',
  xPDUSystemOutputTotalPowerFactor => '1.3.6.1.4.1.318.1.1.15.3.4.5',
  xPDUSystemOutputFrequencyTolerance => '1.3.6.1.4.1.318.1.1.15.3.4.6',
  xPDUSystemOutputFrequencyToleranceDefinition => 'PowerNet-MIB::xPDUSystemOutputFrequencyTolerance',
  xPDUSystemOutputMaxKWPower => '1.3.6.1.4.1.318.1.1.15.3.4.7',
  xPDUSystemOutputOverVoltThreshold => '1.3.6.1.4.1.318.1.1.15.3.4.8',
  xPDUSystemOutputUnderVoltThreshold => '1.3.6.1.4.1.318.1.1.15.3.4.9',
  xPDUSystemOutputOverCurrentThreshold => '1.3.6.1.4.1.318.1.1.15.3.4.10',
  xPDUSystemOutputOverCurrentNeutralThreshold => '1.3.6.1.4.1.318.1.1.15.3.4.11',
  xPDUSystemOutputUnderCurrentThreshold => '1.3.6.1.4.1.318.1.1.15.3.4.12',
  xPDUSystemOutputTableSize => '1.3.6.1.4.1.318.1.1.15.3.4.13',
  xPDUSystemOutputPhaseTable => '1.3.6.1.4.1.318.1.1.15.3.4.14',
  xPDUSystemOutputPhaseEntry => '1.3.6.1.4.1.318.1.1.15.3.4.14.1',
  xPDUSystemOutputPhaseIndex => '1.3.6.1.4.1.318.1.1.15.3.4.14.1.1',
  xPDUSystemOutputPhaseIndexDefinition => 'PowerNet-MIB::xPDUSystemOutputPhaseIndex',
  xPDUSystemOutputVoltageLtoL => '1.3.6.1.4.1.318.1.1.15.3.4.14.1.2',
  xPDUSystemOutputVoltageLtoN => '1.3.6.1.4.1.318.1.1.15.3.4.14.1.3',
  xPDUSystemOutputPhaseCurrent => '1.3.6.1.4.1.318.1.1.15.3.4.14.1.4',
  xPDUSystemOutputPower => '1.3.6.1.4.1.318.1.1.15.3.4.14.1.5',
  xPDUSystemOutputApparentPower => '1.3.6.1.4.1.318.1.1.15.3.4.14.1.6',
  xPDUSystemOutputPowerFactor => '1.3.6.1.4.1.318.1.1.15.3.4.14.1.7',
  xPDUGroundMonitorPoint => '1.3.6.1.4.1.318.1.1.15.3.5',
  xPDUGroundCurrent => '1.3.6.1.4.1.318.1.1.15.3.5.1',
  xPDUGroundCurrentThreshold => '1.3.6.1.4.1.318.1.1.15.3.5.2',
  xPDUCircuitBreakers => '1.3.6.1.4.1.318.1.1.15.4',
  xPDUSystemBreakers => '1.3.6.1.4.1.318.1.1.15.4.1',
  xPDUSystemBreakerTableSize => '1.3.6.1.4.1.318.1.1.15.4.1.1',
  xPDUSystemBreakerTable => '1.3.6.1.4.1.318.1.1.15.4.1.2',
  xPDUSystemBreakerEntry => '1.3.6.1.4.1.318.1.1.15.4.1.2.1',
  xPDUSystemBreakerTableIndex => '1.3.6.1.4.1.318.1.1.15.4.1.2.1.1',
  xPDUSystemBreakerDescription => '1.3.6.1.4.1.318.1.1.15.4.1.2.1.2',
  xPDUSystemBreakerPosition => '1.3.6.1.4.1.318.1.1.15.4.1.2.1.3',
  xPDUSystemBreakerPositionDefinition => 'PowerNet-MIB::xPDUSystemBreakerPosition',
  xPDUBranchBreakers => '1.3.6.1.4.1.318.1.1.15.4.2',
  xPDUNumOfBranchBreakers => '1.3.6.1.4.1.318.1.1.15.4.2.1',
  xPDUBranchBreakerTableSize => '1.3.6.1.4.1.318.1.1.15.4.2.2',
  xPDUBranchBreakerTable => '1.3.6.1.4.1.318.1.1.15.4.2.3',
  xPDUBranchBreakerEntry => '1.3.6.1.4.1.318.1.1.15.4.2.3.1',
  xPDUBranchBreakerTableIndex => '1.3.6.1.4.1.318.1.1.15.4.2.3.1.1',
  xPDUBranchBreakerRating => '1.3.6.1.4.1.318.1.1.15.4.2.3.1.2',
  xPDUBranchBreakerRDPFeed => '1.3.6.1.4.1.318.1.1.15.4.2.3.1.3',
  xPDUBranchBreakerRDPFeedDefinition => 'PowerNet-MIB::xPDUBranchBreakerRDPFeed',
  xPDUBranchBreakerTieIndicator => '1.3.6.1.4.1.318.1.1.15.4.2.3.1.4',
  xPDUBranchBreakerTieIndicatorDefinition => 'PowerNet-MIB::xPDUBranchBreakerTieIndicator',
  xPDUBranchBreakerCurrent => '1.3.6.1.4.1.318.1.1.15.4.2.3.1.5',
  xPDUBranchBreakerOverCurrentThreshold => '1.3.6.1.4.1.318.1.1.15.4.2.3.1.6',
  xPDUBranchBreakerUnderCurrentThreshold => '1.3.6.1.4.1.318.1.1.15.4.2.3.1.7',
  xPDUBranchBreakerMaxCurrentThreshold => '1.3.6.1.4.1.318.1.1.15.4.2.3.1.8',
  xPDUBranchBreakerMinCurrentThreshold => '1.3.6.1.4.1.318.1.1.15.4.2.3.1.9',
  xPDUBranchBreakerName => '1.3.6.1.4.1.318.1.1.15.4.2.3.1.10',
  xPDUBranchBreakerLocation => '1.3.6.1.4.1.318.1.1.15.4.2.3.1.11',
  xPDUInputContacts => '1.3.6.1.4.1.318.1.1.15.5',
  xPDUInputContactNumContacts => '1.3.6.1.4.1.318.1.1.15.5.1',
  xPDUInputContactTableSize => '1.3.6.1.4.1.318.1.1.15.5.2',
  xPDUInputContactTable => '1.3.6.1.4.1.318.1.1.15.5.3',
  xPDUInputContactEntry => '1.3.6.1.4.1.318.1.1.15.5.3.1',
  xPDUInputContactNumber => '1.3.6.1.4.1.318.1.1.15.5.3.1.1',
  xPDUInputContactName => '1.3.6.1.4.1.318.1.1.15.5.3.1.2',
  xPDUInputContactNormalState => '1.3.6.1.4.1.318.1.1.15.5.3.1.3',
  xPDUInputContactNormalStateDefinition => 'PowerNet-MIB::xPDUInputContactNormalState',
  xPDUInputContactCurrentState => '1.3.6.1.4.1.318.1.1.15.5.3.1.4',
  xPDUInputContactCurrentStateDefinition => 'PowerNet-MIB::xPDUInputContactCurrentState',
  xPDUOutputRelays => '1.3.6.1.4.1.318.1.1.15.6',
  xPDUOutputRelaysNumRelays => '1.3.6.1.4.1.318.1.1.15.6.1',
  xPDUOutputRelaysTableSize => '1.3.6.1.4.1.318.1.1.15.6.2',
  xPDUOutputRelayTable => '1.3.6.1.4.1.318.1.1.15.6.3',
  xPDUOutputRelayEntry => '1.3.6.1.4.1.318.1.1.15.6.3.1',
  xPDUOutputRelayNumber => '1.3.6.1.4.1.318.1.1.15.6.3.1.1',
  xPDUOutputRelayName => '1.3.6.1.4.1.318.1.1.15.6.3.1.2',
  xPDUOutputRelayNormalState => '1.3.6.1.4.1.318.1.1.15.6.3.1.3',
  xPDUOutputRelayNormalStateDefinition => 'PowerNet-MIB::xPDUOutputRelayNormalState',
  xPDUOutputRelayCurrentState => '1.3.6.1.4.1.318.1.1.15.6.3.1.4',
  xPDUOutputRelayCurrentStateDefinition => 'PowerNet-MIB::xPDUOutputRelayCurrentState',
  xPDUMiscGroup => '1.3.6.1.4.1.318.1.1.15.7',
  xPDUEPOMode => '1.3.6.1.4.1.318.1.1.15.7.1',
  xPDUEPOModeDefinition => 'PowerNet-MIB::xPDUEPOMode',
  xPDUTransformTempStatus => '1.3.6.1.4.1.318.1.1.15.7.2',
  xPDUTransformTempStatusDefinition => 'PowerNet-MIB::xPDUTransformTempStatus',
  xPDUCoolingFanStatus => '1.3.6.1.4.1.318.1.1.15.7.3',
  xPDUCoolingFanStatusDefinition => 'PowerNet-MIB::xPDUCoolingFanStatus',
  battMan => '1.3.6.1.4.1.318.1.1.16',
  battManIdent => '1.3.6.1.4.1.318.1.1.16.1',
  battManIdentProductName => '1.3.6.1.4.1.318.1.1.16.1.1',
  battManIdentHardwareRev => '1.3.6.1.4.1.318.1.1.16.1.2',
  battManIdentFirmwareRev => '1.3.6.1.4.1.318.1.1.16.1.3',
  battManIdentDateOfManufacture => '1.3.6.1.4.1.318.1.1.16.1.4',
  battManIdentModelNumber => '1.3.6.1.4.1.318.1.1.16.1.5',
  battManIdentSerialNumber => '1.3.6.1.4.1.318.1.1.16.1.6',
  battManSystemCalib => '1.3.6.1.4.1.318.1.1.16.2',
  battManOhmicValueCorrectionFactor => '1.3.6.1.4.1.318.1.1.16.2.1',
  battManUnitCalib => '1.3.6.1.4.1.318.1.1.16.3',
  battManUnitCalibTableSize => '1.3.6.1.4.1.318.1.1.16.3.1',
  battManUnitCalibTable => '1.3.6.1.4.1.318.1.1.16.3.2',
  battManUnitCalibEntry => '1.3.6.1.4.1.318.1.1.16.3.2.1',
  battManUnitCalibIndex => '1.3.6.1.4.1.318.1.1.16.3.2.1.1',
  battManUnitSerialNumber => '1.3.6.1.4.1.318.1.1.16.3.2.1.2',
  battManBatteryVoltageZeroCalib => '1.3.6.1.4.1.318.1.1.16.3.2.1.3',
  battManBatteryVoltageSpanCalib => '1.3.6.1.4.1.318.1.1.16.3.2.1.4',
  battManStringCalib => '1.3.6.1.4.1.318.1.1.16.4',
  battManStringCalibTableSize => '1.3.6.1.4.1.318.1.1.16.4.1',
  battManStringCalibTable => '1.3.6.1.4.1.318.1.1.16.4.2',
  battManStringCalibEntry => '1.3.6.1.4.1.318.1.1.16.4.2.1',
  battManStringCalibIndex => '1.3.6.1.4.1.318.1.1.16.4.2.1.1',
  battManDCCurrentZeroCalib => '1.3.6.1.4.1.318.1.1.16.4.2.1.2',
  battManACCurrentZeroCalib => '1.3.6.1.4.1.318.1.1.16.4.2.1.3',
  battManProbeRange => '1.3.6.1.4.1.318.1.1.16.4.2.1.4',
  battManProbeRangeDefinition => 'PowerNet-MIB::battManProbeRange',
  battManBatteryCalib => '1.3.6.1.4.1.318.1.1.16.5',
  battManString1BatteryCalibTableSize => '1.3.6.1.4.1.318.1.1.16.5.1',
  battManString1BatteryCalibTable => '1.3.6.1.4.1.318.1.1.16.5.2',
  battManString1BatteryCalibEntry => '1.3.6.1.4.1.318.1.1.16.5.2.1',
  battManString1BatteryCalibIndex => '1.3.6.1.4.1.318.1.1.16.5.2.1.1',
  battManString1BatteryInterTierOhmicValue => '1.3.6.1.4.1.318.1.1.16.5.2.1.2',
  battManString2BatteryCalibTableSize => '1.3.6.1.4.1.318.1.1.16.5.3',
  battManString2BatteryCalibTable => '1.3.6.1.4.1.318.1.1.16.5.4',
  battManString2BatteryCalibEntry => '1.3.6.1.4.1.318.1.1.16.5.4.1',
  battManString2BatteryCalibIndex => '1.3.6.1.4.1.318.1.1.16.5.4.1.1',
  battManString2BatteryInterTierOhmicValue => '1.3.6.1.4.1.318.1.1.16.5.4.1.2',
  battManConfig => '1.3.6.1.4.1.318.1.1.16.6',
  battManConfigApplication => '1.3.6.1.4.1.318.1.1.16.6.1',
  battManConfigApplicationDefinition => 'PowerNet-MIB::battManConfigApplication',
  battManConfigBatteryChemistry => '1.3.6.1.4.1.318.1.1.16.6.2',
  battManConfigBatteryChemistryDefinition => 'PowerNet-MIB::battManConfigBatteryChemistry',
  battManConfigBatteryAHCapacity => '1.3.6.1.4.1.318.1.1.16.6.3',
  battManConfigNumberofStrings => '1.3.6.1.4.1.318.1.1.16.6.4',
  battManConfigBatteriesperString => '1.3.6.1.4.1.318.1.1.16.6.5',
  battManConfigCellsperBattery => '1.3.6.1.4.1.318.1.1.16.6.6',
  battManConfigCellsperBatteryDefinition => 'PowerNet-MIB::battManConfigCellsperBattery',
  battManConfigMinCellVoltage => '1.3.6.1.4.1.318.1.1.16.6.7',
  battManConfigMaxCellVoltage => '1.3.6.1.4.1.318.1.1.16.6.8',
  battManConfigMaxPilotTempF => '1.3.6.1.4.1.318.1.1.16.6.9',
  battManConfigMaxPilotTempC => '1.3.6.1.4.1.318.1.1.16.6.10',
  battManConfigMaxAmbientTempF => '1.3.6.1.4.1.318.1.1.16.6.11',
  battManConfigMaxAmbientTempC => '1.3.6.1.4.1.318.1.1.16.6.12',
  battManConfigMinAmbientTempF => '1.3.6.1.4.1.318.1.1.16.6.13',
  battManConfigMinAmbientTempC => '1.3.6.1.4.1.318.1.1.16.6.14',
  battManConfigMaxRippleCurrent => '1.3.6.1.4.1.318.1.1.16.6.15',
  battManConfigMaxCurrentAcceptanceDeviation => '1.3.6.1.4.1.318.1.1.16.6.16',
  battManConfigMonitorWireLength => '1.3.6.1.4.1.318.1.1.16.6.17',
  battManConfigMonitorWireLengthDefinition => 'PowerNet-MIB::battManConfigMonitorWireLength',
  battManConfigDischargeVoltageAlarmLevel => '1.3.6.1.4.1.318.1.1.16.6.18',
  battManConfigAutoAnnunciatorReset => '1.3.6.1.4.1.318.1.1.16.6.19',
  battManConfigAutoAnnunciatorResetDefinition => 'PowerNet-MIB::battManConfigAutoAnnunciatorReset',
  battManConfigSuspendCellVoltage => '1.3.6.1.4.1.318.1.1.16.6.20',
  battManConfigOhmicTestWaitTime => '1.3.6.1.4.1.318.1.1.16.6.21',
  battManConfigNumberOfBoosts => '1.3.6.1.4.1.318.1.1.16.6.22',
  battManAlarm => '1.3.6.1.4.1.318.1.1.16.7',
  battManAlarmManagementController => '1.3.6.1.4.1.318.1.1.16.7.1',
  battManAlarmManagementControllerDefinition => 'PowerNet-MIB::battManAlarmManagementController',
  battManAlarmBatteries => '1.3.6.1.4.1.318.1.1.16.7.2',
  battManAlarmBatteriesDefinition => 'PowerNet-MIB::battManAlarmBatteries',
  battManAlarmCharger => '1.3.6.1.4.1.318.1.1.16.7.3',
  battManAlarmChargerDefinition => 'PowerNet-MIB::battManAlarmCharger',
  battManAlarmEnvironment => '1.3.6.1.4.1.318.1.1.16.7.4',
  battManAlarmEnvironmentDefinition => 'PowerNet-MIB::battManAlarmEnvironment',
  battManSystemStatus => '1.3.6.1.4.1.318.1.1.16.8',
  battManSystemAmbientTempC => '1.3.6.1.4.1.318.1.1.16.8.1',
  battManSystemAmbientTempF => '1.3.6.1.4.1.318.1.1.16.8.2',
  battManSystemPilotTempC => '1.3.6.1.4.1.318.1.1.16.8.3',
  battManSystemPilotTempF => '1.3.6.1.4.1.318.1.1.16.8.4',
  battManSystemAmbientHighTempAlarm => '1.3.6.1.4.1.318.1.1.16.8.5',
  battManSystemAmbientHighTempAlarmDefinition => 'PowerNet-MIB::battManSystemAmbientHighTempAlarm',
  battManSystemAmbientLowTempAlarm => '1.3.6.1.4.1.318.1.1.16.8.6',
  battManSystemAmbientLowTempAlarmDefinition => 'PowerNet-MIB::battManSystemAmbientLowTempAlarm',
  battManSystemPilotBatteryHighTempAlarm => '1.3.6.1.4.1.318.1.1.16.8.7',
  battManSystemPilotBatteryHighTempAlarmDefinition => 'PowerNet-MIB::battManSystemPilotBatteryHighTempAlarm',
  battManSystemPilotProbeDisconnected => '1.3.6.1.4.1.318.1.1.16.8.8',
  battManSystemPilotProbeDisconnectedDefinition => 'PowerNet-MIB::battManSystemPilotProbeDisconnected',
  battManSystemAmbientProbeDisconnected => '1.3.6.1.4.1.318.1.1.16.8.9',
  battManSystemAmbientProbeDisconnectedDefinition => 'PowerNet-MIB::battManSystemAmbientProbeDisconnected',
  battManSystemConfigurationInvalid => '1.3.6.1.4.1.318.1.1.16.8.10',
  battManSystemConfigurationInvalidDefinition => 'PowerNet-MIB::battManSystemConfigurationInvalid',
  battManSystemSuspendVoltage => '1.3.6.1.4.1.318.1.1.16.8.11',
  battManSystemSuspendVoltageDefinition => 'PowerNet-MIB::battManSystemSuspendVoltage',
  battManStringStatus => '1.3.6.1.4.1.318.1.1.16.9',
  battManStringTableSize => '1.3.6.1.4.1.318.1.1.16.9.1',
  battManStringTable => '1.3.6.1.4.1.318.1.1.16.9.2',
  battManStringEntry => '1.3.6.1.4.1.318.1.1.16.9.2.1',
  battManStringIndex => '1.3.6.1.4.1.318.1.1.16.9.2.1.1',
  battManStringCurrent => '1.3.6.1.4.1.318.1.1.16.9.2.1.2',
  battManStringRippleCurrent => '1.3.6.1.4.1.318.1.1.16.9.2.1.3',
  battManStringChargerHighVoltageAlarm => '1.3.6.1.4.1.318.1.1.16.9.2.1.4',
  battManStringChargerHighVoltageAlarmDefinition => 'PowerNet-MIB::battManStringChargerHighVoltageAlarm',
  battManStringChargerLowVoltageAlarm => '1.3.6.1.4.1.318.1.1.16.9.2.1.5',
  battManStringChargerLowVoltageAlarmDefinition => 'PowerNet-MIB::battManStringChargerLowVoltageAlarm',
  battManStringCurrentProbeDisconnected => '1.3.6.1.4.1.318.1.1.16.9.2.1.6',
  battManStringCurrentProbeDisconnectedDefinition => 'PowerNet-MIB::battManStringCurrentProbeDisconnected',
  battManStringOnBattery => '1.3.6.1.4.1.318.1.1.16.9.2.1.7',
  battManStringOnBatteryDefinition => 'PowerNet-MIB::battManStringOnBattery',
  battManStringHighRippleCurrent => '1.3.6.1.4.1.318.1.1.16.9.2.1.8',
  battManStringHighRippleCurrentDefinition => 'PowerNet-MIB::battManStringHighRippleCurrent',
  battManStringVoltage => '1.3.6.1.4.1.318.1.1.16.9.2.1.9',
  battManStringDischargeLess5Seconds => '1.3.6.1.4.1.318.1.1.16.9.2.1.10',
  battManStringDischarge5to10Seconds => '1.3.6.1.4.1.318.1.1.16.9.2.1.11',
  battManStringDischarge10to60Seconds => '1.3.6.1.4.1.318.1.1.16.9.2.1.12',
  battManStringDischargeMore60Seconds => '1.3.6.1.4.1.318.1.1.16.9.2.1.13',
  battManBatteryStatus => '1.3.6.1.4.1.318.1.1.16.10',
  battManString1BatteryTableSize => '1.3.6.1.4.1.318.1.1.16.10.1',
  battManString1BatteryTable => '1.3.6.1.4.1.318.1.1.16.10.2',
  battManString1BatteryEntry => '1.3.6.1.4.1.318.1.1.16.10.2.1',
  battManString1BatteryIndex => '1.3.6.1.4.1.318.1.1.16.10.2.1.1',
  battManString1BatteryVoltage => '1.3.6.1.4.1.318.1.1.16.10.2.1.2',
  battManString1BatteryLowestVoltage => '1.3.6.1.4.1.318.1.1.16.10.2.1.3',
  battManString1BatteryCellShorted => '1.3.6.1.4.1.318.1.1.16.10.2.1.4',
  battManString1BatteryCellShortedDefinition => 'PowerNet-MIB::battManString1BatteryCellShorted',
  battManString1BatteryOpenFuseOrConnection => '1.3.6.1.4.1.318.1.1.16.10.2.1.5',
  battManString1BatteryOpenFuseOrConnectionDefinition => 'PowerNet-MIB::battManString1BatteryOpenFuseOrConnection',
  battManString1BatteryLowCapacity => '1.3.6.1.4.1.318.1.1.16.10.2.1.6',
  battManString1BatteryLowCapacityDefinition => 'PowerNet-MIB::battManString1BatteryLowCapacity',
  battManString1BatteryHighOhmicValue => '1.3.6.1.4.1.318.1.1.16.10.2.1.7',
  battManString1BatteryHighOhmicValueDefinition => 'PowerNet-MIB::battManString1BatteryHighOhmicValue',
  battManString1BatteryThermalRunaway => '1.3.6.1.4.1.318.1.1.16.10.2.1.8',
  battManString1BatteryThermalRunawayDefinition => 'PowerNet-MIB::battManString1BatteryThermalRunaway',
  battManString1BatteryDryout => '1.3.6.1.4.1.318.1.1.16.10.2.1.9',
  battManString1BatteryDryoutDefinition => 'PowerNet-MIB::battManString1BatteryDryout',
  battManString1BatteryUserHighVoltageAlarm => '1.3.6.1.4.1.318.1.1.16.10.2.1.10',
  battManString1BatteryUserHighVoltageAlarmDefinition => 'PowerNet-MIB::battManString1BatteryUserHighVoltageAlarm',
  battManString1BatteryUserLowVoltageAlarm => '1.3.6.1.4.1.318.1.1.16.10.2.1.11',
  battManString1BatteryUserLowVoltageAlarmDefinition => 'PowerNet-MIB::battManString1BatteryUserLowVoltageAlarm',
  battManString1BatteryChemHighVoltageAlarm => '1.3.6.1.4.1.318.1.1.16.10.2.1.12',
  battManString1BatteryChemHighVoltageAlarmDefinition => 'PowerNet-MIB::battManString1BatteryChemHighVoltageAlarm',
  battManString1BatteryChemLowVoltageAlarm => '1.3.6.1.4.1.318.1.1.16.10.2.1.13',
  battManString1BatteryChemLowVoltageAlarmDefinition => 'PowerNet-MIB::battManString1BatteryChemLowVoltageAlarm',
  battManString1BatteryOpenCell => '1.3.6.1.4.1.318.1.1.16.10.2.1.14',
  battManString1BatteryOpenCellDefinition => 'PowerNet-MIB::battManString1BatteryOpenCell',
  battManString2BatteryTableSize => '1.3.6.1.4.1.318.1.1.16.10.3',
  battManString2BatteryTable => '1.3.6.1.4.1.318.1.1.16.10.4',
  battManString2BatteryEntry => '1.3.6.1.4.1.318.1.1.16.10.4.1',
  battManString2BatteryIndex => '1.3.6.1.4.1.318.1.1.16.10.4.1.1',
  battManString2BatteryVoltage => '1.3.6.1.4.1.318.1.1.16.10.4.1.2',
  battManString2BatteryLowestVoltage => '1.3.6.1.4.1.318.1.1.16.10.4.1.3',
  battManString2BatteryCellShorted => '1.3.6.1.4.1.318.1.1.16.10.4.1.4',
  battManString2BatteryCellShortedDefinition => 'PowerNet-MIB::battManString2BatteryCellShorted',
  battManString2BatteryOpenFuseOrConnection => '1.3.6.1.4.1.318.1.1.16.10.4.1.5',
  battManString2BatteryOpenFuseOrConnectionDefinition => 'PowerNet-MIB::battManString2BatteryOpenFuseOrConnection',
  battManString2BatteryLowCapacity => '1.3.6.1.4.1.318.1.1.16.10.4.1.6',
  battManString2BatteryLowCapacityDefinition => 'PowerNet-MIB::battManString2BatteryLowCapacity',
  battManString2BatteryHighOhmicValue => '1.3.6.1.4.1.318.1.1.16.10.4.1.7',
  battManString2BatteryHighOhmicValueDefinition => 'PowerNet-MIB::battManString2BatteryHighOhmicValue',
  battManString2BatteryThermalRunaway => '1.3.6.1.4.1.318.1.1.16.10.4.1.8',
  battManString2BatteryThermalRunawayDefinition => 'PowerNet-MIB::battManString2BatteryThermalRunaway',
  battManString2BatteryDryout => '1.3.6.1.4.1.318.1.1.16.10.4.1.9',
  battManString2BatteryDryoutDefinition => 'PowerNet-MIB::battManString2BatteryDryout',
  battManString2BatteryUserHighVoltageAlarm => '1.3.6.1.4.1.318.1.1.16.10.4.1.10',
  battManString2BatteryUserHighVoltageAlarmDefinition => 'PowerNet-MIB::battManString2BatteryUserHighVoltageAlarm',
  battManString2BatteryUserLowVoltageAlarm => '1.3.6.1.4.1.318.1.1.16.10.4.1.11',
  battManString2BatteryUserLowVoltageAlarmDefinition => 'PowerNet-MIB::battManString2BatteryUserLowVoltageAlarm',
  battManString2BatteryChemHighVoltageAlarm => '1.3.6.1.4.1.318.1.1.16.10.4.1.12',
  battManString2BatteryChemHighVoltageAlarmDefinition => 'PowerNet-MIB::battManString2BatteryChemHighVoltageAlarm',
  battManString2BatteryChemLowVoltageAlarm => '1.3.6.1.4.1.318.1.1.16.10.4.1.13',
  battManString2BatteryChemLowVoltageAlarmDefinition => 'PowerNet-MIB::battManString2BatteryChemLowVoltageAlarm',
  battManString2BatteryOpenCell => '1.3.6.1.4.1.318.1.1.16.10.4.1.14',
  battManString2BatteryOpenCellDefinition => 'PowerNet-MIB::battManString2BatteryOpenCell',
  battManInputContactStatus => '1.3.6.1.4.1.318.1.1.16.11',
  battManInputContactTableSize => '1.3.6.1.4.1.318.1.1.16.11.1',
  battManInputContactTable => '1.3.6.1.4.1.318.1.1.16.11.2',
  battManInputContactEntry => '1.3.6.1.4.1.318.1.1.16.11.2.1',
  battManInputContactIndex => '1.3.6.1.4.1.318.1.1.16.11.2.1.1',
  battManInputContactName => '1.3.6.1.4.1.318.1.1.16.11.2.1.2',
  battManInputContactAlarmState => '1.3.6.1.4.1.318.1.1.16.11.2.1.3',
  battManInputContactAlarmStateDefinition => 'PowerNet-MIB::battManInputContactAlarmState',
  battManInputContactState => '1.3.6.1.4.1.318.1.1.16.11.2.1.4',
  battManInputContactStateDefinition => 'PowerNet-MIB::battManInputContactState',
  battManInputContactNormalState => '1.3.6.1.4.1.318.1.1.16.11.2.1.5',
  battManInputContactNormalStateDefinition => 'PowerNet-MIB::battManInputContactNormalState',
  battManInputContactAlarmDelay => '1.3.6.1.4.1.318.1.1.16.11.2.1.6',
  battManControl => '1.3.6.1.4.1.318.1.1.16.12',
  battManRemoteAnnunciatorReset => '1.3.6.1.4.1.318.1.1.16.12.1',
  battManRemoteAnnunciatorResetDefinition => 'PowerNet-MIB::battManRemoteAnnunciatorReset',
  battManResetChargeCurrentDeviationBenchmark => '1.3.6.1.4.1.318.1.1.16.12.2',
  battManResetChargeCurrentDeviationBenchmarkDefinition => 'PowerNet-MIB::battManResetChargeCurrentDeviationBenchmark',
  battManResetLowestDischargeVoltages => '1.3.6.1.4.1.318.1.1.16.12.3',
  battManResetLowestDischargeVoltagesDefinition => 'PowerNet-MIB::battManResetLowestDischargeVoltages',
  battManResetDischargeCounters => '1.3.6.1.4.1.318.1.1.16.12.4',
  battManResetDischargeCountersDefinition => 'PowerNet-MIB::battManResetDischargeCounters',
  battManTestResults => '1.3.6.1.4.1.318.1.1.16.13',
  battManString1OhmicValueLastDischargeInfo => '1.3.6.1.4.1.318.1.1.16.13.1',
  battManString1OhmicValueTableSize => '1.3.6.1.4.1.318.1.1.16.13.2',
  battManString1OhmicValueTable => '1.3.6.1.4.1.318.1.1.16.13.3',
  battManString1OhmicValueEntry => '1.3.6.1.4.1.318.1.1.16.13.3.1',
  battManString1OhmicValueIndex => '1.3.6.1.4.1.318.1.1.16.13.3.1.1',
  battManString1OhmicValueData => '1.3.6.1.4.1.318.1.1.16.13.3.1.2',
  battManString1ResponseTestChangeTableSize => '1.3.6.1.4.1.318.1.1.16.13.4',
  battManString1ResponseTestChangeTable => '1.3.6.1.4.1.318.1.1.16.13.5',
  battManString1ResponseTestChangeEntry => '1.3.6.1.4.1.318.1.1.16.13.5.1',
  battManString1ResponseTestChangeIndex => '1.3.6.1.4.1.318.1.1.16.13.5.1.1',
  battManString1ResponseTestChangeData => '1.3.6.1.4.1.318.1.1.16.13.5.1.2',
  battManString2OhmicValueLastDischargeInfo => '1.3.6.1.4.1.318.1.1.16.13.6',
  battManString2OhmicValueTableSize => '1.3.6.1.4.1.318.1.1.16.13.7',
  battManString2OhmicValueTable => '1.3.6.1.4.1.318.1.1.16.13.8',
  battManString2OhmicValueEntry => '1.3.6.1.4.1.318.1.1.16.13.8.1',
  battManString2OhmicValueIndex => '1.3.6.1.4.1.318.1.1.16.13.8.1.1',
  battManString2OhmicValueData => '1.3.6.1.4.1.318.1.1.16.13.8.1.2',
  battManString2ResponseTestChangeTableSize => '1.3.6.1.4.1.318.1.1.16.13.9',
  battManString2ResponseTestChangeTable => '1.3.6.1.4.1.318.1.1.16.13.10',
  battManString2ResponseTestChangeEntry => '1.3.6.1.4.1.318.1.1.16.13.10.1',
  battManString2ResponseTestChangeIndex => '1.3.6.1.4.1.318.1.1.16.13.10.1.1',
  battManString2ResponseTestChangeData => '1.3.6.1.4.1.318.1.1.16.13.10.1.2',
  battManString1ResponseTestCurrentTableSize => '1.3.6.1.4.1.318.1.1.16.13.11',
  battManString1ResponseTestCurrentTable => '1.3.6.1.4.1.318.1.1.16.13.12',
  battManString1ResponseTestCurrentEntry => '1.3.6.1.4.1.318.1.1.16.13.12.1',
  battManString1ResponseTestCurrentIndex => '1.3.6.1.4.1.318.1.1.16.13.12.1.1',
  battManString1ResponseTestCurrentData => '1.3.6.1.4.1.318.1.1.16.13.12.1.2',
  battManString2ResponseTestCurrentTableSize => '1.3.6.1.4.1.318.1.1.16.13.13',
  battManString2ResponseTestCurrentTable => '1.3.6.1.4.1.318.1.1.16.13.14',
  battManString2ResponseTestCurrentEntry => '1.3.6.1.4.1.318.1.1.16.13.14.1',
  battManString2ResponseTestCurrentIndex => '1.3.6.1.4.1.318.1.1.16.13.14.1.1',
  battManString2ResponseTestCurrentData => '1.3.6.1.4.1.318.1.1.16.13.14.1.2',
  battManString1ResponseTestCurrentBenchmarkTableSize => '1.3.6.1.4.1.318.1.1.16.13.15',
  battManString1ResponseTestCurrentBenchmarkTable => '1.3.6.1.4.1.318.1.1.16.13.16',
  battManString1ResponseTestCurrentBenchmarkEntry => '1.3.6.1.4.1.318.1.1.16.13.16.1',
  battManString1ResponseTestCurrentBenchmarkIndex => '1.3.6.1.4.1.318.1.1.16.13.16.1.1',
  battManString1ResponseTestCurrentBenchmarkData => '1.3.6.1.4.1.318.1.1.16.13.16.1.2',
  battManString2ResponseTestCurrentBenchmarkTableSize => '1.3.6.1.4.1.318.1.1.16.13.17',
  battManString2ResponseTestCurrentBenchmarkTable => '1.3.6.1.4.1.318.1.1.16.13.18',
  battManString2ResponseTestCurrentBenchmarkEntry => '1.3.6.1.4.1.318.1.1.16.13.18.1',
  battManString2ResponseTestCurrentBenchmarkIndex => '1.3.6.1.4.1.318.1.1.16.13.18.1.1',
  battManString2ResponseTestCurrentBenchmarkData => '1.3.6.1.4.1.318.1.1.16.13.18.1.2',
  battManUnitStatus => '1.3.6.1.4.1.318.1.1.16.14',
  battManUnitStatusTableSize => '1.3.6.1.4.1.318.1.1.16.14.1',
  battManUnitStatusTable => '1.3.6.1.4.1.318.1.1.16.14.2',
  battManUnitStatusEntry => '1.3.6.1.4.1.318.1.1.16.14.2.1',
  battManUnitStatusIndex => '1.3.6.1.4.1.318.1.1.16.14.2.1.1',
  battManUnitStatusSerialNumber => '1.3.6.1.4.1.318.1.1.16.14.2.1.2',
  battManUnitHardwareRev => '1.3.6.1.4.1.318.1.1.16.14.2.1.3',
  battManUnitFirmwareRev => '1.3.6.1.4.1.318.1.1.16.14.2.1.4',
  battManUnitCommLoss => '1.3.6.1.4.1.318.1.1.16.14.2.1.5',
  battManUnitCommLossDefinition => 'PowerNet-MIB::battManUnitCommLoss',
  battManUnitRelayStuck => '1.3.6.1.4.1.318.1.1.16.14.2.1.6',
  battManUnitRelayStuckDefinition => 'PowerNet-MIB::battManUnitRelayStuck',
  xATS => '1.3.6.1.4.1.318.1.1.17',
  xATSIdent => '1.3.6.1.4.1.318.1.1.17.1',
  xATSIdentProductName => '1.3.6.1.4.1.318.1.1.17.1.1',
  xATSIdentHardwareRev => '1.3.6.1.4.1.318.1.1.17.1.2',
  xATSIdentFirmwareAppRev => '1.3.6.1.4.1.318.1.1.17.1.3',
  xATSIdentFirmwareAppOSRev => '1.3.6.1.4.1.318.1.1.17.1.4',
  xATSIdentFirmwareControllerRev => '1.3.6.1.4.1.318.1.1.17.1.5',
  xATSIdentDateOfManufacture => '1.3.6.1.4.1.318.1.1.17.1.6',
  xATSIdentModelNumber => '1.3.6.1.4.1.318.1.1.17.1.7',
  xATSIdentSerialNumber => '1.3.6.1.4.1.318.1.1.17.1.8',
  xATSDevice => '1.3.6.1.4.1.318.1.1.17.2',
  xATSDeviceServiceType => '1.3.6.1.4.1.318.1.1.17.2.1',
  xATSDeviceServiceTypeDefinition => 'PowerNet-MIB::xATSDeviceServiceType',
  xATSDeviceNominalVoltage => '1.3.6.1.4.1.318.1.1.17.2.2',
  xATSDeviceNominalFrequency => '1.3.6.1.4.1.318.1.1.17.2.3',
  xATSDeviceTransferSwitchRating => '1.3.6.1.4.1.318.1.1.17.2.4',
  xATSDeviceDCBackUpPresent => '1.3.6.1.4.1.318.1.1.17.2.5',
  xATSDeviceDCBackUpPresentDefinition => 'PowerNet-MIB::xATSDeviceDCBackUpPresent',
  xATSSwitch => '1.3.6.1.4.1.318.1.1.17.3',
  xATSSwitchStatus => '1.3.6.1.4.1.318.1.1.17.3.1',
  xATSSwitchStatusSelectedSource => '1.3.6.1.4.1.318.1.1.17.3.1.1',
  xATSSwitchStatusSelectedSourceDefinition => 'PowerNet-MIB::xATSSwitchStatusSelectedSource',
  xATSSwitchStatusOperationalMode => '1.3.6.1.4.1.318.1.1.17.3.1.2',
  xATSSwitchStatusOperationalModeDefinition => 'PowerNet-MIB::xATSSwitchStatusOperationalMode',
  xATSSwitchStatusAutomaticOperationSwitch => '1.3.6.1.4.1.318.1.1.17.3.1.3',
  xATSSwitchStatusAutomaticOperationSwitchDefinition => 'PowerNet-MIB::xATSSwitchStatusAutomaticOperationSwitch',
  xATSSwitchStatusEngineStartSignal => '1.3.6.1.4.1.318.1.1.17.3.1.4',
  xATSSwitchStatusEngineStartSignalDefinition => 'PowerNet-MIB::xATSSwitchStatusEngineStartSignal',
  xATSSwitchSettings => '1.3.6.1.4.1.318.1.1.17.3.2',
  xATSSwitchSettingsLowVoltageTransferPoint => '1.3.6.1.4.1.318.1.1.17.3.2.1',
  xATSSwitchSettingsHighVoltageTransferPoint => '1.3.6.1.4.1.318.1.1.17.3.2.2',
  xATSSwitchSettingsMaxFrequencyDeviation => '1.3.6.1.4.1.318.1.1.17.3.2.3',
  xATSSwitchSettingsMinPhaseBalance => '1.3.6.1.4.1.318.1.1.17.3.2.4',
  xATSSwitchSettingsNominalRotation => '1.3.6.1.4.1.318.1.1.17.3.2.5',
  xATSSwitchSettingsNominalRotationDefinition => 'PowerNet-MIB::xATSSwitchSettingsNominalRotation',
  xATSSwitchSettingsAllowClosedTransfer => '1.3.6.1.4.1.318.1.1.17.3.2.6',
  xATSSwitchSettingsAllowClosedTransferDefinition => 'PowerNet-MIB::xATSSwitchSettingsAllowClosedTransfer',
  xATSSwitchSettingsMaxSyncTime => '1.3.6.1.4.1.318.1.1.17.3.2.7',
  xATSSwitchSettingsNeutralTransferTime => '1.3.6.1.4.1.318.1.1.17.3.2.8',
  xATSSwitchSettingsClearLatchedAlarms => '1.3.6.1.4.1.318.1.1.17.3.2.9',
  xATSSwitchSettingsClearLatchedAlarmsDefinition => 'PowerNet-MIB::xATSSwitchSettingsClearLatchedAlarms',
  xATSSwitchSettingsSetToFactoryDefaults => '1.3.6.1.4.1.318.1.1.17.3.2.10',
  xATSSwitchSettingsSetToFactoryDefaultsDefinition => 'PowerNet-MIB::xATSSwitchSettingsSetToFactoryDefaults',
  xATSSwitchTimers => '1.3.6.1.4.1.318.1.1.17.3.3',
  xATSSwitchTimersTableSize => '1.3.6.1.4.1.318.1.1.17.3.3.1',
  xATSSwitchTimersTable => '1.3.6.1.4.1.318.1.1.17.3.3.2',
  xATSSwitchTimersEntry => '1.3.6.1.4.1.318.1.1.17.3.3.2.1',
  xATSSwitchTimersIndex => '1.3.6.1.4.1.318.1.1.17.3.3.2.1.1',
  xATSSwitchTimersName => '1.3.6.1.4.1.318.1.1.17.3.3.2.1.2',
  xATSSwitchTimersAbort => '1.3.6.1.4.1.318.1.1.17.3.3.2.1.3',
  xATSSwitchTimersAbortDefinition => 'PowerNet-MIB::xATSSwitchTimersAbort',
  xATSSwitchTimersStatus => '1.3.6.1.4.1.318.1.1.17.3.3.2.1.4',
  xATSSwitchTimersStatusDefinition => 'PowerNet-MIB::xATSSwitchTimersStatus',
  xATSSwitchTimersRemainingTime => '1.3.6.1.4.1.318.1.1.17.3.3.2.1.5',
  xATSSwitchTimersDelaySetting => '1.3.6.1.4.1.318.1.1.17.3.3.2.1.6',
  xATSSwitchBlockMap => '1.3.6.1.4.1.318.1.1.17.3.4',
  xATSSwitchBlockMapTableSize => '1.3.6.1.4.1.318.1.1.17.3.4.1',
  xATSSwitchBlockMapTable => '1.3.6.1.4.1.318.1.1.17.3.4.2',
  xATSSwitchBlockMapEntry => '1.3.6.1.4.1.318.1.1.17.3.4.2.1',
  xATSSwitchBlockMapIndex => '1.3.6.1.4.1.318.1.1.17.3.4.2.1.1',
  xATSSwitchBlockMapName => '1.3.6.1.4.1.318.1.1.17.3.4.2.1.2',
  xATSSwitchBlockMapStatus => '1.3.6.1.4.1.318.1.1.17.3.4.2.1.3',
  xATSSwitchBlockMapSetting => '1.3.6.1.4.1.318.1.1.17.3.4.2.1.4',
  xATSSwitchStatistics => '1.3.6.1.4.1.318.1.1.17.3.5',
  xATSSwitchStatisticsTableSize => '1.3.6.1.4.1.318.1.1.17.3.5.1',
  xATSSwitchStatisticsTable => '1.3.6.1.4.1.318.1.1.17.3.5.2',
  xATSSwitchStatisticsEntry => '1.3.6.1.4.1.318.1.1.17.3.5.2.1',
  xATSSwitchStatisticsIndex => '1.3.6.1.4.1.318.1.1.17.3.5.2.1.1',
  xATSSwitchStatisticsName => '1.3.6.1.4.1.318.1.1.17.3.5.2.1.2',
  xATSSwitchStatisticsValue => '1.3.6.1.4.1.318.1.1.17.3.5.2.1.3',
  xATSSwitchStatisticsReset => '1.3.6.1.4.1.318.1.1.17.3.5.2.1.4',
  xATSSwitchStatisticsResetDefinition => 'PowerNet-MIB::xATSSwitchStatisticsReset',
  xATSACMonitoringPoint => '1.3.6.1.4.1.318.1.1.17.4',
  xATSSource1 => '1.3.6.1.4.1.318.1.1.17.4.1',
  xATSSource1Name => '1.3.6.1.4.1.318.1.1.17.4.1.1',
  xATSSource1Position => '1.3.6.1.4.1.318.1.1.17.4.1.2',
  xATSSource1PositionDefinition => 'PowerNet-MIB::xATSSource1Position',
  xATSSource1Frequency => '1.3.6.1.4.1.318.1.1.17.4.1.3',
  xATSSource1Quality => '1.3.6.1.4.1.318.1.1.17.4.1.4',
  xATSSource1QualityDefinition => 'PowerNet-MIB::xATSSource1Quality',
  xATSSource1Rotation => '1.3.6.1.4.1.318.1.1.17.4.1.5',
  xATSSource1RotationDefinition => 'PowerNet-MIB::xATSSource1Rotation',
  xATSSource1TableSize => '1.3.6.1.4.1.318.1.1.17.4.1.6',
  xATSSource1PhaseTable => '1.3.6.1.4.1.318.1.1.17.4.1.7',
  xATSSource1PhaseEntry => '1.3.6.1.4.1.318.1.1.17.4.1.7.1',
  xATSSource1Index => '1.3.6.1.4.1.318.1.1.17.4.1.7.1.1',
  xATSSource1IndexDefinition => 'PowerNet-MIB::xATSSource1Index',
  xATSSource1VoltageLtoL => '1.3.6.1.4.1.318.1.1.17.4.1.7.1.2',
  xATSSource1VoltageLtoN => '1.3.6.1.4.1.318.1.1.17.4.1.7.1.3',
  xATSSource2 => '1.3.6.1.4.1.318.1.1.17.4.2',
  xATSSource2Name => '1.3.6.1.4.1.318.1.1.17.4.2.1',
  xATSSource2Position => '1.3.6.1.4.1.318.1.1.17.4.2.2',
  xATSSource2PositionDefinition => 'PowerNet-MIB::xATSSource2Position',
  xATSSource2Frequency => '1.3.6.1.4.1.318.1.1.17.4.2.3',
  xATSSource2Quality => '1.3.6.1.4.1.318.1.1.17.4.2.4',
  xATSSource2QualityDefinition => 'PowerNet-MIB::xATSSource2Quality',
  xATSSource2Rotation => '1.3.6.1.4.1.318.1.1.17.4.2.5',
  xATSSource2RotationDefinition => 'PowerNet-MIB::xATSSource2Rotation',
  xATSSource2TableSize => '1.3.6.1.4.1.318.1.1.17.4.2.6',
  xATSSource2PhaseTable => '1.3.6.1.4.1.318.1.1.17.4.2.7',
  xATSSource2PhaseEntry => '1.3.6.1.4.1.318.1.1.17.4.2.7.1',
  xATSSource2Index => '1.3.6.1.4.1.318.1.1.17.4.2.7.1.1',
  xATSSource2IndexDefinition => 'PowerNet-MIB::xATSSource2Index',
  xATSSource2VoltageLtoL => '1.3.6.1.4.1.318.1.1.17.4.2.7.1.2',
  xATSSource2VoltageLtoN => '1.3.6.1.4.1.318.1.1.17.4.2.7.1.3',
  xATSSystemOutput => '1.3.6.1.4.1.318.1.1.17.4.3',
  xATSSystemOutputFrequency => '1.3.6.1.4.1.318.1.1.17.4.3.1',
  xATSSystemOutputTotalPower => '1.3.6.1.4.1.318.1.1.17.4.3.2',
  xATSSystemOutputTotalApparentPower => '1.3.6.1.4.1.318.1.1.17.4.3.3',
  xATSSystemOutputTotalPowerFactor => '1.3.6.1.4.1.318.1.1.17.4.3.4',
  xATSSystemOutputFrequencyTolerance => '1.3.6.1.4.1.318.1.1.17.4.3.5',
  xATSSystemOutputFrequencyToleranceDefinition => 'PowerNet-MIB::xATSSystemOutputFrequencyTolerance',
  xATSSystemOutputOverVoltThreshold => '1.3.6.1.4.1.318.1.1.17.4.3.6',
  xATSSystemOutputUnderVoltThreshold => '1.3.6.1.4.1.318.1.1.17.4.3.7',
  xATSSystemOutputOverCurrentThreshold => '1.3.6.1.4.1.318.1.1.17.4.3.8',
  xATSSystemOutputUnderCurrentThreshold => '1.3.6.1.4.1.318.1.1.17.4.3.9',
  xATSSystemOutputAlarmDelayThreshold => '1.3.6.1.4.1.318.1.1.17.4.3.10',
  xATSSystemOutputTableSize => '1.3.6.1.4.1.318.1.1.17.4.3.11',
  xATSSystemOutputPhaseTable => '1.3.6.1.4.1.318.1.1.17.4.3.12',
  xATSSystemOutputPhaseEntry => '1.3.6.1.4.1.318.1.1.17.4.3.12.1',
  xATSSystemOutputPhaseIndex => '1.3.6.1.4.1.318.1.1.17.4.3.12.1.1',
  xATSSystemOutputPhaseIndexDefinition => 'PowerNet-MIB::xATSSystemOutputPhaseIndex',
  xATSSystemOutputVoltageLtoL => '1.3.6.1.4.1.318.1.1.17.4.3.12.1.2',
  xATSSystemOutputVoltageLtoN => '1.3.6.1.4.1.318.1.1.17.4.3.12.1.3',
  xATSSystemOutputPhaseCurrent => '1.3.6.1.4.1.318.1.1.17.4.3.12.1.4',
  xATSSystemOutputPower => '1.3.6.1.4.1.318.1.1.17.4.3.12.1.5',
  xATSSystemOutputApparentPower => '1.3.6.1.4.1.318.1.1.17.4.3.12.1.6',
  xATSSystemOutputPowerFactor => '1.3.6.1.4.1.318.1.1.17.4.3.12.1.7',
  xATSTesting => '1.3.6.1.4.1.318.1.1.17.5',
  xATSTestingStatus => '1.3.6.1.4.1.318.1.1.17.5.1',
  xATSTestingStatusSelectTestProcess => '1.3.6.1.4.1.318.1.1.17.5.1.1',
  xATSTestingStatusSelectTestProcessDefinition => 'PowerNet-MIB::xATSTestingStatusSelectTestProcess',
  xATSTestingStatusTestStatus => '1.3.6.1.4.1.318.1.1.17.5.1.2',
  xATSTestingStatusTestStatusDefinition => 'PowerNet-MIB::xATSTestingStatusTestStatus',
  xATSTestingStatusProfileWarmupTime => '1.3.6.1.4.1.318.1.1.17.5.1.3',
  xATSTestingStatusProfileLoadedTime => '1.3.6.1.4.1.318.1.1.17.5.1.4',
  xATSTestingStatusProfileUnloadedTime => '1.3.6.1.4.1.318.1.1.17.5.1.5',
  xATSTestingResults => '1.3.6.1.4.1.318.1.1.17.5.2',
  xATSTestingResultsLastDateOfTest => '1.3.6.1.4.1.318.1.1.17.5.2.1',
  xATSTestingResultsLastResult => '1.3.6.1.4.1.318.1.1.17.5.2.2',
  xATSTestingResultsLastResultDefinition => 'PowerNet-MIB::xATSTestingResultsLastResult',
  xATSTestingResultsTestLastTestTime => '1.3.6.1.4.1.318.1.1.17.5.2.3',
  xATSTestingResultsLastCrankDuration => '1.3.6.1.4.1.318.1.1.17.5.2.4',
  xATSTestingResultsLastWarmupDuration => '1.3.6.1.4.1.318.1.1.17.5.2.5',
  xATSTestingResultsLastLoadedDuration => '1.3.6.1.4.1.318.1.1.17.5.2.6',
  xATSTestingResultsLastUnloadedDuration => '1.3.6.1.4.1.318.1.1.17.5.2.7',
  xATSTestingSchedule => '1.3.6.1.4.1.318.1.1.17.5.3',
  xATSTestingScheduleFrequency => '1.3.6.1.4.1.318.1.1.17.5.3.1',
  xATSTestingScheduleFrequencyDefinition => 'PowerNet-MIB::xATSTestingScheduleFrequency',
  xATSTestingScheduleTestDay => '1.3.6.1.4.1.318.1.1.17.5.3.2',
  xATSTestingScheduleTestTime => '1.3.6.1.4.1.318.1.1.17.5.3.3',
  xATSTestingScheduleTestWithLoadInterval => '1.3.6.1.4.1.318.1.1.17.5.3.4',
  xATSTestingScheduleTestWithLoadIntervalDefinition => 'PowerNet-MIB::xATSTestingScheduleTestWithLoadInterval',
  xATSTestingScheduleTestWithLoadSelectMonth => '1.3.6.1.4.1.318.1.1.17.5.3.5',
  xATSTestingScheduleNextTestDate => '1.3.6.1.4.1.318.1.1.17.5.3.6',
  xATSTestingSimulatePowerFail => '1.3.6.1.4.1.318.1.1.17.5.4',
  xATSTestingSimulatePowerFailTest => '1.3.6.1.4.1.318.1.1.17.5.4.1',
  xATSTestingSimulatePowerFailTestDefinition => 'PowerNet-MIB::xATSTestingSimulatePowerFailTest',
  xATSTestingSimulatePowerFailTimeRemaining => '1.3.6.1.4.1.318.1.1.17.5.4.2',
  xATSInputContacts => '1.3.6.1.4.1.318.1.1.17.6',
  xATSInputContactNumContacts => '1.3.6.1.4.1.318.1.1.17.6.1',
  xATSInputContactTableSize => '1.3.6.1.4.1.318.1.1.17.6.2',
  xATSInputContactTable => '1.3.6.1.4.1.318.1.1.17.6.3',
  xATSInputContactEntry => '1.3.6.1.4.1.318.1.1.17.6.3.1',
  xATSInputContactNumber => '1.3.6.1.4.1.318.1.1.17.6.3.1.1',
  xATSInputContactName => '1.3.6.1.4.1.318.1.1.17.6.3.1.2',
  xATSInputContactNormalState => '1.3.6.1.4.1.318.1.1.17.6.3.1.3',
  xATSInputContactNormalStateDefinition => 'PowerNet-MIB::xATSInputContactNormalState',
  xATSInputContactCurrentState => '1.3.6.1.4.1.318.1.1.17.6.3.1.4',
  xATSInputContactCurrentStateDefinition => 'PowerNet-MIB::xATSInputContactCurrentState',
  xATSOutputRelays => '1.3.6.1.4.1.318.1.1.17.7',
  xATSOutputRelayNumRelays => '1.3.6.1.4.1.318.1.1.17.7.1',
  xATSOutputRelayTableSize => '1.3.6.1.4.1.318.1.1.17.7.2',
  xATSOutputRelayTable => '1.3.6.1.4.1.318.1.1.17.7.3',
  xATSOutputRelayEntry => '1.3.6.1.4.1.318.1.1.17.7.3.1',
  xATSOutputRelayNumber => '1.3.6.1.4.1.318.1.1.17.7.3.1.1',
  xATSOutputRelayName => '1.3.6.1.4.1.318.1.1.17.7.3.1.2',
  xATSOutputRelayNormalState => '1.3.6.1.4.1.318.1.1.17.7.3.1.3',
  xATSOutputRelayNormalStateDefinition => 'PowerNet-MIB::xATSOutputRelayNormalState',
  xATSOutputRelayCurrentState => '1.3.6.1.4.1.318.1.1.17.7.3.1.4',
  xATSOutputRelayCurrentStateDefinition => 'PowerNet-MIB::xATSOutputRelayCurrentState',
  xATSMisc => '1.3.6.1.4.1.318.1.1.17.8',
  generator => '1.3.6.1.4.1.318.1.1.18',
  xATSGenerator => '1.3.6.1.4.1.318.1.1.18.1',
  xATSGeneratorIdent => '1.3.6.1.4.1.318.1.1.18.1.1',
  xATSGeneratorIdentModelNumber => '1.3.6.1.4.1.318.1.1.18.1.1.1',
  xATSGeneratorIdentSerialNumber => '1.3.6.1.4.1.318.1.1.18.1.1.2',
  xATSGeneratorIdentDateofManufacture => '1.3.6.1.4.1.318.1.1.18.1.1.3',
  xATSGeneratorIdentVoltageConfiguration => '1.3.6.1.4.1.318.1.1.18.1.1.4',
  xATSGeneratorIdentMaxPowerRating => '1.3.6.1.4.1.318.1.1.18.1.1.5',
  xATSGeneratorIdentAlternatorFrequency => '1.3.6.1.4.1.318.1.1.18.1.1.6',
  xATSGeneratorStatus => '1.3.6.1.4.1.318.1.1.18.1.2',
  xATSGeneratorStatusGeneratorName => '1.3.6.1.4.1.318.1.1.18.1.2.1',
  xATSGeneratorStatusOperational => '1.3.6.1.4.1.318.1.1.18.1.2.2',
  xATSGeneratorStatusOperationalDefinition => 'PowerNet-MIB::xATSGeneratorStatusOperational',
  xATSGeneratorStatusModeSwitchPosition => '1.3.6.1.4.1.318.1.1.18.1.2.3',
  xATSGeneratorStatusModeSwitchPositionDefinition => 'PowerNet-MIB::xATSGeneratorStatusModeSwitchPosition',
  xATSGeneratorStatusRemoteStart => '1.3.6.1.4.1.318.1.1.18.1.2.4',
  xATSGeneratorStatusRemoteStartDefinition => 'PowerNet-MIB::xATSGeneratorStatusRemoteStart',
  xATSGeneratorAdvStatus => '1.3.6.1.4.1.318.1.1.18.1.3',
  xATSGeneratorAdvStatusBatteryVoltage => '1.3.6.1.4.1.318.1.1.18.1.3.1',
  xATSGeneratorAdvStatusOilPressure => '1.3.6.1.4.1.318.1.1.18.1.3.2',
  xATSGeneratorAdvStatusCoolantTemperature => '1.3.6.1.4.1.318.1.1.18.1.3.3',
  xATSGeneratorAdvStatusEngineRPM => '1.3.6.1.4.1.318.1.1.18.1.3.4',
  xATSGeneratorAdvStatusOilLevel => '1.3.6.1.4.1.318.1.1.18.1.3.5',
  xATSGeneratorAdvStatusOilLevelDefinition => 'PowerNet-MIB::xATSGeneratorAdvStatusOilLevel',
  xATSGeneratorAdvStatusCoolantLevel => '1.3.6.1.4.1.318.1.1.18.1.3.6',
  xATSGeneratorAdvStatusCoolantLevelDefinition => 'PowerNet-MIB::xATSGeneratorAdvStatusCoolantLevel',
  xATSGeneratorOutput => '1.3.6.1.4.1.318.1.1.18.1.4',
  xATSGeneratorOutputFrequency => '1.3.6.1.4.1.318.1.1.18.1.4.1',
  xATSGeneratorOutputTotalPower => '1.3.6.1.4.1.318.1.1.18.1.4.2',
  xATSGeneratorOutputTotalApparentPower => '1.3.6.1.4.1.318.1.1.18.1.4.3',
  xATSGeneratorOutputTotalPowerFactor => '1.3.6.1.4.1.318.1.1.18.1.4.4',
  xATSGeneratorOutputTableSize => '1.3.6.1.4.1.318.1.1.18.1.4.5',
  xATSGeneratorOutputPhaseTable => '1.3.6.1.4.1.318.1.1.18.1.4.6',
  xATSGeneratorOutputPhaseEntry => '1.3.6.1.4.1.318.1.1.18.1.4.6.1',
  xATSGeneratorOutputPhaseIndex => '1.3.6.1.4.1.318.1.1.18.1.4.6.1.1',
  xATSGeneratorOutputPhaseIndexDefinition => 'PowerNet-MIB::xATSGeneratorOutputPhaseIndex',
  xATSGeneratorOutputVoltageLtoL => '1.3.6.1.4.1.318.1.1.18.1.4.6.1.2',
  xATSGeneratorOutputVoltageLtoN => '1.3.6.1.4.1.318.1.1.18.1.4.6.1.3',
  xATSGeneratorOutputPhaseCurrent => '1.3.6.1.4.1.318.1.1.18.1.4.6.1.4',
  xATSGeneratorOutputPower => '1.3.6.1.4.1.318.1.1.18.1.4.6.1.5',
  xATSGeneratorOutputApparentPower => '1.3.6.1.4.1.318.1.1.18.1.4.6.1.6',
  xATSGeneratorOutputPowerFactor => '1.3.6.1.4.1.318.1.1.18.1.4.6.1.7',
  xATSGeneratorSettings => '1.3.6.1.4.1.318.1.1.18.1.5',
  xATSGeneratorSettingsVoltageAdjust => '1.3.6.1.4.1.318.1.1.18.1.5.1',
  xATSGeneratorSettingsFrequencyAdjust => '1.3.6.1.4.1.318.1.1.18.1.5.2',
  xATSGeneratorSettingsStartDelay => '1.3.6.1.4.1.318.1.1.18.1.5.3',
  xATSGeneratorSettingsStopDelay => '1.3.6.1.4.1.318.1.1.18.1.5.4',
  xATSGeneratorSettingsCrankCycleEnable => '1.3.6.1.4.1.318.1.1.18.1.5.5',
  xATSGeneratorSettingsCrankCycleEnableDefinition => 'PowerNet-MIB::xATSGeneratorSettingsCrankCycleEnable',
  xATSGeneratorSettingsCrankTime => '1.3.6.1.4.1.318.1.1.18.1.5.6',
  xATSGeneratorSettingsCrankRestTime => '1.3.6.1.4.1.318.1.1.18.1.5.7',
  xATSGeneratorSettingsNumberCrank => '1.3.6.1.4.1.318.1.1.18.1.5.8',
  xATSGeneratorSettingsMetricUnit => '1.3.6.1.4.1.318.1.1.18.1.5.9',
  xATSGeneratorSettingsMetricUnitDefinition => 'PowerNet-MIB::xATSGeneratorSettingsMetricUnit',
  xATSGeneratorService => '1.3.6.1.4.1.318.1.1.18.1.6',
  xATSGeneratorServiceTotalRunHoursLifetime => '1.3.6.1.4.1.318.1.1.18.1.6.1',
  xATSGeneratorServiceEngineStartsLifetime => '1.3.6.1.4.1.318.1.1.18.1.6.2',
  xATSGeneratorServiceTotalkWhLifetime => '1.3.6.1.4.1.318.1.1.18.1.6.3',
  xATSGeneratorServiceTotalRunHoursSinceMaintenance => '1.3.6.1.4.1.318.1.1.18.1.6.4',
  xATSGeneratorServiceEngineStartsSinceMaintenance => '1.3.6.1.4.1.318.1.1.18.1.6.5',
  xATSGeneratorServiceTotalkWhMaintenance => '1.3.6.1.4.1.318.1.1.18.1.6.6',
  xATSGeneratorServiceResetRecord => '1.3.6.1.4.1.318.1.1.18.1.6.7',
  xATSGeneratorServiceResetRecordDefinition => 'PowerNet-MIB::xATSGeneratorServiceResetRecord',
  xATSGeneratorServiceRecordResetDate => '1.3.6.1.4.1.318.1.1.18.1.6.8',
  xATSGeneratorServiceNextServiceDate => '1.3.6.1.4.1.318.1.1.18.1.6.9',
  xATSGeneratorServiceRunHoursUntilServiceDate => '1.3.6.1.4.1.318.1.1.18.1.6.10',
  xATSGeneratorServiceRunHoursThreshold => '1.3.6.1.4.1.318.1.1.18.1.6.11',
  xATSGeneratorServiceRunHoursThresholdDefinition => 'PowerNet-MIB::xATSGeneratorServiceRunHoursThreshold',
  xATSGeneratorServiceCalendarIntervalThreshold => '1.3.6.1.4.1.318.1.1.18.1.6.12',
  xATSGeneratorServiceCalendarIntervalThresholdDefinition => 'PowerNet-MIB::xATSGeneratorServiceCalendarIntervalThreshold',
  xATSGeneratorFuelSystem => '1.3.6.1.4.1.318.1.1.18.1.7',
  xATSGeneratorFuelSystemType => '1.3.6.1.4.1.318.1.1.18.1.7.1',
  xATSGeneratorFuelSystemTypeDefinition => 'PowerNet-MIB::xATSGeneratorFuelSystemType',
  xATSGeneratorFuelSystemTankSize => '1.3.6.1.4.1.318.1.1.18.1.7.2',
  xATSGeneratorFuelSystemFuelLevel => '1.3.6.1.4.1.318.1.1.18.1.7.3',
  xATSGeneratorFuelSystemRuntimePower => '1.3.6.1.4.1.318.1.1.18.1.7.4',
  xATSGeneratorFuelSystemEstimatedRunTime => '1.3.6.1.4.1.318.1.1.18.1.7.5',
  xATSGeneratorFuelSystemLowRunTimeThreshold => '1.3.6.1.4.1.318.1.1.18.1.7.6',
  xATSGeneratorFuelSystemLowRunTimeThresholdDefinition => 'PowerNet-MIB::xATSGeneratorFuelSystemLowRunTimeThreshold',
  xATSGeneratorFuelSystemVeryLowRunTimeThreshold => '1.3.6.1.4.1.318.1.1.18.1.7.7',
  xATSGeneratorFuelSystemVeryLowRunTimeThresholdDefinition => 'PowerNet-MIB::xATSGeneratorFuelSystemVeryLowRunTimeThreshold',
  xATSGeneratorFuelSystemLowFuelLevelThreshold => '1.3.6.1.4.1.318.1.1.18.1.7.8',
  xATSGeneratorFuelSystemVeryLowFuelLevelThreshold => '1.3.6.1.4.1.318.1.1.18.1.7.9',
  consolePortServer => '1.3.6.1.4.1.318.1.1.19',
  cpsAP930x => '1.3.6.1.4.1.318.1.1.19.1',
  cpsAP930xSys => '1.3.6.1.4.1.318.1.1.19.1.1',
  apCPSpname => '1.3.6.1.4.1.318.1.1.19.1.1.1',
  apCPSversion => '1.3.6.1.4.1.318.1.1.19.1.1.2',
  apCPSPower => '1.3.6.1.4.1.318.1.1.19.1.1.3',
  apCPSPwNum => '1.3.6.1.4.1.318.1.1.19.1.1.3.1',
  apCPSPw1 => '1.3.6.1.4.1.318.1.1.19.1.1.3.2',
  apCPSPw2 => '1.3.6.1.4.1.318.1.1.19.1.1.3.3',
  apCPSPcmcia => '1.3.6.1.4.1.318.1.1.19.1.1.4',
  apCPSNPcmcia => '1.3.6.1.4.1.318.1.1.19.1.1.4.1',
  cpsCardIdentTable => '1.3.6.1.4.1.318.1.1.19.1.1.4.2',
  cpsCardIdentEntry => '1.3.6.1.4.1.318.1.1.19.1.1.4.2.1',
  cpsCardIdentIndex => '1.3.6.1.4.1.318.1.1.19.1.1.4.2.1.1',
  cpsCardIdentProd => '1.3.6.1.4.1.318.1.1.19.1.1.4.2.1.2',
  cpsCardIdentMan => '1.3.6.1.4.1.318.1.1.19.1.1.4.2.1.3',
  cpsCardIdentFunc => '1.3.6.1.4.1.318.1.1.19.1.1.4.2.1.4',
  cpsCardIdentPCI => '1.3.6.1.4.1.318.1.1.19.1.1.4.2.1.5',
  cpsCardConfTable => '1.3.6.1.4.1.318.1.1.19.1.1.4.3',
  cpsCardConfEntry => '1.3.6.1.4.1.318.1.1.19.1.1.4.3.1',
  cpsCardConfIndex => '1.3.6.1.4.1.318.1.1.19.1.1.4.3.1.1',
  cpsCardConfPower => '1.3.6.1.4.1.318.1.1.19.1.1.4.3.1.2',
  cpsCardConfType => '1.3.6.1.4.1.318.1.1.19.1.1.4.3.1.3',
  cpsCardConfInter => '1.3.6.1.4.1.318.1.1.19.1.1.4.3.1.4',
  cpsCardConfFunc => '1.3.6.1.4.1.318.1.1.19.1.1.4.3.1.5',
  cpsCardConfCardv => '1.3.6.1.4.1.318.1.1.19.1.1.4.3.1.6',
  cpsCardConfPort1 => '1.3.6.1.4.1.318.1.1.19.1.1.4.3.1.7',
  cpsCardConfPort2 => '1.3.6.1.4.1.318.1.1.19.1.1.4.3.1.8',
  cpsCardStatusTable => '1.3.6.1.4.1.318.1.1.19.1.1.4.4',
  cpsCardStatusEntry => '1.3.6.1.4.1.318.1.1.19.1.1.4.4.1',
  cpsCardStatusIndex => '1.3.6.1.4.1.318.1.1.19.1.1.4.4.1.1',
  cpsCardStatusCard => '1.3.6.1.4.1.318.1.1.19.1.1.4.4.1.2',
  cpsCardStatusFunc => '1.3.6.1.4.1.318.1.1.19.1.1.4.4.1.3',
  apCPSFlashSize => '1.3.6.1.4.1.318.1.1.19.1.1.5',
  apCPSRAMSize => '1.3.6.1.4.1.318.1.1.19.1.1.6',
  apCPSCPUfreq => '1.3.6.1.4.1.318.1.1.19.1.1.7',
  apCPSDevId => '1.3.6.1.4.1.318.1.1.19.1.1.8',
  cpsAP930xConf => '1.3.6.1.4.1.318.1.1.19.1.2',
  cpsHostName => '1.3.6.1.4.1.318.1.1.19.1.2.1',
  cpsConsoleBanner => '1.3.6.1.4.1.318.1.1.19.1.2.2',
  cpsMotd => '1.3.6.1.4.1.318.1.1.19.1.2.3',
  cpsEthItf => '1.3.6.1.4.1.318.1.1.19.1.2.4',
  cpsEthDhcpc => '1.3.6.1.4.1.318.1.1.19.1.2.4.1',
  cpsEthIPaddr => '1.3.6.1.4.1.318.1.1.19.1.2.4.2',
  cpsEthIPmask => '1.3.6.1.4.1.318.1.1.19.1.2.4.3',
  cpsEthMTU => '1.3.6.1.4.1.318.1.1.19.1.2.4.4',
  cpsEthIPaddr2 => '1.3.6.1.4.1.318.1.1.19.1.2.4.5',
  cpsEthIPmask2 => '1.3.6.1.4.1.318.1.1.19.1.2.4.6',
  cpsNameService => '1.3.6.1.4.1.318.1.1.19.1.2.5',
  cpsResolverOrder => '1.3.6.1.4.1.318.1.1.19.1.2.5.1',
  cpsMultipleIP => '1.3.6.1.4.1.318.1.1.19.1.2.5.2',
  cpsDNSserv => '1.3.6.1.4.1.318.1.1.19.1.2.5.3',
  cpsDNSpriserv => '1.3.6.1.4.1.318.1.1.19.1.2.5.3.1',
  cpsDNSsecserv => '1.3.6.1.4.1.318.1.1.19.1.2.5.3.2',
  cpsDNSdomain => '1.3.6.1.4.1.318.1.1.19.1.2.5.3.3',
  cpsSerialPortConf => '1.3.6.1.4.1.318.1.1.19.1.2.6',
  cpsSerialGlobal => '1.3.6.1.4.1.318.1.1.19.1.2.6.1',
  cpsSerialInclude => '1.3.6.1.4.1.318.1.1.19.1.2.6.1.1',
  cpsSerialNFS => '1.3.6.1.4.1.318.1.1.19.1.2.6.1.2',
  cpsSerialLockDir => '1.3.6.1.4.1.318.1.1.19.1.2.6.1.3',
  cpsSerialRlogin => '1.3.6.1.4.1.318.1.1.19.1.2.6.1.4',
  cpsSerialPppd => '1.3.6.1.4.1.318.1.1.19.1.2.6.1.5',
  cpsSerialTelnet => '1.3.6.1.4.1.318.1.1.19.1.2.6.1.6',
  cpsSerialSsh => '1.3.6.1.4.1.318.1.1.19.1.2.6.1.7',
  cpsSerialLocalLogins => '1.3.6.1.4.1.318.1.1.19.1.2.6.1.8',
  cpsSerialFacility => '1.3.6.1.4.1.318.1.1.19.1.2.6.1.9',
  cpsSerialDBFacility => '1.3.6.1.4.1.318.1.1.19.1.2.6.1.10',
  cpsSerialGroupTable => '1.3.6.1.4.1.318.1.1.19.1.2.6.1.11',
  cpsSerialGroupEntry => '1.3.6.1.4.1.318.1.1.19.1.2.6.1.11.1',
  cpsSerialGroupIndex => '1.3.6.1.4.1.318.1.1.19.1.2.6.1.11.1.1',
  cpsSerialGroupName => '1.3.6.1.4.1.318.1.1.19.1.2.6.1.11.1.2',
  cpsSerialGroupUsers => '1.3.6.1.4.1.318.1.1.19.1.2.6.1.11.1.3',
  cpsSerialSpec => '1.3.6.1.4.1.318.1.1.19.1.2.6.2',
  cpsSerialPortTable => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1',
  cpsSerialPortEntry => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1.1',
  cpsSerialPortNumber => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1.1.1',
  cpsSerialPortTty => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1.1.2',
  cpsSerialPortName => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1.1.3',
  cpsSerialPortSpeed => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1.1.4',
  cpsSerialPortDataSize => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1.1.5',
  cpsSerialPortStopBits => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1.1.6',
  cpsSerialPortParity => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1.1.7',
  cpsSerialPortFlowCtrl => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1.1.8',
  cpsSerialPortDTRdelay => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1.1.9',
  cpsSerialPortDCDCtrl => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1.1.10',
  cpsSerialPortLogUtmp => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1.1.11',
  cpsSerialPortLogWtmp => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1.1.12',
  cpsSerialPortLogform => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1.1.13',
  cpsSerialPortAuthtype => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1.1.14',
  cpsSerialPortAuthSrv1 => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1.1.15',
  cpsSerialPortAccSrv1 => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1.1.16',
  cpsSerialPortAuthTmo => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1.1.17',
  cpsSerialPortAuthRetr => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1.1.18',
  cpsSerialPortAuthSrv2 => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1.1.19',
  cpsSerialPortAccSrv2 => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1.1.20',
  cpsSerialPortAuthSecret => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1.1.21',
  cpsSerialPortAuthRadP => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1.1.22',
  cpsSerialPortAuthAcc => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1.1.23',
  cpsSerialPortProtocol => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1.1.24',
  cpsSerialPortRemoteIP => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1.1.25',
  cpsSerialPortSocketPort => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1.1.26',
  cpsSerialPortRemHost => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1.1.27',
  cpsSerialPortBanner => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1.1.28',
  cpsSerialPortPrompt => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1.1.29',
  cpsSerialPortTermType => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1.1.30',
  cpsSerialPortAutomUsr => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1.1.31',
  cpsSerialPortNetMask => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1.1.32',
  cpsSerialPortPppMtu => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1.1.33',
  cpsSerialPortPppMru => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1.1.34',
  cpsSerialPortPppOptions => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1.1.35',
  cpsSerialPortPppFoption => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1.1.36',
  cpsSerialPortModemChat => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1.1.37',
  cpsSerialPortSttyCmd => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1.1.38',
  cpsSerialPortSockTx => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1.1.39',
  cpsSerialPortSockPoll => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1.1.40',
  cpsSerialPortSockIdle => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1.1.41',
  cpsSerialPortDBsize => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1.1.42',
  cpsSerialPortDBtime => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1.1.43',
  cpsSerialPortDBmode => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1.1.44',
  cpsSerialPortDBsyslog => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1.1.45',
  cpsSerialPortDBmenu => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1.1.46',
  cpsSerialPortDBalarm => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1.1.47',
  cpsSerialPortSSHbreak => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1.1.48',
  cpsSerialPortSniffSess => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1.1.49',
  cpsSerialPortSniffAdm => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1.1.50',
  cpsSerialPortSniffEsc => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1.1.51',
  cpsSerialPortSniffMsess => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1.1.52',
  cpsSerialPortTelnetMode => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1.1.53',
  cpsSerialPortSysBufSess => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1.1.54',
  cpsSerialPortLFSuppress => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1.1.55',
  cpsSerialPortAutoInput => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1.1.56',
  cpsSerialPortAutoOutput => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1.1.57',
  cpsSerialPortBreakInterval => '1.3.6.1.4.1.318.1.1.19.1.2.6.2.1.1.58',
  cpsAP930xInfo => '1.3.6.1.4.1.318.1.1.19.1.3',
  cpsInfoSerialPortTable => '1.3.6.1.4.1.318.1.1.19.1.3.1',
  cpsInfoSerialPortEntry => '1.3.6.1.4.1.318.1.1.19.1.3.1.1',
  cpsInfoSerialPortNumber => '1.3.6.1.4.1.318.1.1.19.1.3.1.1.1',
  cpsInfoSerialPortTty => '1.3.6.1.4.1.318.1.1.19.1.3.1.1.2',
  cpsInfoSerialPortName => '1.3.6.1.4.1.318.1.1.19.1.3.1.1.3',
  cpsInfoSerialPortSpeed => '1.3.6.1.4.1.318.1.1.19.1.3.1.1.4',
  cpsInfoSerialPortTxBytes => '1.3.6.1.4.1.318.1.1.19.1.3.1.1.5',
  cpsInfoSerialPortRXBytes => '1.3.6.1.4.1.318.1.1.19.1.3.1.1.6',
  cpsInfoSerialPortErrFrame => '1.3.6.1.4.1.318.1.1.19.1.3.1.1.7',
  cpsInfoSerialPortErrParity => '1.3.6.1.4.1.318.1.1.19.1.3.1.1.8',
  cpsInfoSerialPortErrBreaks => '1.3.6.1.4.1.318.1.1.19.1.3.1.1.9',
  cpsInfoSerialPortErrOverrun => '1.3.6.1.4.1.318.1.1.19.1.3.1.1.10',
  cpsInfoSerialPortSigDTR => '1.3.6.1.4.1.318.1.1.19.1.3.1.1.11',
  cpsInfoSerialPortSigCD => '1.3.6.1.4.1.318.1.1.19.1.3.1.1.12',
  cpsInfoSerialPortSigDSR => '1.3.6.1.4.1.318.1.1.19.1.3.1.1.13',
  cpsInfoSerialPortSigRTS => '1.3.6.1.4.1.318.1.1.19.1.3.1.1.14',
  cpsInfoSerialPortSigCTS => '1.3.6.1.4.1.318.1.1.19.1.3.1.1.15',
  cpsInfoSerialPortSigRI => '1.3.6.1.4.1.318.1.1.19.1.3.1.1.16',
  cpsAP930xAdm => '1.3.6.1.4.1.318.1.1.19.1.4',
  apCPSSave => '1.3.6.1.4.1.318.1.1.19.1.4.1',
  apCPSSerialHUP => '1.3.6.1.4.1.318.1.1.19.1.4.2',
  accessControl => '1.3.6.1.4.1.318.1.1.20',
  accessPX => '1.3.6.1.4.1.318.1.1.20.1',
  accessPXIdent => '1.3.6.1.4.1.318.1.1.20.1.1',
  accessPXIdentAlarmStatus => '1.3.6.1.4.1.318.1.1.20.1.1.1',
  accessPXIdentProductNumber => '1.3.6.1.4.1.318.1.1.20.1.1.2',
  accessPXIdentHardwareRev => '1.3.6.1.4.1.318.1.1.20.1.1.3',
  accessPXIdentDateOfManufacture => '1.3.6.1.4.1.318.1.1.20.1.1.4',
  accessPXIdentSerialNumber => '1.3.6.1.4.1.318.1.1.20.1.1.5',
  accessPXConfig => '1.3.6.1.4.1.318.1.1.20.1.2',
  accessPXConfigCardReaderEnableDisableAction => '1.3.6.1.4.1.318.1.1.20.1.2.1',
  accessPXConfigCardReaderEnableDisableActionDefinition => 'PowerNet-MIB::accessPXConfigCardReaderEnableDisableAction',
  accessPXConfigAutoRelockTime => '1.3.6.1.4.1.318.1.1.20.1.2.2',
  accessPXConfigCardFormat => '1.3.6.1.4.1.318.1.1.20.1.2.3',
  accessPXConfigCardFormatDefinition => 'PowerNet-MIB::accessPXConfigCardFormat',
  accessPXConfigFront => '1.3.6.1.4.1.318.1.1.20.1.3',
  accessPXConfigFrontDoorLockControl => '1.3.6.1.4.1.318.1.1.20.1.3.1',
  accessPXConfigFrontDoorLockControlDefinition => 'PowerNet-MIB::accessPXConfigFrontDoorLockControl',
  accessPXConfigFrontDoorMaxOpenTime => '1.3.6.1.4.1.318.1.1.20.1.3.2',
  accessPXStatusFront => '1.3.6.1.4.1.318.1.1.20.1.4',
  accessPXStatusFrontDoorLock => '1.3.6.1.4.1.318.1.1.20.1.4.1',
  accessPXStatusFrontDoorLockDefinition => 'PowerNet-MIB::accessPXStatusFrontDoorLock',
  accessPXStatusFrontDoor => '1.3.6.1.4.1.318.1.1.20.1.4.2',
  accessPXStatusFrontDoorDefinition => 'PowerNet-MIB::accessPXStatusFrontDoor',
  accessPXStatusFrontDoorHandle => '1.3.6.1.4.1.318.1.1.20.1.4.3',
  accessPXStatusFrontDoorHandleDefinition => 'PowerNet-MIB::accessPXStatusFrontDoorHandle',
  accessPXStatusFrontDoorMaxOpenTime => '1.3.6.1.4.1.318.1.1.20.1.4.4',
  accessPXStatusFrontDoorAlarmStatus => '1.3.6.1.4.1.318.1.1.20.1.4.5',
  accessPXConfigRear => '1.3.6.1.4.1.318.1.1.20.1.5',
  accessPXConfigRearDoorLockControl => '1.3.6.1.4.1.318.1.1.20.1.5.1',
  accessPXConfigRearDoorLockControlDefinition => 'PowerNet-MIB::accessPXConfigRearDoorLockControl',
  accessPXConfigRearDoorMaxOpenTime => '1.3.6.1.4.1.318.1.1.20.1.5.2',
  accessPXStatusRear => '1.3.6.1.4.1.318.1.1.20.1.6',
  accessPXStatusRearDoorLock => '1.3.6.1.4.1.318.1.1.20.1.6.1',
  accessPXStatusRearDoorLockDefinition => 'PowerNet-MIB::accessPXStatusRearDoorLock',
  accessPXStatusRearDoor => '1.3.6.1.4.1.318.1.1.20.1.6.2',
  accessPXStatusRearDoorDefinition => 'PowerNet-MIB::accessPXStatusRearDoor',
  accessPXStatusRearDoorHandle => '1.3.6.1.4.1.318.1.1.20.1.6.3',
  accessPXStatusRearDoorHandleDefinition => 'PowerNet-MIB::accessPXStatusRearDoorHandle',
  accessPXStatusRearDoorMaxOpenTime => '1.3.6.1.4.1.318.1.1.20.1.6.4',
  accessPXStatusRearDoorAlarmStatus => '1.3.6.1.4.1.318.1.1.20.1.6.5',
  accessPXConfigBeacon => '1.3.6.1.4.1.318.1.1.20.1.7',
  accessPXConfigBeaconName => '1.3.6.1.4.1.318.1.1.20.1.7.1',
  accessPXConfigBeaconLocation => '1.3.6.1.4.1.318.1.1.20.1.7.2',
  accessPXConfigBeaconAction => '1.3.6.1.4.1.318.1.1.20.1.7.3',
  accessPXConfigBeaconActionDefinition => 'PowerNet-MIB::accessPXConfigBeaconAction',
  accessPXStatusBeacon => '1.3.6.1.4.1.318.1.1.20.1.8',
  accessPXStatusBeaconName => '1.3.6.1.4.1.318.1.1.20.1.8.1',
  accessPXStatusBeaconLocation => '1.3.6.1.4.1.318.1.1.20.1.8.2',
  accessPXStatusBeaconCurrentState => '1.3.6.1.4.1.318.1.1.20.1.8.3',
  accessPXStatusBeaconCurrentStateDefinition => 'PowerNet-MIB::accessPXStatusBeaconCurrentState',
  apcLocalDisplay => '1.3.6.1.4.1.318.1.1.21',
  apcLocalDisplayIdent => '1.3.6.1.4.1.318.1.1.21.1',
  apcLocalDisplayIdentDisplayType => '1.3.6.1.4.1.318.1.1.21.1.1',
  apcLocalDisplayIdentDisplayTypeDefinition => 'PowerNet-MIB::apcLocalDisplayIdentDisplayType',
  apcLocalDisplayIdentModelNumber => '1.3.6.1.4.1.318.1.1.21.1.2',
  apcLocalDisplayIdentFirmwareRev => '1.3.6.1.4.1.318.1.1.21.1.3',
  apcLocalDisplayIdentOptions => '1.3.6.1.4.1.318.1.1.21.1.4',
  apcLocalDisplayIdentDateOfManufacture => '1.3.6.1.4.1.318.1.1.21.1.5',
  apcLocalDisplayIdentSerialNumber => '1.3.6.1.4.1.318.1.1.21.1.6',
  apcLocalDisplayConfig => '1.3.6.1.4.1.318.1.1.21.2',
  apcLocalDisplayConfigAlarmBeeper => '1.3.6.1.4.1.318.1.1.21.2.1',
  apcLocalDisplayConfigAlarmBeeperDefinition => 'PowerNet-MIB::apcLocalDisplayConfigAlarmBeeper',
  apcLocalDisplayConfigBeeperVolume => '1.3.6.1.4.1.318.1.1.21.2.2',
  apcLocalDisplayConfigBeeperVolumeDefinition => 'PowerNet-MIB::apcLocalDisplayConfigBeeperVolume',
  apcLocalDisplayConfigCheckLogIndicator => '1.3.6.1.4.1.318.1.1.21.2.3',
  apcLocalDisplayConfigCheckLogIndicatorDefinition => 'PowerNet-MIB::apcLocalDisplayConfigCheckLogIndicator',
  apcLocalDisplayConfigKeyClick => '1.3.6.1.4.1.318.1.1.21.2.4',
  apcLocalDisplayConfigKeyClickDefinition => 'PowerNet-MIB::apcLocalDisplayConfigKeyClick',
  apcLocalDisplayConfigContrast => '1.3.6.1.4.1.318.1.1.21.2.5',
  apcLocalDisplayConfigContrastDefinition => 'PowerNet-MIB::apcLocalDisplayConfigContrast',
  isxModularDistribution => '1.3.6.1.4.1.318.1.1.22',
  isxModularDistInfo => '1.3.6.1.4.1.318.1.1.22.1',
  isxModularDistInfoTableSize => '1.3.6.1.4.1.318.1.1.22.1.1',
  isxModularDistInfoTable => '1.3.6.1.4.1.318.1.1.22.1.2',
  isxModularDistInfoEntry => '1.3.6.1.4.1.318.1.1.22.1.2.1',
  isxModularDistInfoSegmentIndex => '1.3.6.1.4.1.318.1.1.22.1.2.1.1',
  isxModularDistInfoMeterModelNumber => '1.3.6.1.4.1.318.1.1.22.1.2.1.2',
  isxModularDistInfoMeterSerialNumber => '1.3.6.1.4.1.318.1.1.22.1.2.1.3',
  isxModularDistInfoMeterDateOfManufacture => '1.3.6.1.4.1.318.1.1.22.1.2.1.4',
  isxModularDistInfoMeterFirmwareRev => '1.3.6.1.4.1.318.1.1.22.1.2.1.5',
  isxModularDistInfoMeterHardwareRev => '1.3.6.1.4.1.318.1.1.22.1.2.1.6',
  isxModularDistModules => '1.3.6.1.4.1.318.1.1.22.2',
  isxModularDistModuleInfoTableSize => '1.3.6.1.4.1.318.1.1.22.2.1',
  isxModularDistModuleInfoTable => '1.3.6.1.4.1.318.1.1.22.2.2',
  isxModularDistModuleInfoEntry => '1.3.6.1.4.1.318.1.1.22.2.2.1',
  isxModularDistModuleInfoModIndex => '1.3.6.1.4.1.318.1.1.22.2.2.1.1',
  isxModularDistModuleInfoAlarmStatus => '1.3.6.1.4.1.318.1.1.22.2.2.1.2',
  isxModularDistModuleInfoAlarmStatusDefinition => 'PowerNet-MIB::isxModularDistModuleInfoAlarmStatus',
  isxModularDistModuleInfoModelNumber => '1.3.6.1.4.1.318.1.1.22.2.2.1.3',
  isxModularDistModuleInfoSerialNumber => '1.3.6.1.4.1.318.1.1.22.2.2.1.4',
  isxModularDistModuleInfoDateOfManufacture => '1.3.6.1.4.1.318.1.1.22.2.2.1.5',
  isxModularDistModuleInfoNumCables => '1.3.6.1.4.1.318.1.1.22.2.2.1.6',
  isxModularDistModuleBreakerTableSize => '1.3.6.1.4.1.318.1.1.22.2.3',
  isxModularDistModuleBreakerTable => '1.3.6.1.4.1.318.1.1.22.2.4',
  isxModularDistModuleBreakerEntry => '1.3.6.1.4.1.318.1.1.22.2.4.1',
  isxModularDistModuleBreakerModIndex => '1.3.6.1.4.1.318.1.1.22.2.4.1.1',
  isxModularDistModuleBreakerPhaseIndex => '1.3.6.1.4.1.318.1.1.22.2.4.1.2',
  isxModularDistModuleBreakerPhaseIndexDefinition => 'PowerNet-MIB::isxModularDistModuleBreakerPhaseIndex',
  isxModularDistModuleBreakerAlarmStatus => '1.3.6.1.4.1.318.1.1.22.2.4.1.3',
  isxModularDistModuleBreakerRating => '1.3.6.1.4.1.318.1.1.22.2.4.1.4',
  isxModularDistModuleBreakerPhysicalGroup => '1.3.6.1.4.1.318.1.1.22.2.4.1.5',
  isxModularDistModuleBreakerCableNum => '1.3.6.1.4.1.318.1.1.22.2.4.1.6',
  isxModularDistModuleBreakerPosition => '1.3.6.1.4.1.318.1.1.22.2.4.1.7',
  isxModularDistModuleBreakerPositionDefinition => 'PowerNet-MIB::isxModularDistModuleBreakerPosition',
  isxModularDistModuleBreakerPositionAlarms => '1.3.6.1.4.1.318.1.1.22.2.4.1.8',
  isxModularDistModuleBreakerPositionAlarmsDefinition => 'PowerNet-MIB::isxModularDistModuleBreakerPositionAlarms',
  isxModularDistModuleBreakerCurrent => '1.3.6.1.4.1.318.1.1.22.2.4.1.9',
  isxModularDistModuleBreakerPercent => '1.3.6.1.4.1.318.1.1.22.2.4.1.10',
  isxModularDistModuleBreakerPower => '1.3.6.1.4.1.318.1.1.22.2.4.1.11',
  isxModularDistModuleOutputsTableSize => '1.3.6.1.4.1.318.1.1.22.2.5',
  isxModularDistModuleOutputTable => '1.3.6.1.4.1.318.1.1.22.2.6',
  isxModularDistModuleOutputEntry => '1.3.6.1.4.1.318.1.1.22.2.6.1',
  isxModularDistModuleOutputModIndex => '1.3.6.1.4.1.318.1.1.22.2.6.1.1',
  isxModularDistModuleOutputNumCables => '1.3.6.1.4.1.318.1.1.22.2.6.1.2',
  isxModularDistModuleOutputCordIndex => '1.3.6.1.4.1.318.1.1.22.2.6.1.3',
  isxModularDistModuleOutputName => '1.3.6.1.4.1.318.1.1.22.2.6.1.4',
  isxModularDistModuleOutputLocation => '1.3.6.1.4.1.318.1.1.22.2.6.1.5',
  isxModularDistModuleOutputStatus => '1.3.6.1.4.1.318.1.1.22.2.6.1.6',
  isxModularDistModuleOutputStatusDefinition => 'PowerNet-MIB::isxModularDistModuleOutputStatus',
  isxModularDistModuleOutputAlarmGeneration => '1.3.6.1.4.1.318.1.1.22.2.6.1.7',
  isxModularDistModuleOutputAlarmGenerationDefinition => 'PowerNet-MIB::isxModularDistModuleOutputAlarmGeneration',
  isxModularDistModuleOutputBreakerMap => '1.3.6.1.4.1.318.1.1.22.2.6.1.8',
  isxModularDistModuleOutputThresholdMin => '1.3.6.1.4.1.318.1.1.22.2.6.1.9',
  isxModularDistModuleOutputThresholdLow => '1.3.6.1.4.1.318.1.1.22.2.6.1.10',
  isxModularDistModuleOutputThresholdHigh => '1.3.6.1.4.1.318.1.1.22.2.6.1.11',
  isxModularDistModuleOutputThresholdMax => '1.3.6.1.4.1.318.1.1.22.2.6.1.12',
  isxModularDistModuleOutputAlarmMinEnable => '1.3.6.1.4.1.318.1.1.22.2.6.1.13',
  isxModularDistModuleOutputAlarmMinEnableDefinition => 'PowerNet-MIB::isxModularDistModuleOutputAlarmMinEnable',
  isxModularDistModuleOutputAlarmLowEnable => '1.3.6.1.4.1.318.1.1.22.2.6.1.14',
  isxModularDistModuleOutputAlarmLowEnableDefinition => 'PowerNet-MIB::isxModularDistModuleOutputAlarmLowEnable',
  isxModularDistModuleOutputAlarmHighEnable => '1.3.6.1.4.1.318.1.1.22.2.6.1.15',
  isxModularDistModuleOutputAlarmHighEnableDefinition => 'PowerNet-MIB::isxModularDistModuleOutputAlarmHighEnable',
  isxModularDistModuleOutputAlarmMaxEnable => '1.3.6.1.4.1.318.1.1.22.2.6.1.16',
  isxModularDistModuleOutputAlarmMaxEnableDefinition => 'PowerNet-MIB::isxModularDistModuleOutputAlarmMaxEnable',
  isxModularDistModuleOutputCableLength => '1.3.6.1.4.1.318.1.1.22.2.6.1.17',
  isxModularDistModuleOutputConnectorType => '1.3.6.1.4.1.318.1.1.22.2.6.1.18',
  isxModularDistModuleOutputAvailableVoltages => '1.3.6.1.4.1.318.1.1.22.2.6.1.19',
  isxModularDistModuleOutputTotalPower => '1.3.6.1.4.1.318.1.1.22.2.6.1.20',
  isxModularDistModuleOutputKwhUsage => '1.3.6.1.4.1.318.1.1.22.2.6.1.21',
  isxModularDistModuleOutputKwhReset => '1.3.6.1.4.1.318.1.1.22.2.6.1.22',
  isxModularDistModuleOutputKwhResetDefinition => 'PowerNet-MIB::isxModularDistModuleOutputKwhReset',
  isxModularDistModuleOutputKwhResetDate => '1.3.6.1.4.1.318.1.1.22.2.6.1.23',
  isxModularDistSubFeeds => '1.3.6.1.4.1.318.1.1.22.3',
  isxModularDistSubFeedInfoTableSize => '1.3.6.1.4.1.318.1.1.22.3.1',
  isxModularDistSubFeedInfoTable => '1.3.6.1.4.1.318.1.1.22.3.2',
  isxModularDistSubFeedInfoEntry => '1.3.6.1.4.1.318.1.1.22.3.2.1',
  isxModularDistSubFeedInfoSubIndex => '1.3.6.1.4.1.318.1.1.22.3.2.1.1',
  isxModularDistSubFeedInfoName => '1.3.6.1.4.1.318.1.1.22.3.2.1.2',
  isxModularDistSubFeedInfoLocation => '1.3.6.1.4.1.318.1.1.22.3.2.1.3',
  isxModularDistSubFeedInfoBreakerRating => '1.3.6.1.4.1.318.1.1.22.3.2.1.4',
  isxModularDistSubFeedInfoBreakerPosition => '1.3.6.1.4.1.318.1.1.22.3.2.1.5',
  isxModularDistSubFeedInfoBreakerPositionDefinition => 'PowerNet-MIB::isxModularDistSubFeedInfoBreakerPosition',
  isxModularDistSubFeedInfoAlarmStatus => '1.3.6.1.4.1.318.1.1.22.3.2.1.6',
  isxModularDistSubFeedInfoAlarmStatusDefinition => 'PowerNet-MIB::isxModularDistSubFeedInfoAlarmStatus',
  isxModularDistSubFeedInfoAlarmGeneration => '1.3.6.1.4.1.318.1.1.22.3.2.1.7',
  isxModularDistSubFeedInfoAlarmGenerationDefinition => 'PowerNet-MIB::isxModularDistSubFeedInfoAlarmGeneration',
  isxModularDistSubFeedInfoThresholdMin => '1.3.6.1.4.1.318.1.1.22.3.2.1.8',
  isxModularDistSubFeedInfoThresholdLow => '1.3.6.1.4.1.318.1.1.22.3.2.1.9',
  isxModularDistSubFeedInfoThresholdHigh => '1.3.6.1.4.1.318.1.1.22.3.2.1.10',
  isxModularDistSubFeedInfoThresholdMax => '1.3.6.1.4.1.318.1.1.22.3.2.1.11',
  isxModularDistSubFeedInfoAlarmMinEnable => '1.3.6.1.4.1.318.1.1.22.3.2.1.12',
  isxModularDistSubFeedInfoAlarmMinEnableDefinition => 'PowerNet-MIB::isxModularDistSubFeedInfoAlarmMinEnable',
  isxModularDistSubFeedInfoAlarmLowEnable => '1.3.6.1.4.1.318.1.1.22.3.2.1.13',
  isxModularDistSubFeedInfoAlarmLowEnableDefinition => 'PowerNet-MIB::isxModularDistSubFeedInfoAlarmLowEnable',
  isxModularDistSubFeedInfoAlarmHighEnable => '1.3.6.1.4.1.318.1.1.22.3.2.1.14',
  isxModularDistSubFeedInfoAlarmHighEnableDefinition => 'PowerNet-MIB::isxModularDistSubFeedInfoAlarmHighEnable',
  isxModularDistSubFeedInfoAlarmMaxEnable => '1.3.6.1.4.1.318.1.1.22.3.2.1.15',
  isxModularDistSubFeedInfoAlarmMaxEnableDefinition => 'PowerNet-MIB::isxModularDistSubFeedInfoAlarmMaxEnable',
  isxModularDistSubFeedInfoBreakerAlarmEnable => '1.3.6.1.4.1.318.1.1.22.3.2.1.16',
  isxModularDistSubFeedInfoBreakerAlarmEnableDefinition => 'PowerNet-MIB::isxModularDistSubFeedInfoBreakerAlarmEnable',
  isxModularDistSubFeedInfoTotalPower => '1.3.6.1.4.1.318.1.1.22.3.2.1.17',
  isxModularDistSubFeedInfoKwhUsage => '1.3.6.1.4.1.318.1.1.22.3.2.1.18',
  isxModularDistSubFeedInfoKwhReset => '1.3.6.1.4.1.318.1.1.22.3.2.1.19',
  isxModularDistSubFeedInfoKwhResetDefinition => 'PowerNet-MIB::isxModularDistSubFeedInfoKwhReset',
  isxModularDistSubFeedInfoKwhResetDate => '1.3.6.1.4.1.318.1.1.22.3.2.1.20',
  isxModularDistSubFeedLoadingTableSize => '1.3.6.1.4.1.318.1.1.22.3.3',
  isxModularDistSubFeedLoadingTable => '1.3.6.1.4.1.318.1.1.22.3.4',
  isxModularDistSubFeedLoadingEntry => '1.3.6.1.4.1.318.1.1.22.3.4.1',
  isxModularDistSubFeedLoadingSubIndex => '1.3.6.1.4.1.318.1.1.22.3.4.1.1',
  isxModularDistSubFeedLoadingPhaseIndex => '1.3.6.1.4.1.318.1.1.22.3.4.1.2',
  isxModularDistSubFeedLoadingPhaseIndexDefinition => 'PowerNet-MIB::isxModularDistSubFeedLoadingPhaseIndex',
  isxModularDistSubFeedLoadingAlarmStatus => '1.3.6.1.4.1.318.1.1.22.3.4.1.3',
  isxModularDistSubFeedLoadingCurrent => '1.3.6.1.4.1.318.1.1.22.3.4.1.4',
  isxModularDistSubFeedLoadingPercent => '1.3.6.1.4.1.318.1.1.22.3.4.1.5',
  isxModularDistSubFeedLoadingPower => '1.3.6.1.4.1.318.1.1.22.3.4.1.6',
  isxModularDistTotals => '1.3.6.1.4.1.318.1.1.22.4',
  isxModularDistSysVoltage => '1.3.6.1.4.1.318.1.1.22.4.1',
  isxModularDistSysOutputVoltageNominalLineToNeutral => '1.3.6.1.4.1.318.1.1.22.4.1.1',
  isxModularDistSysOutputVoltageNominalLineToLine => '1.3.6.1.4.1.318.1.1.22.4.1.2',
  isxModularDistSysOutputNominalFrequency => '1.3.6.1.4.1.318.1.1.22.4.1.3',
  isxModularDistSysOutputFrequency => '1.3.6.1.4.1.318.1.1.22.4.1.4',
  isxModularDistSysOutputVoltageMonitoring => '1.3.6.1.4.1.318.1.1.22.4.1.5',
  isxModularDistSysOutputVoltageMonitoringDefinition => 'PowerNet-MIB::isxModularDistSysOutputVoltageMonitoring',
  isxModularDistSysOutputVoltageThresholdMin => '1.3.6.1.4.1.318.1.1.22.4.1.6',
  isxModularDistSysOutputVoltageThresholdLow => '1.3.6.1.4.1.318.1.1.22.4.1.7',
  isxModularDistSysOutputVoltageThresholdHigh => '1.3.6.1.4.1.318.1.1.22.4.1.8',
  isxModularDistSysOutputVoltageThresholdMax => '1.3.6.1.4.1.318.1.1.22.4.1.9',
  isxModularDistSysOutputVoltageAlarmMinEnable => '1.3.6.1.4.1.318.1.1.22.4.1.10',
  isxModularDistSysOutputVoltageAlarmMinEnableDefinition => 'PowerNet-MIB::isxModularDistSysOutputVoltageAlarmMinEnable',
  isxModularDistSysOutputVoltageAlarmLowEnable => '1.3.6.1.4.1.318.1.1.22.4.1.11',
  isxModularDistSysOutputVoltageAlarmLowEnableDefinition => 'PowerNet-MIB::isxModularDistSysOutputVoltageAlarmLowEnable',
  isxModularDistSysOutputVoltageAlarmHighEnable => '1.3.6.1.4.1.318.1.1.22.4.1.12',
  isxModularDistSysOutputVoltageAlarmHighEnableDefinition => 'PowerNet-MIB::isxModularDistSysOutputVoltageAlarmHighEnable',
  isxModularDistSysOutputVoltageAlarmMaxEnable => '1.3.6.1.4.1.318.1.1.22.4.1.13',
  isxModularDistSysOutputVoltageAlarmMaxEnableDefinition => 'PowerNet-MIB::isxModularDistSysOutputVoltageAlarmMaxEnable',
  isxModularDistSysOutputVoltageFrequencyTolerance => '1.3.6.1.4.1.318.1.1.22.4.1.14',
  isxModularDistSysOutputVoltageFrequencyToleranceDefinition => 'PowerNet-MIB::isxModularDistSysOutputVoltageFrequencyTolerance',
  isxModularDistSysVoltageTable => '1.3.6.1.4.1.318.1.1.22.4.1.15',
  isxModularDistSysVoltageEntry => '1.3.6.1.4.1.318.1.1.22.4.1.15.1',
  isxModularDistSysVoltagePhaseIndex => '1.3.6.1.4.1.318.1.1.22.4.1.15.1.1',
  isxModularDistSysVoltagePhaseIndexDefinition => 'PowerNet-MIB::isxModularDistSysVoltagePhaseIndex',
  isxModularDistSysVoltageAlarmStatus => '1.3.6.1.4.1.318.1.1.22.4.1.15.1.2',
  isxModularDistSysVoltageLtoN => '1.3.6.1.4.1.318.1.1.22.4.1.15.1.3',
  isxModularDistSysVoltageLtoL => '1.3.6.1.4.1.318.1.1.22.4.1.15.1.4',
  isxModularDistSysCurrent => '1.3.6.1.4.1.318.1.1.22.4.2',
  isxModularDistSysCurrentRating => '1.3.6.1.4.1.318.1.1.22.4.2.1',
  isxModularDistSysCurrentMonitoring => '1.3.6.1.4.1.318.1.1.22.4.2.2',
  isxModularDistSysCurrentMonitoringDefinition => 'PowerNet-MIB::isxModularDistSysCurrentMonitoring',
  isxModularDistSysCurrentThresholdMin => '1.3.6.1.4.1.318.1.1.22.4.2.3',
  isxModularDistSysCurrentThresholdLow => '1.3.6.1.4.1.318.1.1.22.4.2.4',
  isxModularDistSysCurrentThresholdHigh => '1.3.6.1.4.1.318.1.1.22.4.2.5',
  isxModularDistSysCurrentThresholdMax => '1.3.6.1.4.1.318.1.1.22.4.2.6',
  isxModularDistSysCurrentAlarmMinEnable => '1.3.6.1.4.1.318.1.1.22.4.2.7',
  isxModularDistSysCurrentAlarmMinEnableDefinition => 'PowerNet-MIB::isxModularDistSysCurrentAlarmMinEnable',
  isxModularDistSysCurrentAlarmLowEnable => '1.3.6.1.4.1.318.1.1.22.4.2.8',
  isxModularDistSysCurrentAlarmLowEnableDefinition => 'PowerNet-MIB::isxModularDistSysCurrentAlarmLowEnable',
  isxModularDistSysCurrentAlarmHighEnable => '1.3.6.1.4.1.318.1.1.22.4.2.9',
  isxModularDistSysCurrentAlarmHighEnableDefinition => 'PowerNet-MIB::isxModularDistSysCurrentAlarmHighEnable',
  isxModularDistSysCurrentAlarmMaxEnable => '1.3.6.1.4.1.318.1.1.22.4.2.10',
  isxModularDistSysCurrentAlarmMaxEnableDefinition => 'PowerNet-MIB::isxModularDistSysCurrentAlarmMaxEnable',
  isxModularDistSysCurrentTable => '1.3.6.1.4.1.318.1.1.22.4.2.11',
  isxModularDistSysCurrentEntry => '1.3.6.1.4.1.318.1.1.22.4.2.11.1',
  isxModularDistSysCurrentPhaseIndex => '1.3.6.1.4.1.318.1.1.22.4.2.11.1.1',
  isxModularDistSysCurrentPhaseIndexDefinition => 'PowerNet-MIB::isxModularDistSysCurrentPhaseIndex',
  isxModularDistSysCurrentAlarmStatus => '1.3.6.1.4.1.318.1.1.22.4.2.11.1.2',
  isxModularDistSysCurrentAmps => '1.3.6.1.4.1.318.1.1.22.4.2.11.1.3',
  isxModularDistSysCurrentPercent => '1.3.6.1.4.1.318.1.1.22.4.2.11.1.4',
  isxModularDistSysPower => '1.3.6.1.4.1.318.1.1.22.4.3',
  isxModularDistSysPowerTotal => '1.3.6.1.4.1.318.1.1.22.4.3.1',
  isxModularDistSysPowerKwhUsage => '1.3.6.1.4.1.318.1.1.22.4.3.2',
  isxModularDistSysPowerKwhReset => '1.3.6.1.4.1.318.1.1.22.4.3.3',
  isxModularDistSysPowerKwhResetDefinition => 'PowerNet-MIB::isxModularDistSysPowerKwhReset',
  isxModularDistSysPowerKwhResetDate => '1.3.6.1.4.1.318.1.1.22.4.3.4',
  isxModularDistSysPowerTable => '1.3.6.1.4.1.318.1.1.22.4.3.5',
  isxModularDistSysPowerEntry => '1.3.6.1.4.1.318.1.1.22.4.3.5.1',
  isxModularDistSysPowerPhaseIndex => '1.3.6.1.4.1.318.1.1.22.4.3.5.1.1',
  isxModularDistSysPowerPhaseIndexDefinition => 'PowerNet-MIB::isxModularDistSysPowerPhaseIndex',
  isxModularDistSysPowerKw => '1.3.6.1.4.1.318.1.1.22.4.3.5.1.2',
  isxModularDistSysPowerKwhPhaseUsage => '1.3.6.1.4.1.318.1.1.22.4.3.5.1.3',
  isxModularPdu => '1.3.6.1.4.1.318.1.1.23',
  isxModularPduIdent => '1.3.6.1.4.1.318.1.1.23.1',
  isxModularPduIdentModelNumber => '1.3.6.1.4.1.318.1.1.23.1.1',
  isxModularPduIdentSerialNumber => '1.3.6.1.4.1.318.1.1.23.1.2',
  isxModularPduIdentDateOfManufacture => '1.3.6.1.4.1.318.1.1.23.1.3',
  isxModularPduIdentMonitorCardSerialNumber => '1.3.6.1.4.1.318.1.1.23.1.4',
  isxModularPduIdentMonitorCardHardwareRev => '1.3.6.1.4.1.318.1.1.23.1.5',
  isxModularPduIdentMonitorCardFirmwareAppRev => '1.3.6.1.4.1.318.1.1.23.1.6',
  isxModularPduIdentMonitorCardFirmwareAppOSRev => '1.3.6.1.4.1.318.1.1.23.1.7',
  isxModularPduDevice => '1.3.6.1.4.1.318.1.1.23.2',
  isxModularPduDeviceTransformerPresent => '1.3.6.1.4.1.318.1.1.23.2.1',
  isxModularPduDeviceTransformerPresentDefinition => 'PowerNet-MIB::isxModularPduDeviceTransformerPresent',
  isxModularPduDeviceServiceType => '1.3.6.1.4.1.318.1.1.23.2.2',
  isxModularPduDeviceServiceTypeDefinition => 'PowerNet-MIB::isxModularPduDeviceServiceType',
  isxModularPduDeviceFansPresent => '1.3.6.1.4.1.318.1.1.23.2.3',
  isxModularPduDeviceFansPresentDefinition => 'PowerNet-MIB::isxModularPduDeviceFansPresent',
  isxModularPduDeviceNominalMainInputVoltage => '1.3.6.1.4.1.318.1.1.23.2.4',
  isxModularPduStatus => '1.3.6.1.4.1.318.1.1.23.3',
  isxModularPduAlarmStatus => '1.3.6.1.4.1.318.1.1.23.3.1',
  isxModularPduAlarmStatusDefinition => 'PowerNet-MIB::isxModularPduAlarmStatus',
  isxModularPduTransformerTempStatus => '1.3.6.1.4.1.318.1.1.23.3.2',
  isxModularPduTransformerTempStatusDefinition => 'PowerNet-MIB::isxModularPduTransformerTempStatus',
  isxModularPduFanStatus => '1.3.6.1.4.1.318.1.1.23.3.3',
  isxModularPduFanStatusDefinition => 'PowerNet-MIB::isxModularPduFanStatus',
  universalInputOutput => '1.3.6.1.4.1.318.1.1.25',
  uioSensor => '1.3.6.1.4.1.318.1.1.25.1',
  uioSensorStatusTableSize => '1.3.6.1.4.1.318.1.1.25.1.1',
  uioSensorStatusTable => '1.3.6.1.4.1.318.1.1.25.1.2',
  uioSensorStatusEntry => '1.3.6.1.4.1.318.1.1.25.1.2.1',
  uioSensorStatusPortID => '1.3.6.1.4.1.318.1.1.25.1.2.1.1',
  uioSensorStatusSensorID => '1.3.6.1.4.1.318.1.1.25.1.2.1.2',
  uioSensorStatusSensorName => '1.3.6.1.4.1.318.1.1.25.1.2.1.3',
  uioSensorStatusSensorLocation => '1.3.6.1.4.1.318.1.1.25.1.2.1.4',
  uioSensorStatusTemperatureDegF => '1.3.6.1.4.1.318.1.1.25.1.2.1.5',
  uioSensorStatusTemperatureDegC => '1.3.6.1.4.1.318.1.1.25.1.2.1.6',
  uioSensorStatusHumidity => '1.3.6.1.4.1.318.1.1.25.1.2.1.7',
  uioSensorStatusViolationStatus => '1.3.6.1.4.1.318.1.1.25.1.2.1.8',
  uioSensorStatusAlarmStatus => '1.3.6.1.4.1.318.1.1.25.1.2.1.9',
  uioSensorStatusAlarmStatusDefinition => 'PowerNet-MIB::uioSensorStatusAlarmStatus',
  uioSensorStatusCommStatus => '1.3.6.1.4.1.318.1.1.25.1.2.1.10',
  uioSensorStatusCommStatusDefinition => 'PowerNet-MIB::uioSensorStatusCommStatus',
  uioInputContact => '1.3.6.1.4.1.318.1.1.25.2',
  uioInputContactStatusTableSize => '1.3.6.1.4.1.318.1.1.25.2.1',
  uioInputContactStatusTable => '1.3.6.1.4.1.318.1.1.25.2.2',
  uioInputContactStatusEntry => '1.3.6.1.4.1.318.1.1.25.2.2.1',
  uioInputContactStatusPortID => '1.3.6.1.4.1.318.1.1.25.2.2.1.1',
  uioInputContactStatusContactID => '1.3.6.1.4.1.318.1.1.25.2.2.1.2',
  uioInputContactStatusContactName => '1.3.6.1.4.1.318.1.1.25.2.2.1.3',
  uioInputContactStatusContactLocation => '1.3.6.1.4.1.318.1.1.25.2.2.1.4',
  uioInputContactStatusCurrentState => '1.3.6.1.4.1.318.1.1.25.2.2.1.5',
  uioInputContactStatusCurrentStateDefinition => 'PowerNet-MIB::uioInputContactStatusCurrentState',
  uioInputContactStatusAlarmStatus => '1.3.6.1.4.1.318.1.1.25.2.2.1.6',
  uioInputContactStatusAlarmStatusDefinition => 'PowerNet-MIB::uioInputContactStatusAlarmStatus',
  uioInputContactStatusCommStatus => '1.3.6.1.4.1.318.1.1.25.2.2.1.7',
  uioInputContactStatusCommStatusDefinition => 'PowerNet-MIB::uioInputContactStatusCommStatus',
  uioOutputRelay => '1.3.6.1.4.1.318.1.1.25.3',
  uioOutputRelayStatusTableSize => '1.3.6.1.4.1.318.1.1.25.3.1',
  uioOutputRelayStatusTable => '1.3.6.1.4.1.318.1.1.25.3.2',
  uioOutputRelayStatusEntry => '1.3.6.1.4.1.318.1.1.25.3.2.1',
  uioOutputRelayStatusPortID => '1.3.6.1.4.1.318.1.1.25.3.2.1.1',
  uioOutputRelayStatusRelayID => '1.3.6.1.4.1.318.1.1.25.3.2.1.2',
  uioOutputRelayStatusRelayName => '1.3.6.1.4.1.318.1.1.25.3.2.1.3',
  uioOutputRelayStatusRelayLocation => '1.3.6.1.4.1.318.1.1.25.3.2.1.4',
  uioOutputRelayStatusCurrentState => '1.3.6.1.4.1.318.1.1.25.3.2.1.5',
  uioOutputRelayStatusCurrentStateDefinition => 'PowerNet-MIB::uioOutputRelayStatusCurrentState',
  uioOutputRelayStatusAlarmStatus => '1.3.6.1.4.1.318.1.1.25.3.2.1.6',
  uioOutputRelayStatusAlarmStatusDefinition => 'PowerNet-MIB::uioOutputRelayStatusAlarmStatus',
  uioOutputRelayStatusCommStatus => '1.3.6.1.4.1.318.1.1.25.3.2.1.7',
  uioOutputRelayStatusCommStatusDefinition => 'PowerNet-MIB::uioOutputRelayStatusCommStatus',
  rPDU2 => '1.3.6.1.4.1.318.1.1.26',
  rPDU2IdentTableSize => '1.3.6.1.4.1.318.1.1.26.1',
  rPDU2IdentTable => '1.3.6.1.4.1.318.1.1.26.2',
  rPDU2IdentEntry => '1.3.6.1.4.1.318.1.1.26.2.1',
  rPDU2IdentIndex => '1.3.6.1.4.1.318.1.1.26.2.1.1',
  rPDU2IdentModule => '1.3.6.1.4.1.318.1.1.26.2.1.2',
  rPDU2IdentName => '1.3.6.1.4.1.318.1.1.26.2.1.3',
  rPDU2IdentLocation => '1.3.6.1.4.1.318.1.1.26.2.1.4',
  rPDU2IdentHardwareRev => '1.3.6.1.4.1.318.1.1.26.2.1.5',
  rPDU2IdentFirmwareRev => '1.3.6.1.4.1.318.1.1.26.2.1.6',
  rPDU2IdentDateOfManufacture => '1.3.6.1.4.1.318.1.1.26.2.1.7',
  rPDU2IdentModelNumber => '1.3.6.1.4.1.318.1.1.26.2.1.8',
  rPDU2IdentSerialNumber => '1.3.6.1.4.1.318.1.1.26.2.1.9',
  rPDU2IdentContact => '1.3.6.1.4.1.318.1.1.26.2.1.10',
  rPDU2DeviceTableSize => '1.3.6.1.4.1.318.1.1.26.3',
  rPDU2Device => '1.3.6.1.4.1.318.1.1.26.4',
  rPDU2DeviceConfigTable => '1.3.6.1.4.1.318.1.1.26.4.1',
  rPDU2DeviceConfigEntry => '1.3.6.1.4.1.318.1.1.26.4.1.1',
  rPDU2DeviceConfigIndex => '1.3.6.1.4.1.318.1.1.26.4.1.1.1',
  rPDU2DeviceConfigModule => '1.3.6.1.4.1.318.1.1.26.4.1.1.2',
  rPDU2DeviceConfigName => '1.3.6.1.4.1.318.1.1.26.4.1.1.3',
  rPDU2DeviceConfigLocation => '1.3.6.1.4.1.318.1.1.26.4.1.1.4',
  rPDU2DeviceConfigDisplayOrientation => '1.3.6.1.4.1.318.1.1.26.4.1.1.5',
  rPDU2DeviceConfigDisplayOrientationDefinition => 'PowerNet-MIB::rPDU2DeviceConfigDisplayOrientation',
  rPDU2DeviceConfigColdstartDelay => '1.3.6.1.4.1.318.1.1.26.4.1.1.6',
  rPDU2DeviceConfigLowLoadPowerThreshold => '1.3.6.1.4.1.318.1.1.26.4.1.1.7',
  rPDU2DeviceConfigNearOverloadPowerThreshold => '1.3.6.1.4.1.318.1.1.26.4.1.1.8',
  rPDU2DeviceConfigOverloadPowerThreshold => '1.3.6.1.4.1.318.1.1.26.4.1.1.9',
  rPDU2DeviceConfigDevicePeakPowerReset => '1.3.6.1.4.1.318.1.1.26.4.1.1.10',
  rPDU2DeviceConfigDevicePeakPowerResetDefinition => 'PowerNet-MIB::rPDU2DeviceConfigDevicePeakPowerReset',
  rPDU2DeviceConfigDeviceEnergyReset => '1.3.6.1.4.1.318.1.1.26.4.1.1.11',
  rPDU2DeviceConfigDeviceEnergyResetDefinition => 'PowerNet-MIB::rPDU2DeviceConfigDeviceEnergyReset',
  rPDU2DeviceConfigOutletsEnergyReset => '1.3.6.1.4.1.318.1.1.26.4.1.1.12',
  rPDU2DeviceConfigOutletsEnergyResetDefinition => 'PowerNet-MIB::rPDU2DeviceConfigOutletsEnergyReset',
  rPDU2DeviceConfigOutletsPeakLoadReset => '1.3.6.1.4.1.318.1.1.26.4.1.1.13',
  rPDU2DeviceConfigOutletsPeakLoadResetDefinition => 'PowerNet-MIB::rPDU2DeviceConfigOutletsPeakLoadReset',
  rPDU2DeviceConfigContact => '1.3.6.1.4.1.318.1.1.26.4.1.1.14',
  rPDU2DevicePropertiesTable => '1.3.6.1.4.1.318.1.1.26.4.2',
  rPDU2DevicePropertiesEntry => '1.3.6.1.4.1.318.1.1.26.4.2.1',
  rPDU2DevicePropertiesIndex => '1.3.6.1.4.1.318.1.1.26.4.2.1.1',
  rPDU2DevicePropertiesModule => '1.3.6.1.4.1.318.1.1.26.4.2.1.2',
  rPDU2DevicePropertiesName => '1.3.6.1.4.1.318.1.1.26.4.2.1.3',
  rPDU2DevicePropertiesNumOutlets => '1.3.6.1.4.1.318.1.1.26.4.2.1.4',
  rPDU2DevicePropertiesNumSwitchedOutlets => '1.3.6.1.4.1.318.1.1.26.4.2.1.5',
  rPDU2DevicePropertiesNumMeteredOutlets => '1.3.6.1.4.1.318.1.1.26.4.2.1.6',
  rPDU2DevicePropertiesNumPhases => '1.3.6.1.4.1.318.1.1.26.4.2.1.7',
  rPDU2DevicePropertiesNumMeteredBanks => '1.3.6.1.4.1.318.1.1.26.4.2.1.8',
  rPDU2DevicePropertiesMaxCurrentRating => '1.3.6.1.4.1.318.1.1.26.4.2.1.9',
  rPDU2DevicePropertiesOrientation => '1.3.6.1.4.1.318.1.1.26.4.2.1.10',
  rPDU2DevicePropertiesOrientationDefinition => 'PowerNet-MIB::rPDU2DevicePropertiesOrientation',
  rPDU2DevicePropertiesOutletLayout => '1.3.6.1.4.1.318.1.1.26.4.2.1.11',
  rPDU2DevicePropertiesOutletLayoutDefinition => 'PowerNet-MIB::rPDU2DevicePropertiesOutletLayout',
  rPDU2DevicePropertiesMaxPhaseCurrentRating => '1.3.6.1.4.1.318.1.1.26.4.2.1.12',
  rPDU2DeviceStatusTable => '1.3.6.1.4.1.318.1.1.26.4.3',
  rPDU2DeviceStatusEntry => '1.3.6.1.4.1.318.1.1.26.4.3.1',
  rPDU2DeviceStatusIndex => '1.3.6.1.4.1.318.1.1.26.4.3.1.1',
  rPDU2DeviceStatusModule => '1.3.6.1.4.1.318.1.1.26.4.3.1.2',
  rPDU2DeviceStatusName => '1.3.6.1.4.1.318.1.1.26.4.3.1.3',
  rPDU2DeviceStatusLoadState => '1.3.6.1.4.1.318.1.1.26.4.3.1.4',
  rPDU2DeviceStatusLoadStateDefinition => 'PowerNet-MIB::rPDU2DeviceStatusLoadState',
  rPDU2DeviceStatusPower => '1.3.6.1.4.1.318.1.1.26.4.3.1.5',
  rPDU2DeviceStatusPeakPower => '1.3.6.1.4.1.318.1.1.26.4.3.1.6',
  rPDU2DeviceStatusPeakPowerTimestamp => '1.3.6.1.4.1.318.1.1.26.4.3.1.7',
  rPDU2DeviceStatusPeakPowerStartTime => '1.3.6.1.4.1.318.1.1.26.4.3.1.8',
  rPDU2DeviceStatusEnergy => '1.3.6.1.4.1.318.1.1.26.4.3.1.9',
  rPDU2DeviceStatusEnergyStartTime => '1.3.6.1.4.1.318.1.1.26.4.3.1.10',
  rPDU2DeviceStatusCommandPending => '1.3.6.1.4.1.318.1.1.26.4.3.1.11',
  rPDU2DeviceStatusCommandPendingDefinition => 'PowerNet-MIB::rPDU2DeviceStatusCommandPending',
  rPDU2DeviceStatusPowerSupplyAlarm => '1.3.6.1.4.1.318.1.1.26.4.3.1.12',
  rPDU2DeviceStatusPowerSupplyAlarmDefinition => 'PowerNet-MIB::rPDU2DeviceStatusPowerSupplyAlarm',
  rPDU2DeviceStatusPowerSupply1Status => '1.3.6.1.4.1.318.1.1.26.4.3.1.13',
  rPDU2DeviceStatusPowerSupply1StatusDefinition => 'PowerNet-MIB::rPDU2DeviceStatusPowerSupply1Status',
  rPDU2DeviceStatusPowerSupply2Status => '1.3.6.1.4.1.318.1.1.26.4.3.1.14',
  rPDU2DeviceStatusPowerSupply2StatusDefinition => 'PowerNet-MIB::rPDU2DeviceStatusPowerSupply2Status',
  rPDU2DeviceStatusOutletsEnergyStartTime => '1.3.6.1.4.1.318.1.1.26.4.3.1.15',
  rPDU2DeviceStatusApparentPower => '1.3.6.1.4.1.318.1.1.26.4.3.1.16',
  rPDU2DeviceStatusPowerFactor => '1.3.6.1.4.1.318.1.1.26.4.3.1.17',
  rPDU2DeviceStatusNPSType => '1.3.6.1.4.1.318.1.1.26.4.3.1.18',
  rPDU2DeviceStatusNPSTypeDefinition => 'PowerNet-MIB::rPDU2DeviceStatusNPSType',
  rPDU2DeviceControlTable => '1.3.6.1.4.1.318.1.1.26.4.4',
  rPDU2DeviceControlEntry => '1.3.6.1.4.1.318.1.1.26.4.4.1',
  rPDU2DeviceControlIndex => '1.3.6.1.4.1.318.1.1.26.4.4.1.1',
  rPDU2DeviceControlModule => '1.3.6.1.4.1.318.1.1.26.4.4.1.2',
  rPDU2DeviceControlName => '1.3.6.1.4.1.318.1.1.26.4.4.1.3',
  rPDU2DeviceControlCommand => '1.3.6.1.4.1.318.1.1.26.4.4.1.4',
  rPDU2DeviceControlCommandDefinition => 'PowerNet-MIB::rPDU2DeviceControlCommand',
  rPDU2PhaseTableSize => '1.3.6.1.4.1.318.1.1.26.5',
  rPDU2Phase => '1.3.6.1.4.1.318.1.1.26.6',
  rPDU2PhaseConfigTable => '1.3.6.1.4.1.318.1.1.26.6.1',
  rPDU2PhaseConfigEntry => '1.3.6.1.4.1.318.1.1.26.6.1.1',
  rPDU2PhaseConfigIndex => '1.3.6.1.4.1.318.1.1.26.6.1.1.1',
  rPDU2PhaseConfigModule => '1.3.6.1.4.1.318.1.1.26.6.1.1.2',
  rPDU2PhaseConfigNumber => '1.3.6.1.4.1.318.1.1.26.6.1.1.3',
  rPDU2PhaseConfigOverloadRestriction => '1.3.6.1.4.1.318.1.1.26.6.1.1.4',
  rPDU2PhaseConfigOverloadRestrictionDefinition => 'PowerNet-MIB::rPDU2PhaseConfigOverloadRestriction',
  rPDU2PhaseConfigLowLoadCurrentThreshold => '1.3.6.1.4.1.318.1.1.26.6.1.1.5',
  rPDU2PhaseConfigNearOverloadCurrentThreshold => '1.3.6.1.4.1.318.1.1.26.6.1.1.6',
  rPDU2PhaseConfigOverloadCurrentThreshold => '1.3.6.1.4.1.318.1.1.26.6.1.1.7',
  rPDU2PhaseConfigPhasePeakCurrentReset => '1.3.6.1.4.1.318.1.1.26.6.1.1.8',
  rPDU2PhaseConfigPhasePeakCurrentResetDefinition => 'PowerNet-MIB::rPDU2PhaseConfigPhasePeakCurrentReset',
  rPDU2PhasePropertiesTable => '1.3.6.1.4.1.318.1.1.26.6.2',
  rPDU2PhasePropertiesEntry => '1.3.6.1.4.1.318.1.1.26.6.2.1',
  rPDU2PhasePropertiesIndex => '1.3.6.1.4.1.318.1.1.26.6.2.1.1',
  rPDU2PhasePropertiesModule => '1.3.6.1.4.1.318.1.1.26.6.2.1.2',
  rPDU2PhasePropertiesNumber => '1.3.6.1.4.1.318.1.1.26.6.2.1.3',
  rPDU2PhaseStatusTable => '1.3.6.1.4.1.318.1.1.26.6.3',
  rPDU2PhaseStatusEntry => '1.3.6.1.4.1.318.1.1.26.6.3.1',
  rPDU2PhaseStatusIndex => '1.3.6.1.4.1.318.1.1.26.6.3.1.1',
  rPDU2PhaseStatusModule => '1.3.6.1.4.1.318.1.1.26.6.3.1.2',
  rPDU2PhaseStatusNumber => '1.3.6.1.4.1.318.1.1.26.6.3.1.3',
  rPDU2PhaseStatusLoadState => '1.3.6.1.4.1.318.1.1.26.6.3.1.4',
  rPDU2PhaseStatusLoadStateDefinition => 'PowerNet-MIB::rPDU2PhaseStatusLoadState',
  rPDU2PhaseStatusCurrent => '1.3.6.1.4.1.318.1.1.26.6.3.1.5',
  rPDU2PhaseStatusVoltage => '1.3.6.1.4.1.318.1.1.26.6.3.1.6',
  rPDU2PhaseStatusPower => '1.3.6.1.4.1.318.1.1.26.6.3.1.7',
  rPDU2PhaseStatusApparentPower => '1.3.6.1.4.1.318.1.1.26.6.3.1.8',
  rPDU2PhaseStatusPowerFactor => '1.3.6.1.4.1.318.1.1.26.6.3.1.9',
  rPDU2PhaseStatusPeakCurrent => '1.3.6.1.4.1.318.1.1.26.6.3.1.10',
  rPDU2PhaseStatusPeakCurrentTimestamp => '1.3.6.1.4.1.318.1.1.26.6.3.1.11',
  rPDU2PhaseStatusPeakCurrentStartTime => '1.3.6.1.4.1.318.1.1.26.6.3.1.12',
  rPDU2BankTableSize => '1.3.6.1.4.1.318.1.1.26.7',
  rPDU2Bank => '1.3.6.1.4.1.318.1.1.26.8',
  rPDU2BankConfigTable => '1.3.6.1.4.1.318.1.1.26.8.1',
  rPDU2BankConfigEntry => '1.3.6.1.4.1.318.1.1.26.8.1.1',
  rPDU2BankConfigIndex => '1.3.6.1.4.1.318.1.1.26.8.1.1.1',
  rPDU2BankConfigModule => '1.3.6.1.4.1.318.1.1.26.8.1.1.2',
  rPDU2BankConfigNumber => '1.3.6.1.4.1.318.1.1.26.8.1.1.3',
  rPDU2BankConfigOverloadRestriction => '1.3.6.1.4.1.318.1.1.26.8.1.1.4',
  rPDU2BankConfigOverloadRestrictionDefinition => 'PowerNet-MIB::rPDU2BankConfigOverloadRestriction',
  rPDU2BankConfigLowLoadCurrentThreshold => '1.3.6.1.4.1.318.1.1.26.8.1.1.5',
  rPDU2BankConfigNearOverloadCurrentThreshold => '1.3.6.1.4.1.318.1.1.26.8.1.1.6',
  rPDU2BankConfigOverloadCurrentThreshold => '1.3.6.1.4.1.318.1.1.26.8.1.1.7',
  rPDU2BankConfigBankPeakCurrentReset => '1.3.6.1.4.1.318.1.1.26.8.1.1.8',
  rPDU2BankConfigBankPeakCurrentResetDefinition => 'PowerNet-MIB::rPDU2BankConfigBankPeakCurrentReset',
  rPDU2BankPropertiesTable => '1.3.6.1.4.1.318.1.1.26.8.2',
  rPDU2BankPropertiesEntry => '1.3.6.1.4.1.318.1.1.26.8.2.1',
  rPDU2BankPropertiesIndex => '1.3.6.1.4.1.318.1.1.26.8.2.1.1',
  rPDU2BankPropertiesModule => '1.3.6.1.4.1.318.1.1.26.8.2.1.2',
  rPDU2BankPropertiesNumber => '1.3.6.1.4.1.318.1.1.26.8.2.1.3',
  rPDU2BankPropertiesPhaseLayout => '1.3.6.1.4.1.318.1.1.26.8.2.1.4',
  rPDU2BankPropertiesPhaseLayoutDefinition => 'PowerNet-MIB::Rpdu2OutletPhaseLayoutType',
  rPDU2BankStatusTable => '1.3.6.1.4.1.318.1.1.26.8.3',
  rPDU2BankStatusEntry => '1.3.6.1.4.1.318.1.1.26.8.3.1',
  rPDU2BankStatusIndex => '1.3.6.1.4.1.318.1.1.26.8.3.1.1',
  rPDU2BankStatusModule => '1.3.6.1.4.1.318.1.1.26.8.3.1.2',
  rPDU2BankStatusNumber => '1.3.6.1.4.1.318.1.1.26.8.3.1.3',
  rPDU2BankStatusLoadState => '1.3.6.1.4.1.318.1.1.26.8.3.1.4',
  rPDU2BankStatusLoadStateDefinition => 'PowerNet-MIB::rPDU2BankStatusLoadState',
  rPDU2BankStatusCurrent => '1.3.6.1.4.1.318.1.1.26.8.3.1.5',
  rPDU2BankStatusPeakCurrent => '1.3.6.1.4.1.318.1.1.26.8.3.1.6',
  rPDU2BankStatusPeakCurrentTimestamp => '1.3.6.1.4.1.318.1.1.26.8.3.1.7',
  rPDU2BankStatusPeakCurrentStartTime => '1.3.6.1.4.1.318.1.1.26.8.3.1.8',
  rPDU2Outlet => '1.3.6.1.4.1.318.1.1.26.9',
  rPDU2OutletSwitchedTableSize => '1.3.6.1.4.1.318.1.1.26.9.1',
  rPDU2OutletSwitched => '1.3.6.1.4.1.318.1.1.26.9.2',
  rPDU2OutletSwitchedConfigTable => '1.3.6.1.4.1.318.1.1.26.9.2.1',
  rPDU2OutletSwitchedConfigEntry => '1.3.6.1.4.1.318.1.1.26.9.2.1.1',
  rPDU2OutletSwitchedConfigIndex => '1.3.6.1.4.1.318.1.1.26.9.2.1.1.1',
  rPDU2OutletSwitchedConfigModule => '1.3.6.1.4.1.318.1.1.26.9.2.1.1.2',
  rPDU2OutletSwitchedConfigName => '1.3.6.1.4.1.318.1.1.26.9.2.1.1.3',
  rPDU2OutletSwitchedConfigNumber => '1.3.6.1.4.1.318.1.1.26.9.2.1.1.4',
  rPDU2OutletSwitchedConfigPowerOnTime => '1.3.6.1.4.1.318.1.1.26.9.2.1.1.5',
  rPDU2OutletSwitchedConfigPowerOffTime => '1.3.6.1.4.1.318.1.1.26.9.2.1.1.6',
  rPDU2OutletSwitchedConfigRebootDuration => '1.3.6.1.4.1.318.1.1.26.9.2.1.1.7',
  rPDU2OutletSwitchedPropertiesTable => '1.3.6.1.4.1.318.1.1.26.9.2.2',
  rPDU2OutletSwitchedPropertiesEntry => '1.3.6.1.4.1.318.1.1.26.9.2.2.1',
  rPDU2OutletSwitchedPropertiesIndex => '1.3.6.1.4.1.318.1.1.26.9.2.2.1.1',
  rPDU2OutletSwitchedPropertiesModule => '1.3.6.1.4.1.318.1.1.26.9.2.2.1.2',
  rPDU2OutletSwitchedPropertiesName => '1.3.6.1.4.1.318.1.1.26.9.2.2.1.3',
  rPDU2OutletSwitchedPropertiesNumber => '1.3.6.1.4.1.318.1.1.26.9.2.2.1.4',
  rPDU2OutletSwitchedPropertiesPhaseLayout => '1.3.6.1.4.1.318.1.1.26.9.2.2.1.5',
  rPDU2OutletSwitchedPropertiesPhaseLayoutDefinition => 'PowerNet-MIB::Rpdu2OutletPhaseLayoutType',
  rPDU2OutletSwitchedPropertiesBank => '1.3.6.1.4.1.318.1.1.26.9.2.2.1.6',
  rPDU2OutletSwitchedStatusTable => '1.3.6.1.4.1.318.1.1.26.9.2.3',
  rPDU2OutletSwitchedStatusEntry => '1.3.6.1.4.1.318.1.1.26.9.2.3.1',
  rPDU2OutletSwitchedStatusIndex => '1.3.6.1.4.1.318.1.1.26.9.2.3.1.1',
  rPDU2OutletSwitchedStatusModule => '1.3.6.1.4.1.318.1.1.26.9.2.3.1.2',
  rPDU2OutletSwitchedStatusName => '1.3.6.1.4.1.318.1.1.26.9.2.3.1.3',
  rPDU2OutletSwitchedStatusNumber => '1.3.6.1.4.1.318.1.1.26.9.2.3.1.4',
  rPDU2OutletSwitchedStatusState => '1.3.6.1.4.1.318.1.1.26.9.2.3.1.5',
  rPDU2OutletSwitchedStatusStateDefinition => 'PowerNet-MIB::rPDU2OutletSwitchedStatusState',
  rPDU2OutletSwitchedStatusCommandPending => '1.3.6.1.4.1.318.1.1.26.9.2.3.1.6',
  rPDU2OutletSwitchedStatusCommandPendingDefinition => 'PowerNet-MIB::rPDU2OutletSwitchedStatusCommandPending',
  rPDU2OutletSwitchedControlTable => '1.3.6.1.4.1.318.1.1.26.9.2.4',
  rPDU2OutletSwitchedControlEntry => '1.3.6.1.4.1.318.1.1.26.9.2.4.1',
  rPDU2OutletSwitchedControlIndex => '1.3.6.1.4.1.318.1.1.26.9.2.4.1.1',
  rPDU2OutletSwitchedControlModule => '1.3.6.1.4.1.318.1.1.26.9.2.4.1.2',
  rPDU2OutletSwitchedControlName => '1.3.6.1.4.1.318.1.1.26.9.2.4.1.3',
  rPDU2OutletSwitchedControlNumber => '1.3.6.1.4.1.318.1.1.26.9.2.4.1.4',
  rPDU2OutletSwitchedControlCommand => '1.3.6.1.4.1.318.1.1.26.9.2.4.1.5',
  rPDU2OutletSwitchedControlCommandDefinition => 'PowerNet-MIB::rPDU2OutletSwitchedControlCommand',
  rPDU2OutletMeteredTableSize => '1.3.6.1.4.1.318.1.1.26.9.3',
  rPDU2OutletMetered => '1.3.6.1.4.1.318.1.1.26.9.4',
  rPDU2OutletMeteredConfigTable => '1.3.6.1.4.1.318.1.1.26.9.4.1',
  rPDU2OutletMeteredConfigEntry => '1.3.6.1.4.1.318.1.1.26.9.4.1.1',
  rPDU2OutletMeteredConfigIndex => '1.3.6.1.4.1.318.1.1.26.9.4.1.1.1',
  rPDU2OutletMeteredConfigModule => '1.3.6.1.4.1.318.1.1.26.9.4.1.1.2',
  rPDU2OutletMeteredConfigName => '1.3.6.1.4.1.318.1.1.26.9.4.1.1.3',
  rPDU2OutletMeteredConfigNumber => '1.3.6.1.4.1.318.1.1.26.9.4.1.1.4',
  rPDU2OutletMeteredConfigLowLoadCurrentThreshold => '1.3.6.1.4.1.318.1.1.26.9.4.1.1.5',
  rPDU2OutletMeteredConfigNearOverloadCurrentThreshold => '1.3.6.1.4.1.318.1.1.26.9.4.1.1.6',
  rPDU2OutletMeteredConfigOverloadCurrentThreshold => '1.3.6.1.4.1.318.1.1.26.9.4.1.1.7',
  rPDU2OutletMeteredPropertiesTable => '1.3.6.1.4.1.318.1.1.26.9.4.2',
  rPDU2OutletMeteredPropertiesEntry => '1.3.6.1.4.1.318.1.1.26.9.4.2.1',
  rPDU2OutletMeteredPropertiesIndex => '1.3.6.1.4.1.318.1.1.26.9.4.2.1.1',
  rPDU2OutletMeteredPropertiesModule => '1.3.6.1.4.1.318.1.1.26.9.4.2.1.2',
  rPDU2OutletMeteredPropertiesName => '1.3.6.1.4.1.318.1.1.26.9.4.2.1.3',
  rPDU2OutletMeteredPropertiesNumber => '1.3.6.1.4.1.318.1.1.26.9.4.2.1.4',
  rPDU2OutletMeteredPropertiesLayout => '1.3.6.1.4.1.318.1.1.26.9.4.2.1.5',
  rPDU2OutletMeteredPropertiesLayoutDefinition => 'PowerNet-MIB::Rpdu2OutletPhaseLayoutType',
  rPDU2OutletMeteredPropertiesPowerRating => '1.3.6.1.4.1.318.1.1.26.9.4.2.1.6',
  rPDU2OutletMeteredPropertiesBank => '1.3.6.1.4.1.318.1.1.26.9.4.2.1.7',
  rPDU2OutletMeteredStatusTable => '1.3.6.1.4.1.318.1.1.26.9.4.3',
  rPDU2OutletMeteredStatusEntry => '1.3.6.1.4.1.318.1.1.26.9.4.3.1',
  rPDU2OutletMeteredStatusIndex => '1.3.6.1.4.1.318.1.1.26.9.4.3.1.1',
  rPDU2OutletMeteredStatusModule => '1.3.6.1.4.1.318.1.1.26.9.4.3.1.2',
  rPDU2OutletMeteredStatusName => '1.3.6.1.4.1.318.1.1.26.9.4.3.1.3',
  rPDU2OutletMeteredStatusNumber => '1.3.6.1.4.1.318.1.1.26.9.4.3.1.4',
  rPDU2OutletMeteredStatusState => '1.3.6.1.4.1.318.1.1.26.9.4.3.1.5',
  rPDU2OutletMeteredStatusStateDefinition => 'PowerNet-MIB::rPDU2OutletMeteredStatusState',
  rPDU2OutletMeteredStatusCurrent => '1.3.6.1.4.1.318.1.1.26.9.4.3.1.6',
  rPDU2OutletMeteredStatusPower => '1.3.6.1.4.1.318.1.1.26.9.4.3.1.7',
  rPDU2OutletMeteredStatusPeakPower => '1.3.6.1.4.1.318.1.1.26.9.4.3.1.8',
  rPDU2OutletMeteredStatusPeakPowerTimestamp => '1.3.6.1.4.1.318.1.1.26.9.4.3.1.9',
  rPDU2OutletMeteredStatusPeakPowerStartTime => '1.3.6.1.4.1.318.1.1.26.9.4.3.1.10',
  rPDU2OutletMeteredStatusEnergy => '1.3.6.1.4.1.318.1.1.26.9.4.3.1.11',
  rPDU2Sensor => '1.3.6.1.4.1.318.1.1.26.10',
  rPDU2SensorTempHumidityTableSize => '1.3.6.1.4.1.318.1.1.26.10.1',
  rPDU2SensorTempHumidity => '1.3.6.1.4.1.318.1.1.26.10.2',
  rPDU2SensorTempHumidityConfigTable => '1.3.6.1.4.1.318.1.1.26.10.2.1',
  rPDU2SensorTempHumidityConfigEntry => '1.3.6.1.4.1.318.1.1.26.10.2.1.1',
  rPDU2SensorTempHumidityConfigIndex => '1.3.6.1.4.1.318.1.1.26.10.2.1.1.1',
  rPDU2SensorTempHumidityConfigModule => '1.3.6.1.4.1.318.1.1.26.10.2.1.1.2',
  rPDU2SensorTempHumidityConfigName => '1.3.6.1.4.1.318.1.1.26.10.2.1.1.3',
  rPDU2SensorTempHumidityConfigNumber => '1.3.6.1.4.1.318.1.1.26.10.2.1.1.4',
  rPDU2SensorTempHumidityConfigTemperatureAlarmEnable => '1.3.6.1.4.1.318.1.1.26.10.2.1.1.5',
  rPDU2SensorTempHumidityConfigTemperatureAlarmEnableDefinition => 'PowerNet-MIB::rPDU2SensorTempHumidityConfigTemperatureAlarmEnable',
  rPDU2SensorTempHumidityConfigHumidityAlarmEnable => '1.3.6.1.4.1.318.1.1.26.10.2.1.1.6',
  rPDU2SensorTempHumidityConfigHumidityAlarmEnableDefinition => 'PowerNet-MIB::rPDU2SensorTempHumidityConfigHumidityAlarmEnable',
  rPDU2SensorTempHumidityConfigTempMaxThreshF => '1.3.6.1.4.1.318.1.1.26.10.2.1.1.7',
  rPDU2SensorTempHumidityConfigTempHighThreshF => '1.3.6.1.4.1.318.1.1.26.10.2.1.1.8',
  rPDU2SensorTempHumidityConfigTempHysteresisF => '1.3.6.1.4.1.318.1.1.26.10.2.1.1.9',
  rPDU2SensorTempHumidityConfigTempMaxThreshC => '1.3.6.1.4.1.318.1.1.26.10.2.1.1.10',
  rPDU2SensorTempHumidityConfigTempHighThreshC => '1.3.6.1.4.1.318.1.1.26.10.2.1.1.11',
  rPDU2SensorTempHumidityConfigTempHysteresisC => '1.3.6.1.4.1.318.1.1.26.10.2.1.1.12',
  rPDU2SensorTempHumidityConfigHumidityLowThresh => '1.3.6.1.4.1.318.1.1.26.10.2.1.1.13',
  rPDU2SensorTempHumidityConfigHumidityMinThresh => '1.3.6.1.4.1.318.1.1.26.10.2.1.1.14',
  rPDU2SensorTempHumidityConfigHumidityHysteresis => '1.3.6.1.4.1.318.1.1.26.10.2.1.1.15',
  rPDU2SensorTempHumidityStatusTable => '1.3.6.1.4.1.318.1.1.26.10.2.2',
  rPDU2SensorTempHumidityStatusEntry => '1.3.6.1.4.1.318.1.1.26.10.2.2.1',
  rPDU2SensorTempHumidityStatusIndex => '1.3.6.1.4.1.318.1.1.26.10.2.2.1.1',
  rPDU2SensorTempHumidityStatusModule => '1.3.6.1.4.1.318.1.1.26.10.2.2.1.2',
  rPDU2SensorTempHumidityStatusName => '1.3.6.1.4.1.318.1.1.26.10.2.2.1.3',
  rPDU2SensorTempHumidityStatusNumber => '1.3.6.1.4.1.318.1.1.26.10.2.2.1.4',
  rPDU2SensorTempHumidityStatusType => '1.3.6.1.4.1.318.1.1.26.10.2.2.1.5',
  rPDU2SensorTempHumidityStatusTypeDefinition => 'PowerNet-MIB::rPDU2SensorTempHumidityStatusType',
  rPDU2SensorTempHumidityStatusCommStatus => '1.3.6.1.4.1.318.1.1.26.10.2.2.1.6',
  rPDU2SensorTempHumidityStatusCommStatusDefinition => 'PowerNet-MIB::rPDU2SensorTempHumidityStatusCommStatus',
  rPDU2SensorTempHumidityStatusTempF => '1.3.6.1.4.1.318.1.1.26.10.2.2.1.7',
  rPDU2SensorTempHumidityStatusTempC => '1.3.6.1.4.1.318.1.1.26.10.2.2.1.8',
  rPDU2SensorTempHumidityStatusTempStatus => '1.3.6.1.4.1.318.1.1.26.10.2.2.1.9',
  rPDU2SensorTempHumidityStatusTempStatusDefinition => 'PowerNet-MIB::rPDU2SensorTempHumidityStatusTempStatus',
  rPDU2SensorTempHumidityStatusRelativeHumidity => '1.3.6.1.4.1.318.1.1.26.10.2.2.1.10',
  rPDU2SensorTempHumidityStatusHumidityStatus => '1.3.6.1.4.1.318.1.1.26.10.2.2.1.11',
  rPDU2SensorTempHumidityStatusHumidityStatusDefinition => 'PowerNet-MIB::rPDU2SensorTempHumidityStatusHumidityStatus',
  rPDU2SensorDiscreteTableSize => '1.3.6.1.4.1.318.1.1.26.10.3',
  rPDU2SensorDiscrete => '1.3.6.1.4.1.318.1.1.26.10.4',
  rPDU2SensorDiscreteConfigTable => '1.3.6.1.4.1.318.1.1.26.10.4.1',
  rPDU2SensorDiscreteConfigEntry => '1.3.6.1.4.1.318.1.1.26.10.4.1.1',
  rPDU2SensorDiscreteConfigIndex => '1.3.6.1.4.1.318.1.1.26.10.4.1.1.1',
  rPDU2SensorDiscreteConfigModule => '1.3.6.1.4.1.318.1.1.26.10.4.1.1.2',
  rPDU2SensorDiscreteConfigName => '1.3.6.1.4.1.318.1.1.26.10.4.1.1.3',
  rPDU2SensorDiscreteConfigNumber => '1.3.6.1.4.1.318.1.1.26.10.4.1.1.4',
  rPDU2SensorDiscreteConfigNormalState => '1.3.6.1.4.1.318.1.1.26.10.4.1.1.5',
  rPDU2SensorDiscreteConfigNormalStateDefinition => 'PowerNet-MIB::rPDU2SensorDiscreteConfigNormalState',
  rPDU2SensorDiscreteConfigAbnormalSeverity => '1.3.6.1.4.1.318.1.1.26.10.4.1.1.6',
  rPDU2SensorDiscreteConfigAbnormalSeverityDefinition => 'PowerNet-MIB::rPDU2SensorDiscreteConfigAbnormalSeverity',
  rPDU2SensorDiscreteStatusTable => '1.3.6.1.4.1.318.1.1.26.10.4.2',
  rPDU2SensorDiscreteStatusEntry => '1.3.6.1.4.1.318.1.1.26.10.4.2.1',
  rPDU2SensorDiscreteStatusIndex => '1.3.6.1.4.1.318.1.1.26.10.4.2.1.1',
  rPDU2SensorDiscreteStatusModule => '1.3.6.1.4.1.318.1.1.26.10.4.2.1.2',
  rPDU2SensorDiscreteStatusName => '1.3.6.1.4.1.318.1.1.26.10.4.2.1.3',
  rPDU2SensorDiscreteStatusNumber => '1.3.6.1.4.1.318.1.1.26.10.4.2.1.4',
  rPDU2SensorDiscreteStatusType => '1.3.6.1.4.1.318.1.1.26.10.4.2.1.5',
  rPDU2SensorDiscreteStatusTypeDefinition => 'PowerNet-MIB::rPDU2SensorDiscreteStatusType',
  rPDU2SensorDiscreteStatusCommStatus => '1.3.6.1.4.1.318.1.1.26.10.4.2.1.6',
  rPDU2SensorDiscreteStatusCommStatusDefinition => 'PowerNet-MIB::rPDU2SensorDiscreteStatusCommStatus',
  rPDU2SensorDiscreteStatusCurrentState => '1.3.6.1.4.1.318.1.1.26.10.4.2.1.7',
  rPDU2SensorDiscreteStatusCurrentStateDefinition => 'PowerNet-MIB::rPDU2SensorDiscreteStatusCurrentState',
  rPDU2SensorDiscreteStatusAlarmState => '1.3.6.1.4.1.318.1.1.26.10.4.2.1.8',
  rPDU2SensorDiscreteStatusAlarmStateDefinition => 'PowerNet-MIB::rPDU2SensorDiscreteStatusAlarmState',
  rPDU2Group => '1.3.6.1.4.1.318.1.1.26.11',
  rPDU2GroupNumberOfDevices => '1.3.6.1.4.1.318.1.1.26.11.1',
  rPDU2GroupTotalPower => '1.3.6.1.4.1.318.1.1.26.11.2',
  rPDU2GroupTotalEnergy => '1.3.6.1.4.1.318.1.1.26.11.3',
  rPDU2GroupEnergyReset => '1.3.6.1.4.1.318.1.1.26.11.4',
  rPDU2GroupEnergyResetDefinition => 'PowerNet-MIB::rPDU2GroupEnergyReset',
  rPDU2PhaseToPhaseStatusTableSize => '1.3.6.1.4.1.318.1.1.26.12',
  rPDU2PhaseToPhase => '1.3.6.1.4.1.318.1.1.26.13',
  rPDU2PhaseToPhaseStatusTable => '1.3.6.1.4.1.318.1.1.26.13.1',
  rPDU2PhaseToPhaseStatusEntry => '1.3.6.1.4.1.318.1.1.26.13.1.1',
  rPDU2PhaseToPhaseStatusIndex => '1.3.6.1.4.1.318.1.1.26.13.1.1.1',
  rPDU2PhaseToPhaseStatusModule => '1.3.6.1.4.1.318.1.1.26.13.1.1.2',
  rPDU2PhaseToPhaseStatusVoltage1to2 => '1.3.6.1.4.1.318.1.1.26.13.1.1.3',
  rPDU2PhaseToPhaseStatusVoltage2to3 => '1.3.6.1.4.1.318.1.1.26.13.1.1.4',
  rPDU2PhaseToPhaseStatusVoltage3to1 => '1.3.6.1.4.1.318.1.1.26.13.1.1.5',
  cooling => '1.3.6.1.4.1.318.1.1.27',
  coolingUnit => '1.3.6.1.4.1.318.1.1.27.1',
  coolingUnitTableSize => '1.3.6.1.4.1.318.1.1.27.1.1',
  coolingUnitTable => '1.3.6.1.4.1.318.1.1.27.1.2',
  coolingUnitEntry => '1.3.6.1.4.1.318.1.1.27.1.2.1',
  coolingUnitTableIndex => '1.3.6.1.4.1.318.1.1.27.1.2.1.1',
  coolingUnitAbout => '1.3.6.1.4.1.318.1.1.27.1.3',
  coolingUnitAboutTableSize => '1.3.6.1.4.1.318.1.1.27.1.3.1',
  coolingUnitAboutTable => '1.3.6.1.4.1.318.1.1.27.1.3.2',
  coolingUnitAboutEntry => '1.3.6.1.4.1.318.1.1.27.1.3.2.1',
  coolingUnitAboutTableIndex => '1.3.6.1.4.1.318.1.1.27.1.3.2.1.1',
  coolingUnitAboutDescription => '1.3.6.1.4.1.318.1.1.27.1.3.2.1.2',
  coolingUnitAboutValue => '1.3.6.1.4.1.318.1.1.27.1.3.2.1.3',
  coolingUnitStatus => '1.3.6.1.4.1.318.1.1.27.1.4',
  coolingUnitStatusAnalog => '1.3.6.1.4.1.318.1.1.27.1.4.1',
  coolingUnitStatusAnalogTableSize => '1.3.6.1.4.1.318.1.1.27.1.4.1.1',
  coolingUnitStatusAnalogTable => '1.3.6.1.4.1.318.1.1.27.1.4.1.2',
  coolingUnitStatusAnalogEntry => '1.3.6.1.4.1.318.1.1.27.1.4.1.2.1',
  coolingUnitStatusAnalogTableIndex => '1.3.6.1.4.1.318.1.1.27.1.4.1.2.1.1',
  coolingUnitStatusAnalogDescription => '1.3.6.1.4.1.318.1.1.27.1.4.1.2.1.2',
  coolingUnitStatusAnalogValue => '1.3.6.1.4.1.318.1.1.27.1.4.1.2.1.3',
  coolingUnitStatusAnalogUnits => '1.3.6.1.4.1.318.1.1.27.1.4.1.2.1.4',
  coolingUnitStatusAnalogScale => '1.3.6.1.4.1.318.1.1.27.1.4.1.2.1.5',
  coolingUnitStatusDiscrete => '1.3.6.1.4.1.318.1.1.27.1.4.2',
  coolingUnitStatusDiscreteTableSize => '1.3.6.1.4.1.318.1.1.27.1.4.2.1',
  coolingUnitStatusDiscreteTable => '1.3.6.1.4.1.318.1.1.27.1.4.2.2',
  coolingUnitStatusDiscreteEntry => '1.3.6.1.4.1.318.1.1.27.1.4.2.2.1',
  coolingUnitStatusDiscreteTableIndex => '1.3.6.1.4.1.318.1.1.27.1.4.2.2.1.1',
  coolingUnitStatusDiscreteDescription => '1.3.6.1.4.1.318.1.1.27.1.4.2.2.1.2',
  coolingUnitStatusDiscreteValueAsString => '1.3.6.1.4.1.318.1.1.27.1.4.2.2.1.3',
  coolingUnitStatusDiscreteValueAsInteger => '1.3.6.1.4.1.318.1.1.27.1.4.2.2.1.4',
  coolingUnitStatusDiscreteIntegerReferenceKey => '1.3.6.1.4.1.318.1.1.27.1.4.2.2.1.5',
  coolingUnitConfiguration => '1.3.6.1.4.1.318.1.1.27.1.5',
  coolingUnitConfigurationAnalog => '1.3.6.1.4.1.318.1.1.27.1.5.1',
  coolingUnitConfigurationAnalogTableSize => '1.3.6.1.4.1.318.1.1.27.1.5.1.1',
  coolingUnitConfigurationAnalogTable => '1.3.6.1.4.1.318.1.1.27.1.5.1.2',
  coolingUnitConfigurationAnalogEntry => '1.3.6.1.4.1.318.1.1.27.1.5.1.2.1',
  coolingUnitConfigurationAnalogTableIndex => '1.3.6.1.4.1.318.1.1.27.1.5.1.2.1.1',
  coolingUnitConfigurationAnalogDescription => '1.3.6.1.4.1.318.1.1.27.1.5.1.2.1.2',
  coolingUnitConfigurationAnalogValue => '1.3.6.1.4.1.318.1.1.27.1.5.1.2.1.3',
  coolingUnitConfigurationAnalogUnits => '1.3.6.1.4.1.318.1.1.27.1.5.1.2.1.4',
  coolingUnitConfigurationAnalogScale => '1.3.6.1.4.1.318.1.1.27.1.5.1.2.1.5',
  coolingUnitConfigurationAnalogAccess => '1.3.6.1.4.1.318.1.1.27.1.5.1.2.1.6',
  coolingUnitConfigurationAnalogAccessDefinition => 'PowerNet-MIB::coolingUnitConfigurationAnalogAccess',
  coolingUnitConfigurationAnalogMinimum => '1.3.6.1.4.1.318.1.1.27.1.5.1.2.1.7',
  coolingUnitConfigurationAnalogMaximum => '1.3.6.1.4.1.318.1.1.27.1.5.1.2.1.8',
  coolingUnitConfigurationDiscrete => '1.3.6.1.4.1.318.1.1.27.1.5.2',
  coolingUnitConfigurationDiscreteTableSize => '1.3.6.1.4.1.318.1.1.27.1.5.2.1',
  coolingUnitConfigurationDiscreteTable => '1.3.6.1.4.1.318.1.1.27.1.5.2.2',
  coolingUnitConfigurationDiscreteEntry => '1.3.6.1.4.1.318.1.1.27.1.5.2.2.1',
  coolingUnitConfigurationDiscreteTableIndex => '1.3.6.1.4.1.318.1.1.27.1.5.2.2.1.1',
  coolingUnitConfigurationDiscreteDescription => '1.3.6.1.4.1.318.1.1.27.1.5.2.2.1.2',
  coolingUnitConfigurationDiscreteValueAsString => '1.3.6.1.4.1.318.1.1.27.1.5.2.2.1.3',
  coolingUnitConfigurationDiscreteValueAsInteger => '1.3.6.1.4.1.318.1.1.27.1.5.2.2.1.4',
  coolingUnitConfigurationDiscreteIntegerReferenceKey => '1.3.6.1.4.1.318.1.1.27.1.5.2.2.1.5',
  coolingUnitConfigurationDiscreteAccess => '1.3.6.1.4.1.318.1.1.27.1.5.2.2.1.6',
  coolingUnitConfigurationDiscreteAccessDefinition => 'PowerNet-MIB::coolingUnitConfigurationDiscreteAccess',
  coolingUnitConfigurationString => '1.3.6.1.4.1.318.1.1.27.1.5.3',
  coolingUnitConfigurationStringTableSize => '1.3.6.1.4.1.318.1.1.27.1.5.3.1',
  coolingUnitConfigurationStringTable => '1.3.6.1.4.1.318.1.1.27.1.5.3.2',
  coolingUnitConfigurationStringEntry => '1.3.6.1.4.1.318.1.1.27.1.5.3.2.1',
  coolingUnitConfigurationStringTableIndex => '1.3.6.1.4.1.318.1.1.27.1.5.3.2.1.1',
  coolingUnitConfigurationStringDescription => '1.3.6.1.4.1.318.1.1.27.1.5.3.2.1.2',
  coolingUnitConfigurationStringValue => '1.3.6.1.4.1.318.1.1.27.1.5.3.2.1.3',
  coolingUnitConfigurationStringMaxLength => '1.3.6.1.4.1.318.1.1.27.1.5.3.2.1.4',
  coolingUnitConfigurationStringAccess => '1.3.6.1.4.1.318.1.1.27.1.5.3.2.1.5',
  coolingUnitConfigurationStringAccessDefinition => 'PowerNet-MIB::coolingUnitConfigurationStringAccess',
  coolingUnitExtended => '1.3.6.1.4.1.318.1.1.27.1.6',
  coolingUnitExtendedAnalog => '1.3.6.1.4.1.318.1.1.27.1.6.1',
  coolingUnitExtendedAnalogTableSize => '1.3.6.1.4.1.318.1.1.27.1.6.1.1',
  coolingUnitExtendedAnalogTable => '1.3.6.1.4.1.318.1.1.27.1.6.1.2',
  coolingUnitExtendedAnalogEntry => '1.3.6.1.4.1.318.1.1.27.1.6.1.2.1',
  coolingUnitExtendedAnalogTableIndex => '1.3.6.1.4.1.318.1.1.27.1.6.1.2.1.1',
  coolingUnitExtendedAnalogDescription => '1.3.6.1.4.1.318.1.1.27.1.6.1.2.1.2',
  coolingUnitExtendedAnalogValue => '1.3.6.1.4.1.318.1.1.27.1.6.1.2.1.3',
  coolingUnitExtendedAnalogUnits => '1.3.6.1.4.1.318.1.1.27.1.6.1.2.1.4',
  coolingUnitExtendedAnalogScale => '1.3.6.1.4.1.318.1.1.27.1.6.1.2.1.5',
  coolingUnitExtendedDiscrete => '1.3.6.1.4.1.318.1.1.27.1.6.2',
  coolingUnitExtendedDiscreteTableSize => '1.3.6.1.4.1.318.1.1.27.1.6.2.1',
  coolingUnitExtendedDiscreteTable => '1.3.6.1.4.1.318.1.1.27.1.6.2.2',
  coolingUnitExtendedDiscreteEntry => '1.3.6.1.4.1.318.1.1.27.1.6.2.2.1',
  coolingUnitExtendedDiscreteTableIndex => '1.3.6.1.4.1.318.1.1.27.1.6.2.2.1.1',
  coolingUnitExtendedDiscreteDescription => '1.3.6.1.4.1.318.1.1.27.1.6.2.2.1.2',
  coolingUnitExtendedDiscreteValueAsString => '1.3.6.1.4.1.318.1.1.27.1.6.2.2.1.3',
  coolingUnitExtendedDiscreteValueAsInteger => '1.3.6.1.4.1.318.1.1.27.1.6.2.2.1.4',
  coolingUnitExtendedDiscreteIntegerReferenceKey => '1.3.6.1.4.1.318.1.1.27.1.6.2.2.1.5',
  coolingUnitExtendedString => '1.3.6.1.4.1.318.1.1.27.1.6.3',
  coolingUnitExtendedStringTableSize => '1.3.6.1.4.1.318.1.1.27.1.6.3.1',
  coolingUnitExtendedStringTable => '1.3.6.1.4.1.318.1.1.27.1.6.3.2',
  coolingUnitExtendedStringEntry => '1.3.6.1.4.1.318.1.1.27.1.6.3.2.1',
  coolingUnitExtendedStringTableIndex => '1.3.6.1.4.1.318.1.1.27.1.6.3.2.1.1',
  coolingUnitExtendedStringDescription => '1.3.6.1.4.1.318.1.1.27.1.6.3.2.1.2',
  coolingUnitExtendedStringValue => '1.3.6.1.4.1.318.1.1.27.1.6.3.2.1.3',
  software => '1.3.6.1.4.1.318.1.2',
  powerNetSubAgent => '1.3.6.1.4.1.318.1.2.1',
  powerNetSoftwareSystem => '1.3.6.1.4.1.318.1.2.1.1',
  powerNetSoftwareSystemDescription => '1.3.6.1.4.1.318.1.2.1.1.1',
  powerNetSoftwareOid => '1.3.6.1.4.1.318.1.2.1.1.2',
  powerNetSoftwareSystemUpTime => '1.3.6.1.4.1.318.1.2.1.1.3',
  powerNetSoftwareConfig => '1.3.6.1.4.1.318.1.2.1.2',
  powerNetSoftwareTableSize => '1.3.6.1.4.1.318.1.2.1.2.1',
  powerNetSoftwareTable => '1.3.6.1.4.1.318.1.2.1.2.2',
  powerNetSoftwareEntry => '1.3.6.1.4.1.318.1.2.1.2.2.1',
  moduleNumber => '1.3.6.1.4.1.318.1.2.1.2.2.1.1',
  moduleName => '1.3.6.1.4.1.318.1.2.1.2.2.1.2',
  moduleVersion => '1.3.6.1.4.1.318.1.2.1.2.2.1.3',
  moduleDate => '1.3.6.1.4.1.318.1.2.1.2.2.1.4',
  struxureWareOperations => '1.3.6.1.4.1.318.1.2.2',
  struxureWareOperationsStatus => '1.3.6.1.4.1.318.1.2.2.1',
  serverStatus => '1.3.6.1.4.1.318.1.2.2.1.1',
  serverStatusDefinition => 'PowerNet-MIB::serverStatus',
  databaseStatus => '1.3.6.1.4.1.318.1.2.2.1.2',
  databaseStatusDefinition => 'PowerNet-MIB::databaseStatus',
  loadBalancerStatus => '1.3.6.1.4.1.318.1.2.2.1.3',
  loadBalancerStatusDefinition => 'PowerNet-MIB::loadBalancerStatus',
  essentialServicesStatus => '1.3.6.1.4.1.318.1.2.2.1.4',
  essentialServicesStatusDefinition => 'PowerNet-MIB::essentialServicesStatus',
  etlStatus => '1.3.6.1.4.1.318.1.2.2.1.5',
  etlStatusDefinition => 'PowerNet-MIB::etlStatus',
  system => '1.3.6.1.4.1.318.1.3',
  backUPS => '1.3.6.1.4.1.318.1.3.1',
  smartUPS => '1.3.6.1.4.1.318.1.3.2',
  smartUPS250 => '1.3.6.1.4.1.318.1.3.2.1',
  smartUPS400 => '1.3.6.1.4.1.318.1.3.2.2',
  smartUPS600 => '1.3.6.1.4.1.318.1.3.2.3',
  smartUPS900 => '1.3.6.1.4.1.318.1.3.2.4',
  smartUPS1250 => '1.3.6.1.4.1.318.1.3.2.5',
  smartUPS2000 => '1.3.6.1.4.1.318.1.3.2.6',
  smartUPS450 => '1.3.6.1.4.1.318.1.3.2.7',
  smartUPS700 => '1.3.6.1.4.1.318.1.3.2.8',
  smartUPS1000 => '1.3.6.1.4.1.318.1.3.2.9',
  smartUPS1400 => '1.3.6.1.4.1.318.1.3.2.10',
  smartUPS2200 => '1.3.6.1.4.1.318.1.3.2.11',
  smartUPS3000 => '1.3.6.1.4.1.318.1.3.2.12',
  smartUPS5000 => '1.3.6.1.4.1.318.1.3.2.13',
  smartUPS7500 => '1.3.6.1.4.1.318.1.3.2.14',
  smartUPS10000 => '1.3.6.1.4.1.318.1.3.2.15',
  smartUPS1500 => '1.3.6.1.4.1.318.1.3.2.16',
  smartUPS3000DSP => '1.3.6.1.4.1.318.1.3.2.17',
  smartUPS5000DSP => '1.3.6.1.4.1.318.1.3.2.18',
  smartUPS8000 => '1.3.6.1.4.1.318.1.3.2.19',
  matrixUPS => '1.3.6.1.4.1.318.1.3.3',
  matrixUPS3000 => '1.3.6.1.4.1.318.1.3.3.1',
  matrixUPS5000 => '1.3.6.1.4.1.318.1.3.3.2',
  masterSwitch => '1.3.6.1.4.1.318.1.3.4',
  masterSwitchV1 => '1.3.6.1.4.1.318.1.3.4.1',
  masterSwitchV2 => '1.3.6.1.4.1.318.1.3.4.2',
  masterSwitchVM => '1.3.6.1.4.1.318.1.3.4.3',
  masterSwitchMSP => '1.3.6.1.4.1.318.1.3.4.4',
  masterSwitchrPDU => '1.3.6.1.4.1.318.1.3.4.5',
  masterSwitchrPDU2 => '1.3.6.1.4.1.318.1.3.4.6',
  masterSwitchsPDU => '1.3.6.1.4.1.318.1.3.4.7',
  symmetraUPS => '1.3.6.1.4.1.318.1.3.5',
  symmetraUPS4kVA => '1.3.6.1.4.1.318.1.3.5.1',
  symmetraUPS8kVA => '1.3.6.1.4.1.318.1.3.5.2',
  symmetraUPS12kVA => '1.3.6.1.4.1.318.1.3.5.3',
  symmetraUPS16kVA => '1.3.6.1.4.1.318.1.3.5.4',
  dp100E => '1.3.6.1.4.1.318.1.3.6',
  dp300E => '1.3.6.1.4.1.318.1.3.7',
  monitors => '1.3.6.1.4.1.318.1.3.8',
  environmental => '1.3.6.1.4.1.318.1.3.8.1',
  environmentalMgtSystem => '1.3.6.1.4.1.318.1.3.8.2',
  emu2 => '1.3.6.1.4.1.318.1.3.8.3',
  mem => '1.3.6.1.4.1.318.1.3.8.4',
  redundantSwitch => '1.3.6.1.4.1.318.1.3.9',
  dcPower => '1.3.6.1.4.1.318.1.3.10',
  dm3 => '1.3.6.1.4.1.318.1.3.10.1',
  dcmim2 => '1.3.6.1.4.1.318.1.3.10.2',
  automaticXferSwitch => '1.3.6.1.4.1.318.1.3.11',
  netLock => '1.3.6.1.4.1.318.1.3.12',
  symmetra3PhaseUPS => '1.3.6.1.4.1.318.1.3.13',
  symmetra3PhaseUPS40kVA => '1.3.6.1.4.1.318.1.3.13.1',
  symmetra3PhaseUPS60kVA => '1.3.6.1.4.1.318.1.3.13.2',
  symmetra3PhaseUPS80kVA => '1.3.6.1.4.1.318.1.3.13.3',
  symmetra3PhaseUPS20kVA => '1.3.6.1.4.1.318.1.3.13.4',
  networkAir => '1.3.6.1.4.1.318.1.3.14',
  airFMSeries => '1.3.6.1.4.1.318.1.3.14.1',
  rackAirRemovalUnit => '1.3.6.1.4.1.318.1.3.14.2',
  airPASeries => '1.3.6.1.4.1.318.1.3.14.3',
  airIRSC100Series => '1.3.6.1.4.1.318.1.3.14.4',
  airIRRC100Series => '1.3.6.1.4.1.318.1.3.14.5',
  airIRRP100Series => '1.3.6.1.4.1.318.1.3.14.6',
  airIRRP500Series => '1.3.6.1.4.1.318.1.3.14.7',
  airIRRD100Series => '1.3.6.1.4.1.318.1.3.14.8',
  airInRoomPerimeter => '1.3.6.1.4.1.318.1.3.14.9',
  airACRC300Series => '1.3.6.1.4.1.318.1.3.14.10',
  airLESeries => '1.3.6.1.4.1.318.1.3.14.11',
  airIRRDU => '1.3.6.1.4.1.318.1.3.14.12',
  airEcoBreeze => '1.3.6.1.4.1.318.1.3.14.13',
  airLELSeries => '1.3.6.1.4.1.318.1.3.14.14',
  airACRC600Series => '1.3.6.1.4.1.318.1.3.14.15',
  airACRD600Series => '1.3.6.1.4.1.318.1.3.14.16',
  infraStruXurePDU => '1.3.6.1.4.1.318.1.3.15',
  ais5000UPS => '1.3.6.1.4.1.318.1.3.16',
  ais5000UPS10kVA => '1.3.6.1.4.1.318.1.3.16.1',
  ais5000UPS20kVA => '1.3.6.1.4.1.318.1.3.16.2',
  ais5000UPS30kVA => '1.3.6.1.4.1.318.1.3.16.3',
  ais5000UPS40kVA => '1.3.6.1.4.1.318.1.3.16.4',
  ais5000UPS60kVA => '1.3.6.1.4.1.318.1.3.16.5',
  ais5000UPS80kVA => '1.3.6.1.4.1.318.1.3.16.6',
  ais5000UPS100kVA => '1.3.6.1.4.1.318.1.3.16.7',
  smartUPS3Phase => '1.3.6.1.4.1.318.1.3.17',
  smartUPS3Phase10kVA => '1.3.6.1.4.1.318.1.3.17.1',
  smartUPS3Phase15kVA => '1.3.6.1.4.1.318.1.3.17.2',
  smartUPS3Phase20kVA => '1.3.6.1.4.1.318.1.3.17.3',
  smartUPS3Phase30kVA => '1.3.6.1.4.1.318.1.3.17.4',
  smartUPS3Phase40kVA => '1.3.6.1.4.1.318.1.3.17.5',
  battManager => '1.3.6.1.4.1.318.1.3.18',
  infraStruXureATS => '1.3.6.1.4.1.318.1.3.19',
  conPortServ => '1.3.6.1.4.1.318.1.3.20',
  conPortServAP930x => '1.3.6.1.4.1.318.1.3.20.1',
  gutor => '1.3.6.1.4.1.318.1.3.21',
  gutorPEW => '1.3.6.1.4.1.318.1.3.21.1',
  gutorPDW => '1.3.6.1.4.1.318.1.3.21.2',
  gutorWEW => '1.3.6.1.4.1.318.1.3.21.3',
  gutorWDW => '1.3.6.1.4.1.318.1.3.21.4',
  gutorSDC => '1.3.6.1.4.1.318.1.3.21.5',
  accControl => '1.3.6.1.4.1.318.1.3.22',
  accPX => '1.3.6.1.4.1.318.1.3.22.1',
  symmetraPX => '1.3.6.1.4.1.318.1.3.23',
  symmetraPx48kVA => '1.3.6.1.4.1.318.1.3.23.1',
  symmetraPx160kVA => '1.3.6.1.4.1.318.1.3.23.2',
  symmetraPx250kVA => '1.3.6.1.4.1.318.1.3.23.3',
  symmetraPx500kVA => '1.3.6.1.4.1.318.1.3.23.4',
  symmetraPx100kVA => '1.3.6.1.4.1.318.1.3.23.5',
  symmetraPxDisplay => '1.3.6.1.4.1.318.1.3.23.6',
  isxModDistribution => '1.3.6.1.4.1.318.1.3.24',
  isx24ModuleHalfRackPdu => '1.3.6.1.4.1.318.1.3.24.1',
  isx6ModuleRackPdu => '1.3.6.1.4.1.318.1.3.24.2',
  isxServers => '1.3.6.1.4.1.318.1.3.25',
  isxcBasic => '1.3.6.1.4.1.318.1.3.25.1',
  isxcStandard => '1.3.6.1.4.1.318.1.3.25.2',
  isxcEnterprise => '1.3.6.1.4.1.318.1.3.25.3',
  isxcVirtual => '1.3.6.1.4.1.318.1.3.25.4',
  smartUPS2 => '1.3.6.1.4.1.318.1.3.27',
  galaxy => '1.3.6.1.4.1.318.1.3.28',
  galaxy7000UPS200kVA => '1.3.6.1.4.1.318.1.3.28.1',
  galaxy7000UPS250kVA => '1.3.6.1.4.1.318.1.3.28.2',
  galaxy7000UPS300kVA => '1.3.6.1.4.1.318.1.3.28.3',
  galaxy7000UPS400kVA => '1.3.6.1.4.1.318.1.3.28.4',
  galaxy7000UPS500kVA => '1.3.6.1.4.1.318.1.3.28.5',
  galaxy7000SSC800kVA => '1.3.6.1.4.1.318.1.3.28.6',
  galaxy7000SSC1200kVA => '1.3.6.1.4.1.318.1.3.28.7',
  galaxy7000SSC2000kVA => '1.3.6.1.4.1.318.1.3.28.8',
  galaxy300UPS10kVA33 => '1.3.6.1.4.1.318.1.3.28.9',
  galaxy300UPS15kVA33 => '1.3.6.1.4.1.318.1.3.28.10',
  galaxy300UPS20kVA33 => '1.3.6.1.4.1.318.1.3.28.11',
  galaxy300UPS30kVA33 => '1.3.6.1.4.1.318.1.3.28.12',
  galaxy300UPS40kVA33 => '1.3.6.1.4.1.318.1.3.28.13',
  galaxy300UPS10kVA31 => '1.3.6.1.4.1.318.1.3.28.14',
  galaxy300UPS15kVA31 => '1.3.6.1.4.1.318.1.3.28.15',
  galaxy300UPS20kVA31 => '1.3.6.1.4.1.318.1.3.28.16',
  galaxy300UPS30kVA31 => '1.3.6.1.4.1.318.1.3.28.17',
  galaxy5000UPS20KVA => '1.3.6.1.4.1.318.1.3.28.18',
  galaxy5000UPS30KVA => '1.3.6.1.4.1.318.1.3.28.19',
  galaxy5000UPS40KVA => '1.3.6.1.4.1.318.1.3.28.20',
  galaxy5000UPS50KVA => '1.3.6.1.4.1.318.1.3.28.21',
  galaxy5000UPS60KVA => '1.3.6.1.4.1.318.1.3.28.22',
  galaxy5000UPS80KVA => '1.3.6.1.4.1.318.1.3.28.23',
  galaxy5000UPS100KVA => '1.3.6.1.4.1.318.1.3.28.24',
  galaxy5000UPS120KVA => '1.3.6.1.4.1.318.1.3.28.25',
  galaxy5000UPS130KVA => '1.3.6.1.4.1.318.1.3.28.26',
  galaxy5500UPS20KVA => '1.3.6.1.4.1.318.1.3.28.27',
  galaxy5500UPS30KVA => '1.3.6.1.4.1.318.1.3.28.28',
  galaxy5500UPS40KVA => '1.3.6.1.4.1.318.1.3.28.29',
  galaxy5500UPS50KVA => '1.3.6.1.4.1.318.1.3.28.30',
  galaxy5500UPS60KVA => '1.3.6.1.4.1.318.1.3.28.31',
  galaxy5500UPS80KVA => '1.3.6.1.4.1.318.1.3.28.32',
  galaxy5500UPS100KVA => '1.3.6.1.4.1.318.1.3.28.33',
  galaxy5500UPS120KVA => '1.3.6.1.4.1.318.1.3.28.34',
  galaxy5500UPS130KVA => '1.3.6.1.4.1.318.1.3.28.35',
  galaxyVMUPS50kVA => '1.3.6.1.4.1.318.1.3.28.36',
  galaxyVMUPS60kVA => '1.3.6.1.4.1.318.1.3.28.37',
  galaxyVMUPS80kVA => '1.3.6.1.4.1.318.1.3.28.38',
  galaxyVMUPS90kVA => '1.3.6.1.4.1.318.1.3.28.39',
  galaxyVMUPS100kVA => '1.3.6.1.4.1.318.1.3.28.40',
  galaxyVMUPS110kVA => '1.3.6.1.4.1.318.1.3.28.41',
  galaxyVMUPS120kVA => '1.3.6.1.4.1.318.1.3.28.42',
  galaxyVMUPS130kVA => '1.3.6.1.4.1.318.1.3.28.43',
  galaxyVMUPS160kVA => '1.3.6.1.4.1.318.1.3.28.44',
  galaxyVMUPS180kVA => '1.3.6.1.4.1.318.1.3.28.45',
  galaxyVMUPS200kVA => '1.3.6.1.4.1.318.1.3.28.46',
  galaxyVMUPS225kVA => '1.3.6.1.4.1.318.1.3.28.47',
  galaxy9000UPS => '1.3.6.1.4.1.318.1.3.28.48',
  galaxy9000SSC => '1.3.6.1.4.1.318.1.3.28.49',
  galaxy9000UPSWithSSC => '1.3.6.1.4.1.318.1.3.28.50',
  galaxy9000FreqConverter => '1.3.6.1.4.1.318.1.3.28.51',
  eps => '1.3.6.1.4.1.318.1.3.30',
  eps6000UPS => '1.3.6.1.4.1.318.1.3.30.1',
  eps6000SSC => '1.3.6.1.4.1.318.1.3.30.2',
  eps6000UPSWithSSC => '1.3.6.1.4.1.318.1.3.30.3',
  eps6000FreqConverter => '1.3.6.1.4.1.318.1.3.30.4',
  eps7000UPS => '1.3.6.1.4.1.318.1.3.30.5',
  eps7000SSC => '1.3.6.1.4.1.318.1.3.30.6',
  eps7000UPSWithSSC => '1.3.6.1.4.1.318.1.3.30.7',
  eps7000FreqConverter => '1.3.6.1.4.1.318.1.3.30.8',
  eps8000UPS => '1.3.6.1.4.1.318.1.3.30.9',
  eps8000SSC => '1.3.6.1.4.1.318.1.3.30.10',
  eps8000UPSWithSSC => '1.3.6.1.4.1.318.1.3.30.11',
  eps8000FreqConverter => '1.3.6.1.4.1.318.1.3.30.12',
  experimental => '1.3.6.1.4.1.318.1.4',
  apcmgmt => '1.3.6.1.4.1.318.2',
  mconfig => '1.3.6.1.4.1.318.2.1',
  mconfigNumTrapReceivers => '1.3.6.1.4.1.318.2.1.1',
  mconfigTrapReceiverTable => '1.3.6.1.4.1.318.2.1.2',
  mconfigTrapReceiverEntry => '1.3.6.1.4.1.318.2.1.2.1',
  trapIndex => '1.3.6.1.4.1.318.2.1.2.1.1',
  receiverAddr => '1.3.6.1.4.1.318.2.1.2.1.2',
  communityString => '1.3.6.1.4.1.318.2.1.2.1.3',
  severity => '1.3.6.1.4.1.318.2.1.2.1.4',
  severityDefinition => 'PowerNet-MIB::severity',
  acceptThisReceiver => '1.3.6.1.4.1.318.2.1.2.1.5',
  acceptThisReceiverDefinition => 'PowerNet-MIB::acceptThisReceiver',
  receiveTrapType => '1.3.6.1.4.1.318.2.1.2.1.6',
  receiveTrapTypeDefinition => 'PowerNet-MIB::receiveTrapType',
  mconfigBOOTPEnabled => '1.3.6.1.4.1.318.2.1.3',
  mconfigBOOTPEnabledDefinition => 'PowerNet-MIB::mconfigBOOTPEnabled',
  mconfigTFTPServerIP => '1.3.6.1.4.1.318.2.1.4',
  newCodeAuthentViaTFTP => '1.3.6.1.4.1.318.2.1.5',
  newCodeAuthentViaTFTPDefinition => 'PowerNet-MIB::newCodeAuthentViaTFTP',
  mconfigClock => '1.3.6.1.4.1.318.2.1.6',
  mconfigClockDate => '1.3.6.1.4.1.318.2.1.6.1',
  mconfigClockTime => '1.3.6.1.4.1.318.2.1.6.2',
  mcontrol => '1.3.6.1.4.1.318.2.2',
  mcontrolRestartAgent => '1.3.6.1.4.1.318.2.2.1',
  mcontrolRestartAgentDefinition => 'PowerNet-MIB::mcontrolRestartAgent',
  mtrapargs => '1.3.6.1.4.1.318.2.3',
  mtrapargsInteger => '1.3.6.1.4.1.318.2.3.1',
  mtrapargsIpAddress => '1.3.6.1.4.1.318.2.3.2',
  mtrapargsString => '1.3.6.1.4.1.318.2.3.3',
  mtrapargsGauge => '1.3.6.1.4.1.318.2.3.4',
  mtrapargsTimeTicks => '1.3.6.1.4.1.318.2.3.5',
  mtrapargsInteger02 => '1.3.6.1.4.1.318.2.3.6',
  mtrapargsInteger03 => '1.3.6.1.4.1.318.2.3.7',
  mtrapargsIpAddress02 => '1.3.6.1.4.1.318.2.3.8',
  mtrapargsIpAddress03 => '1.3.6.1.4.1.318.2.3.9',
  mtrapargsString02 => '1.3.6.1.4.1.318.2.3.10',
  mtrapargsString03 => '1.3.6.1.4.1.318.2.3.11',
  mtrapargsGauge02 => '1.3.6.1.4.1.318.2.3.12',
  mtrapargsGauge03 => '1.3.6.1.4.1.318.2.3.13',
  mtrapargsTimeTicks02 => '1.3.6.1.4.1.318.2.3.14',
  mtrapargsTimeTicks03 => '1.3.6.1.4.1.318.2.3.15',
  mtrapargsString04 => '1.3.6.1.4.1.318.2.3.16',
  mtrapargsString05 => '1.3.6.1.4.1.318.2.3.17',
  mtrapargsInteger04 => '1.3.6.1.4.1.318.2.3.18',
  mtrapargsInteger05 => '1.3.6.1.4.1.318.2.3.19',
  mtrapargsString06 => '1.3.6.1.4.1.318.2.3.20',
  mtrapargsString07 => '1.3.6.1.4.1.318.2.3.21',
  mtrapargsString08 => '1.3.6.1.4.1.318.2.3.22',
  mtrapargsOctetString => '1.3.6.1.4.1.318.2.3.23',
  mtrapargsOctetString02 => '1.3.6.1.4.1.318.2.3.24',
  mtrapargsOctetString03 => '1.3.6.1.4.1.318.2.3.25',
  mtrapargsOctetString04 => '1.3.6.1.4.1.318.2.3.26',
  mtrapargsOctetString05 => '1.3.6.1.4.1.318.2.3.27',
  mtrapargsOctetString06 => '1.3.6.1.4.1.318.2.3.28',
  mtrapargsOctetString07 => '1.3.6.1.4.1.318.2.3.29',
  mtrapargsOctetString08 => '1.3.6.1.4.1.318.2.3.30',
  mfiletransfer => '1.3.6.1.4.1.318.2.4',
  mfiletransferStatus => '1.3.6.1.4.1.318.2.4.1',
  mfiletransferStatusLastTransferResult => '1.3.6.1.4.1.318.2.4.1.1',
  mfiletransferStatusLastTransferResultDefinition => 'PowerNet-MIB::mfiletransferStatusLastTransferResult',
  mfiletransferConfig => '1.3.6.1.4.1.318.2.4.2',
  mfiletransferConfigSettings => '1.3.6.1.4.1.318.2.4.2.1',
  mfiletransferConfigSettingsFilename => '1.3.6.1.4.1.318.2.4.2.1.1',
  mfiletransferConfigTFTP => '1.3.6.1.4.1.318.2.4.2.2',
  mfiletransferConfigTFTPServerAddress => '1.3.6.1.4.1.318.2.4.2.2.1',
  mfiletransferConfigFTP => '1.3.6.1.4.1.318.2.4.2.3',
  mfiletransferConfigFTPServerAddress => '1.3.6.1.4.1.318.2.4.2.3.1',
  mfiletransferConfigFTPServerUser => '1.3.6.1.4.1.318.2.4.2.3.2',
  mfiletransferConfigFTPServerPassword => '1.3.6.1.4.1.318.2.4.2.3.3',
  mfiletransferControl => '1.3.6.1.4.1.318.2.4.3',
  mfiletransferControlInitiateFileTransfer => '1.3.6.1.4.1.318.2.4.3.1',
  mfiletransferControlInitiateFileTransferDefinition => 'PowerNet-MIB::mfiletransferControlInitiateFileTransfer',
};

$Monitoring::GLPlugin::SNMP::MibsAndOids::definitions->{'PowerNet-MIB'} = {
  upsAdvTestDiagnosticsResults => {
    '1' => 'ok',
    '2' => 'failed',
    '3' => 'invalidTest',
    '4' => 'testInProgress',
  },
  upsDiagPMLifetimeStatus => {
    '1' => 'ok',
    '2' => 'nearEnd',
    '3' => 'exceeded',
    '4' => 'unknown',
  },
  airIRRP500UnitStatusLeakSensor => {
    '1' => 'no-leak',
    '2' => 'leak',
  },
  atsStatusSourceBStatus => {
    '1' => 'fail',
    '2' => 'ok',
  },
  airFMGroupSysPresentRole => {
    '1' => 'primary',
    '2' => 'backup',
  },
  airIRRP100UnitConfigInputNormalState => {
    '1' => 'open',
    '2' => 'closed',
  },
  airFMSysAlarmMapMainModHighSupplyTemp => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  battManString2BatteryLowCapacity => {
    '1' => 'normal',
    '2' => 'alarm',
  },
  airFMSysAlarmMapSysHighEnvTemp => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  airFMModRHHumReset => {
    '1' => 'notApplicable',
    '2' => 'noOperation',
    '3' => 'reset',
  },
  rPDU2DevicePropertiesOrientation => {
    '1' => 'horizontal',
    '2' => 'vertical',
    '3' => 'verticalISXv2',
  },
  airIRmPmLouver1Position => {
    '1' => 'closed',
    '2' => 'open',
  },
  airIRmPmLouver3Position => {
    '1' => 'closed',
    '2' => 'open',
  },
  airFMModHumidifierType => {
    '1' => 'notApplicable',
    '2' => 'none',
    '3' => 'steamElectrode',
    '4' => 'liveSteam',
  },
  dm3ConfigRect1ofNAlarm => {
    '1' => 'alarmIgnore',
    '2' => 'alarmRelay1',
    '3' => 'alarmRelay2',
    '4' => 'alarmRelay3',
    '5' => 'alarmRelay4',
    '6' => 'alarmRelay5',
    '7' => 'alarmRelay6',
    '8' => 'alarmMinor',
    '9' => 'alarmMajor',
  },
  dm3ConfigBattHighTempAlarm => {
    '1' => 'alarmIgnore',
    '2' => 'alarmRelay1',
    '3' => 'alarmRelay2',
    '4' => 'alarmRelay3',
    '5' => 'alarmRelay4',
    '6' => 'alarmRelay5',
    '7' => 'alarmRelay6',
    '8' => 'alarmMinor',
    '9' => 'alarmMajor',
  },
  rPDUOutletControlOutletPhase => {
    '1' => 'phase1',
    '2' => 'phase2',
    '3' => 'phase3',
    '4' => 'phase1-2',
    '5' => 'phase2-3',
    '6' => 'phase3-1',
  },
  upsAdvControlTurnOnUPS => {
    '1' => 'noTurnOnUPS',
    '2' => 'turnOnUPS',
    '3' => 'turnOnUPSSyncGroup',
  },
  isxModularPduDeviceFansPresent => {
    '1' => 'notPresent',
    '2' => 'present',
  },
  airFMSysAlarmMapExpMod1MaintReq => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  xATSOutputRelayNormalState => {
    '1' => 'open',
    '2' => 'closed',
  },
  airFMGroupFailoverSysPrimarySensorFail => {
    '1' => 'notApplicable',
    '2' => 'disable',
    '3' => 'enable',
  },
  atsStatusResetMaxMinValues => {
    '1' => 'none',
    '2' => 'reset',
  },
  emConfigContactSeverity => {
    '1' => 'critical',
    '2' => 'warning',
    '3' => 'informational',
  },
  upsAdvTestDiagnosticDay => {
    '1' => 'monday',
    '2' => 'tuesday',
    '3' => 'wednesday',
    '4' => 'thursday',
    '5' => 'friday',
    '6' => 'saturday',
    '7' => 'sunday',
  },
  atsStatusSwitchStatus => {
    '1' => 'fail',
    '2' => 'ok',
  },
  monitoringStatus => {
    '1' => 'unknown',
    '2' => 'enabled',
    '3' => 'disabled',
  },
  dcmim2ConfigLVDState => {
    '1' => 'statusClosed',
    '2' => 'statusOpened',
  },
  airFMGroupCfgDmdFightStatus => {
    '1' => 'off',
    '2' => 'on',
  },
  xATSSwitchSettingsNominalRotation => {
    '1' => 'abc',
    '2' => 'cba',
    '3' => 'any',
    '4' => 'unknown',
  },
  dm3ConfigSysHardwareTempAlarm => {
    '1' => 'alarmIgnore',
    '2' => 'alarmRelay1',
    '3' => 'alarmRelay2',
    '4' => 'alarmRelay3',
    '5' => 'alarmRelay4',
    '6' => 'alarmRelay5',
    '7' => 'alarmRelay6',
    '8' => 'alarmMinor',
    '9' => 'alarmMajor',
  },
  dm3StatusConvFanFail => {
    '1' => 'statusTrue',
    '2' => 'statusFalse',
  },
  airIRG3GroupConfigLoadAssistEnable => {
    '1' => 'disable',
    '2' => 'enable',
  },
  airIRG2GroupConfigCapacityControlType => {
    '1' => 'discrete',
    '2' => 'proportional',
  },
  airFMGroupFailoverSysCommLost => {
    '1' => 'notApplicable',
    '2' => 'disable',
    '3' => 'enable',
  },
  airIRmPmHumidifier2Type => {
    '1' => 'direct',
    '2' => 'proportional',
  },
  airIRRP500UnitStatusOperateMode => {
    '1' => 'standby',
    '2' => 'on',
    '3' => 'idle',
    '4' => 'prestart',
    '5' => 'backup',
    '6' => 'assist',
  },
  sPDUOutletConfigMSPallOutletCtrlMode => {
    '1' => 'modeGracefulShutdown',
    '2' => 'modeAnnunciator',
  },
  atsConfigFrequencyDeviation => {
    '1' => 'one',
    '2' => 'two',
    '3' => 'three',
  },
  battManString1BatteryOpenCell => {
    '1' => 'normal',
    '2' => 'alarm',
  },
  xATSGeneratorStatusModeSwitchPosition => {
    '1' => 'off',
    '2' => 'manual',
    '3' => 'automatic',
    '4' => 'unknown',
  },
  airFMModHeaterType => {
    '1' => 'notApplicable',
    '2' => 'none',
    '3' => 'electricSCR',
    '4' => 'steam',
    '5' => 'hotWaterOnOff',
    '6' => 'hotGasReheat',
    '7' => 'hotGasAndElectric',
    '8' => 'hotWaterProp',
  },
  rPDUPowerSupplyAlarm => {
    '1' => 'allAvailablePowerSuppliesOK',
    '2' => 'powerSupplyOneFailed',
    '3' => 'powerSupplyTwoFailed',
    '4' => 'powerSupplyOneandTwoFailed',
  },
  airFMSysFastStartup => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  airFMSysAlarmMapInput16 => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  atsConfigResetValues => {
    '1' => 'none',
    '2' => 'reset',
  },
  rARUStatusAruManualSetpoint => {
    '1' => 'aruOff',
    '2' => 'aru85F-29C',
    '3' => 'aru90F-32C',
    '4' => 'aru95F-35C',
    '5' => 'aru100F-38C',
    '6' => 'aru7kW',
    '7' => 'aru5kW',
    '8' => 'aru3kW',
    '9' => 'aru2kW',
    '10' => 'aruRem',
  },
  dm3ConfigRectHwVoltAlarm => {
    '1' => 'alarmIgnore',
    '2' => 'alarmRelay1',
    '3' => 'alarmRelay2',
    '4' => 'alarmRelay3',
    '5' => 'alarmRelay4',
    '6' => 'alarmRelay5',
    '7' => 'alarmRelay6',
    '8' => 'alarmMinor',
    '9' => 'alarmMajor',
  },
  dm3ConfigConvLowVoltAlarm => {
    '1' => 'alarmIgnore',
    '2' => 'alarmRelay1',
    '3' => 'alarmRelay2',
    '4' => 'alarmRelay3',
    '5' => 'alarmRelay4',
    '6' => 'alarmRelay5',
    '7' => 'alarmRelay6',
    '8' => 'alarmMinor',
    '9' => 'alarmMajor',
  },
  rPDU2SensorTempHumidityConfigTemperatureAlarmEnable => {
    '1' => 'disabled',
    '2' => 'enabled',
  },
  airIRmPmLouver1ManOpPosition => {
    '1' => 'closed',
    '2' => 'open',
  },
  airFMSysAlarmMapInput14 => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  airIRmPmLouver2Position => {
    '1' => 'closed',
    '2' => 'open',
  },
  isxModularDistSysOutputVoltageAlarmMinEnable => {
    '1' => 'disabled',
    '2' => 'enabled',
  },
  airFMModRHComp2Reset => {
    '1' => 'notApplicable',
    '2' => 'noOperation',
    '3' => 'reset',
  },
  airFMSysAlarmMapExpMod2LowSupplyTemp => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  emStatusProbeHighTempViolation => {
    '1' => 'noViolation',
    '2' => 'highTempViolation',
    '3' => 'disabled',
  },
  airFMSysAlarmMapExpMod2BlwrCntl1Fail => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  dm3StatusSysConvAvailable => {
    '1' => 'statusTrue',
    '2' => 'statusFalse',
  },
  serverStatus => {
    '1' => 'unknown',
    '2' => 'stopped',
    '3' => 'running',
    '4' => 'running-missing',
    '5' => 'initializing',
    '6' => 'starting',
    '7' => 'disaster-recovery',
    '8' => 'postoffice-inconsistent',
    '9' => 'missing-jgroups',
  },
  airFMModSmokeDetector => {
    '1' => 'notApplicable',
    '2' => 'notPresent',
    '3' => 'present',
  },
  upsAdvControlBypassSwitch => {
    '1' => 'noBypassSwitch',
    '2' => 'switchToBypass',
    '3' => 'switchOutOfBypass',
  },
  airIRRCGroupSetpointsActiveFlowControlBias => {
    '1' => 'positive',
    '2' => 'slightlyPositive',
    '3' => 'zero',
    '4' => 'slightlyNegative',
    '5' => 'negative',
  },
  dm3ConfigBattDischargeAlarm => {
    '1' => 'alarmIgnore',
    '2' => 'alarmRelay1',
    '3' => 'alarmRelay2',
    '4' => 'alarmRelay3',
    '5' => 'alarmRelay4',
    '6' => 'alarmRelay5',
    '7' => 'alarmRelay6',
    '8' => 'alarmMinor',
    '9' => 'alarmMajor',
  },
  isxModularDistModuleOutputAlarmGeneration => {
    '1' => 'disabled',
    '2' => 'enabled',
  },
  airFMSysActualHumCtrl => {
    '1' => 'notApplicable',
    '2' => 'relativeHum',
    '3' => 'dewPoint',
  },
  airIRG3RDUStatusOutputState => {
    '1' => 'open',
    '2' => 'closed',
  },
  dm3StatusRectFanFail => {
    '1' => 'statusTrue',
    '2' => 'statusFalse',
  },
  atsStatusSourceAStatus => {
    '1' => 'fail',
    '2' => 'ok',
  },
  isxModularDistModuleBreakerPosition => {
    '1' => 'open',
    '2' => 'closed',
  },
  airIRG3CMConfigRemoteOnStandby => {
    '1' => 'standBy',
    '2' => 'on',
  },
  dm3StatusSysRectAvailable => {
    '1' => 'statusTrue',
    '2' => 'statusFalse',
  },
  airIRRP500UnitConfigHeatAssistEnable => {
    '1' => 'enable',
    '2' => 'disable',
  },
  isxModularDistSubFeedInfoAlarmLowEnable => {
    '1' => 'disabled',
    '2' => 'enabled',
  },
  rPDU2SensorDiscreteStatusType => {
    '1' => 'notConnected',
    '2' => 'doorContactSensor',
    '3' => 'smokeSensor',
    '4' => 'motionDetector',
    '5' => 'vibrationSensor',
    '6' => 'dryContactSensor',
    '7' => 'spotLeakSensor',
  },
  airFMSysPresentRole => {
    '1' => 'notApplicable',
    '2' => 'primary',
    '3' => 'backup',
  },
  upsAdvInputLineFailCause => {
    '1' => 'noTransfer',
    '2' => 'highLineVoltage',
    '3' => 'brownout',
    '4' => 'blackout',
    '5' => 'smallMomentarySag',
    '6' => 'deepMomentarySag',
    '7' => 'smallMomentarySpike',
    '8' => 'largeMomentarySpike',
    '9' => 'selfTest',
    '10' => 'rateOfVoltageChange',
  },
  airFMSysAlarmMapExpMod2WaterDetected => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  memSensorsAlarmGeneration => {
    '1' => 'disabled',
    '2' => 'enabled',
  },
  dm3ConfigLVDEnable => {
    '1' => 'enabledYes',
    '2' => 'enabledNo',
  },
  uioOutputRelayStatusAlarmStatus => {
    '1' => 'uioNormal',
    '2' => 'uioWarning',
    '3' => 'uioCritical',
    '4' => 'inputStatusNotApplicable',
  },
  upsOutletGroupConfigOutletType => {
    '1' => 'upsSwitchedOutletGroup',
    '2' => 'upsMainOutletGroup',
  },
  emStatusProbeTempUnits => {
    '1' => 'celsius',
    '2' => 'fahrenheit',
  },
  AirIRSCFanSpeedControl => {
    '1' => 'automatic',
    '2' => 'manual',
  },
  upsDiagFlyWheelStatus => {
    '1' => 'unknown',
    '2' => 'present',
    '3' => 'notPresent',
  },
  airFMSysAlarmMapOutput7 => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  airIRRP500UnitConfigCoolCapacity => {
    '1' => 'automatic',
    '2' => 'maximum',
  },
  airFMSysCoolState => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  airFMModElectricHeaterType => {
    '1' => 'notApplicable',
    '2' => 'kw10',
    '3' => 'kw15',
  },
  iemStatusProbeLowTempViolation => {
    '1' => 'noViolation',
    '2' => 'lowTempViolation',
    '3' => 'disabled',
  },
  emsAlarmDeviceControlDeviceCommand => {
    '1' => 'alarmDeviceOnEMS',
    '2' => 'alarmDeviceOffEMS',
    '3' => 'alarmDeviceNotInstalledEMS',
  },
  upsDiagSubSysBattMonitorStatus => {
    '1' => 'unknown',
    '2' => 'notInstalled',
    '3' => 'offOk',
    '4' => 'onOk',
    '5' => 'offFail',
    '6' => 'onFail',
    '7' => 'lostComm',
  },
  airIRSCUnitConfigOpControl => {
    '1' => 'standby',
    '2' => 'on',
  },
  rARUStatusAruRemoteSetpoint => {
    '1' => 'aruOff',
    '2' => 'aru85F-29C',
    '3' => 'aru90F-32C',
    '4' => 'aru95F-35C',
    '5' => 'aru100F-38C',
    '6' => 'aru7kW-1200cfm',
    '7' => 'aru5kW-800cfm',
    '8' => 'aru3kW-500cfm',
    '9' => 'aru2kW-300cfm',
    '10' => 'aru400cfm',
    '11' => 'aru600cfm',
    '12' => 'aru700cfm',
    '13' => 'aru900cfm',
    '14' => 'aru1000cfm',
    '15' => 'aru1400cfm',
    '16' => 'aru1600cfm',
    '17' => 'aru1800cfm',
    '18' => 'aru2000cfm',
  },
  battManSystemSuspendVoltage => {
    '1' => 'normal',
    '2' => 'alarm',
  },
  xATSInputContactCurrentState => {
    '1' => 'open',
    '2' => 'closed',
  },
  xPDUDeviceInfraStruXureType => {
    '1' => 'typeB',
    '2' => 'typeC',
  },
  airFMModBlwr2ElOvMode => {
    '1' => 'notApplicable',
    '2' => 'inactive',
    '3' => 'active',
  },
  upsAdvConfigACWiringSetting => {
    '1' => 'threeWire',
    '2' => 'fourWire',
  },
  airIRmPmEheating3Type => {
    '1' => 'direct',
    '2' => 'pwm',
  },
  isxModularDistSubFeedInfoBreakerAlarmEnable => {
    '1' => 'disabled',
    '2' => 'enabled',
  },
  rPDU2DeviceConfigOutletsPeakLoadReset => {
    '1' => 'noOperation',
    '2' => 'reset',
    '3' => 'notSupported',
  },
  dm3ConfigOutRlyAlarm => {
    '1' => 'alarmIgnore',
    '2' => 'alarmRelay1',
    '3' => 'alarmRelay2',
    '4' => 'alarmRelay3',
    '5' => 'alarmRelay4',
    '6' => 'alarmRelay5',
    '7' => 'alarmRelay6',
    '8' => 'alarmMinor',
    '9' => 'alarmMajor',
  },
  airFMSysAlarmMapExpMod1HighFltrDP => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  airIRG2GroupConfigLoadAssistEnable => {
    '1' => 'disable',
    '2' => 'enable',
  },
  upsDiagIMType => {
    '1' => 'imUnknown',
    '2' => 'imMIM',
    '3' => 'imRIM',
  },
  airFMModOutputCapacity => {
    '1' => 'notApplicable',
    '2' => 'kw45',
    '3' => 'kw35',
    '4' => 'kw40',
    '5' => 'kw50',
    '6' => 'kw80',
  },
  switchgearBreakerType => {
    '1' => 'unknown',
    '2' => 'unitInputBreaker',
    '3' => 'staticSwitchInputBreaker',
    '4' => 'maintenanceBypassBreaker',
    '5' => 'unitOutputBreaker',
    '6' => 'systemIsolationBreaker',
  },
  airIRG2RDT2ConfigUnitIdleOnCoolFail => {
    '1' => 'no',
    '2' => 'yes',
  },
  airIRSCUnitConfigOutputSource => {
    '1' => 'anyAlarm',
    '2' => 'criticalAlarm',
  },
  airFMSysAlarmMapExpMod2HumReplCyl => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  dm3ConfigSysLowTempAlarm => {
    '1' => 'alarmIgnore',
    '2' => 'alarmRelay1',
    '3' => 'alarmRelay2',
    '4' => 'alarmRelay3',
    '5' => 'alarmRelay4',
    '6' => 'alarmRelay5',
    '7' => 'alarmRelay6',
    '8' => 'alarmMinor',
    '9' => 'alarmMajor',
  },
  xATSGeneratorStatusOperational => {
    '1' => 'nocomm',
    '2' => 'off',
    '3' => 'ready',
    '4' => 'starting',
    '5' => 'idle',
    '6' => 'running',
    '7' => 'normalStop',
    '8' => 'emergencyStop',
    '9' => 'notInAuto',
    '10' => 'shutdown',
    '11' => 'unknown',
  },
  emsInputContactStatusInputContactNormalState => {
    '1' => 'normallyClosedEMS',
    '2' => 'normallyOpenEMS',
  },
  dm3ConfigConvFailAlarm => {
    '1' => 'alarmIgnore',
    '2' => 'alarmRelay1',
    '3' => 'alarmRelay2',
    '4' => 'alarmRelay3',
    '5' => 'alarmRelay4',
    '6' => 'alarmRelay5',
    '7' => 'alarmRelay6',
    '8' => 'alarmMinor',
    '9' => 'alarmMajor',
    '10' => 'alarmNofN',
  },
  xATSGeneratorSettingsCrankCycleEnable => {
    '1' => 'disabled',
    '2' => 'enabled',
    '3' => 'unknown',
  },
  airFMGroupCfgResetFieldServiceDefaults => {
    '1' => 'noOperation',
    '2' => 'reset',
  },
  airIRRP100UnitStatusOutputState => {
    '1' => 'open',
    '2' => 'closed',
  },
  upsIntegratedATSSourceStatus => {
    '1' => 'upsIntegratedATSSourceGood',
    '2' => 'upsIntegratedATSSourceBad',
    '3' => 'upsIntegratedATSSourceUnknown',
  },
  airFMSysAlarmMapExpMod1CoolFail => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  xPDUOutputRelayCurrentState => {
    '1' => 'open',
    '2' => 'closed',
    '3' => 'unknown',
  },
  xATSSwitchSettingsAllowClosedTransfer => {
    '1' => 'yes',
    '2' => 'no',
    '3' => 'unknown',
  },
  upsDiagPMEnclDoorFltrStatus => {
    '1' => 'ok',
    '2' => 'nearEnd',
    '3' => 'exceeded',
    '4' => 'unknown',
  },
  rPDU2PhaseStatusLoadState => {
    '1' => 'lowLoad',
    '2' => 'normal',
    '3' => 'nearOverload',
    '4' => 'overload',
  },
  airIRRP100GroupConfigConfigurationType => {
    '1' => 'racs',
    '2' => 'hacs',
    '3' => 'in-row',
    '4' => 'cacs',
  },
  atsStatusCommStatus => {
    '1' => 'atsNeverDiscovered',
    '2' => 'atsCommEstablished',
    '3' => 'atsCommLost',
  },
  upsPhaseResetMaxMinValues => {
    '1' => 'none',
    '2' => 'reset',
  },
  upsAdvTestRuntimeCalibration => {
    '1' => 'noPerformCalibration',
    '2' => 'performCalibration',
    '3' => 'cancelCurrentCalibration',
  },
  atsStatusHardwareStatus => {
    '1' => 'fail',
    '2' => 'ok',
  },
  rPDU2DeviceConfigDevicePeakPowerReset => {
    '1' => 'noOperation',
    '2' => 'reset',
  },
  sPDUOutletConfigMSPmupsP1LowTemp => {
    '1' => 'disableAlarm',
    '2' => 'enableAlarm',
  },
  airIRRP500GroupConfigConfigurationType => {
    '1' => 'racs',
    '2' => 'hacs',
    '3' => 'in-row',
    '4' => 'cacs',
  },
  AirIRmStopState => {
    '1' => 'maybeOn',
    '2' => 'unitOff',
  },
  airFMSysCoolEconIsolFunction => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  xPDUCoolingFanStatus => {
    '1' => 'normal',
    '2' => 'failed',
    '3' => 'noCoolingFansPresent',
    '4' => 'unknown',
  },
  dm3StatusLVDState => {
    '1' => 'statusClosed',
    '2' => 'statusOpened',
  },
  atsInputType => {
    '1' => 'unknown',
    '2' => 'main',
    '3' => 'bypass',
  },
  airFMSysAlarmMapMainModHighFltrDP => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  airIRRP500UnitServiceIntervalFansAlarm => {
    '1' => 'enable',
    '2' => 'disable',
  },
  airFMSysAlarmMapSysPrimSensFail => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  xATSSwitchSettingsClearLatchedAlarms => {
    '1' => 'yes',
    '2' => 'no',
  },
  airFMGroupFailoverModLossOrLowAirFlow => {
    '1' => 'notApplicable',
    '2' => 'disable',
    '3' => 'enable',
  },
  airFMSysAlarmMapInput5 => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  airFMGroupFailoverSysLowEnvHum => {
    '1' => 'notApplicable',
    '2' => 'disable',
    '3' => 'enable',
  },
  receiveTrapType => {
    '1' => 'powernet',
    '2' => 'ietf',
    '3' => 'both',
  },
  accessPXStatusRearDoorLock => {
    '1' => 'unlocked',
    '2' => 'locked',
    '3' => 'notInstalled',
    '4' => 'disconnected',
  },
  dm3ConfigLVDOpenAlarm => {
    '1' => 'alarmIgnore',
    '2' => 'alarmRelay1',
    '3' => 'alarmRelay2',
    '4' => 'alarmRelay3',
    '5' => 'alarmRelay4',
    '6' => 'alarmRelay5',
    '7' => 'alarmRelay6',
    '8' => 'alarmMinor',
    '9' => 'alarmMajor',
  },
  upsDiagSwitchGearBypassSwitchStatus => {
    '1' => 'unknown',
    '2' => 'notInstalled',
    '3' => 'opened',
    '4' => 'closed',
  },
  emConfigProbeMaxHumidEnable => {
    '1' => 'disabled',
    '2' => 'enabled',
  },
  iemConfigProbeHighHumidEnable => {
    '1' => 'disabled',
    '2' => 'enabled',
  },
  dm3ConfigRect2ofNAlarm => {
    '1' => 'alarmIgnore',
    '2' => 'alarmRelay1',
    '3' => 'alarmRelay2',
    '4' => 'alarmRelay3',
    '5' => 'alarmRelay4',
    '6' => 'alarmRelay5',
    '7' => 'alarmRelay6',
    '8' => 'alarmMinor',
    '9' => 'alarmMajor',
  },
  airFMSysHumEssFunction => {
    '1' => 'notApplicable',
    '2' => 'yes',
    '3' => 'no',
  },
  iemConfigProbeLowHumidEnable => {
    '1' => 'disabled',
    '2' => 'enabled',
  },
  severity => {
    '1' => 'information',
    '2' => 'warning',
    '3' => 'severe',
  },
  airFMSysDehumPIDMethod => {
    '1' => 'notApplicable',
    '2' => 'p',
    '3' => 'pi',
    '4' => 'pid',
  },
  airIRG3RDUConfigOutputNormalState => {
    '1' => 'open',
    '2' => 'closed',
  },
  airIRRP100UnitServiceIntervalCondensatePumpAlarm => {
    '1' => 'enable',
    '2' => 'disable',
  },
  airFMSysAlarmMapSysLowEnvHum => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  xATSTestingResultsLastResult => {
    '1' => 'noResultsAvailable',
    '2' => 'startTestPassed',
    '3' => 'loadTestPassed',
    '4' => 'startSignalFailure',
    '5' => 'failedGenNotInAuto',
    '6' => 'failedGenEmerStop',
    '7' => 'failedGenShutdown',
    '8' => 'failedGenDidNotStart',
    '9' => 'failedS2NeverGood',
    '10' => 'genFailedDuringWarmup',
    '11' => 'failureOnXferToS1',
    '12' => 'genFailedLoaded',
    '13' => 'failureOnRexferToS2',
    '14' => 'failedOnCooldown',
    '15' => 'genFailedToStop',
    '16' => 'failedAtsInternalFault',
    '17' => 'failedAtsNotInAuto',
    '18' => 'canceledManualTest',
    '19' => 'canceledScheduledTest',
  },
  uioOutputRelayStatusCommStatus => {
    '1' => 'notInstalled',
    '2' => 'commsOK',
    '3' => 'commsLost',
  },
  sPDUOutletCtl => {
    '1' => 'outletOn',
    '2' => 'outletOff',
    '3' => 'outletReboot',
    '4' => 'outletUnknown',
    '5' => 'outletOnWithDelay',
    '6' => 'outletOffWithDelay',
    '7' => 'outletRebootWithDelay',
  },
  atsStatus24VSourceBPowerSupply => {
    '1' => 'atsPowerSupplyFailure',
    '2' => 'atsPowerSupplyOK',
  },
  isxModularDistSysVoltagePhaseIndex => {
    '1' => 'phase1',
    '2' => 'phase2',
    '3' => 'phase3',
  },
  iemConfigRelayNormalState => {
    '1' => 'open',
    '2' => 'closed',
  },
  airIRmPmCmp2ManOperationActive => {
    '1' => 'automatic',
    '2' => 'manual',
  },
  emsSensorControlSensorCommand => {
    '1' => 'noCommandEMS',
    '2' => 'resetCommandEMS',
  },
  battManConfigMonitorWireLength => {
    '1' => 'fiftyFeetOrLess',
    '2' => 'moreThanFiftyFeet',
  },
  airFMSysAlarmMapInput11 => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  airIRRP500UnitConfigOutputSource => {
    '1' => 'anyAlarm',
    '2' => 'criticalAlarm',
  },
  dm3ConfigConvDiagAlarm => {
    '1' => 'alarmIgnore',
    '2' => 'alarmRelay1',
    '3' => 'alarmRelay2',
    '4' => 'alarmRelay3',
    '5' => 'alarmRelay4',
    '6' => 'alarmRelay5',
    '7' => 'alarmRelay6',
    '8' => 'alarmMinor',
    '9' => 'alarmMajor',
    '10' => 'alarmNofN',
  },
  dm3ConfigConvImbalanceAlarm => {
    '1' => 'alarmIgnore',
    '2' => 'alarmRelay1',
    '3' => 'alarmRelay2',
    '4' => 'alarmRelay3',
    '5' => 'alarmRelay4',
    '6' => 'alarmRelay5',
    '7' => 'alarmRelay6',
    '8' => 'alarmMinor',
    '9' => 'alarmMajor',
    '10' => 'alarmNofN',
  },
  airFMGroupFailoverSysHighEnvTemp => {
    '1' => 'notApplicable',
    '2' => 'disable',
    '3' => 'enable',
  },
  xPDUSystemOutputPhaseIndex => {
    '1' => 'phase1',
    '2' => 'phase2',
    '3' => 'phase3',
  },
  xATSGeneratorFuelSystemVeryLowRunTimeThreshold => {
    '1' => 'disabled',
    '2' => 'oneHour',
    '3' => 'twoHours',
    '4' => 'threeHours',
    '5' => 'fourHours',
    '6' => 'fiveHours',
    '7' => 'sixHours',
    '8' => 'twelveHours',
    '9' => 'oneDay',
    '10' => 'twoDays',
    '11' => 'threeDays',
    '12' => 'fourDays',
    '13' => 'fiveDays',
    '14' => 'sixDays',
    '15' => 'sevenDays',
  },
  airIRRP100UnitServiceIntervalAirFilterAlarm => {
    '1' => 'enable',
    '2' => 'disable',
  },
  rPDU2SensorTempHumidityStatusTempStatus => {
    '1' => 'notPresent',
    '2' => 'belowMin',
    '3' => 'belowLow',
    '4' => 'normal',
    '5' => 'aboveHigh',
    '6' => 'aboveMax',
  },
  dm3StatusSysRectVoltSanity => {
    '1' => 'saneYES',
    '2' => 'saneNO',
  },
  airFMSysAlarmMapInput15 => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  iemConfigContactSeverity => {
    '1' => 'critical',
    '2' => 'warning',
    '3' => 'informational',
  },
  dm3StatusConvPresent => {
    '1' => 'statusTrue',
    '2' => 'statusFalse',
  },
  rPDU2SensorDiscreteStatusCommStatus => {
    '1' => 'notInstalled',
    '2' => 'commsOK',
    '3' => 'commsLost',
  },
  isxModularDistSysOutputVoltageAlarmLowEnable => {
    '1' => 'disabled',
    '2' => 'enabled',
  },
  airFMSysAlarmMapOutput12 => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  emStatusProbeMaxTempViolation => {
    '1' => 'noViolation',
    '2' => 'maxTempViolation',
    '3' => 'disabled',
  },
  memBeaconStatusCurrentState => {
    '1' => 'off',
    '2' => 'on',
  },
  atsOutputPhaseState => {
    '1' => 'normal',
    '2' => 'lowload',
    '3' => 'nearoverload',
    '4' => 'overload',
  },
  airIRRP500UnitStatusInputState => {
    '1' => 'open',
    '2' => 'closed',
  },
  atsOutputVoltageOrientation => {
    '1' => 'unknown',
    '2' => 'singlePhase',
    '3' => 'splitPhase',
    '4' => 'threePhasePhaseToNeutral',
    '5' => 'threePhasePhaseToPhase',
  },
  airFMGroupFailoverModHighFilterDP => {
    '1' => 'notApplicable',
    '2' => 'disable',
    '3' => 'enable',
  },
  airFMGroupCfgDmdFightSetting => {
    '1' => 'disable',
    '2' => 'enable',
  },
  upsAdvConfigUPSFail => {
    '1' => 'unknown',
    '2' => 'gotoBypass',
    '3' => 'dropLoad',
  },
  airFMSysActualSteamHotGasReheat => {
    '1' => 'notApplicable',
    '2' => 'off',
    '3' => 'on',
  },
  airFMSysResetSysFailure => {
    '1' => 'notApplicable',
    '2' => 'noOperation',
    '3' => 'reset',
  },
  airIRRP100GroupConfigActiveFlowControllerLampTest => {
    '1' => 'off',
    '2' => 'on',
  },
  airFMSysAlarmMapExpMod2HighFltrDP => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  airIRRCUnitConfigOutputSource => {
    '1' => 'anyAlarm',
    '2' => 'criticalAlarm',
  },
  sPDUOutletConfigMSPmupsP2HiTemp => {
    '1' => 'disableAlarm',
    '2' => 'enableAlarm',
  },
  isxModularDistSysPowerPhaseIndex => {
    '1' => 'phase1',
    '2' => 'phase2',
    '3' => 'phase3',
  },
  emConfigProbeHighHumidEnable => {
    '1' => 'disabled',
    '2' => 'enabled',
  },
  airFMSysTempCtrlMethod => {
    '1' => 'notApplicable',
    '2' => 'avgReturn',
    '3' => 'avgRemote',
    '4' => 'maxRemote',
  },
  rARUConfigAruTempOvrdEnableDisable => {
    '1' => 'disabled',
    '2' => 'enabled',
  },
  airFMSysReheatEssFunction => {
    '1' => 'notApplicable',
    '2' => 'yes',
    '3' => 'no',
  },
  isxModularDistModuleOutputAlarmMinEnable => {
    '1' => 'disabled',
    '2' => 'enabled',
  },
  airIRmPmLouver3ManOpPosition => {
    '1' => 'closed',
    '2' => 'open',
  },
  upsAdvTestDiagnostics => {
    '1' => 'noTestDiagnostics',
    '2' => 'testDiagnostics',
  },
  airIRG2RDT2ConfigUnitRoleOverride => {
    '1' => 'automatic',
    '2' => 'forcedOn',
  },
  upsDiagSwitchGearBypassInputSwitchStatus => {
    '1' => 'unknown',
    '2' => 'notInstalled',
    '3' => 'opened',
    '4' => 'closed',
  },
  airFMSysAlarmMapMainModHumReplCyl => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  upsAdvBatteryCurrentPolarity => {
    '0' => 'positive',
    '1' => 'negative',
  },
  battManAlarmEnvironment => {
    '1' => 'normal',
    '2' => 'alarm',
  },
  airFMSysAlarmMapMainModCondPumpFail => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  xATSDeviceServiceType => {
    '1' => 'threeWire',
    '2' => 'fourWire',
  },
  airFMSysCoilCfg => {
    '1' => 'notApplicable',
    '2' => 'dx',
    '3' => 'econ',
    '4' => 'multicool',
    '5' => 'chilledWater',
  },
  airIRRP500UnitConfigSecondaryPowerFeedCapability => {
    '1' => 'full',
    '2' => 'reduced',
  },
  isxModularDistSubFeedInfoKwhReset => {
    '1' => 'no',
    '2' => 'yes',
  },
  airFMSysActualSteamHum => {
    '1' => 'notApplicable',
    '2' => 'off',
    '3' => 'on',
  },
  battManSystemAmbientProbeDisconnected => {
    '1' => 'normal',
    '2' => 'alarm',
  },
  upsSCGACInputStatus => {
    '1' => 'acInGood',
    '2' => 'acInBad',
  },
  atsConfigVoltageSensitivity => {
    '1' => 'high',
    '2' => 'low',
  },
  accessPXStatusFrontDoor => {
    '1' => 'open',
    '2' => 'closed',
    '3' => 'notInstalled',
    '4' => 'disconnected',
  },
  dm3ConfigConvFanFailAlarm => {
    '1' => 'alarmIgnore',
    '2' => 'alarmRelay1',
    '3' => 'alarmRelay2',
    '4' => 'alarmRelay3',
    '5' => 'alarmRelay4',
    '6' => 'alarmRelay5',
    '7' => 'alarmRelay6',
    '8' => 'alarmMinor',
    '9' => 'alarmMajor',
    '10' => 'alarmNofN',
  },
  battManString2BatteryCellShorted => {
    '1' => 'normal',
    '2' => 'alarm',
  },
  battManString2BatteryOpenCell => {
    '1' => 'normal',
    '2' => 'alarm',
  },
  isxModularDistSysOutputVoltageFrequencyTolerance => {
    '1' => 'freqToleranceOff',
    '2' => 'freqTolerancePointTwo',
    '3' => 'freqTolerancePointFive',
    '4' => 'freqToleranceOne',
    '5' => 'freqToleranceOnePointFive',
    '6' => 'freqToleranceTwo',
    '7' => 'freqToleranceThree',
    '8' => 'freqToleranceFour',
    '9' => 'freqToleranceFive',
    '10' => 'freqToleranceNine',
    '11' => 'freqToleranceNotAvailable',
  },
  xPDUDeviceFansPresent => {
    '1' => 'notPresent',
    '2' => 'present',
  },
  airFMSysSteamHotGasReheatDmd => {
    '1' => 'notApplicable',
    '2' => 'off',
    '3' => 'on',
  },
  airFMGroupSysRole => {
    '1' => 'rolePrimary',
    '2' => 'roleBackup',
  },
  airIRmPmFan2Type => {
    '1' => 'direct',
    '2' => 'proportional',
  },
  xATSSource2Index => {
    '1' => 'phase1',
    '2' => 'phase2',
    '3' => 'phase3',
  },
  airFMModServIntBlwrCtrl2Reset => {
    '1' => 'notApplicable',
    '2' => 'noOperation',
    '3' => 'reset',
  },
  airFMSysAlarmMapExpMod1AirBlckIntOpen => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  atsStatusSelectedSource => {
    '1' => 'sourceA',
    '2' => 'sourceB',
  },
  airIRRCUnitConfigIdleOnLeakDetect => {
    '1' => 'yes',
    '2' => 'no',
  },
  isxModularDistModuleBreakerPositionAlarms => {
    '1' => 'disabled',
    '2' => 'enabled',
  },
  airFMSysAlarmMapSysSecSensActive => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  isxModularDistSysCurrentPhaseIndex => {
    '1' => 'phase1',
    '2' => 'phase2',
    '3' => 'phase3',
  },
  memInputAbnormalSeverity => {
    '1' => 'inputSeverityinformational',
    '2' => 'inputSeveritywarning',
    '3' => 'inputSeveritysevere',
    '4' => 'inputSeverityNotApplicable',
  },
  battManSystemConfigurationInvalid => {
    '1' => 'normal',
    '2' => 'alarm',
  },
  emsConfigCheckLogLight => {
    '1' => 'lightDisabled',
    '2' => 'lightOnInformational',
    '3' => 'lightOnWarning',
    '4' => 'lightOnSevere',
  },
  airIRG3GroupConfigCoolPIDReset => {
    '1' => 'readBack',
    '2' => 'reset',
  },
  airIRRP100GroupConfigRuntimeBalancingEnable => {
    '1' => 'disable',
    '2' => 'enable',
  },
  airIRSCUnitStatusOutputState => {
    '1' => 'open',
    '2' => 'closed',
  },
  emStatusProbeHighHumidViolation => {
    '1' => 'noViolation',
    '2' => 'highHumidViolation',
    '3' => 'disabled',
  },
  isxModularPduDeviceTransformerPresent => {
    '1' => 'notPresent',
    '2' => 'isoXfmrPresent',
    '3' => 'autoXfmrPresent',
  },
  airIRG3RDUConfigInputNormalState => {
    '1' => 'open',
    '2' => 'closed',
  },
  upsOutletGroupControlCommand => {
    '1' => 'upsOutletGroupImmediateOn',
    '2' => 'upsOutletGroupImmediateOff',
    '3' => 'upsOutletGroupImmediateRebootWithOrWithoutAC',
    '4' => 'upsOutletGroupDelayedOn',
    '5' => 'upsOutletGroupDelayedOff',
    '6' => 'upsOutletGroupDelayedRebootWithOrWithoutAC',
    '7' => 'upsOutletGroupCancelPendingCommand',
    '8' => 'upsOutletGroupControlUnknown',
    '9' => 'upsOutletGroupImmediateRebootShutdown',
    '10' => 'upsOutletGroupDelayedRebootShutdown',
  },
  airIRSCUnitStatusCompressor => {
    '1' => 'off',
    '2' => 'on',
  },
  uioSensorStatusCommStatus => {
    '1' => 'notInstalled',
    '2' => 'commsOK',
    '3' => 'commsLost',
  },
  rPDULoadBankConfigAlarm => {
    '1' => 'noLoadAlarm',
    '2' => 'underCurrentAlarm',
    '3' => 'nearOverCurrentAlarm',
    '4' => 'overCurrentAlarm',
  },
  upsAdvConfigOutputFreqSlewRate => {
    '1' => 'unknown',
    '2' => 'slewRateQuarterHzPerSec',
    '3' => 'slewRateHalfHzPerSec',
    '4' => 'slewRate1HzPerSec',
    '5' => 'slewRate2HzPerSec',
    '6' => 'slewRate4HzPerSec',
    '7' => 'slewRate6HzPerSec',
  },
  isxModularDistSubFeedInfoAlarmMaxEnable => {
    '1' => 'disabled',
    '2' => 'enabled',
  },
  rPDU2DeviceStatusNPSType => {
    '1' => 'notNPS',
    '2' => 'host',
    '3' => 'guest',
  },
  isxModularPduDeviceServiceType => {
    '1' => 'threeWire',
    '2' => 'fourWire',
  },
  battManSystemPilotProbeDisconnected => {
    '1' => 'normal',
    '2' => 'alarm',
  },
  battManString1BatteryUserHighVoltageAlarm => {
    '1' => 'normal',
    '2' => 'alarm',
  },
  iemStatusContactStatus => {
    '1' => 'noFault',
    '2' => 'fault',
    '3' => 'disabled',
  },
  airFMGroupLoadShareCoolRequests => {
    '1' => 'disable',
    '2' => 'enable',
  },
  upsOutletGroupConfigLoadShedControlRuntimeRemaining => {
    '1' => 'upsOutletGroupConfigDisableRuntimeRemainingLoadShed',
    '2' => 'upsOutletGroupConfigEnableRuntimeRemainingLoadShed',
  },
  isxModularDistModuleOutputStatus => {
    '1' => 'normal',
    '2' => 'warning',
    '3' => 'critical',
    '4' => 'notPresent',
    '6' => 'unknown',
  },
  sPDUOutletConfigMSPmupsP2LowTemp => {
    '1' => 'disableAlarm',
    '2' => 'enableAlarm',
  },
  upsAdvConfigSetEEPROMDefaults => {
    '1' => 'noSetEEPROMDefaults',
    '2' => 'setEEPROMDefaults',
  },
  sPDUOutletConfigMSPannunOutletCtrlMode => {
    '1' => 'modeGracefulShutdown',
    '2' => 'modeAnnunciator',
  },
  airFMSysAlarmMapExpMod2MaintReq => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  airIRSCUnitConfigInputNormalState => {
    '1' => 'open',
    '2' => 'closed',
  },
  atsOutputPhaseIndex => {
    '1' => 'phase1',
    '2' => 'phase2',
    '3' => 'phase3',
    '4' => 'neutral',
  },
  iemConfigProbeTempUnits => {
    '1' => 'celsius',
    '2' => 'fahrenheit',
  },
  iemConfigContactNormalState => {
    '1' => 'open',
    '2' => 'closed',
  },
  airFMSysAlarmMapExpMod1BlwrCntl2Fail => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  airFMSysAlarmMapInput9 => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  atsConfigPreferredSource => {
    '1' => 'sourceA',
    '2' => 'sourceB',
    '3' => 'none',
  },
  airFMSysAlarmMapOutput14 => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  upsHighPrecBatteryActualVoltagePolarity => {
    '0' => 'positive',
    '1' => 'negative',
  },
  airFMSysAlarmMapInput8 => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  emsAlarmDeviceStatusDeviceState => {
    '1' => 'alarmDeviceOnEMS',
    '2' => 'alarmDeviceOffEMS',
    '3' => 'alarmDeviceNotInstalledEMS',
  },
  airFMSysAlarmMapSystemOn => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  accessPXStatusFrontDoorHandle => {
    '1' => 'open',
    '2' => 'closed',
    '3' => 'notInstalled',
    '4' => 'disconnected',
  },
  airIRG3RDUConfigByPassValveEnabled => {
    '1' => 'no',
    '2' => 'yes',
  },
  airIRG3GroupConfigFanSpeedControl => {
    '1' => 'automatic',
    '2' => 'manual',
  },
  upsDiagSubSysInverterStatus => {
    '1' => 'unknown',
    '2' => 'notInstalled',
    '3' => 'offOk',
    '4' => 'onOk',
    '5' => 'offFail',
    '6' => 'onFail',
    '7' => 'lostComm',
  },
  airFMGroupFailoverSysSupplySensorFail => {
    '1' => 'notApplicable',
    '2' => 'disable',
    '3' => 'enable',
  },
  battManStringOnBattery => {
    '1' => 'normal',
    '2' => 'alarm',
  },
  xPDUBypassInputVoltagePhaseIndex => {
    '1' => 'phase1',
    '2' => 'phase2',
    '3' => 'phase3',
  },
  sPDUOutletStatusVMOutletState => {
    '1' => 'outletStatusVMOn',
    '2' => 'outletStatusVMOff',
  },
  airFMModStmElectHumMode => {
    '1' => 'notApplicable',
    '2' => 'off',
    '3' => 'auto',
    '4' => 'drain',
  },
  upsAdvConfigMainsSetting => {
    '1' => 'singleInput',
    '2' => 'dualInput',
  },
  dm3ConfigConv2ofNAlarm => {
    '1' => 'alarmIgnore',
    '2' => 'alarmRelay1',
    '3' => 'alarmRelay2',
    '4' => 'alarmRelay3',
    '5' => 'alarmRelay4',
    '6' => 'alarmRelay5',
    '7' => 'alarmRelay6',
    '8' => 'alarmMinor',
    '9' => 'alarmMajor',
  },
  airFMSysAlarmMapInput7 => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  xATSGeneratorFuelSystemType => {
    '1' => 'diesel',
    '2' => 'propane',
    '3' => 'naturalGas',
    '4' => 'unknown',
  },
  emsOutletConfigOutletNormalState => {
    '1' => 'normallyOnEMS',
    '2' => 'normallyOffEMS',
  },
  airFMSysAlarmMapExpMod1HumFail => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  airIRRCUnitStatusInputState => {
    '1' => 'open',
    '2' => 'closed',
  },
  upsAdvBatteryReplaceIndicator => {
    '1' => 'noBatteryNeedsReplacing',
    '2' => 'batteryNeedsReplacing',
  },
  battManRemoteAnnunciatorReset => {
    '1' => 'noOperation',
    '2' => 'reset',
  },
  rPDULoadPhaseConfigIndex => {
    '1' => 'phase1',
    '2' => 'phase2',
    '3' => 'phase3',
  },
  atsStatus5VPowerSupply => {
    '1' => 'atsPowerSupplyFailure',
    '2' => 'atsPowerSupplyOK',
  },
  airIRRP100GroupSetpointsActiveFlowControlBias => {
    '1' => 'positive',
    '2' => 'slightlyPositive',
    '3' => 'zero',
    '4' => 'slightlyNegative',
    '5' => 'negative',
  },
  battManStringChargerHighVoltageAlarm => {
    '1' => 'normal',
    '2' => 'alarm',
  },
  airIRmPmHumidifier1Type => {
    '1' => 'direct',
    '2' => 'proportional',
  },
  airIRmPmControllerType => {
    '1' => 'unknown',
    '2' => 'c4000',
    '3' => 'c1001',
    '4' => 'c1002',
    '5' => 'c5000',
    '6' => 'c6000',
    '7' => 'c1010',
    '8' => 'c7000IOC',
    '9' => 'c7000AT',
    '10' => 'c7000PT',
    '11' => 'c5MSC',
    '12' => 'c7000PT2',
  },
  atsCalibrationPowerSupplyVoltage => {
    '1' => 'powerSupply24V',
    '2' => 'powerSupply12V',
    '3' => 'powerSupply',
    '4' => 'powerSupply24VSourceB',
    '5' => 'powerSupplyMinus12V',
  },
  emStatusProbeStatus => {
    '1' => 'disconnected',
    '2' => 'connected',
  },
  memSensorsCommStatus => {
    '1' => 'notInstalled',
    '2' => 'commsOK',
    '3' => 'commsLost',
  },
  upsDiagPMFanLifetimeStatus => {
    '1' => 'ok',
    '2' => 'nearEnd',
    '3' => 'exceeded',
    '4' => 'unknown',
  },
  loadBalancerStatus => {
    '1' => 'unknown',
    '2' => 'stopped',
    '3' => 'running',
    '4' => 'running-missing',
  },
  xATSSwitchStatusEngineStartSignal => {
    '1' => 'run',
    '2' => 'stop',
    '3' => 'unknown',
  },
  upsHighPrecBatteryCurrentPolarity => {
    '0' => 'positive',
    '1' => 'negative',
  },
  rARUStatusSysTempUnits => {
    '1' => 'celsius',
    '2' => 'fahrenheit',
  },
  coolingUnitConfigurationAnalogAccess => {
    '1' => 'readOnly',
    '2' => 'readWrite',
  },
  sPDUOutletControlVMOutletCommand => {
    '1' => 'immediateOnVM',
    '2' => 'immediateOffVM',
    '3' => 'immediateRebootVM',
    '4' => 'delayedOnVM',
    '5' => 'delayedOffVM',
    '6' => 'delayedRebootVM',
    '7' => 'cancelPendingCommandVM',
  },
  airFMSysHotWaterVlvAct => {
    '1' => 'notApplicable',
    '2' => 'none',
    '3' => 'springAnalog',
    '4' => 'floatingControl',
  },
  airFMSysCoolPIDMethod => {
    '1' => 'notApplicable',
    '2' => 'p',
    '3' => 'pi',
    '4' => 'pid',
  },
  dcmim2ControlRunCapacityBatteryTest => {
    '1' => 'battTestOff',
    '2' => 'battTestOn',
  },
  dm3StatusRectStandby => {
    '1' => 'statusTrue',
    '2' => 'statusFalse',
  },
  xATSTestingScheduleTestWithLoadInterval => {
    '1' => 'applyLoadEveryTest',
    '2' => 'neverApplyLoad',
    '3' => 'applyLoadMonthly',
    '4' => 'applyLoadMonthlyDetailed',
  },
  sPDUOutletPending => {
    '1' => 'commandPending',
    '2' => 'noCommandPending',
    '3' => 'commandPendingUnknown',
  },
  rPDUIdentDeviceDisplayOrientation => {
    '1' => 'displayNormal',
    '2' => 'displayReverse',
  },
  atsCalibrationOutputPhasesTableIndex => {
    '1' => 'phase1',
    '2' => 'phase2',
    '3' => 'phase3',
    '4' => 'neutral',
  },
  airFMModServIntBlwr2Reset => {
    '1' => 'notApplicable',
    '2' => 'noOperation',
    '3' => 'reset',
  },
  upsDiagSubSysFrameType => {
    '1' => 'unknown',
    '2' => 'notInstalled',
    '3' => 'frameTypeMain',
    '4' => 'frameTypeXR',
    '5' => 'frameTypeLXR',
  },
  airFMStatusSystemOn => {
    '1' => 'statusOn',
    '2' => 'statusOff',
  },
  airFMSysAlarmMapSysHighEnvHum => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  battManString1BatteryChemLowVoltageAlarm => {
    '1' => 'normal',
    '2' => 'alarm',
  },
  airFMGroupCfgFailoverCommLoss => {
    '1' => 'disable',
    '2' => 'enable',
  },
  xPDUOutputRelayNormalState => {
    '1' => 'open',
    '2' => 'closed',
  },
  airFMSysAlarmMapExpMod2AnyAlarm => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  battManStringHighRippleCurrent => {
    '1' => 'normal',
    '2' => 'alarm',
  },
  rPDU2SensorTempHumidityStatusCommStatus => {
    '1' => 'notInstalled',
    '2' => 'commsOK',
    '3' => 'commsLost',
  },
  airFMSysFlowSwitch => {
    '1' => 'notApplicable',
    '2' => 'none',
    '3' => 'dxEcon',
    '4' => 'multiCoolChillWater',
  },
  memOutletAction => {
    '1' => 'turnOff',
    '2' => 'turnOn',
  },
  rPDUOutletPhaseIndex => {
    '1' => 'phase1',
    '2' => 'phase2',
    '3' => 'phase3',
  },
  atsConfigTransferVoltageRange => {
    '1' => 'wide',
    '2' => 'medium',
    '3' => 'narrow',
  },
  atsConfigFrontPanelLockout => {
    '1' => 'disableFrontPanel',
    '2' => 'enableFrontPanel',
  },
  airIRG3CMStatusUnitType => {
    '1' => 'unconfigured',
    '2' => 'oa',
    '3' => 'ra',
  },
  airIRRP100UnitStatusLeakSensor => {
    '1' => 'no-leak',
    '2' => 'leak',
  },
  iemStatusProbeLowHumidViolation => {
    '1' => 'noViolation',
    '2' => 'lowHumidViolation',
    '3' => 'disabled',
  },
  rPDULoadStatusLoadState => {
    '1' => 'phaseLoadNormal',
    '2' => 'phaseLoadLow',
    '3' => 'phaseLoadNearOverload',
    '4' => 'phaseLoadOverload',
  },
  airFMSysDischAirPtrn => {
    '1' => 'notApplicable',
    '2' => 'upFlow',
    '3' => 'downFlow',
    '4' => 'horizFlow',
  },
  airIRG3GroupConfigConfigurationType => {
    '1' => 'racs',
    '2' => 'spot',
    '3' => 'in-row',
    '4' => 'hacs',
  },
  upsDiagComBusExternalMIMStatus => {
    '1' => 'unknown',
    '2' => 'notInstalled',
    '3' => 'ok',
    '4' => 'lostComm',
    '5' => 'rxFailure',
    '6' => 'txFailure',
  },
  airFMSysAlarmMapExpMod1LowAirFlow => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  airFMStatusSystemDehumidifyEnabled => {
    '1' => 'enabledYes',
    '2' => 'enabledNo',
  },
  emsOutputRelayConfigOutputRelayNormalState => {
    '1' => 'normallyClosedEMS',
    '2' => 'normallyOpenEMS',
  },
  rPDULoadPhaseConfigAlarm => {
    '1' => 'noLoadAlarm',
    '2' => 'underCurrentAlarm',
    '3' => 'nearOverCurrentAlarm',
    '4' => 'overCurrentAlarm',
  },
  battManResetLowestDischargeVoltages => {
    '1' => 'noOperation',
    '2' => 'reset',
  },
  iemConfigProbeMaxHumidEnable => {
    '1' => 'disabled',
    '2' => 'enabled',
  },
  airFMModBlwr2CtrlType => {
    '1' => 'notApplicable',
    '2' => 'fujiVFD',
    '3' => 'ecController',
    '4' => 'danfossVFD',
  },
  xPDUBranchBreakerRDPFeed => {
    '1' => 'remoteDistribution',
    '2' => 'noRemoteDistribution',
  },
  coolingUnitConfigurationDiscreteAccess => {
    '1' => 'readOnly',
    '2' => 'readWrite',
  },
  xATSSource1Position => {
    '1' => 'open',
    '2' => 'closed',
    '3' => 'tripped',
    '4' => 'unknown',
  },
  upsAdvConfigLCDLocalLanguage => {
    '1' => 'english',
    '2' => 'french',
    '3' => 'italian',
    '4' => 'german',
    '5' => 'spanish',
    '6' => 'portuguese',
    '7' => 'japanese',
  },
  airIRRP100GroupSetpointsFanSpeedControl => {
    '1' => 'automatic',
    '2' => 'manual',
  },
  sPDUOutletStatusMSPOutletCtrlMode => {
    '1' => 'modeGracefulShutdown',
    '2' => 'modeAnnunciator',
  },
  upsAdvStateEcomode => {
    '1' => 'upsOnEcoMode',
    '2' => 'upsNotOnEcoMode',
  },
  airFMSysSuctPresCompensation => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  emStatusProbeMaxHumidViolation => {
    '1' => 'noViolation',
    '2' => 'maxHumidViolation',
    '3' => 'disabled',
  },
  emConfigProbeLowTempEnable => {
    '1' => 'disabled',
    '2' => 'enabled',
  },
  iemStatusProbeMinHumidViolation => {
    '1' => 'noViolation',
    '2' => 'minHumidViolation',
    '3' => 'disabled',
  },
  apcLocalDisplayConfigBeeperVolume => {
    '1' => 'beeperDisabled',
    '2' => 'beeperLow',
    '3' => 'beeperMedium',
    '4' => 'beeperHigh',
  },
  upsBasicSystemPFCStatus => {
    '1' => 'unknown',
    '2' => 'ok',
    '3' => 'inFaultCondition',
  },
  rPDUIdentDeviceOrientation => {
    '1' => 'orientHorizontal',
    '2' => 'orientVertical',
  },
  upsAdvConfigOutputFreqRange => {
    '1' => 'unknown',
    '2' => 'freqRangeAUTO',
    '3' => 'freqRange60Var1',
    '4' => 'freqRange60Var3',
    '5' => 'freqRange50Var1',
    '6' => 'freqRange50Var3',
    '7' => 'freqRange60Var10',
    '8' => 'freqRange50Var10',
    '9' => 'freqRange60Var1dot0',
    '10' => 'freqRange50Var1dot0',
    '11' => 'freqRange50Pct0dot5',
    '12' => 'freqRange50Pct1',
    '13' => 'freqRange50Pct2',
    '14' => 'freqRange50Pct4',
    '15' => 'freqRange50Pct6',
    '16' => 'freqRange50Pct8',
    '17' => 'freqRange60Pct0dot5',
    '18' => 'freqRange60Pct1',
    '19' => 'freqRange60Pct2',
    '20' => 'freqRange60Pct4',
    '21' => 'freqRange60Pct6',
    '22' => 'freqRange60Pct8',
  },
  dm3StatusConvFail => {
    '1' => 'statusTrue',
    '2' => 'statusFalse',
  },
  airIRG3CMStatusLocalDisplayOnOffEnabled => {
    '1' => 'no',
    '2' => 'yes',
  },
  iemConfigProbeMinTempEnable => {
    '1' => 'disabled',
    '2' => 'enabled',
  },
  airFMSysCndsrFluidVlvAct => {
    '1' => 'notApplicable',
    '2' => 'none',
    '3' => 'floatingControl',
  },
  airFMSysAlarmMapSysEconIsol => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  airPACondenserFan => {
    '1' => 'statusON',
    '2' => 'statusOFF',
  },
  emConfigContactNormalState => {
    '1' => 'open',
    '2' => 'closed',
  },
  airFMSysAlarmMapMainModMaintReq => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  battManConfigApplication => {
    '1' => 'silcon',
    '2' => 'other',
  },
  airFMSysAlarmMapOutput10 => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  xATSSwitchStatusAutomaticOperationSwitch => {
    '1' => 'disabled',
    '2' => 'enabled',
    '3' => 'unknown',
  },
  airFMSysAlarmMapOutput13 => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  emsOutputRelayStatusOutputRelayNormalState => {
    '1' => 'normallyClosedEMS',
    '2' => 'normallyOpenEMS',
  },
  rPDUPowerSupply1Status => {
    '1' => 'powerSupplyOneOk',
    '2' => 'powerSupplyOneFailed',
  },
  rARUPowerStatusPrimaryAcPresent => {
    '1' => 'yes',
    '2' => 'no',
  },
  rARUPowerStatusRedundantAcConfig => {
    '1' => 'singleCord',
    '2' => 'dualCord',
  },
  apcLocalDisplayConfigCheckLogIndicator => {
    '1' => 'checklogNotPresent',
    '2' => 'checklogDisabled',
    '3' => 'checklogInformational',
    '4' => 'checklogWarning',
    '5' => 'checklogCritical',
  },
  airFMGroupSysComm => {
    '1' => 'commLost',
    '2' => 'commEstablished',
  },
  airIRRCGroupSetpointsFanSpeedPreference => {
    '1' => 'low',
    '2' => 'med-low',
    '3' => 'med',
    '4' => 'med-high',
    '5' => 'high',
  },
  upsAdvControlUpsSleep => {
    '1' => 'noPutUpsToSleep',
    '2' => 'putUpsToSleep',
    '3' => 'putUpsToSleepGracefully',
    '4' => 'putUpsSyncGroupToSleep',
    '5' => 'putUpsSyncGroupToSleepGracefully',
  },
  dm3ConfigConvCurrLimitAlarm => {
    '1' => 'alarmIgnore',
    '2' => 'alarmRelay1',
    '3' => 'alarmRelay2',
    '4' => 'alarmRelay3',
    '5' => 'alarmRelay4',
    '6' => 'alarmRelay5',
    '7' => 'alarmRelay6',
    '8' => 'alarmMinor',
    '9' => 'alarmMajor',
    '10' => 'alarmNofN',
  },
  dm3ConfigConvConfigAlarm => {
    '1' => 'alarmIgnore',
    '2' => 'alarmRelay1',
    '3' => 'alarmRelay2',
    '4' => 'alarmRelay3',
    '5' => 'alarmRelay4',
    '6' => 'alarmRelay5',
    '7' => 'alarmRelay6',
    '8' => 'alarmMinor',
    '9' => 'alarmMajor',
  },
  apcLocalDisplayConfigContrast => {
    '1' => 'contrast1',
    '2' => 'contrast2',
    '3' => 'contrast3',
    '4' => 'contrast4',
    '5' => 'contrast5',
    '6' => 'contrast6',
    '7' => 'contrast7',
    '8' => 'contrast8',
  },
  xATSTestingStatusSelectTestProcess => {
    '1' => 'engineStartTest',
    '2' => 'systemLoadTest',
    '3' => 'generatorHoldTest',
    '4' => 'cancelTest',
  },
  accessPXStatusFrontDoorLock => {
    '1' => 'unlocked',
    '2' => 'locked',
    '3' => 'notInstalled',
    '4' => 'disconnected',
  },
  upsDiagSubSysExternalSwitchGearStatus => {
    '1' => 'unknown',
    '2' => 'notInstalled',
    '3' => 'offOk',
    '4' => 'onOk',
    '5' => 'offFail',
    '6' => 'onFail',
    '7' => 'lostComm',
  },
  airIRG2GroupStatusActiveFlowControlStatus => {
    '1' => 'under',
    '2' => 'okay',
    '3' => 'over',
    '4' => 'notApplicable',
  },
  airIRG2RDT2ConfigUnitType => {
    '1' => 'fluidCooled',
    '2' => 'airCooled',
  },
  airIRRCGroupStatusActiveFlowControlStatus => {
    '1' => 'under',
    '2' => 'okay',
    '3' => 'over',
    '4' => 'notApplicable',
  },
  emConfigProbeMinHumidEnable => {
    '1' => 'disabled',
    '2' => 'enabled',
  },
  iemConfigProbeLowTempEnable => {
    '1' => 'disabled',
    '2' => 'enabled',
  },
  dm3StatusOutRlyStatus => {
    '1' => 'statusOn',
    '2' => 'statusOff',
  },
  sPDUOutletConfigMSPgsDeviceConfirm => {
    '1' => 'deviceConfirmNo',
    '2' => 'deviceConfirmYes',
  },
  upsDiagPMEnclDoorFltrLifetime => {
    '1' => 'heavyFiltration15days',
    '2' => 'normalFiltration30days',
    '3' => 'lightFiltration60days',
    '4' => 'notPresent',
  },
  xATSSource1Rotation => {
    '1' => 'abc',
    '2' => 'cba',
    '3' => 'unknown',
  },
  airIRRP500UnitConfigHumidifierControl => {
    '1' => 'auto',
    '2' => 'drainOff',
  },
  airIRSCGroupConfigActiveFlowControllerLampTest => {
    '1' => 'off',
    '2' => 'on',
  },
  rPDU2DeviceConfigDisplayOrientation => {
    '1' => 'displayNormal',
    '2' => 'displayReverse',
  },
  dm3StatusRectCfg => {
    '1' => 'statusTrue',
    '2' => 'statusFalse',
  },
  airFMSysAlarmMapInput1 => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  iemStatusRelayStatus => {
    '1' => 'faultState',
    '2' => 'normalState',
  },
  memBeaconAction => {
    '1' => 'turnOff',
    '2' => 'turnOn',
  },
  xATSTestingSimulatePowerFailTest => {
    '1' => 'cancelSimulation',
    '2' => 'fiveSecondsSimulation',
    '3' => 'tenSecondsSimulation',
    '4' => 'thirtySecondsSimulation',
    '5' => 'oneMinuteSimulation',
    '6' => 'threeMinutesSimulation',
    '7' => 'fiveMinutesSimulation',
    '8' => 'tenMinutesSimulation',
  },
  airIRRP500GroupConfigLoadAssistEnable => {
    '1' => 'disable',
    '2' => 'enable',
  },
  battManResetChargeCurrentDeviationBenchmark => {
    '1' => 'noOperation',
    '2' => 'reset',
  },
  airFMModRHBlwr1Reset => {
    '1' => 'notApplicable',
    '2' => 'noOperation',
    '3' => 'reset',
  },
  airFMSysAlarmMapSystemOffline => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  dm3ConfigBattHwTempAlarm => {
    '1' => 'alarmIgnore',
    '2' => 'alarmRelay1',
    '3' => 'alarmRelay2',
    '4' => 'alarmRelay3',
    '5' => 'alarmRelay4',
    '6' => 'alarmRelay5',
    '7' => 'alarmRelay6',
    '8' => 'alarmMinor',
    '9' => 'alarmMajor',
  },
  battManSystemAmbientHighTempAlarm => {
    '1' => 'normal',
    '2' => 'alarm',
  },
  upsCommStatus => {
    '1' => 'ok',
    '2' => 'noComm',
  },
  essentialServicesStatus => {
    '1' => 'unknown',
    '2' => 'stopped',
    '3' => 'running',
    '4' => 'time-sync-problems',
    '5' => 'backup-problems',
  },
  airFMGroupFailoverModBlwrCntrl1Fail => {
    '1' => 'notApplicable',
    '2' => 'disable',
    '3' => 'enable',
  },
  upsSCGActiveMembershipStatus => {
    '1' => 'enabledSCG',
    '2' => 'disabledSCG',
  },
  xPDUDeviceCrossTieOutputPresent => {
    '1' => 'notPresent',
    '2' => 'present',
  },
  iemConfigProbeMaxTempEnable => {
    '1' => 'disabled',
    '2' => 'enabled',
  },
  airFMStatusSystemReheatingEnabled => {
    '1' => 'enabledYes',
    '2' => 'enabledNo',
  },
  airIRmPmLouver2ManOpPosition => {
    '1' => 'closed',
    '2' => 'open',
  },
  xPDUDeviceFusesPresent => {
    '1' => 'notPresent',
    '2' => 'present',
  },
  airIRRP100UnitServiceIntervalHeaterAlarm => {
    '1' => 'enable',
    '2' => 'disable',
  },
  airFMSysAlarmMapExpMod1BlwrCntl1Fail => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  airFMModServIntHeaterReset => {
    '1' => 'notApplicable',
    '2' => 'noOperation',
    '3' => 'reset',
  },
  rPDU2PhaseConfigOverloadRestriction => {
    '1' => 'alwaysAllowTurnON',
    '2' => 'restrictOnNearOverload',
    '3' => 'restrictOnOverload',
    '4' => 'notSupported',
  },
  xPDUSystemBreakerPosition => {
    '1' => 'open',
    '2' => 'closed',
    '3' => 'unknown',
  },
  airIRG3RDUConfigRefrigerantLeakDetectorEnabled => {
    '1' => 'no',
    '2' => 'yes',
  },
  memSensorsStatusSysTempUnits => {
    '1' => 'celsius',
    '2' => 'fahrenheit',
  },
  xATSInputContactNormalState => {
    '1' => 'open',
    '2' => 'closed',
  },
  airFMModServIntHumReset => {
    '1' => 'notApplicable',
    '2' => 'noOperation',
    '3' => 'reset',
  },
  airFMGroupFailoverSysReturnSensorFail => {
    '1' => 'notApplicable',
    '2' => 'disable',
    '3' => 'enable',
  },
  dm3StatusConvDiagPass => {
    '1' => 'statusTrue',
    '2' => 'statusFalse',
  },
  dm3ConfigConvHwVoltAlarm => {
    '1' => 'alarmIgnore',
    '2' => 'alarmRelay1',
    '3' => 'alarmRelay2',
    '4' => 'alarmRelay3',
    '5' => 'alarmRelay4',
    '6' => 'alarmRelay5',
    '7' => 'alarmRelay6',
    '8' => 'alarmMinor',
    '9' => 'alarmMajor',
    '10' => 'alarmNofN',
  },
  xATSSwitchStatisticsReset => {
    '1' => 'yes',
    '2' => 'no',
  },
  xATSGeneratorServiceResetRecord => {
    '1' => 'yes',
    '2' => 'no',
  },
  battManString2BatteryUserLowVoltageAlarm => {
    '1' => 'normal',
    '2' => 'alarm',
  },
  upsAdvControlUpsOff => {
    '1' => 'noTurnUpsOff',
    '2' => 'turnUpsOff',
    '3' => 'turnUpsOffGracefully',
    '4' => 'turnUpsSyncGroupOff',
    '5' => 'turnUpsSyncGroupOffAfterDelay',
    '6' => 'turnUpsSyncGroupOffGracefully',
  },
  airFMSysRefrigType => {
    '1' => 'notApplicable',
    '2' => 'r22',
    '3' => 'r407C',
  },
  airPAOperatingMode => {
    '1' => 'modeOFF',
    '2' => 'modeVENTING',
    '3' => 'modeCOOLING',
  },
  rARUStatusAruCommStatus => {
    '1' => 'commsNeverDiscovered',
    '2' => 'commsEstablished',
    '3' => 'commsLost',
  },
  airIRG2GroupSetpointsActiveFlowControlBias => {
    '1' => 'positive',
    '2' => 'slightlyPositive',
    '3' => 'zero',
    '4' => 'slightlyNegative',
    '5' => 'negative',
  },
  airFMSysCoilFluidVlvType => {
    '1' => 'notApplicable',
    '2' => 'twoWay',
    '3' => 'threeWay',
  },
  dcmim2ControlRunFunctBatteryTest => {
    '1' => 'battTestOff',
    '2' => 'battTestOn',
  },
  emsOutputRelayControlOutputRelayCommand => {
    '1' => 'immediateCloseEMS',
    '2' => 'immediateOpenEMS',
  },
  isxModularDistModuleOutputAlarmLowEnable => {
    '1' => 'disabled',
    '2' => 'enabled',
  },
  atsControlClearAllAlarms => {
    '1' => 'none',
    '2' => 'clear',
  },
  emStatusProbeLowTempViolation => {
    '1' => 'noViolation',
    '2' => 'lowTempViolation',
    '3' => 'disabled',
  },
  accessPXConfigBeaconAction => {
    '1' => 'turnOff',
    '2' => 'turnOn',
    '3' => 'notInstalledReadOnly',
    '4' => 'disconnectedReadOnly',
  },
  sPDUMasterStatusVMLowLoadCondition => {
    '1' => 'lowLoadConditionTrueVM',
    '2' => 'lowLoadConditionFalseVM',
  },
  airIRRCUnitConfigInputNormalState => {
    '1' => 'open',
    '2' => 'closed',
  },
  xATSGeneratorStatusRemoteStart => {
    '1' => 'stop',
    '2' => 'run',
    '3' => 'unknown',
  },
  airFMSysHeatRejection => {
    '1' => 'notApplicable',
    '2' => 'airCooled',
    '3' => 'waterCooled',
    '4' => 'glycolCooled',
  },
  emStatusProbeMinHumidViolation => {
    '1' => 'noViolation',
    '2' => 'minHumidViolation',
    '3' => 'disabled',
  },
  airIRRP500GroupConfigRuntimeBalancingEnable => {
    '1' => 'disable',
    '2' => 'enable',
  },
  accessPXConfigFrontDoorLockControl => {
    '1' => 'unlock',
    '2' => 'lock',
    '3' => 'notInstalledReadOnly',
    '4' => 'disconnectedReadOnly',
  },
  upsAdvConfigBypassPhaseLockRequired => {
    '1' => 'unknown',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  airIRRP500UnitStatusActivePowerSource => {
    '1' => 'sourceA',
    '2' => 'sourceB',
  },
  battManProbeRange => {
    '1' => 'amps1000',
    '2' => 'amps500',
    '3' => 'amps100',
    '4' => 'amps200',
    '5' => 'amps2000',
  },
  airFMSysCoolEssFunction => {
    '1' => 'notApplicable',
    '2' => 'yes',
    '3' => 'no',
  },
  airFMSysAlarmMapExpMod1LowSupplyTemp => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  battManString2BatteryUserHighVoltageAlarm => {
    '1' => 'normal',
    '2' => 'alarm',
  },
  airIRG2RDT2StatusCompressor => {
    '1' => 'off',
    '2' => 'on',
  },
  rPDU2SensorDiscreteStatusAlarmState => {
    '1' => 'normal',
    '2' => 'alarm',
  },
  isxModularDistSysOutputVoltageAlarmMaxEnable => {
    '1' => 'disabled',
    '2' => 'enabled',
  },
  airFMSysAlarmMapExpMod1HighSupplyTemp => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  airFMGroupFailoverModBlwrCntrl2Fail => {
    '1' => 'notApplicable',
    '2' => 'disable',
    '3' => 'enable',
  },
  airIRRP100GroupStatusActiveFlowControlStatus => {
    '1' => 'under',
    '2' => 'okay',
    '3' => 'over',
    '4' => 'notApplicable',
  },
  upsDiagBatteryFramePresent => {
    '0' => 'notPresent',
    '1' => 'present',
  },
  upsOutletGroupConfigLoadShedControlTimeOnBattery => {
    '1' => 'upsOutletGroupConfigDisableTimeOnBatteryLoadShed',
    '2' => 'upsOutletGroupConfigEnableTimeOnBatteryLoadShed',
  },
  upsDiagSwitchGearOutputSwitchStatus => {
    '1' => 'unknown',
    '2' => 'notInstalled',
    '3' => 'opened',
    '4' => 'closed',
  },
  airIRRP100UnitConfigIdleOnCoolFail => {
    '1' => 'enable',
    '2' => 'disable',
  },
  isxModularDistSysCurrentAlarmMinEnable => {
    '1' => 'disabled',
    '2' => 'enabled',
  },
  airFMGroupCfgShutdownSmoke => {
    '1' => 'disable',
    '2' => 'enable',
  },
  upsAsiUpsControlServerRequestShutdown => {
    '1' => 'serverShutdownOff',
    '2' => 'serverShutdownReboot',
  },
  accessPXConfigCardReaderEnableDisableAction => {
    '1' => 'disabled',
    '2' => 'enable',
  },
  battManAlarmCharger => {
    '1' => 'normal',
    '2' => 'alarm',
  },
  airIRG3RDUStatusInputState => {
    '1' => 'open',
    '2' => 'closed',
  },
  dm3ConfigRectStandbyAlarm => {
    '1' => 'alarmIgnore',
    '2' => 'alarmRelay1',
    '3' => 'alarmRelay2',
    '4' => 'alarmRelay3',
    '5' => 'alarmRelay4',
    '6' => 'alarmRelay5',
    '7' => 'alarmRelay6',
    '8' => 'alarmMinor',
    '9' => 'alarmMajor',
    '10' => 'alarmNofN',
  },
  rPDUOutletPhaseOverloadRestriction => {
    '1' => 'alwaysAllowTurnON',
    '2' => 'restrictOnNearOverload',
    '3' => 'restrictOnOverload',
  },
  isxModularDistSysCurrentAlarmLowEnable => {
    '1' => 'disabled',
    '2' => 'enabled',
  },
  airFMSysAlarmMapMainModWaterDetected => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  xATSGeneratorServiceCalendarIntervalThreshold => {
    '1' => 'disabled',
    '2' => 'interval1month',
    '3' => 'interval2month',
    '4' => 'interval3month',
    '5' => 'interval6month',
    '6' => 'intervalyearly',
  },
  rARUStatusAruTempOvrdStatus => {
    '1' => 'inactive',
    '2' => 'active',
  },
  airIRG3CMStatusOperatingMode => {
    '1' => 'standBy',
    '2' => 'on',
    '3' => 'idle',
  },
  switchgearBreakerPresent => {
    '1' => 'notPresent',
    '2' => 'present',
  },
  airIRRP500GroupSetpointsActiveFlowControlBias => {
    '1' => 'positive',
    '2' => 'slightlyPositive',
    '3' => 'zero',
    '4' => 'slightlyNegative',
    '5' => 'negative',
  },
  airFMGroupFailoverSysSecondarySensorFail => {
    '1' => 'notApplicable',
    '2' => 'disable',
    '3' => 'enable',
  },
  rPDUOutletStatusCommandPending => {
    '1' => 'outletStatusCommandPending',
    '2' => 'outletStatusNoCommandPending',
  },
  airIRG3GroupConfigCapacityControlType => {
    '1' => 'discrete',
    '2' => 'proportional',
  },
  rARUPowerStatusAuxiliaryAcPresent => {
    '1' => 'yes',
    '2' => 'no',
  },
  rPDUStatusOutletState => {
    '1' => 'outletLoadNormal',
    '2' => 'outletLoadLow',
    '3' => 'outletLoadNearOverload',
    '4' => 'outletLoadOverload',
  },
  upsAdvConfigAlarm => {
    '1' => 'timed',
    '2' => 'atLowBattery',
    '3' => 'never',
    '4' => 'mute',
  },
  accessPXConfigCardFormat => {
    '1' => 'hidStd26',
    '2' => 'hid37Bit',
    '3' => 'hid37BitWithFacility',
    '4' => 'hidCorp1000',
  },
  upsAdvControlFirmwareUpdate => {
    '1' => 'noFirmwareUpdate',
    '2' => 'firmwareUpdate',
    '3' => 'updateInProcess',
    '4' => 'updateSuccessful',
    '5' => 'updateFailed',
  },
  airFMSysResetUserDflts => {
    '1' => 'notApplicable',
    '2' => 'noOperation',
    '3' => 'reset',
  },
  memInputNormalState => {
    '1' => 'inputClosedHighMEM',
    '2' => 'inputOpenLowMEM',
    '3' => 'inputDisabled',
    '4' => 'inputStateNotApplicable',
  },
  switchgearBreakerStatus => {
    '1' => 'unknown',
    '2' => 'opened',
    '3' => 'closed',
  },
  iemStatusProbeStatus => {
    '1' => 'disconnected',
    '2' => 'connected',
  },
  battManConfigAutoAnnunciatorReset => {
    '1' => 'disabled',
    '2' => 'enabled',
  },
  airFMSysAlarmMapExpMod1HumReplCyl => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  airIRG3RDUServiceIntervalsAirFilterAlarm => {
    '1' => 'enable',
    '2' => 'disable',
  },
  airIRmPmRemoteUPS => {
    '1' => 'off',
    '2' => 'on',
  },
  airFMSysAlarmMapInput6 => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  airIRRCUnitStatusOutputState => {
    '1' => 'open',
    '2' => 'closed',
  },
  dm3ConfigBattLowTempAlarm => {
    '1' => 'alarmIgnore',
    '2' => 'alarmRelay1',
    '3' => 'alarmRelay2',
    '4' => 'alarmRelay3',
    '5' => 'alarmRelay4',
    '6' => 'alarmRelay5',
    '7' => 'alarmRelay6',
    '8' => 'alarmMinor',
    '9' => 'alarmMajor',
  },
  xATSTestingScheduleFrequency => {
    '1' => 'never',
    '2' => 'daily',
    '3' => 'weekly',
    '4' => 'monthly',
  },
  airFMGroupFailoverSysNoSensorsAvailable => {
    '1' => 'notApplicable',
    '2' => 'disable',
    '3' => 'enable',
  },
  emConfigProbeTempUnits => {
    '1' => 'celsius',
    '2' => 'fahrenheit',
  },
  iemStatusProbeMinTempViolation => {
    '1' => 'noViolation',
    '2' => 'minTempViolation',
    '3' => 'disabled',
  },
  upsDiagSwitchGearInputSwitchStatus => {
    '1' => 'unknown',
    '2' => 'notInstalled',
    '3' => 'opened',
    '4' => 'closed',
  },
  airIRRP100UnitConfigIdleOnLeakDetect => {
    '1' => 'yes',
    '2' => 'no',
  },
  airFMGroupSysRoleAssignment => {
    '1' => 'staticManual',
    '2' => 'dynamicAutomatic',
  },
  airFMSysCndsrFluidVlvType => {
    '1' => 'notApplicable',
    '2' => 'twoWay',
    '3' => 'threeWay',
  },
  airFMSysAlarmMapExpMod1AnyAlarm => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  airFMSysAlarmMapOutput11 => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  battManStringChargerLowVoltageAlarm => {
    '1' => 'normal',
    '2' => 'alarm',
  },
  isxModularDistSubFeedLoadingPhaseIndex => {
    '1' => 'phase1',
    '2' => 'phase2',
    '3' => 'phase3',
  },
  xPDUDeviceLoadTieBreakerPresent => {
    '1' => 'notPresent',
    '2' => 'present',
  },
  airFMModComp2 => {
    '1' => 'notApplicable',
    '2' => 'on',
    '3' => 'off',
  },
  airIRmPmFan3Type => {
    '1' => 'direct',
    '2' => 'proportional',
  },
  xATSSource2Position => {
    '1' => 'open',
    '2' => 'closed',
    '3' => 'tripped',
    '4' => 'unknown',
  },
  rPDU2SensorDiscreteConfigNormalState => {
    '1' => 'normallyOpen',
    '2' => 'normallyClosed',
  },
  airFMGroupFailoverSysFireAlarm => {
    '1' => 'notApplicable',
    '2' => 'disable',
    '3' => 'enable',
  },
  airIRRP500UnitConfigIdleOnLeakDetect => {
    '1' => 'yes',
    '2' => 'no',
  },
  airFMSysDehumCapacity => {
    '1' => 'notApplicable',
    '2' => 'half',
    '3' => 'full',
  },
  airFMModHumidifier => {
    '1' => 'notApplicable',
    '2' => 'none',
    '3' => 'steamElectrode',
    '4' => 'liveSteam',
  },
  accessPXStatusBeaconCurrentState => {
    '1' => 'off',
    '2' => 'on',
    '3' => 'notInstalled',
    '4' => 'disconnected',
  },
  emConfigContactEnable => {
    '1' => 'disabled',
    '2' => 'enabled',
  },
  xATSSwitchSettingsSetToFactoryDefaults => {
    '1' => 'yes',
    '2' => 'no',
  },
  airFMGroupLoadShareHumRequests => {
    '1' => 'disable',
    '2' => 'enable',
  },
  dm3ConfigConv1ofNAlarm => {
    '1' => 'alarmIgnore',
    '2' => 'alarmRelay1',
    '3' => 'alarmRelay2',
    '4' => 'alarmRelay3',
    '5' => 'alarmRelay4',
    '6' => 'alarmRelay5',
    '7' => 'alarmRelay6',
    '8' => 'alarmMinor',
    '9' => 'alarmMajor',
  },
  atsOutputPhase => {
    '1' => 'phase1',
    '2' => 'phase2',
    '3' => 'phase3',
  },
  airIRmPmUnitTemperatureScale => {
    '1' => 'celsius',
    '2' => 'fahrenheit',
  },
  atsStatusPhaseSyncStatus => {
    '1' => 'inSync',
    '2' => 'outOfSync',
  },
  airIRRP100GroupConfigLoadAssistEnable => {
    '1' => 'disable',
    '2' => 'enable',
  },
  sPDUOutletConfigMSPgsOutletCtrlMode => {
    '1' => 'modeGracefulShutdown',
    '2' => 'modeAnnunciator',
  },
  airFMModRHHeaterReset => {
    '1' => 'notApplicable',
    '2' => 'noOperation',
    '3' => 'reset',
  },
  dm3StatusSysTempSanity => {
    '1' => 'saneYES',
    '2' => 'saneNO',
  },
  accessPXStatusRearDoor => {
    '1' => 'open',
    '2' => 'closed',
    '3' => 'notInstalled',
    '4' => 'disconnected',
  },
  coolingUnitConfigurationStringAccess => {
    '1' => 'readOnly',
    '2' => 'readWrite',
  },
  memInputType => {
    '1' => 'noConnection',
    '2' => 'dryContact',
    '3' => 'digital',
    '4' => 'analogmAmps',
    '5' => 'analogVolts',
  },
  sPDUOutletConfigMSPannunInitialState => {
    '1' => 'initialStateOff',
    '2' => 'initialStateOn',
  },
  AirIRSCFanSpeedPreference => {
    '1' => 'low',
    '2' => 'med-low',
    '3' => 'med',
    '4' => 'med-high',
    '5' => 'high',
  },
  emConfigProbeMinTempEnable => {
    '1' => 'disabled',
    '2' => 'enabled',
  },
  airIRG3GroupSetpointsAirFlowControl => {
    '1' => 'automatic',
    '2' => 'manual',
  },
  upsDiagSubSysXRCommunicationCardStatus => {
    '1' => 'unknown',
    '2' => 'notInstalled',
    '3' => 'offOk',
    '4' => 'onOk',
    '5' => 'offFail',
    '6' => 'onFail',
    '7' => 'lostComm',
  },
  upsAdvConfigLCDLockOut => {
    '1' => 'disable',
    '2' => 'enable',
  },
  airFMSysAlarmMapExpMod2CondPumpFail => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  airIRRP500GroupSetpointsFanSpeedControl => {
    '1' => 'automatic',
    '2' => 'manual',
  },
  upsOutletGroupStatusCommandPending => {
    '1' => 'upsOutletGroupCommandPending',
    '2' => 'upsOutletGroupNoCommandPending',
  },
  sPDUOutletConfigMSPmupsZone1 => {
    '1' => 'disableAlarm',
    '2' => 'enableAlarm',
  },
  airFMSysAlarmMapMainModBlwrCntl1Fail => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  dm3ConfigRectCurrLimitAlarm => {
    '1' => 'alarmIgnore',
    '2' => 'alarmRelay1',
    '3' => 'alarmRelay2',
    '4' => 'alarmRelay3',
    '5' => 'alarmRelay4',
    '6' => 'alarmRelay5',
    '7' => 'alarmRelay6',
    '8' => 'alarmMinor',
    '9' => 'alarmMajor',
    '10' => 'alarmNofN',
  },
  airFMSysInputStatus => {
    '1' => 'open',
    '2' => 'closed',
  },
  xPDUUPSInputVoltagePhaseIndex => {
    '1' => 'phase1',
    '2' => 'phase2',
    '3' => 'phase3',
  },
  upsDiagComBusExternalRIMStatus => {
    '1' => 'unknown',
    '2' => 'notInstalled',
    '3' => 'ok',
    '4' => 'lostComm',
    '5' => 'rxFailure',
    '6' => 'txFailure',
  },
  rPDU2SensorDiscreteConfigAbnormalSeverity => {
    '1' => 'informational',
    '2' => 'warning',
    '3' => 'critical',
  },
  upsDiagSubSysDisplayInterfaceCardStatus => {
    '1' => 'unknown',
    '2' => 'notInstalled',
    '3' => 'offOk',
    '4' => 'onOk',
    '5' => 'offFail',
    '6' => 'onFail',
    '7' => 'lostComm',
  },
  airFMGroupAutoRoleNumPrimary => {
    '1' => 'one',
    '2' => 'two',
    '3' => 'three',
    '4' => 'four',
  },
  rPDU2DeviceStatusCommandPending => {
    '1' => 'commandPending',
    '2' => 'noCommandPending',
    '3' => 'commandPendingUnknown',
  },
  airIRRP500UnitConfigHumidifyEnable => {
    '1' => 'enable',
    '2' => 'disable',
  },
  memOutputNormalState => {
    '1' => 'memOutputClosed',
    '2' => 'memOutputOpen',
  },
  airFMSysAlarmMapOutput3 => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  airIRmPmUnitType => {
    '1' => 'mc',
    '2' => 'dx',
    '3' => 'cw',
    '4' => 'ch',
    '5' => 'ecoCool',
    '6' => 'msc',
    '7' => 'ge1',
    '8' => 'ge2',
    '9' => 'dualFluid',
    '10' => 'cw2',
    '256' => 'unknown',
  },
  dcmim2StatusLVDState => {
    '1' => 'statusClosed',
    '2' => 'statusOpened',
  },
  battManInputContactAlarmState => {
    '1' => 'normal',
    '2' => 'alarm',
  },
  rPDU2DeviceStatusPowerSupply2Status => {
    '1' => 'normal',
    '2' => 'alarm',
    '3' => 'notInstalled',
  },
  airIRRP100GroupSetpointsFanSpeedPreference => {
    '1' => 'low',
    '2' => 'med-low',
    '3' => 'med',
    '4' => 'med-high',
    '5' => 'high',
  },
  upsAdvControlSimulatePowerFail => {
    '1' => 'noSimulatePowerFailure',
    '2' => 'simulatePowerFailure',
  },
  rPDU2SensorTempHumidityConfigHumidityAlarmEnable => {
    '1' => 'disabled',
    '2' => 'enabled',
  },
  battManSystemPilotBatteryHighTempAlarm => {
    '1' => 'normal',
    '2' => 'alarm',
  },
  airIRmPmPWWHeatingType => {
    '1' => 'direct',
    '2' => 'undefined',
  },
  emsProbeStatusProbeCommStatus => {
    '1' => 'commsNeverDiscovered',
    '2' => 'commsEstablished',
    '3' => 'commsLost',
  },
  airIRSCGroupSetpointsActiveFlowControlBias => {
    '1' => 'positive',
    '2' => 'slightlyPositive',
    '3' => 'zero',
    '4' => 'slightlyNegative',
    '5' => 'negative',
  },
  dm3ConfigFusesAlarm => {
    '1' => 'alarmIgnore',
    '2' => 'alarmRelay1',
    '3' => 'alarmRelay2',
    '4' => 'alarmRelay3',
    '5' => 'alarmRelay4',
    '6' => 'alarmRelay5',
    '7' => 'alarmRelay6',
    '8' => 'alarmMinor',
    '9' => 'alarmMajor',
  },
  airIRG3CMServiceIntervalsAirFilterAlarm => {
    '1' => 'disable',
    '2' => 'enable',
  },
  sPDUMasterControlVMCommand => {
    '1' => 'noCommandAllVM',
    '2' => 'immediateAllOnVM',
    '3' => 'immediateAllOffVM',
    '4' => 'immediateAllRebootVM',
    '5' => 'delayedAllOnVM',
    '6' => 'delayedAllOffVM',
    '7' => 'sequencedAllRebootVM',
    '8' => 'delayedAllRebootVM',
    '9' => 'delayedSequenceAllRebootVM',
    '10' => 'cancelAllPendingCommandsVM',
    '11' => 'audioAlarmMute',
  },
  airFMGroupCfgSetpointShareSetting => {
    '1' => 'disable',
    '2' => 'enable',
  },
  isxModularDistSysOutputVoltageMonitoring => {
    '1' => 'notPresent',
    '2' => 'present',
  },
  airFMGroupFailoverModCoolFail => {
    '1' => 'notApplicable',
    '2' => 'disable',
    '3' => 'enable',
  },
  dm3StatusConvCfg => {
    '1' => 'statusTrue',
    '2' => 'statusFalse',
  },
  memInputsCommStatus => {
    '1' => 'notInstalled',
    '2' => 'commsOK',
    '3' => 'commsLost',
  },
  xPDUMainInputVoltagePhaseIndex => {
    '1' => 'phase1',
    '2' => 'phase2',
    '3' => 'phase3',
  },
  upsParallelSysRedundancy => {
    '1' => 'nplus0',
    '2' => 'nplus1',
    '3' => 'nplus2',
    '4' => 'nplus3',
    '5' => 'nplus4',
    '6' => 'nplus5',
  },
  upsDiagSubSysSystemPowerSupplyStatus => {
    '1' => 'unknown',
    '2' => 'notInstalled',
    '3' => 'offOk',
    '4' => 'onOk',
    '5' => 'offFail',
    '6' => 'onFail',
    '7' => 'lostComm',
  },
  airFMSysAlarmMapMainModBlwrCntl2Fail => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  upsIntegratedATSSelectedSource => {
    '1' => 'noSourceSelected',
    '2' => 'unknown',
    '3' => 'sourceA',
    '4' => 'sourceB',
  },
  rARUStatusAruMasterControl => {
    '1' => 'aruOn',
    '2' => 'aruOff',
  },
  emStatusCommStatus => {
    '1' => 'noComm',
    '2' => 'comm',
    '3' => 'commLost',
  },
  airFMSysReheatState => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  airFMSysAlarmMapExpMod2LowAirFlow => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  xATSSource2Rotation => {
    '1' => 'abc',
    '2' => 'cba',
    '3' => 'unknown',
  },
  battManConfigCellsperBattery => {
    '1' => 'oneCell',
    '2' => 'twoCells',
    '4' => 'fourCells',
    '6' => 'sixCells',
  },
  upsParallelSysRedundancyStatus => {
    '1' => 'nplus0',
    '2' => 'nplus1',
    '3' => 'nplus2',
    '4' => 'nplus3',
    '5' => 'nplus4',
    '6' => 'nplus5',
  },
  rARUFanStatusFanOperatingStatus => {
    '1' => 'unknown',
    '2' => 'off',
    '3' => 'onOk',
    '4' => 'onDegraded',
    '5' => 'offFailed',
  },
  apcLocalDisplayConfigKeyClick => {
    '1' => 'keyclickDisabled',
    '2' => 'keyclickEnabled',
  },
  airFMModServIntComp1Reset => {
    '1' => 'notApplicable',
    '2' => 'noOperation',
    '3' => 'reset',
  },
  airFMModBlwr1CtrlType => {
    '1' => 'notApplicable',
    '2' => 'fujiVFD',
    '3' => 'ecController',
    '4' => 'danfossVFD',
  },
  airFMSysOutputStatus => {
    '1' => 'open',
    '2' => 'closed',
  },
  airFMGroupFailoverModLowSupplyTemp => {
    '1' => 'notApplicable',
    '2' => 'disable',
    '3' => 'enable',
  },
  dm3ConfigLVDHWAlarm => {
    '1' => 'alarmIgnore',
    '2' => 'alarmRelay1',
    '3' => 'alarmRelay2',
    '4' => 'alarmRelay3',
    '5' => 'alarmRelay4',
    '6' => 'alarmRelay5',
    '7' => 'alarmRelay6',
    '8' => 'alarmMinor',
    '9' => 'alarmMajor',
  },
  emsSensorStatusSensorState => {
    '1' => 'sensorFaultedEMS',
    '2' => 'sensorOKEMS',
    '3' => 'sensorNotInstalledEMS',
  },
  airFMGroupFailoverModMaintRequired => {
    '1' => 'notApplicable',
    '2' => 'disable',
    '3' => 'enable',
  },
  dm3StatusInRlyStatus => {
    '1' => 'statusOn',
    '2' => 'statusOff',
  },
  airIRmPmCoolingPriority => {
    '1' => 'ge',
    '2' => 'cw',
    '3' => 'dx',
  },
  atsStatusFrontPanel => {
    '1' => 'locked',
    '2' => 'unlocked',
  },
  airIRRCGroupSetpointsFanSpeedControl => {
    '1' => 'automatic',
    '2' => 'manual',
  },
  airIRmPmEheating2Type => {
    '1' => 'direct',
    '2' => 'pwm',
  },
  emsStatusCommStatus => {
    '1' => 'noComm',
    '2' => 'comm',
    '3' => 'commLost',
  },
  AirIRmControlState => {
    '1' => 'off',
    '2' => 'on',
  },
  upsDiagComBusInternalMIMStatus => {
    '1' => 'unknown',
    '2' => 'notInstalled',
    '3' => 'ok',
    '4' => 'lostComm',
    '5' => 'rxFailure',
    '6' => 'txFailure',
  },
  isxModularPduFanStatus => {
    '1' => 'normal',
    '2' => 'failed',
    '3' => 'noCoolingFansPresent',
    '4' => 'unknown',
  },
  airFMSysAlarmMapExpMod2CoolFail => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  isxModularDistModuleBreakerPhaseIndex => {
    '1' => 'phaseL1',
    '2' => 'phaseL2',
    '3' => 'phaseL3',
  },
  battManString1BatteryDryout => {
    '1' => 'normal',
    '2' => 'alarm',
  },
  xATSSystemOutputFrequencyTolerance => {
    '1' => 'freqToleranceOff',
    '2' => 'freqTolerancePointTwo',
    '3' => 'freqTolerancePointFive',
    '4' => 'freqToleranceOne',
    '5' => 'freqToleranceOnePointFive',
    '6' => 'freqToleranceTwo',
    '7' => 'freqToleranceThree',
    '8' => 'freqToleranceFour',
    '9' => 'freqToleranceFive',
    '10' => 'freqToleranceNine',
  },
  airIRSCGroupStatusActiveFlowControlStatus => {
    '1' => 'under',
    '2' => 'okay',
    '3' => 'over',
    '4' => 'notApplicable',
  },
  mcontrolRestartAgent => {
    '1' => 'restartCurrentAgent',
    '2' => 'continueCurrentAgent',
    '3' => 'loadAndExecuteNewAgent',
    '4' => 'restartWithoutAgent',
    '5' => 'resetNetworkAndRestart',
    '6' => 'resetNetworkLeaveModeAndRestart',
  },
  airIRRP100UnitConfigReheatEnable => {
    '1' => 'enable',
    '2' => 'disable',
  },
  airIRRP500UnitServiceIntervalAirFilterAlarm => {
    '1' => 'enable',
    '2' => 'disable',
  },
  battManString2BatteryChemHighVoltageAlarm => {
    '1' => 'normal',
    '2' => 'alarm',
  },
  airIRmPmEheating1Type => {
    '1' => 'direct',
    '2' => 'pwm',
  },
  xATSSwitchTimersStatus => {
    '1' => 'inactive',
    '2' => 'active',
  },
  airIRRP100UnitConfigDehumidifyEnable => {
    '1' => 'enable',
    '2' => 'disable',
  },
  airIRG3RDUStatusOperatingMode => {
    '1' => 'standby',
    '2' => 'ready',
    '3' => 'on',
    '4' => 'stop',
    '5' => 'maintenancemode',
  },
  airPABlowerSpeed => {
    '1' => 'speedLOW',
    '2' => 'speedHIGH',
  },
  isxModularDistSubFeedInfoAlarmStatus => {
    '1' => 'normal',
    '2' => 'warning',
    '3' => 'critical',
  },
  isxModularPduAlarmStatus => {
    '1' => 'normal',
    '2' => 'warning',
    '3' => 'critical',
  },
  airIRRP500GroupConfigActiveFlowControllerLampTest => {
    '1' => 'off',
    '2' => 'on',
  },
  airFMAlarmSeverity => {
    '1' => 'informational',
    '2' => 'warningMinor',
    '3' => 'criticalMajor',
  },
  airFMGroupFailoverModHumFail => {
    '1' => 'notApplicable',
    '2' => 'disable',
    '3' => 'enable',
  },
  airFMGroupLoadShareReheatRequests => {
    '1' => 'disable',
    '2' => 'enable',
  },
  dm3StatusRectFail => {
    '1' => 'statusTrue',
    '2' => 'statusFalse',
  },
  rPDU2DevicePropertiesOutletLayout => {
    '1' => 'seqPhaseToNeutral',
    '2' => 'seqPhaseToPhase',
    '3' => 'seqPhToNeu21PhToPh',
    '4' => 'seqPhToPhGrouped',
    '5' => 'seqPhToNGrouped',
    '6' => 'seqPToN1516PToPGrouped',
    '7' => 'seqPhToPh2xGrouped',
    '8' => 'seqPhToN2xGrouped',
    '9' => 'seqNotApplicable',
    '10' => 'seqPhToNPhToPhPhToN',
  },
  airFMSysAlarmMapOutput8 => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  airFMSysAlarmMapExpMod2HighSupplyTemp => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  emsStatusCheckLogLight => {
    '1' => 'lightOff',
    '2' => 'lightOn',
  },
  airIRRP100UnitConfigSecondaryPowerFeedCapability => {
    '1' => 'full',
    '2' => 'reduced',
  },
  airIRRP100UnitConfigHumidifierControl => {
    '1' => 'auto',
    '2' => 'drainOff',
  },
  battManConfigBatteryChemistry => {
    '1' => 'leadAcid',
    '2' => 'nickel-Cadmium',
  },
  airIRmPmEheating4Type => {
    '1' => 'direct',
    '2' => 'pwm',
  },
  acceptThisDevice => {
    '1' => 'yes',
    '2' => 'no',
  },
  upsPhaseInputVoltageOrientation => {
    '1' => 'unknown',
    '2' => 'singlePhase',
    '3' => 'splitPhase',
    '4' => 'threePhasePhaseToNeutral',
    '5' => 'threePhasePhaseToPhase',
  },
  airIRG2RDT2ConfigOutputSource => {
    '1' => 'anyAlarm',
    '2' => 'criticalAlarm',
  },
  airIRRP100UnitConfigUnitRoleOverride => {
    '1' => 'automatic',
    '2' => 'forcedOn',
  },
  isxModularDistSubFeedInfoBreakerPosition => {
    '1' => 'open',
    '2' => 'closed',
  },
  airIRRCGroupConfigActiveFlowControllerLampTest => {
    '1' => 'off',
    '2' => 'on',
  },
  airIRG2GroupConfigCoolPIDReset => {
    '1' => 'readBack',
    '2' => 'reset',
  },
  iemConfigContactEnable => {
    '1' => 'disabled',
    '2' => 'enabled',
  },
  AirIRSCConfigType => {
    '1' => 'racs',
    '2' => 'spot',
    '3' => 'in-row',
  },
  memOutputAction => {
    '1' => 'memActionClose',
    '2' => 'memActionOpen',
  },
  isxModularDistSysOutputVoltageAlarmHighEnable => {
    '1' => 'disabled',
    '2' => 'enabled',
  },
  dm3ConfigBattHighVoltAlarm => {
    '1' => 'alarmIgnore',
    '2' => 'alarmRelay1',
    '3' => 'alarmRelay2',
    '4' => 'alarmRelay3',
    '5' => 'alarmRelay4',
    '6' => 'alarmRelay5',
    '7' => 'alarmRelay6',
    '8' => 'alarmMinor',
    '9' => 'alarmMajor',
  },
  upsDiagSubSysDCCircuitBreakerStatus => {
    '1' => 'unknown',
    '2' => 'notInstalled',
    '3' => 'opened',
    '4' => 'closed',
  },
  rARUConfigAruMasterControl => {
    '1' => 'aruOn',
    '2' => 'aruOff',
  },
  airIRG2GroupConfigConfigurationType => {
    '1' => 'racs',
    '2' => 'spot',
    '3' => 'in-row',
    '4' => 'hacs',
    '5' => 'cacs',
  },
  airFMSysAlarmMapOutput5 => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  battManSystemAmbientLowTempAlarm => {
    '1' => 'normal',
    '2' => 'alarm',
  },
  airFMGroupFailoverSysHighEnvHum => {
    '1' => 'notApplicable',
    '2' => 'disable',
    '3' => 'enable',
  },
  rPDU2OutletSwitchedControlCommand => {
    '1' => 'immediateOn',
    '2' => 'immediateOff',
    '3' => 'immediateReboot',
    '4' => 'outletUnknown',
    '5' => 'delayedOn',
    '6' => 'delayedOff',
    '7' => 'delayedReboot',
    '8' => 'cancelPendingCommand',
  },
  airIRmPmUnitControlType => {
    '1' => 'room',
    '2' => 'supply',
    '3' => 'room-SupplyLimit',
    '4' => 'supply-RoomLimit',
  },
  airFMGroupLoadShareDehumRequests => {
    '1' => 'disable',
    '2' => 'enable',
  },
  isxModularDistModuleInfoAlarmStatus => {
    '1' => 'normal',
    '2' => 'warning',
    '3' => 'critical',
    '4' => 'notPresent',
    '5' => 'unknown',
  },
  airIRG2GroupSetptsFanSpeedPreference => {
    '1' => 'low',
    '2' => 'med-low',
    '3' => 'med',
    '4' => 'med-high',
    '5' => 'high',
  },
  airIRRP100UnitServiceIntervalCompressorAlarm => {
    '1' => 'enable',
    '2' => 'disable',
  },
  isxModularDistSubFeedInfoAlarmMinEnable => {
    '1' => 'disabled',
    '2' => 'enabled',
  },
  upsDiagIMStatus => {
    '1' => 'unknown',
    '2' => 'notInstalled',
    '3' => 'offOk',
    '4' => 'onOk',
    '5' => 'offFail',
    '6' => 'onFail',
    '7' => 'lostComm',
  },
  emsSensorConfigSensorNormalState => {
    '1' => 'normallyClosedEMS',
    '2' => 'normallyOpenEMS',
  },
  battManUnitRelayStuck => {
    '1' => 'normal',
    '2' => 'alarm',
  },
  xPDUEPOMode => {
    '1' => 'armed',
    '2' => 'disarmed',
    '3' => 'unknown',
  },
  airFMGroupFailoverSysAnyMinorAlarm => {
    '1' => 'notApplicable',
    '2' => 'disable',
    '3' => 'enable',
  },
  rPDU2BankStatusLoadState => {
    '1' => 'lowLoad',
    '2' => 'normal',
    '3' => 'nearOverload',
    '4' => 'overload',
  },
  rARUFanStatusFanRunhourReset => {
    '1' => 'yes',
    '2' => 'no',
  },
  airIRSCUnitStatusLeakSensor => {
    '1' => 'no-leak',
    '2' => 'leak',
  },
  airFMSysAlarmMapOutput1 => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  dm3StatusConvCurrentLimit => {
    '1' => 'statusTrue',
    '2' => 'statusFalse',
  },
  airFMAlarmClearActiveSysModAlarms => {
    '1' => 'noOperation',
    '2' => 'clearAlarms',
  },
  upsAdvTestCalibrationResults => {
    '1' => 'ok',
    '2' => 'invalidCalibration',
    '3' => 'calibrationInProgress',
  },
  airPACondensatePump => {
    '1' => 'statusON',
    '2' => 'statusOFF',
  },
  battManInputContactNormalState => {
    '1' => 'open',
    '2' => 'closed',
  },
  upsOutletGroupConfigLoadShedControlAutoRestart => {
    '1' => 'upsOutletGroupConfigAutoRestart',
    '2' => 'upsOutletGroupConfigManualRestart',
  },
  rPDU2OutletSwitchedStatusState => {
    '1' => 'off',
    '2' => 'on',
  },
  dm3ConfigInRlyAlarm => {
    '1' => 'alarmIgnore',
    '2' => 'alarmRelay1',
    '3' => 'alarmRelay2',
    '4' => 'alarmRelay3',
    '5' => 'alarmRelay4',
    '6' => 'alarmRelay5',
    '7' => 'alarmRelay6',
    '8' => 'alarmMinor',
    '9' => 'alarmMajor',
  },
  rARUConfigAruRemoteSetpoint => {
    '1' => 'aruOff',
    '2' => 'aru85F-29C',
    '3' => 'aru90F-32C',
    '4' => 'aru95F-35C',
    '5' => 'aru100F-38C',
    '6' => 'aru7kW-1200cfm',
    '7' => 'aru5kW-800cfm',
    '8' => 'aru3kW-500cfm',
    '9' => 'aru2kW-300cfm',
    '10' => 'aru400cfm',
    '11' => 'aru600cfm',
    '12' => 'aru700cfm',
    '13' => 'aru900cfm',
    '14' => 'aru1000cfm',
    '15' => 'aru1400cfm',
    '16' => 'aru1600cfm',
    '17' => 'aru1800cfm',
    '18' => 'aru2000cfm',
  },
  upsBasicOutputACwiringConfiguration => {
    '1' => 'unknown',
    '2' => 'noNeutralWiredonSystem',
    '3' => 'neutralUsedforSupplyingLoad',
  },
  airIRG2GroupConfigActiveFlowControllerLampTest => {
    '1' => 'off',
    '2' => 'on',
  },
  mfiletransferStatusLastTransferResult => {
    '1' => 'lastFileTransferResultSuccessful',
    '2' => 'lastFileTransferResultNotAvailable',
    '3' => 'lastFileTransferResultFailureUnknown',
    '4' => 'lastFileTransferResultFailureServerInaccessible',
    '5' => 'lastFileTransferResultFailureServerAccessDenied',
    '6' => 'lastFileTransferResultFailureFileNotFound',
    '7' => 'lastFileTransferResultFailureFileTypeUnknown',
    '8' => 'lastFileTransferResultFailureFileCorrupted',
  },
  rPDUOutletConfigOutletPhase => {
    '1' => 'phase1',
    '2' => 'phase2',
    '3' => 'phase3',
    '4' => 'phase1-2',
    '5' => 'phase2-3',
    '6' => 'phase3-1',
  },
  airFMSysAlarmMapExpMod2HumFail => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  newCodeAuthentViaTFTP => {
    '1' => 'unknown',
    '2' => 'validNewAgentCodeImage',
    '3' => 'sameAgentCodeImage',
    '4' => 'invalidAgentCodeImage',
  },
  airFMSysAlarmMapExpMod2AirBlckIntOpen => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  airIRG3RDUStatusPowerSource => {
    '1' => 'singleFeed',
    '2' => 'dualFeed',
  },
  airIRSCUnitServiceIntervalsAirFilterAlarm => {
    '1' => 'enable',
    '2' => 'disable',
  },
  airFMSysAlarmMapMainModAnyAlarm => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  emsOutletStatusOutletState => {
    '1' => 'outletOnEMS',
    '2' => 'outletOffEMS',
  },
  rPDU2DeviceControlCommand => {
    '1' => 'immediateAllOn',
    '2' => 'delayedAllOn',
    '3' => 'immediateAllOff',
    '4' => 'immediateAllReboot',
    '5' => 'delayedAllReboot',
    '6' => 'noCommandAll',
    '7' => 'delayedAllOff',
    '8' => 'cancelAllPendingCommands',
  },
  airFMSysAlarmMapInput12 => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  upsDiagTransformerStatus => {
    '1' => 'unknown',
    '2' => 'notInstalled',
    '3' => 'ok',
    '4' => 'fail',
    '5' => 'lostComm',
    '6' => 'overtemp',
    '7' => 'opened',
    '8' => 'closed',
  },
  rPDUOutletDevCommand => {
    '1' => 'noCommandAll',
    '2' => 'immediateAllOn',
    '3' => 'immediateAllOff',
    '4' => 'immediateAllReboot',
    '5' => 'delayedAllOn',
    '6' => 'delayedAllOff',
    '7' => 'delayedAllReboot',
    '8' => 'cancelAllPendingCommands',
  },
  airIRG2GroupConfigFanSpeedControl => {
    '1' => 'automatic',
    '2' => 'manual',
  },
  upsPhaseOutputVoltageOrientation => {
    '1' => 'unknown',
    '2' => 'singlePhase',
    '3' => 'splitPhase',
    '4' => 'threePhasePhaseToNeutral',
    '5' => 'threePhasePhaseToPhase',
  },
  dm3ConfigRectFanFailAlarm => {
    '1' => 'alarmIgnore',
    '2' => 'alarmRelay1',
    '3' => 'alarmRelay2',
    '4' => 'alarmRelay3',
    '5' => 'alarmRelay4',
    '6' => 'alarmRelay5',
    '7' => 'alarmRelay6',
    '8' => 'alarmMinor',
    '9' => 'alarmMajor',
    '10' => 'alarmNofN',
  },
  rPDUOutletStatusOutletPhase => {
    '1' => 'phase1',
    '2' => 'phase2',
    '3' => 'phase3',
    '4' => 'phase1-2',
    '5' => 'phase2-3',
    '6' => 'phase3-1',
  },
  dm3StatusBattCurrentSanity => {
    '1' => 'saneYES',
    '2' => 'saneNO',
  },
  iemStatusProbeTempUnits => {
    '1' => 'celsius',
    '2' => 'fahrenheit',
  },
  xATSSwitchTimersAbort => {
    '1' => 'yes',
    '2' => 'no',
  },
  memOutletStatusCurrentState => {
    '1' => 'off',
    '2' => 'on',
  },
  airFMModCondPump => {
    '1' => 'notApplicable',
    '2' => 'notPresent',
    '3' => 'present',
  },
  dm3StatusSysConvVoltSanity => {
    '1' => 'saneYES',
    '2' => 'saneNO',
  },
  memInputsStatusAlarmStatus => {
    '1' => 'memNormal',
    '2' => 'memWarning',
    '3' => 'memCritical',
  },
  airIRSCUnitStatusOperateMode => {
    '1' => 'standby',
    '2' => 'on',
    '3' => 'idle',
  },
  upsBasicBatteryStatus => {
    '1' => 'unknown',
    '2' => 'batteryNormal',
    '3' => 'batteryLow',
    '4' => 'batteryInFaultCondition',
  },
  memOutletNormalState => {
    '1' => 'off',
    '2' => 'on',
  },
  iemConfigProbeMinHumidEnable => {
    '1' => 'disabled',
    '2' => 'enabled',
  },
  airFMGroupFailoverModCondensatePumpFail => {
    '1' => 'notApplicable',
    '2' => 'disable',
    '3' => 'enable',
  },
  sPDUOutletConfigMSPmupsP2LowHum => {
    '1' => 'disableAlarm',
    '2' => 'enableAlarm',
  },
  sPDUOutletConfigMSPmupsP1HiTemp => {
    '1' => 'disableAlarm',
    '2' => 'enableAlarm',
  },
  airFMGroupCfgSetpointShareStatus => {
    '1' => 'off',
    '2' => 'on',
  },
  airIRRP500UnitConfigPowerSourceConfig => {
    '1' => 'single',
    '2' => 'dual',
  },
  upsOutletGroupStatusGroupState => {
    '1' => 'upsOutletGroupStatusOn',
    '2' => 'upsOutletGroupStatusOff',
    '3' => 'upsOutletGroupStatusUnknown',
  },
  acceptThisReceiver => {
    '1' => 'yes',
    '2' => 'no',
  },
  airFMSysHumState => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  sPDUOutletStatusMSPCommandPending => {
    '1' => 'outletStatusMSPCommandPending',
    '2' => 'outletStatusMSPNoCommandPending',
  },
  airIRRP500UnitServiceIntervalHumidifierAlarm => {
    '1' => 'enable',
    '2' => 'disable',
  },
  airFMSysAlarmMapInput3 => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  rPDU2SensorTempHumidityStatusHumidityStatus => {
    '1' => 'notPresent',
    '2' => 'belowMin',
    '3' => 'belowLow',
    '4' => 'normal',
    '5' => 'aboveHigh',
    '6' => 'aboveMax',
  },
  upsDiagSwitchGearStatus => {
    '1' => 'unknown',
    '2' => 'notInstalled',
    '3' => 'ok',
    '4' => 'fail',
    '5' => 'lostComm',
    '6' => 'overtemp',
  },
  upsAdvTotalDCCurrentPolarity => {
    '0' => 'positive',
    '1' => 'negative',
  },
  dm3StatusRectDiagPass => {
    '1' => 'statusTrue',
    '2' => 'statusFalse',
  },
  rPDU2OutletSwitchedStatusCommandPending => {
    '1' => 'commandPending',
    '2' => 'noCommandPending',
    '3' => 'commandPendingUnknown',
  },
  isxModularDistSubFeedInfoAlarmGeneration => {
    '1' => 'disabled',
    '2' => 'enabled',
  },
  airFMModRHComp1Reset => {
    '1' => 'notApplicable',
    '2' => 'noOperation',
    '3' => 'reset',
  },
  sPDUOutletConfigMSPmupsP1HiHum => {
    '1' => 'disableAlarm',
    '2' => 'enableAlarm',
  },
  isxModularDistSubFeedInfoAlarmHighEnable => {
    '1' => 'disabled',
    '2' => 'enabled',
  },
  emStatusProbeMinTempViolation => {
    '1' => 'noViolation',
    '2' => 'minTempViolation',
    '3' => 'disabled',
  },
  airPASystemPower => {
    '1' => 'powerON',
    '2' => 'powerOFF',
  },
  upsAdvConfigSimpleSignalShutdowns => {
    '1' => 'unknown',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  airIRG2RDT2RunHoursFanPSPosition => {
    '1' => 'upper',
    '2' => 'lower',
    '3' => 'left',
    '4' => 'right',
  },
  upsAdvTestDiagnosticSchedule => {
    '1' => 'unknown',
    '2' => 'biweekly',
    '3' => 'weekly',
    '4' => 'atTurnOn',
    '5' => 'never',
    '6' => 'fourWeeks',
    '7' => 'twelveWeeks',
    '8' => 'biweeklySinceLastTest',
    '9' => 'weeklySinceLastTest',
    '10' => 'eightWeeks',
    '11' => 'twentysixWeeks',
    '12' => 'fiftytwoWeeks',
  },
  iemStatusProbeMaxHumidViolation => {
    '1' => 'noViolation',
    '2' => 'maxHumidViolation',
    '3' => 'disabled',
  },
  upsAdvConfigGreenMode => {
    '1' => 'disable',
    '2' => 'enable',
  },
  battManString1BatteryOpenFuseOrConnection => {
    '1' => 'normal',
    '2' => 'alarm',
  },
  airFMModWaterDetector => {
    '1' => 'notApplicable',
    '2' => 'notPresent',
    '3' => 'present',
  },
  airIRSCUnitConfigIdleOnLeakDetect => {
    '1' => 'yes',
    '2' => 'no',
  },
  airFMSysRemoteSensorData => {
    '1' => 'notApplicable',
    '2' => 'average',
    '3' => 'maximum',
  },
  subfeedBreakerPresent => {
    '1' => 'notPresent',
    '2' => 'present',
  },
  airIRRP500UnitConfigUnitRoleOverride => {
    '1' => 'automatic',
    '2' => 'forcedOn',
  },
  databaseStatus => {
    '1' => 'unknown',
    '2' => 'stopped',
    '3' => 'running',
    '4' => 'detached',
    '5' => 'catching-up',
    '6' => 'attaching',
    '7' => 'running-master',
    '8' => 'running-primary-slave',
    '9' => 'running-slave',
    '10' => 'running-alone',
  },
  airFMModBlwr1ElOvMode => {
    '1' => 'notApplicable',
    '2' => 'inactive',
    '3' => 'active',
  },
  emsStatusSysTempUnits => {
    '1' => 'celsius',
    '2' => 'fahrenheit',
  },
  atsControlResetATS => {
    '1' => 'none',
    '2' => 'reset',
  },
  airFMSysAlarmMapInput13 => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  airFMSysAlarmMapOutput15 => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  xATSGeneratorSettingsMetricUnit => {
    '1' => 'disabled',
    '2' => 'enabled',
  },
  battManUnitCommLoss => {
    '1' => 'normal',
    '2' => 'alarm',
  },
  upsDiagPMStatus => {
    '1' => 'unknown',
    '2' => 'notInstalled',
    '3' => 'offOk',
    '4' => 'onOk',
    '5' => 'offFail',
    '6' => 'onFail',
    '7' => 'lostComm',
  },
  battManString1BatteryCellShorted => {
    '1' => 'normal',
    '2' => 'alarm',
  },
  xPDUDeviceEarthGroundMonitorPresent => {
    '1' => 'notPresent',
    '2' => 'present',
  },
  xPDUSystemOutputFrequencyTolerance => {
    '1' => 'freqToleranceOff',
    '2' => 'freqTolerancePointTwo',
    '3' => 'freqTolerancePointFive',
    '4' => 'freqToleranceOne',
    '5' => 'freqToleranceOnePointFive',
    '6' => 'freqToleranceTwo',
    '7' => 'freqToleranceThree',
    '8' => 'freqToleranceFour',
    '9' => 'freqToleranceFive',
    '10' => 'freqToleranceNine',
  },
  atsStatusRedundancyState => {
    '1' => 'atsRedundancyLost',
    '2' => 'atsFullyRedundant',
  },
  airFMGroupFailoverSysLowEnvTemp => {
    '1' => 'notApplicable',
    '2' => 'disable',
    '3' => 'enable',
  },
  rPDU2OutletMeteredStatusState => {
    '1' => 'lowLoad',
    '2' => 'normal',
    '3' => 'nearOverload',
    '4' => 'overload',
  },
  battManString2BatteryChemLowVoltageAlarm => {
    '1' => 'normal',
    '2' => 'alarm',
  },
  airFMGroupFailoverModHighSupplyTemp => {
    '1' => 'notApplicable',
    '2' => 'disable',
    '3' => 'enable',
  },
  apcLocalDisplayIdentDisplayType => {
    '1' => 'noDisplayFound',
    '2' => 'powerviewRM',
    '3' => 'powerviewWW',
  },
  airFMSysNumModules => {
    '1' => 'notApplicable',
    '2' => 'one',
    '3' => 'two',
    '4' => 'three',
  },
  airFMSysAlarmMapExpMod2BlwrCntl2Fail => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  dm3ConfigRectConfigAlarm => {
    '1' => 'alarmIgnore',
    '2' => 'alarmRelay1',
    '3' => 'alarmRelay2',
    '4' => 'alarmRelay3',
    '5' => 'alarmRelay4',
    '6' => 'alarmRelay5',
    '7' => 'alarmRelay6',
    '8' => 'alarmMinor',
    '9' => 'alarmMajor',
  },
  battManStringCurrentProbeDisconnected => {
    '1' => 'normal',
    '2' => 'alarm',
  },
  airIRmPmCmp1ManOperationActive => {
    '1' => 'automatic',
    '2' => 'manual',
  },
  isxModularDistSysPowerKwhReset => {
    '1' => 'no',
    '2' => 'yes',
  },
  airIRG3CMConfigPowerSource => {
    '1' => 'singleFeed',
    '2' => 'dualFeed',
  },
  airFMSysAlarmMapOutput9 => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  iemConfigProbeHighTempEnable => {
    '1' => 'disabled',
    '2' => 'enabled',
  },
  airIRRCUnitConfigCoolCapacity => {
    '1' => 'automatic',
    '2' => 'maximum',
  },
  battManString2BatteryOpenFuseOrConnection => {
    '1' => 'normal',
    '2' => 'alarm',
  },
  airFMSysAlarmMapOutput2 => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  dm3ConfigRectImbalanceAlarm => {
    '1' => 'alarmIgnore',
    '2' => 'alarmRelay1',
    '3' => 'alarmRelay2',
    '4' => 'alarmRelay3',
    '5' => 'alarmRelay4',
    '6' => 'alarmRelay5',
    '7' => 'alarmRelay6',
    '8' => 'alarmMinor',
    '9' => 'alarmMajor',
  },
  emConfigProbeLowHumidEnable => {
    '1' => 'disabled',
    '2' => 'enabled',
  },
  airIRRP500GroupSetpointsFanSpeedPreference => {
    '1' => 'low',
    '2' => 'med-low',
    '3' => 'med',
    '4' => 'med-high',
    '5' => 'high',
  },
  battManString1BatteryChemHighVoltageAlarm => {
    '1' => 'normal',
    '2' => 'alarm',
  },
  airIRRP500UnitServiceIntervalCondensatePumpAlarm => {
    '1' => 'enable',
    '2' => 'disable',
  },
  airFMSysPrimaryControlSensor => {
    '1' => 'notApplicable',
    '2' => 'return',
    '3' => 'remote',
  },
  dm3ConfigCompMethod => {
    '1' => 'tempcompOn',
    '2' => 'tempcompOff',
  },
  emsOutletStatusOutletNormalState => {
    '1' => 'normallyOnEMS',
    '2' => 'normallyOffEMS',
  },
  xPDUTransformTempStatus => {
    '1' => 'normal',
    '2' => 'overtemp',
    '3' => 'noTransformerPresent',
    '4' => 'unknown',
  },
  airFMSysActualTempCtrlMethod => {
    '1' => 'notApplicable',
    '2' => 'avgReturn',
    '3' => 'avgRemote',
    '4' => 'maxRemote',
  },
  airFMSysAlarmMapOutput6 => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  airFMSysReheatPIDMethod => {
    '1' => 'notApplicable',
    '2' => 'p',
    '3' => 'pi',
    '4' => 'pid',
  },
  airIRmPmMaintenance => {
    '1' => 'notNecessary',
    '2' => 'necessary',
  },
  rPDU2DeviceConfigDeviceEnergyReset => {
    '1' => 'noOperation',
    '2' => 'reset',
    '3' => 'notSupported',
  },
  airIRRP500UnitConfigIdleOnCoolFail => {
    '1' => 'enable',
    '2' => 'disable',
  },
  upsDiagSubSysChargerStatus => {
    '1' => 'unknown',
    '2' => 'notInstalled',
    '3' => 'offOk',
    '4' => 'onOk',
    '5' => 'offFail',
    '6' => 'onFail',
    '7' => 'lostComm',
  },
  airIRRCUnitConfigIdleOnCoolFail => {
    '1' => 'yes',
    '2' => 'no',
  },
  uioInputContactStatusAlarmStatus => {
    '1' => 'uioNormal',
    '2' => 'uioWarning',
    '3' => 'uioCritical',
    '4' => 'inputStatusNotApplicable',
  },
  airFMSysCoilFluidVlvAct => {
    '1' => 'notApplicable',
    '2' => 'none',
    '3' => 'springAnalog',
    '4' => 'floatingControl',
  },
  rPDUStatusPhaseState => {
    '1' => 'phaseLoadNormal',
    '2' => 'phaseLoadLow',
    '3' => 'phaseLoadNearOverload',
    '4' => 'phaseLoadOverload',
  },
  airFMSysOutputNormalState => {
    '1' => 'open',
    '2' => 'closed',
  },
  dm3ConfigConvHighVoltAlarm => {
    '1' => 'alarmIgnore',
    '2' => 'alarmRelay1',
    '3' => 'alarmRelay2',
    '4' => 'alarmRelay3',
    '5' => 'alarmRelay4',
    '6' => 'alarmRelay5',
    '7' => 'alarmRelay6',
    '8' => 'alarmMinor',
    '9' => 'alarmMajor',
  },
  dm3ConfigBattHwCurrentAlarm => {
    '1' => 'alarmIgnore',
    '2' => 'alarmRelay1',
    '3' => 'alarmRelay2',
    '4' => 'alarmRelay3',
    '5' => 'alarmRelay4',
    '6' => 'alarmRelay5',
    '7' => 'alarmRelay6',
    '8' => 'alarmMinor',
    '9' => 'alarmMajor',
  },
  rPDU2BankConfigOverloadRestriction => {
    '1' => 'alwaysAllowTurnON',
    '2' => 'restrictOnNearOverload',
    '3' => 'restrictOnOverload',
    '4' => 'notSupported',
  },
  xPDUInputContactNormalState => {
    '1' => 'open',
    '2' => 'closed',
  },
  airFMSysResetFldSrvcDflts => {
    '1' => 'notApplicable',
    '2' => 'noOperation',
    '3' => 'reset',
  },
  airFMSysAlarmMapOutput16 => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  upsSCGACOutputStatus => {
    '1' => 'acOutOn',
    '2' => 'acOutOff',
  },
  upsDiagComBusMIMtoRIMStatus => {
    '1' => 'unknown',
    '2' => 'notInstalled',
    '3' => 'ok',
    '4' => 'lostComm',
    '5' => 'rxFailure',
    '6' => 'txFailure',
  },
  memSensorsAlarmStatus => {
    '1' => 'memNormal',
    '2' => 'memWarning',
    '3' => 'memCritical',
  },
  dm3ConfigSysHighTempAlarm => {
    '1' => 'alarmIgnore',
    '2' => 'alarmRelay1',
    '3' => 'alarmRelay2',
    '4' => 'alarmRelay3',
    '5' => 'alarmRelay4',
    '6' => 'alarmRelay5',
    '7' => 'alarmRelay6',
    '8' => 'alarmMinor',
    '9' => 'alarmMajor',
  },
  rPDUIdentDeviceOutletLayout => {
    '1' => 'seqPhaseToNeutral',
    '2' => 'seqPhaseToPhase',
    '3' => 'seqPhToNeu21PhToPh',
    '4' => 'seqPhToPhGrouped',
    '5' => 'seqPhToNGrouped',
    '6' => 'seqPToN1516PToPGrouped',
    '7' => 'seqPhToPh2xGrouped',
    '8' => 'seqPhToN2xGrouped',
    '9' => 'seqNotApplicable',
  },
  isxModularDistSysCurrentAlarmMaxEnable => {
    '1' => 'disabled',
    '2' => 'enabled',
  },
  isxModularDistModuleOutputAlarmHighEnable => {
    '1' => 'disabled',
    '2' => 'enabled',
  },
  airFMSysAirFltr => {
    '1' => 'notApplicable',
    '2' => 'standard',
    '3' => 'highEfficiency',
  },
  airIRRP500UnitConfigOutputNormalState => {
    '1' => 'open',
    '2' => 'closed',
  },
  airIRG3CMConfigStopOnCoolFail => {
    '1' => 'no',
    '2' => 'yes',
  },
  emStatusProbeLowHumidViolation => {
    '1' => 'noViolation',
    '2' => 'lowHumidViolation',
    '3' => 'disabled',
  },
  atsInputVoltageOrientation => {
    '1' => 'unknown',
    '2' => 'singlePhase',
    '3' => 'splitPhase',
    '4' => 'threePhasePhaseToNeutral',
    '5' => 'threePhasePhaseToPhase',
  },
  sPDUOutletStatusVMCommandPending => {
    '1' => 'outletStatusVMCommandPending',
    '2' => 'outletStatusVMNoCommandPending',
  },
  airFMSysNumber => {
    '1' => 'notApplicable',
    '2' => 'one',
    '3' => 'two',
    '4' => 'three',
    '5' => 'four',
  },
  airIRRP100UnitConfigPowerSourceConfig => {
    '1' => 'single',
    '2' => 'dual',
  },
  sPDUMasterConfigMSPManualButton => {
    '1' => 'manualButtonDisabled',
    '2' => 'manualButtonEnabled',
  },
  upsHighPrecTotalDCCurrentPolarity => {
    '0' => 'positive',
    '1' => 'negative',
  },
  airFMModRHBlwr2Reset => {
    '1' => 'notApplicable',
    '2' => 'noOperation',
    '3' => 'reset',
  },
  airIRRP500UnitServiceIntervalHeaterAlarm => {
    '1' => 'enable',
    '2' => 'disable',
  },
  battManString2BatteryThermalRunaway => {
    '1' => 'normal',
    '2' => 'alarm',
  },
  memInputAlarmGeneration => {
    '1' => 'disabled',
    '2' => 'enabled',
  },
  upsAdvConfigSensitivity => {
    '1' => 'auto',
    '2' => 'low',
    '3' => 'medium',
    '4' => 'high',
  },
  airFMSysAlarmMapSysSecSensFail => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  airIRG3RDUStatusRefrigerantLeakDetector => {
    '1' => 'suspended',
    '2' => 'calibrating',
    '3' => 'operating',
    '4' => 'disabled',
  },
  airFMGroupFailoverSysSmokeAlarm => {
    '1' => 'notApplicable',
    '2' => 'disable',
    '3' => 'enable',
  },
  battManString1BatteryUserLowVoltageAlarm => {
    '1' => 'normal',
    '2' => 'alarm',
  },
  airFMSysResetRunHours => {
    '1' => 'notApplicable',
    '2' => 'noOperation',
    '3' => 'reset',
  },
  sPDUMasterStatusVMCommandPending => {
    '1' => 'commandPendingMasterTrueVM',
    '2' => 'commandPendingMasterFalseVM',
  },
  upsOutletGroupConfigLoadShedControlInOverload => {
    '1' => 'upsOutletGroupConfigDisableInOverloadLoadShed',
    '2' => 'upsOutletGroupConfigEnableInOverloadLoadShed',
  },
  upsDiagMCCBBoxStatus => {
    '1' => 'unknown',
    '2' => 'notInstalled',
    '3' => 'opened',
    '4' => 'closed',
  },
  xATSGeneratorAdvStatusOilLevel => {
    '1' => 'ok',
    '2' => 'low',
    '3' => 'unknown',
  },
  upsDiagSubSysExternalPowerFrameBoardStatus => {
    '1' => 'unknown',
    '2' => 'notInstalled',
    '3' => 'offOk',
    '4' => 'onOk',
    '5' => 'offFail',
    '6' => 'onFail',
    '7' => 'lostComm',
  },
  airIRRCUnitConfigPowerSource => {
    '1' => 'sourceA',
    '2' => 'sourceB',
    '3' => 'sourceAandB',
  },
  airFMAlarmClearActiveGroupAlarms => {
    '1' => 'noOperation',
    '2' => 'clearAlarms',
  },
  rPDU2DeviceConfigOutletsEnergyReset => {
    '1' => 'noOperation',
    '2' => 'reset',
    '3' => 'notSupported',
  },
  airIRRP500GroupStatusActiveFlowControlStatus => {
    '1' => 'under',
    '2' => 'okay',
    '3' => 'over',
    '4' => 'notApplicable',
  },
  airIRRP100UnitServiceIntervalHumidifierAlarm => {
    '1' => 'enable',
    '2' => 'disable',
  },
  rARUStatusAruTempOvrdEnableDisable => {
    '1' => 'disabled',
    '2' => 'enabled',
  },
  airIRRP100UnitConfigCoolCapacity => {
    '1' => 'automatic',
    '2' => 'maximum',
  },
  airIRmPmDayNightMode => {
    '1' => 'day',
    '2' => 'night',
  },
  airFMSysAlarmMapMainModHumFail => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  upsAdvConfigBatterySelection => {
    '1' => 'vrla',
    '2' => 'ventedcell',
  },
  airIRRCUnitConfigOutputNormalState => {
    '1' => 'open',
    '2' => 'closed',
  },
  airFMSysInputNormalState => {
    '1' => 'open',
    '2' => 'closed',
  },
  emConfigProbeHighTempEnable => {
    '1' => 'disabled',
    '2' => 'enabled',
  },
  dcmim2StatusBattFunctTestResult => {
    '1' => 'functTestNotPerformed',
    '2' => 'functTestInProcess',
    '3' => 'functTestInterrupted',
    '4' => 'functTestPass',
    '5' => 'functTestFail',
  },
  xATSGeneratorFuelSystemLowRunTimeThreshold => {
    '1' => 'disabled',
    '2' => 'oneHour',
    '3' => 'twoHours',
    '4' => 'threeHours',
    '5' => 'fourHours',
    '6' => 'fiveHours',
    '7' => 'sixHours',
    '8' => 'twelveHours',
    '9' => 'oneDay',
    '10' => 'twoDays',
    '11' => 'threeDays',
    '12' => 'fourDays',
    '13' => 'fiveDays',
    '14' => 'sixDays',
    '15' => 'sevenDays',
  },
  xPDUDeviceTransformerPresent => {
    '1' => 'notPresent',
    '2' => 'present',
  },
  battManString2BatteryHighOhmicValue => {
    '1' => 'normal',
    '2' => 'alarm',
  },
  xPDUUPSInputVoltageLtoNPresent => {
    '1' => 'notPresent',
    '2' => 'present',
    '3' => 'unknown',
  },
  airIRG3RDUConfigOnReadyStandby => {
    '1' => 'standby',
    '2' => 'ready',
    '3' => 'on',
  },
  airFMGroupFailoverModAirBlockInterlockOpen => {
    '1' => 'notApplicable',
    '2' => 'disable',
    '3' => 'enable',
  },
  upsBasicSystemStatus => {
    '1' => 'unknown',
    '2' => 'onLine',
    '3' => 'onBattery',
    '4' => 'onSmartBoost',
    '5' => 'timedSleeping',
    '6' => 'softwareBypass',
    '7' => 'off',
    '8' => 'rebooting',
    '9' => 'switchedBypass',
    '10' => 'hardwareFailureBypass',
    '11' => 'sleepingUntilPowerReturn',
    '12' => 'onSmartTrim',
    '13' => 'ecoMode',
    '14' => 'inverter',
    '15' => 'eConversion',
    '16' => 'staticBypassStandby',
  },
  dm3ConfigRectLowVoltAlarm => {
    '1' => 'alarmIgnore',
    '2' => 'alarmRelay1',
    '3' => 'alarmRelay2',
    '4' => 'alarmRelay3',
    '5' => 'alarmRelay4',
    '6' => 'alarmRelay5',
    '7' => 'alarmRelay6',
    '8' => 'alarmMinor',
    '9' => 'alarmMajor',
  },
  airIRRP100UnitConfigHumidifyEnable => {
    '1' => 'enable',
    '2' => 'disable',
  },
  airIRG2RDT2StatusOperateMode => {
    '1' => 'standby',
    '2' => 'on',
    '3' => 'idle',
    '4' => 'reserved',
    '5' => 'service',
  },
  AirIRSCCapacityControlType => {
    '1' => 'discrete',
    '2' => 'proportional',
  },
  airFMSysDehumEssFunction => {
    '1' => 'notApplicable',
    '2' => 'yes',
    '3' => 'no',
  },
  dm3StatusBattTempSanity => {
    '1' => 'saneYES',
    '2' => 'saneNO',
  },
  upsIntegratedATSPreferredSource => {
    '1' => 'upsIntegratedATSNoSourcePreference',
    '2' => 'upsIntegratedATSPreferSourceA',
    '3' => 'upsIntegratedATSPreferSourceB',
  },
  airFMGroupFailoverModHumReplaceCylinder => {
    '1' => 'notApplicable',
    '2' => 'disable',
    '3' => 'enable',
  },
  AirIRmActivityState => {
    '1' => 'inactive',
    '2' => 'active',
  },
  airFMSysAlarmMapMainModLowSupplyTemp => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  xPDUDeviceBypassInputPresent => {
    '1' => 'notPresent',
    '2' => 'present',
  },
  atsOutputBank => {
    '1' => 'total',
    '2' => 'bank1',
    '3' => 'bank2',
  },
  airFMGroupCfgNumSystems => {
    '1' => 'one',
    '2' => 'two',
    '3' => 'three',
    '4' => 'four',
  },
  rPDUPowerSupply2Status => {
    '1' => 'powerSupplyTwoOk',
    '2' => 'powerSupplyTwoFailed',
    '3' => 'powerSupplyTwoNotPresent',
  },
  airIRRCUnitServiceIntervalsAirFilterAlarm => {
    '1' => 'enable',
    '2' => 'disable',
  },
  airIRRP100UnitConfigOutputNormalState => {
    '1' => 'open',
    '2' => 'closed',
  },
  isxModularDistSysCurrentMonitoring => {
    '1' => 'notPresent',
    '2' => 'present',
  },
  xATSSource2Quality => {
    '1' => 'sourceGood',
    '2' => 'lowVoltage',
    '3' => 'highVoltage',
    '4' => 'phaseImbalance',
    '5' => 'freqOutOfRange',
    '6' => 'badRotation',
    '7' => 'unknown',
  },
  iemStatusProbeHighHumidViolation => {
    '1' => 'noViolation',
    '2' => 'highHumidViolation',
    '3' => 'disabled',
  },
  airIRG3RDUConfigOutputSource => {
    '1' => 'anyalarm',
    '2' => 'onlycriticalalarms',
  },
  dm3StatusRectCurrentLimit => {
    '1' => 'statusTrue',
    '2' => 'statusFalse',
  },
  dm3ConfigConvStandbyAlarm => {
    '1' => 'alarmIgnore',
    '2' => 'alarmRelay1',
    '3' => 'alarmRelay2',
    '4' => 'alarmRelay3',
    '5' => 'alarmRelay4',
    '6' => 'alarmRelay5',
    '7' => 'alarmRelay6',
    '8' => 'alarmMinor',
    '9' => 'alarmMajor',
    '10' => 'alarmNofN',
  },
  Rpdu2OutletPhaseLayoutType => {
    '1' => 'seqPhase1ToNeutral',
    '2' => 'seqPhase2ToNeutral',
    '3' => 'seqPhase3ToNeutral',
    '4' => 'seqPhase1ToPhase2',
    '5' => 'seqPhase2ToPhase3',
    '6' => 'seqPhase3ToPhase1',
  },
  atsStatusOverCurrentState => {
    '1' => 'atsOverCurrent',
    '2' => 'atsCurrentOK',
  },
  airFMModServIntComp2Reset => {
    '1' => 'notApplicable',
    '2' => 'noOperation',
    '3' => 'reset',
  },
  memOutputStatusCurrentState => {
    '1' => 'memOutputClosed',
    '2' => 'memOutputOpen',
  },
  airIRRP500UnitConfigInputNormalState => {
    '1' => 'open',
    '2' => 'closed',
  },
  dm3ConfigSysRemoteAccess => {
    '1' => 'accessEnabled',
    '2' => 'accessDisabled',
  },
  xATSOutputRelayCurrentState => {
    '1' => 'open',
    '2' => 'closed',
  },
  airFMSysHumCtrlSetting => {
    '1' => 'notApplicable',
    '2' => 'relativeHum',
    '3' => 'dewPoint',
  },
  airFMSysPresentStatus => {
    '1' => 'notApplicable',
    '2' => 'reserved1',
    '3' => 'reserved2',
    '4' => 'onLine',
    '5' => 'idle',
    '6' => 'loadShare',
    '7' => 'failed',
    '8' => 'offLine',
  },
  emsInputContactConfigInputContactNormalState => {
    '1' => 'normallyClosedEMS',
    '2' => 'normallyOpenEMS',
  },
  airFMSysInputAlarmAction => {
    '1' => 'statusOnly',
    '2' => 'minor',
    '3' => 'major',
    '4' => 'remoteRunStop',
    '5' => 'nonessStop',
    '6' => 'immShutdown',
  },
  xATSSystemOutputPhaseIndex => {
    '1' => 'phase1',
    '2' => 'phase2',
    '3' => 'phase3',
  },
  battManAlarmBatteries => {
    '1' => 'normal',
    '2' => 'alarm',
  },
  airIRG2GroupConfigRuntimeBalancingEnable => {
    '1' => 'disable',
    '2' => 'enable',
  },
  airIRRP100UnitServiceIntervalFansAlarm => {
    '1' => 'enable',
    '2' => 'disable',
  },
  upsAdvConfigChargerLevel => {
    '1' => 'unknown',
    '2' => 'low',
    '3' => 'high',
  },
  rPDU2DeviceStatusLoadState => {
    '1' => 'lowLoad',
    '2' => 'normal',
    '3' => 'nearOverload',
    '4' => 'overload',
  },
  airIRRCUnitStatusActivePowerSource => {
    '1' => 'sourceA',
    '2' => 'sourceB',
  },
  rPDU2SensorDiscreteStatusCurrentState => {
    '1' => 'open',
    '2' => 'closed',
    '3' => 'unknown',
  },
  emsOutletControlOutletCommand => {
    '1' => 'immediateOnEMS',
    '2' => 'immediateOffEMS',
  },
  atsStatusPlus12VPowerSupply => {
    '1' => 'atsPowerSupplyFailure',
    '2' => 'atsPowerSupplyOK',
  },
  etlStatus => {
    '1' => 'unknown',
    '2' => 'running',
    '3' => 'failed',
    '4' => 'paused',
    '5' => 'stopped',
  },
  airIRSCUnitStatusInputState => {
    '1' => 'open',
    '2' => 'closed',
  },
  upsOutletGroupConfigLoadShedControlSkipOffDelay => {
    '1' => 'upsOutletGroupConfigSkipOffDelay',
    '2' => 'upsOutletGroupConfigUseOffDelay',
  },
  airFMSysDehumState => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  memInputsStatusCurrentState => {
    '1' => 'inputClosedHighMEM',
    '2' => 'inputOpenLowMEM',
    '3' => 'inputDisabled',
    '4' => 'inputStateNotApplicable',
  },
  rPDU2PhaseConfigPhasePeakCurrentReset => {
    '1' => 'noOperation',
    '2' => 'reset',
  },
  xATSSwitchStatusSelectedSource => {
    '1' => 'none',
    '2' => 'source1',
    '3' => 'source2',
    '4' => 'fault',
    '5' => 'unknown',
  },
  airFMSysAlarmMapMainModCoolFail => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  battManString2BatteryDryout => {
    '1' => 'normal',
    '2' => 'alarm',
  },
  rPDU2GroupEnergyReset => {
    '1' => 'noOperation',
    '2' => 'reset',
    '3' => 'notSupported',
  },
  battManString1BatteryLowCapacity => {
    '1' => 'normal',
    '2' => 'alarm',
  },
  rPDU2SensorTempHumidityStatusType => {
    '1' => 'temperatureOnly',
    '2' => 'temperatureHumidity',
    '3' => 'commsLost',
    '4' => 'notInstalled',
  },
  subfeedBreakerStatus => {
    '1' => 'unknown',
    '2' => 'notInstalled',
    '3' => 'opened',
    '4' => 'closed',
  },
  xATSTestingStatusTestStatus => {
    '1' => 'noTestInProcess',
    '2' => 'testPending',
    '3' => 'startingEngine',
    '4' => 'engineWarmingUp',
    '5' => 'awaitingTransferToS2',
    '6' => 'testingWithLoad',
    '7' => 'awaitingRetransferToS1',
    '8' => 'testingWithoutLoad',
    '9' => 'stoppingEngine',
    '10' => 'holdingOnGenerator',
  },
  upsPhaseInputType => {
    '1' => 'unknown',
    '2' => 'main',
    '3' => 'bypass',
  },
  rARUFanStatusReplacementThreshold => {
    '1' => 'disabled',
    '2' => 'khr20',
    '3' => 'khr25',
    '4' => 'khr30',
    '5' => 'khr35',
    '6' => 'khr40',
    '7' => 'khr50',
  },
  xATSSource1Index => {
    '1' => 'phase1',
    '2' => 'phase2',
    '3' => 'phase3',
  },
  dm3StatusLVDHwFault => {
    '1' => 'statusFault',
    '2' => 'statusNofault',
  },
  airIRG2RDT2ConfigIdleOnLeakDetect => {
    '1' => 'yes',
    '2' => 'no',
  },
  airFMSysAlarmMapMainModAirBlckIntOpen => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  airFMModFireDetector => {
    '1' => 'notApplicable',
    '2' => 'notPresent',
    '3' => 'present',
  },
  airIRG3RDUStatusStopOnLeakDetect => {
    '1' => 'no',
    '2' => 'yes',
  },
  sPDUMasterConfigVMOverloadRestriction => {
    '1' => 'alwaysAllowTurnON',
    '2' => 'restrictOnWarning',
    '3' => 'restrictOnOverload',
  },
  upsAdvConfigVoutReporting => {
    '1' => 'unknown',
    '2' => 'voutAUTO',
    '3' => 'vout208',
    '4' => 'vout240',
  },
  airFMSysAlarmMapSysFireDet => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  upsOutletGroupStatusOutletType => {
    '1' => 'upsSwitchedOutletGroup',
    '2' => 'upsMainOutletGroup',
  },
  battManString1BatteryThermalRunaway => {
    '1' => 'normal',
    '2' => 'alarm',
  },
  isxModularPduTransformerTempStatus => {
    '1' => 'normal',
    '2' => 'overtemp',
    '3' => 'noTransformerPresent',
    '4' => 'unknown',
  },
  dipSwitchStatus => {
    '1' => 'on',
    '2' => 'off',
  },
  airFMSysAlarmMapExpMod1CondPumpFail => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  isxModularDistModuleOutputAlarmMaxEnable => {
    '1' => 'disabled',
    '2' => 'enabled',
  },
  airIRRCUnitStatusOperateMode => {
    '1' => 'standby',
    '2' => 'on',
    '3' => 'idle',
  },
  dm3ConfigRectFailAlarm => {
    '1' => 'alarmIgnore',
    '2' => 'alarmRelay1',
    '3' => 'alarmRelay2',
    '4' => 'alarmRelay3',
    '5' => 'alarmRelay4',
    '6' => 'alarmRelay5',
    '7' => 'alarmRelay6',
    '8' => 'alarmMinor',
    '9' => 'alarmMajor',
    '10' => 'alarmNofN',
  },
  atsConfigPhase => {
    '1' => 'phase1',
    '2' => 'phase2',
    '3' => 'phase3',
  },
  emsInputContactStatusInputContactState => {
    '1' => 'contactClosedEMS',
    '2' => 'contactOpenEMS',
  },
  sPDUOutletControlMSPOutletCommand => {
    '1' => 'immediateOnMSP',
    '2' => 'delayedOnMSP',
    '3' => 'immediateOffMSP',
    '4' => 'gracefulRebootMSP',
    '5' => 'immediateRebootMSP',
    '6' => 'gracefulshutdownMSP',
    '7' => 'overrideBatCapThreshMSP',
    '8' => 'cancelPendingCommandMSP',
  },
  airFMStatusSystemHumidifyEnabled => {
    '1' => 'enabledYes',
    '2' => 'enabledNo',
  },
  dm3StatusBreakersStatus => {
    '1' => 'statusClosed',
    '2' => 'statusOpen',
  },
  iemStatusProbeHighTempViolation => {
    '1' => 'noViolation',
    '2' => 'highTempViolation',
    '3' => 'disabled',
  },
  airFMSysAlarmMapSysRemSensRemoved => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  dm3ConfigBreakersAlarm => {
    '1' => 'alarmIgnore',
    '2' => 'alarmRelay1',
    '3' => 'alarmRelay2',
    '4' => 'alarmRelay3',
    '5' => 'alarmRelay4',
    '6' => 'alarmRelay5',
    '7' => 'alarmRelay6',
    '8' => 'alarmMinor',
    '9' => 'alarmMajor',
  },
  emConfigProbeMaxTempEnable => {
    '1' => 'disabled',
    '2' => 'enabled',
  },
  rPDU2BankConfigBankPeakCurrentReset => {
    '1' => 'noOperation',
    '2' => 'reset',
  },
  emsOutputRelayStatusOutputRelayState => {
    '1' => 'relayClosedEMS',
    '2' => 'relayOpenEMS',
  },
  mconfigBOOTPEnabled => {
    '1' => 'yes',
    '2' => 'no',
  },
  normalState => {
    '1' => 'unknown',
    '2' => 'open',
    '3' => 'closed',
  },
  airFMGroupFailoverSysAnyMajorAlarm => {
    '1' => 'notApplicable',
    '2' => 'disable',
    '3' => 'enable',
  },
  airFMModComp1 => {
    '1' => 'notApplicable',
    '2' => 'on',
    '3' => 'off',
  },
  xPDUInputContactCurrentState => {
    '1' => 'open',
    '2' => 'closed',
    '3' => 'unknown',
  },
  airFMModServIntBlwrCtrl1Reset => {
    '1' => 'notApplicable',
    '2' => 'noOperation',
    '3' => 'reset',
  },
  airFMSysAlarmMapExpMod1WaterDetected => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  airFMSysAlarmMapInput10 => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  dcmim2StatusBattCapacityTestResult => {
    '1' => 'capacityTestNotPerformed',
    '2' => 'capacityTestInProcess',
    '3' => 'capacityTestInterrupted',
    '4' => 'capacityTestPass',
    '5' => 'capacityTestFail',
  },
  apcLocalDisplayConfigAlarmBeeper => {
    '1' => 'beeperDisabled',
    '2' => 'beeperEnabled',
  },
  airFMSysAlarmMapInput4 => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  AirIRmAlarmState => {
    '1' => 'ok',
    '2' => 'alarm',
  },
  uioInputContactStatusCommStatus => {
    '1' => 'notInstalled',
    '2' => 'commsOK',
    '3' => 'commsLost',
  },
  xATSGeneratorOutputPhaseIndex => {
    '1' => 'phase1',
    '2' => 'phase2',
    '3' => 'phase3',
  },
  upsAdvControlRebootShutdownUps => {
    '1' => 'noRebootShutdownUps',
    '2' => 'rebootShutdownUps',
    '3' => 'rebootShutdownUpsGracefully',
    '4' => 'rebootShutdownSyncGroupUps',
    '5' => 'rebootShutdownSyncGroupUpsGracefully',
  },
  dm3StatusSysRemoteAccess => {
    '1' => 'accessEnabled',
    '2' => 'accessDisabled',
  },
  dm3ConfigBattLowVoltAlarm => {
    '1' => 'alarmIgnore',
    '2' => 'alarmRelay1',
    '3' => 'alarmRelay2',
    '4' => 'alarmRelay3',
    '5' => 'alarmRelay4',
    '6' => 'alarmRelay5',
    '7' => 'alarmRelay6',
    '8' => 'alarmMinor',
    '9' => 'alarmMajor',
  },
  rPDUOutletBankOverloadRestriction => {
    '1' => 'alwaysAllowTurnON',
    '2' => 'restrictOnNearOverload',
    '3' => 'restrictOnOverload',
  },
  airIRmPmResetAllAlarms => {
    '1' => 'doNothing',
    '2' => 'reset',
  },
  sPDUOutletConfigMSPmupsP1LowHum => {
    '1' => 'disableAlarm',
    '2' => 'enableAlarm',
  },
  upsBasicOutputStatus => {
    '1' => 'unknown',
    '2' => 'onLine',
    '3' => 'onBattery',
    '4' => 'onSmartBoost',
    '5' => 'timedSleeping',
    '6' => 'softwareBypass',
    '7' => 'off',
    '8' => 'rebooting',
    '9' => 'switchedBypass',
    '10' => 'hardwareFailureBypass',
    '11' => 'sleepingUntilPowerReturn',
    '12' => 'onSmartTrim',
    '13' => 'ecoMode',
    '14' => 'hotStandby',
    '15' => 'onBatteryTest',
    '16' => 'emergencyStaticBypass',
    '17' => 'staticBypassStandby',
    '18' => 'powerSavingMode',
    '19' => 'spotMode',
    '20' => 'eConversion',
    '21' => 'chargerSpotmode',
    '22' => 'inverterSpotmode',
  },
  battManResetDischargeCounters => {
    '1' => 'noOperation',
    '2' => 'reset',
  },
  battManInputContactState => {
    '1' => 'open',
    '2' => 'closed',
  },
  uioInputContactStatusCurrentState => {
    '1' => 'uioInputClosed',
    '2' => 'uioInputOpen',
    '3' => 'uioInputDisabled',
    '4' => 'inputStateNotApplicable',
  },
  dcmim2StatusSysTempUnits => {
    '1' => 'celsius',
    '2' => 'fahrenheit',
  },
  airFMSysAlarmMapSysAnyAlarm => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  airFMStatusSystemCoolingEnabled => {
    '1' => 'enabledYes',
    '2' => 'enabledNo',
  },
  airIRG3RDUConfigStopOnLeakDetect => {
    '1' => 'no',
    '2' => 'yes',
  },
  xPDUBranchBreakerTieIndicator => {
    '1' => 'breakerUnTied',
    '2' => 'breakerTied',
  },
  upsAdvConfigBypassToleranceSetting => {
    '1' => 'unknown',
    '2' => 'wide',
    '3' => 'medium',
    '4' => 'narrow',
    '5' => 'custom',
  },
  emStatusContactStatus => {
    '1' => 'noFault',
    '2' => 'fault',
    '3' => 'disabled',
  },
  airFMGroupCfgShutdownFire => {
    '1' => 'disable',
    '2' => 'enable',
  },
  upsDiagSubSysPowerFactorCorrectionStatus => {
    '1' => 'unknown',
    '2' => 'notInstalled',
    '3' => 'offOk',
    '4' => 'onOk',
    '5' => 'offFail',
    '6' => 'onFail',
    '7' => 'lostComm',
  },
  dm3StatusFusesStatus => {
    '1' => 'statusClosed',
    '2' => 'statusOpen',
  },
  sPDUOutletConfigMSPmupsZone4 => {
    '1' => 'disableAlarm',
    '2' => 'enableAlarm',
  },
  airIRG2RDT2StatusLeakSensor => {
    '1' => 'no-leak',
    '2' => 'leak',
  },
  airFMAlarmType => {
    '1' => 'group',
    '2' => 'system',
    '3' => 'mainMod',
    '4' => 'expMod1',
    '5' => 'expMod2',
  },
  serialPort2Mode => {
    '1' => 'localConsole',
    '2' => 'passthrough',
  },
  airFMGroupSysStatus => {
    '1' => 'statusOnLine',
    '2' => 'statusIdle',
    '3' => 'statusLoadShare',
    '4' => 'statusOffLine',
    '5' => 'statusFailed',
    '6' => 'statusDisabled',
    '7' => 'statusUndefined',
  },
  xATSGeneratorServiceRunHoursThreshold => {
    '1' => 'disabled',
    '2' => 'runThreshold100Hours',
    '3' => 'runThreshold150Hours',
    '4' => 'runThreshold200Hours',
    '5' => 'runThreshold250Hours',
    '6' => 'runThreshold300Hours',
    '7' => 'runThreshold400Hours',
    '8' => 'runThreshold500Hours',
  },
  airIRG3GroupSetpointsFanSpeedPreference => {
    '1' => 'low',
    '2' => 'med-low',
    '3' => 'med',
    '4' => 'med-high',
    '5' => 'high',
  },
  dcmim2StatusRectFail => {
    '1' => 'statusTrue',
    '2' => 'statusFalse',
  },
  airFMSysAlarmMapOutput4 => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  emsSensorStatusSensorNormalState => {
    '1' => 'normallyClosedEMS',
    '2' => 'normallyOpenEMS',
  },
  battManAlarmManagementController => {
    '1' => 'normal',
    '2' => 'alarm',
  },
  atsConfigBank => {
    '1' => 'total',
    '2' => 'bank1',
    '3' => 'bank2',
  },
  rPDU2DeviceStatusPowerSupply1Status => {
    '1' => 'normal',
    '2' => 'alarm',
    '3' => 'notInstalled',
  },
  upsAdvConfigPositionSelector => {
    '1' => 'unknown',
    '2' => 'rack',
    '3' => 'tower',
  },
  sPDUOutletStatusMSPOutletState => {
    '1' => 'outletStatusMSPOn',
    '2' => 'outletStatusMSPOff',
  },
  uioOutputRelayStatusCurrentState => {
    '1' => 'uioOutputClosed',
    '2' => 'uioOutputOpen',
    '3' => 'outputStateNotApplicable',
  },
  atsStatus24VPowerSupply => {
    '1' => 'atsPowerSupplyFailure',
    '2' => 'atsPowerSupplyOK',
  },
  airFMSysHumCtrlMethod => {
    '1' => 'notApplicable',
    '2' => 'avgReturnRH',
    '3' => 'avgReturnDewPt',
    '4' => 'avgRemoteRH',
    '5' => 'avgRemoteDewPt',
  },
  upsDiagBatteryStatus => {
    '1' => 'unknown',
    '2' => 'notInstalled',
    '3' => 'ok',
    '4' => 'failed',
    '5' => 'highTemperature',
    '6' => 'replaceImmediately',
    '7' => 'lowCapacity',
  },
  isxModularDistSysCurrentAlarmHighEnable => {
    '1' => 'disabled',
    '2' => 'enabled',
  },
  airIRRP500UnitConfigReheatEnable => {
    '1' => 'enable',
    '2' => 'disable',
  },
  uioSensorStatusAlarmStatus => {
    '1' => 'uioNormal',
    '2' => 'uioWarning',
    '3' => 'uioCritical',
    '4' => 'sensorStatusNotApplicable',
  },
  battManString1BatteryHighOhmicValue => {
    '1' => 'normal',
    '2' => 'alarm',
  },
  airIRRCGroupConfigConfigurationType => {
    '1' => 'racs',
    '2' => 'hacs',
    '3' => 'in-row',
    '4' => 'cacs',
  },
  iemStatusProbeMaxTempViolation => {
    '1' => 'noViolation',
    '2' => 'maxTempViolation',
    '3' => 'disabled',
  },
  upsAdvBatteryActualVoltagePolarity => {
    '0' => 'positive',
    '1' => 'negative',
  },
  airIRRP100UnitStatusInputState => {
    '1' => 'open',
    '2' => 'closed',
  },
  airFMSysSteamHumDmd => {
    '1' => 'notApplicable',
    '2' => 'off',
    '3' => 'on',
  },
  airPACompressor => {
    '1' => 'statusON',
    '2' => 'statusOFF',
  },
  airIRG3RDUConfigPowerSource => {
    '1' => 'singleFeed',
    '2' => 'dualFeed',
  },
  upsAdvControlFlashAndBeep => {
    '1' => 'noFlashAndBeep',
    '2' => 'flashAndBeep',
    '3' => 'flashAndBeepSyncGroup',
    '4' => 'flashAndBeepCont',
    '5' => 'flashAndBeepCancel',
  },
  airIRmPmFan1Type => {
    '1' => 'direct',
    '2' => 'proportional',
  },
  airIRG3RDUStatusOnReadyStandby => {
    '1' => 'standby',
    '2' => 'ready',
    '3' => 'on',
  },
  airFMSysAlarmMapSysLowEnvTemp => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  xATSSource1Quality => {
    '1' => 'sourceGood',
    '2' => 'lowVoltage',
    '3' => 'highVoltage',
    '4' => 'phaseImbalance',
    '5' => 'freqOutOfRange',
    '6' => 'badRotation',
    '7' => 'unknown',
  },
  airFMSysAlarmMapSysSupplySensFail => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  accessPXStatusRearDoorHandle => {
    '1' => 'open',
    '2' => 'closed',
    '3' => 'notInstalled',
    '4' => 'disconnected',
  },
  rPDUStatusBankState => {
    '1' => 'bankLoadNormal',
    '2' => 'bankLoadLow',
    '3' => 'bankLoadNearOverload',
    '4' => 'bankLoadOverload',
  },
  dm3StatusConvStandby => {
    '1' => 'statusTrue',
    '2' => 'statusFalse',
  },
  dm3ConfigRectHighVoltAlarm => {
    '1' => 'alarmIgnore',
    '2' => 'alarmRelay1',
    '3' => 'alarmRelay2',
    '4' => 'alarmRelay3',
    '5' => 'alarmRelay4',
    '6' => 'alarmRelay5',
    '7' => 'alarmRelay6',
    '8' => 'alarmMinor',
    '9' => 'alarmMajor',
  },
  airFMModCapacityCtrl => {
    '1' => 'notApplicable',
    '2' => 'tandem',
    '3' => 'hotGasBypass',
  },
  sPDUOutletConfigMSPmupsZone3 => {
    '1' => 'disableAlarm',
    '2' => 'enableAlarm',
  },
  upsOutletGroupControlOutletType => {
    '1' => 'upsSwitchedOutletGroup',
    '2' => 'upsMainOutletGroup',
  },
  airFMGroupCfgIdleBlower => {
    '1' => 'off',
    '2' => 'minimumSpeed',
    '3' => 'normalSpeed',
  },
  airFMSysActualHumCtrlMethod => {
    '1' => 'notApplicable',
    '2' => 'avgReturnRH',
    '3' => 'avgReturnDewPt',
    '4' => 'avgRemoteRH',
    '5' => 'avgRemoteDewPt',
  },
  airIRSCUnitConfigOutputNormalState => {
    '1' => 'open',
    '2' => 'closed',
  },
  airFMSysNumPCIOMs => {
    '1' => 'notApplicable',
    '2' => 'one',
    '3' => 'two',
    '4' => 'three',
    '5' => 'four',
  },
  atsStatusVoltageOutStatus => {
    '1' => 'fail',
    '2' => 'ok',
  },
  currentStatus => {
    '1' => 'unknown',
    '2' => 'noFault',
    '3' => 'fault',
  },
  airIRmPmUnitWinterMode => {
    '1' => 'summer',
    '2' => 'winter',
  },
  dm3ConfigRectDiagAlarm => {
    '1' => 'alarmIgnore',
    '2' => 'alarmRelay1',
    '3' => 'alarmRelay2',
    '4' => 'alarmRelay3',
    '5' => 'alarmRelay4',
    '6' => 'alarmRelay5',
    '7' => 'alarmRelay6',
    '8' => 'alarmMinor',
    '9' => 'alarmMajor',
    '10' => 'alarmNofN',
  },
  dm3StatusSysAlarmState => {
    '1' => 'alarmMinor',
    '2' => 'alarmMajor',
    '3' => 'alarmBoth',
    '4' => 'alarmNone',
  },
  airIRRP500UnitStatusOutputState => {
    '1' => 'open',
    '2' => 'closed',
  },
  airIRRP100UnitConfigHeatAssistEnable => {
    '1' => 'enable',
    '2' => 'disable',
  },
  airFMSysAlarmMapSysSmokeDet => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  airFMModServIntBlwr1Reset => {
    '1' => 'notApplicable',
    '2' => 'noOperation',
    '3' => 'reset',
  },
  airFMSysAlarmMapInput2 => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  accessPXConfigRearDoorLockControl => {
    '1' => 'unlock',
    '2' => 'lock',
    '3' => 'notInstalledReadOnly',
    '4' => 'disconnectedReadOnly',
  },
  airFMSysAlarmMapSysReturnSensFail => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  upsAdvControlRebootUpsWithOrWithoutAC => {
    '1' => 'noRebootUpsWithOrWithoutAC',
    '2' => 'rebootUpsImmediatelyWithOrWithoutAC',
    '3' => 'rebootUpsDelayedWithOrWithoutAC',
  },
  sPDUMasterStatusVMOverloadCondition => {
    '1' => 'overloadConditionTrueVM',
    '2' => 'overloadConditionFalseVM',
  },
  upsBasicControlConserveBattery => {
    '1' => 'noTurnOffUps',
    '2' => 'turnOffUpsToConserveBattery',
  },
  xPDUDeviceServiceType => {
    '1' => 'threeWire',
    '2' => 'fourWire',
  },
  airIRG3RDUConfigCalibrateRefrigerantLeakDetector => {
    '1' => 'no',
    '2' => 'yes',
  },
  airIRG3RDUStatusLeadPump => {
    '1' => 'pump1',
    '2' => 'pump2',
  },
  airIRRP100UnitConfigOutputSource => {
    '1' => 'anyAlarm',
    '2' => 'criticalAlarm',
  },
  airFMGroupSysManualRoleSetting => {
    '1' => 'primary',
    '2' => 'backup',
  },
  rPDU2DeviceStatusPowerSupplyAlarm => {
    '1' => 'normal',
    '2' => 'alarm',
  },
  xPDUDeviceLoadTestPortPresent => {
    '1' => 'notPresent',
    '2' => 'present',
  },
  sPDUOutletConfigMSPmupsZone2 => {
    '1' => 'disableAlarm',
    '2' => 'enableAlarm',
  },
  xATSSwitchStatusOperationalMode => {
    '1' => 'automatic',
    '2' => 'notInAutoAbnormal',
    '3' => 'notInAuto',
    '4' => 'unknown',
  },
  dm3StatusRectPresent => {
    '1' => 'statusTrue',
    '2' => 'statusFalse',
  },
  upsBasicSystemInverterStatus => {
    '1' => 'unknown',
    '2' => 'ok',
    '3' => 'inFaultCondition',
  },
  upsDiagComBusInternalRIMStatus => {
    '1' => 'unknown',
    '2' => 'notInstalled',
    '3' => 'ok',
    '4' => 'lostComm',
    '5' => 'rxFailure',
    '6' => 'txFailure',
  },
  dm3StatusSysTempUnits => {
    '1' => 'celsius',
    '2' => 'fahrenheit',
  },
  airIRG3GroupConfigRuntimeBalancingEnable => {
    '1' => 'disable',
    '2' => 'enable',
  },
  airIRG2RDT2ServiceIntervalsAirFilterAlarm => {
    '1' => 'enable',
    '2' => 'disable',
  },
  airFMGroupFailoverModWaterDetected => {
    '1' => 'notApplicable',
    '2' => 'disable',
    '3' => 'enable',
  },
  sPDUMasterConfigVMAudioAlarmActivated => {
    '1' => 'audioAlarmActiveNever',
    '2' => 'audioAlarmActiveOnOverload',
    '3' => 'audioAlarmActiveOnOverloadImminent',
  },
  sPDUMasterControlMSPCommand => {
    '1' => 'noCommandAllMSP',
    '2' => 'immediateAllOnMSP',
    '3' => 'sequencedAllOnMSP',
    '4' => 'immediateAllOffMSP',
    '5' => 'gracefulAllRebootMSP',
    '6' => 'immediateAllRebootMSP',
    '7' => 'gracefulAllShutdownMSP',
    '8' => 'overrideAllBatCapThreshMSP',
    '9' => 'cancelAllPendingCommandsMSP',
    '10' => 'restoreFactoryDefaultsMSP',
  },
  sPDUMasterControlSwitch => {
    '1' => 'turnAllOnNow',
    '2' => 'turnAllOnSequence',
    '3' => 'turnAllOffNow',
    '4' => 'rebootAllNow',
    '5' => 'rebootAllSequence',
    '6' => 'noCommand',
    '7' => 'turnAllOffSequence',
  },
  upsParallelDiagSubSysBreakerStatus => {
    '1' => 'unknown',
    '2' => 'notInstalled',
    '3' => 'opened',
    '4' => 'closed',
  },
  mfiletransferControlInitiateFileTransfer => {
    '1' => 'doNotInitiateFileTransfer',
    '2' => 'initiateFileTransferDownloadViaTFTP',
    '3' => 'initiateFileTransferDownloadViaFTP',
  },
  sPDUOutletConfigMSPmupsP2HiHum => {
    '1' => 'disableAlarm',
    '2' => 'enableAlarm',
  },
  upsDiagSubSysIntBypSwitchStatus => {
    '1' => 'unknown',
    '2' => 'notInstalled',
    '3' => 'offOk',
    '4' => 'onOk',
    '5' => 'offFail',
    '6' => 'onFail',
    '7' => 'lostComm',
  },
  airIRRP100UnitStatusOperateMode => {
    '1' => 'standby',
    '2' => 'on',
    '3' => 'idle',
    '4' => 'prestart',
    '5' => 'service',
    '6' => 'backup',
    '7' => 'assist',
  },
  isxModularDistModuleOutputKwhReset => {
    '1' => 'no',
    '2' => 'yes',
  },
  airFMGroupSysRoleStatus => {
    '1' => 'reserved1',
    '2' => 'reserved2',
    '3' => 'onLine',
    '4' => 'idle',
    '5' => 'loadShare',
    '6' => 'failed',
    '7' => 'offLine',
  },
  xATSGeneratorAdvStatusCoolantLevel => {
    '1' => 'ok',
    '2' => 'low',
    '3' => 'unknown',
  },
  AirIRG2RDType2IOState => {
    '1' => 'open',
    '2' => 'closed',
  },
  rPDUOutletControlOutletCommand => {
    '1' => 'immediateOn',
    '2' => 'immediateOff',
    '3' => 'immediateReboot',
    '4' => 'delayedOn',
    '5' => 'delayedOff',
    '6' => 'delayedReboot',
    '7' => 'cancelPendingCommand',
  },
  airFMSysAlarmMapMainModLowAirFlow => {
    '1' => 'notApplicable',
    '2' => 'disabled',
    '3' => 'enabled',
  },
  xATSDeviceDCBackUpPresent => {
    '1' => 'yes',
    '2' => 'no',
  },
  airIRRP500UnitConfigDehumidifyEnable => {
    '1' => 'enable',
    '2' => 'disable',
  },
  upsAdvBatteryChargerStatus => {
    '1' => 'unknown',
    '2' => 'ok',
    '3' => 'inFaultCondition',
  },
  setPulseOnTXD => {
    '1' => 'noSetPulseOnTXD',
    '2' => 'setPulseOnTXD',
    '3' => 'setTXDLow',
    '4' => 'setTXDHigh',
  },
  atsOutputBankState => {
    '1' => 'normal',
    '2' => 'lowload',
    '3' => 'nearoverload',
    '4' => 'overload',
  },
  rPDUOutletStatusOutletState => {
    '1' => 'outletStatusOn',
    '2' => 'outletStatusOff',
  },
  atsStatusMinus12VPowerSupply => {
    '1' => 'atsPowerSupplyFailure',
    '2' => 'atsPowerSupplyOK',
  },
  'upsBasicStateOutputState' => sub {
    # ftp://ftp.apc.com/apc/public/software/pnetmib/mib/417/powernet417.mib
    my ($state) = @_;
    if ($state eq 'UNKNOWN') {
      return '0'x64;
    } else {
      # The flags are numbered from 1 to 32, and read from left to right
      return '0'.$state;
    }
    # Flag  1: Abnormal Condition Present
    # Flag  2: On Battery
    # Flag  3: Low Battery
    # Flag  4: On Line

    # Flag  5: Replace Battery
    # Flag  6: Serial Communication Established
    # Flag  7: AVR Boost Active
    # Flag  8: AVR Trim Active

    # Flag  9: Overload
    # Flag 10: Runtime Calibration
    # Flag 11: Batteries Discharged
    # Flag 12: Manual Bypass

    # Flag 13: Software Bypass
    # Flag 14: In Bypass due to Internal Fault
    # Flag 15: In Bypass due to Supply Failure
    # Flag 16: In Bypass due to Fan Failure

    # Flag 17: Sleeping on a Timer
    # Flag 18: Sleeping until Utility Power Returns
    # Flag 19: On
    # Flag 20: Rebooting

    # Flag 21: Battery Communication Lost
    # Flag 22: Graceful Shutdown Initiated
    # Flag 23: Smart Boost or Smart Trim Fault
    # Flag 24: Bad Output Voltage

    # Flag 25: Battery Charger Failure
    # Flag 26: High Battery Temperature
    # Flag 27: Warning Battery Temperature
    # Flag 28: Critical Battery Temperature

    # Flag 29: Self Test In Progress
    # Flag 30: Low Battery / On Battery
    # Flag 31: Graceful Shutdown Issued by Upstream Device
    # Flag 32: Graceful Shutdown Issued by Downstream Device

    # Flag 33: No Batteries Attached
    # Flag 34: Synchronized Command is in Progress
    # Flag 35: Synchronized Sleeping Command is in Progress
    # Flag 36: Synchronized Rebooting Command is in Progress

    # Flag 37: Inverter DC Imbalance
    # Flag 38: Transfer Relay Failure
    # Flag 39: Shutdown or Unable to Transfer
    # Flag 40: Low Battery Shutdown

    # Flag 41: Electronic Unit Fan Failure
    # Flag 42: Main Relay Failure
    # Flag 43: Bypass Relay Failure
    # Flag 44: Temporary Bypass

    # Flag 45: High Internal Temperature
    # Flag 46: Battery Temperature Sensor Fault
    # Flag 47: Input Out of Range for Bypass
    # Flag 48: DC Bus Overvoltage

    # Flag 49: PFC Failure
    # Flag 50: Critical Hardware Fault
    # Flag 51: Green Mode/ECO Mode
    # Flag 52: Hot Standby

    # Flag 53: Emergency Power Off (EPO) Activated
    # Flag 54: Load Alarm Violation
    # Flag 55: Bypass Phase Fault
    # Flag 56: UPS Internal Communication Failure

    # Flag 57: Efficiency Booster Mode
    # Flag 58: Off
    # Flag 59: Standby
    # Flag 60: <Not Used>

    # Flag 61: <Not Used>
    # Flag 62: <Not Used>
    # Flag 63: <Not Used>
    # Flag 64: <Not Used>
  },
};
